# frozen_string_literal: true

# Collection of pseudo-legal move tablebases.
module PseudoLegalMoveTablebase
  # Chess chess variant.
  module Chess
    # Computerized database that contains precalculated exhaustive pseudo-legal
    # moves of Chess positions.
    #
    # @see https://developer.sashite.com/specs/general-actor-notation
    DB = {"C:-K"=>{0=>{1=>[{1=>:enemy}, {1=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}]}, 1=>{0=>[{0=>:enemy}, {0=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}]}, 2=>{1=>[{1=>:enemy}, {1=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}]}, 3=>{2=>[{2=>:enemy}, {2=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}]}, 4=>{3=>[{3=>:enemy}, {3=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}]}, 5=>{4=>[{4=>:enemy}, {4=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}]}, 6=>{5=>[{5=>:enemy}, {5=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}]}, 7=>{6=>[{6=>:enemy}, {6=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}]}, 8=>{0=>[{0=>:enemy}, {0=>nil}], 1=>[{1=>:enemy}, {1=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}]}, 9=>{0=>[{0=>:enemy}, {0=>nil}], 1=>[{1=>:enemy}, {1=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}]}, 10=>{1=>[{1=>:enemy}, {1=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}]}, 11=>{2=>[{2=>:enemy}, {2=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}]}, 12=>{3=>[{3=>:enemy}, {3=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}]}, 13=>{4=>[{4=>:enemy}, {4=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}]}, 14=>{5=>[{5=>:enemy}, {5=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}]}, 15=>{6=>[{6=>:enemy}, {6=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}]}, 16=>{8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}]}, 17=>{8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}]}, 18=>{9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}]}, 19=>{10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}]}, 20=>{11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}]}, 21=>{12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}]}, 22=>{13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}]}, 23=>{14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}]}, 24=>{16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}]}, 25=>{16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}]}, 26=>{17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}]}, 27=>{18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}]}, 28=>{19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}]}, 29=>{20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}]}, 30=>{21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}]}, 31=>{22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}]}, 32=>{24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}]}, 33=>{24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}]}, 34=>{25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}]}, 35=>{26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}]}, 36=>{27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}]}, 37=>{28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}]}, 38=>{29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}]}, 39=>{30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}]}, 40=>{32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}]}, 41=>{32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}]}, 42=>{33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}]}, 43=>{34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}]}, 44=>{35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}]}, 45=>{36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}]}, 46=>{37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}]}, 47=>{38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}]}, 48=>{40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 57=>[{57=>:enemy}, {57=>nil}]}, 49=>{40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 58=>[{58=>:enemy}, {58=>nil}]}, 50=>{41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 59=>[{59=>:enemy}, {59=>nil}]}, 51=>{42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 60=>[{60=>:enemy}, {60=>nil}]}, 52=>{43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 61=>[{61=>:enemy}, {61=>nil}]}, 53=>{44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 62=>[{62=>:enemy}, {62=>nil}]}, 54=>{45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 63=>[{63=>:enemy}, {63=>nil}]}, 55=>{46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 63=>[{63=>:enemy}, {63=>nil}]}, 56=>{48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 57=>[{57=>:enemy}, {57=>nil}]}, 57=>{48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 58=>[{58=>:enemy}, {58=>nil}]}, 58=>{49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 59=>[{59=>:enemy}, {59=>nil}]}, 59=>{50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 60=>[{60=>:enemy}, {60=>nil}]}, 60=>{51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 61=>[{61=>:enemy}, {61=>nil}]}, 61=>{52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 62=>[{62=>:enemy}, {62=>nil}]}, 62=>{53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 63=>[{63=>:enemy}, {63=>nil}]}, 63=>{54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 62=>[{62=>:enemy}, {62=>nil}]}}, "C:B"=>{0=>{9=>[{9=>:enemy}, {9=>nil}], 18=>[{9=>nil, 18=>:enemy}, {9=>nil, 18=>nil}], 27=>[{9=>nil, 18=>nil, 27=>:enemy}, {9=>nil, 18=>nil, 27=>nil}], 36=>[{9=>nil, 18=>nil, 27=>nil, 36=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil}], 45=>[{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil}], 54=>[{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}], 63=>[{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 1=>{8=>[{8=>:enemy}, {8=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 19=>[{10=>nil, 19=>:enemy}, {10=>nil, 19=>nil}], 28=>[{10=>nil, 19=>nil, 28=>:enemy}, {10=>nil, 19=>nil, 28=>nil}], 37=>[{10=>nil, 19=>nil, 28=>nil, 37=>:enemy}, {10=>nil, 19=>nil, 28=>nil, 37=>nil}], 46=>[{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, {10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil}], 55=>[{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, {10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}]}, 2=>{9=>[{9=>:enemy}, {9=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 16=>[{9=>nil, 16=>:enemy}, {9=>nil, 16=>nil}], 20=>[{11=>nil, 20=>:enemy}, {11=>nil, 20=>nil}], 29=>[{11=>nil, 20=>nil, 29=>:enemy}, {11=>nil, 20=>nil, 29=>nil}], 38=>[{11=>nil, 20=>nil, 29=>nil, 38=>:enemy}, {11=>nil, 20=>nil, 29=>nil, 38=>nil}], 47=>[{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, {11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil}]}, 3=>{10=>[{10=>:enemy}, {10=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 17=>[{10=>nil, 17=>:enemy}, {10=>nil, 17=>nil}], 24=>[{10=>nil, 17=>nil, 24=>:enemy}, {10=>nil, 17=>nil, 24=>nil}], 21=>[{12=>nil, 21=>:enemy}, {12=>nil, 21=>nil}], 30=>[{12=>nil, 21=>nil, 30=>:enemy}, {12=>nil, 21=>nil, 30=>nil}], 39=>[{12=>nil, 21=>nil, 30=>nil, 39=>:enemy}, {12=>nil, 21=>nil, 30=>nil, 39=>nil}]}, 4=>{11=>[{11=>:enemy}, {11=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 18=>[{11=>nil, 18=>:enemy}, {11=>nil, 18=>nil}], 25=>[{11=>nil, 18=>nil, 25=>:enemy}, {11=>nil, 18=>nil, 25=>nil}], 32=>[{11=>nil, 18=>nil, 25=>nil, 32=>:enemy}, {11=>nil, 18=>nil, 25=>nil, 32=>nil}], 22=>[{13=>nil, 22=>:enemy}, {13=>nil, 22=>nil}], 31=>[{13=>nil, 22=>nil, 31=>:enemy}, {13=>nil, 22=>nil, 31=>nil}]}, 5=>{12=>[{12=>:enemy}, {12=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 19=>[{12=>nil, 19=>:enemy}, {12=>nil, 19=>nil}], 26=>[{12=>nil, 19=>nil, 26=>:enemy}, {12=>nil, 19=>nil, 26=>nil}], 33=>[{12=>nil, 19=>nil, 26=>nil, 33=>:enemy}, {12=>nil, 19=>nil, 26=>nil, 33=>nil}], 40=>[{12=>nil, 19=>nil, 26=>nil, 33=>nil, 40=>:enemy}, {12=>nil, 19=>nil, 26=>nil, 33=>nil, 40=>nil}], 23=>[{14=>nil, 23=>:enemy}, {14=>nil, 23=>nil}]}, 6=>{13=>[{13=>:enemy}, {13=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 20=>[{13=>nil, 20=>:enemy}, {13=>nil, 20=>nil}], 27=>[{13=>nil, 20=>nil, 27=>:enemy}, {13=>nil, 20=>nil, 27=>nil}], 34=>[{13=>nil, 20=>nil, 27=>nil, 34=>:enemy}, {13=>nil, 20=>nil, 27=>nil, 34=>nil}], 41=>[{13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>:enemy}, {13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>nil}], 48=>[{13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>:enemy}, {13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>nil}]}, 7=>{14=>[{14=>:enemy}, {14=>nil}], 21=>[{14=>nil, 21=>:enemy}, {14=>nil, 21=>nil}], 28=>[{14=>nil, 21=>nil, 28=>:enemy}, {14=>nil, 21=>nil, 28=>nil}], 35=>[{14=>nil, 21=>nil, 28=>nil, 35=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil}], 42=>[{14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil}], 49=>[{14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil}], 56=>[{14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>nil}]}, 8=>{1=>[{1=>:enemy}, {1=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 26=>[{17=>nil, 26=>:enemy}, {17=>nil, 26=>nil}], 35=>[{17=>nil, 26=>nil, 35=>:enemy}, {17=>nil, 26=>nil, 35=>nil}], 44=>[{17=>nil, 26=>nil, 35=>nil, 44=>:enemy}, {17=>nil, 26=>nil, 35=>nil, 44=>nil}], 53=>[{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, {17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil}], 62=>[{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, {17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}]}, 9=>{0=>[{0=>:enemy}, {0=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 27=>[{18=>nil, 27=>:enemy}, {18=>nil, 27=>nil}], 36=>[{18=>nil, 27=>nil, 36=>:enemy}, {18=>nil, 27=>nil, 36=>nil}], 45=>[{18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, {18=>nil, 27=>nil, 36=>nil, 45=>nil}], 54=>[{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, {18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}], 63=>[{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 10=>{1=>[{1=>:enemy}, {1=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 24=>[{17=>nil, 24=>:enemy}, {17=>nil, 24=>nil}], 28=>[{19=>nil, 28=>:enemy}, {19=>nil, 28=>nil}], 37=>[{19=>nil, 28=>nil, 37=>:enemy}, {19=>nil, 28=>nil, 37=>nil}], 46=>[{19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, {19=>nil, 28=>nil, 37=>nil, 46=>nil}], 55=>[{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, {19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}]}, 11=>{2=>[{2=>:enemy}, {2=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 25=>[{18=>nil, 25=>:enemy}, {18=>nil, 25=>nil}], 32=>[{18=>nil, 25=>nil, 32=>:enemy}, {18=>nil, 25=>nil, 32=>nil}], 29=>[{20=>nil, 29=>:enemy}, {20=>nil, 29=>nil}], 38=>[{20=>nil, 29=>nil, 38=>:enemy}, {20=>nil, 29=>nil, 38=>nil}], 47=>[{20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, {20=>nil, 29=>nil, 38=>nil, 47=>nil}]}, 12=>{3=>[{3=>:enemy}, {3=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 26=>[{19=>nil, 26=>:enemy}, {19=>nil, 26=>nil}], 33=>[{19=>nil, 26=>nil, 33=>:enemy}, {19=>nil, 26=>nil, 33=>nil}], 40=>[{19=>nil, 26=>nil, 33=>nil, 40=>:enemy}, {19=>nil, 26=>nil, 33=>nil, 40=>nil}], 30=>[{21=>nil, 30=>:enemy}, {21=>nil, 30=>nil}], 39=>[{21=>nil, 30=>nil, 39=>:enemy}, {21=>nil, 30=>nil, 39=>nil}]}, 13=>{4=>[{4=>:enemy}, {4=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 27=>[{20=>nil, 27=>:enemy}, {20=>nil, 27=>nil}], 34=>[{20=>nil, 27=>nil, 34=>:enemy}, {20=>nil, 27=>nil, 34=>nil}], 41=>[{20=>nil, 27=>nil, 34=>nil, 41=>:enemy}, {20=>nil, 27=>nil, 34=>nil, 41=>nil}], 48=>[{20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>:enemy}, {20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>nil}], 31=>[{22=>nil, 31=>:enemy}, {22=>nil, 31=>nil}]}, 14=>{5=>[{5=>:enemy}, {5=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 28=>[{21=>nil, 28=>:enemy}, {21=>nil, 28=>nil}], 35=>[{21=>nil, 28=>nil, 35=>:enemy}, {21=>nil, 28=>nil, 35=>nil}], 42=>[{21=>nil, 28=>nil, 35=>nil, 42=>:enemy}, {21=>nil, 28=>nil, 35=>nil, 42=>nil}], 49=>[{21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>:enemy}, {21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil}], 56=>[{21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>nil}]}, 15=>{6=>[{6=>:enemy}, {6=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 29=>[{22=>nil, 29=>:enemy}, {22=>nil, 29=>nil}], 36=>[{22=>nil, 29=>nil, 36=>:enemy}, {22=>nil, 29=>nil, 36=>nil}], 43=>[{22=>nil, 29=>nil, 36=>nil, 43=>:enemy}, {22=>nil, 29=>nil, 36=>nil, 43=>nil}], 50=>[{22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>:enemy}, {22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>nil}], 57=>[{22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>:enemy}, {22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>nil}]}, 16=>{9=>[{9=>:enemy}, {9=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 2=>[{9=>nil, 2=>:enemy}, {9=>nil, 2=>nil}], 34=>[{25=>nil, 34=>:enemy}, {25=>nil, 34=>nil}], 43=>[{25=>nil, 34=>nil, 43=>:enemy}, {25=>nil, 34=>nil, 43=>nil}], 52=>[{25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, {25=>nil, 34=>nil, 43=>nil, 52=>nil}], 61=>[{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, {25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}]}, 17=>{8=>[{8=>:enemy}, {8=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 3=>[{10=>nil, 3=>:enemy}, {10=>nil, 3=>nil}], 35=>[{26=>nil, 35=>:enemy}, {26=>nil, 35=>nil}], 44=>[{26=>nil, 35=>nil, 44=>:enemy}, {26=>nil, 35=>nil, 44=>nil}], 53=>[{26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, {26=>nil, 35=>nil, 44=>nil, 53=>nil}], 62=>[{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, {26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}]}, 18=>{9=>[{9=>:enemy}, {9=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 0=>[{9=>nil, 0=>:enemy}, {9=>nil, 0=>nil}], 4=>[{11=>nil, 4=>:enemy}, {11=>nil, 4=>nil}], 32=>[{25=>nil, 32=>:enemy}, {25=>nil, 32=>nil}], 36=>[{27=>nil, 36=>:enemy}, {27=>nil, 36=>nil}], 45=>[{27=>nil, 36=>nil, 45=>:enemy}, {27=>nil, 36=>nil, 45=>nil}], 54=>[{27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, {27=>nil, 36=>nil, 45=>nil, 54=>nil}], 63=>[{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 19=>{10=>[{10=>:enemy}, {10=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 1=>[{10=>nil, 1=>:enemy}, {10=>nil, 1=>nil}], 5=>[{12=>nil, 5=>:enemy}, {12=>nil, 5=>nil}], 33=>[{26=>nil, 33=>:enemy}, {26=>nil, 33=>nil}], 40=>[{26=>nil, 33=>nil, 40=>:enemy}, {26=>nil, 33=>nil, 40=>nil}], 37=>[{28=>nil, 37=>:enemy}, {28=>nil, 37=>nil}], 46=>[{28=>nil, 37=>nil, 46=>:enemy}, {28=>nil, 37=>nil, 46=>nil}], 55=>[{28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, {28=>nil, 37=>nil, 46=>nil, 55=>nil}]}, 20=>{11=>[{11=>:enemy}, {11=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 2=>[{11=>nil, 2=>:enemy}, {11=>nil, 2=>nil}], 6=>[{13=>nil, 6=>:enemy}, {13=>nil, 6=>nil}], 34=>[{27=>nil, 34=>:enemy}, {27=>nil, 34=>nil}], 41=>[{27=>nil, 34=>nil, 41=>:enemy}, {27=>nil, 34=>nil, 41=>nil}], 48=>[{27=>nil, 34=>nil, 41=>nil, 48=>:enemy}, {27=>nil, 34=>nil, 41=>nil, 48=>nil}], 38=>[{29=>nil, 38=>:enemy}, {29=>nil, 38=>nil}], 47=>[{29=>nil, 38=>nil, 47=>:enemy}, {29=>nil, 38=>nil, 47=>nil}]}, 21=>{12=>[{12=>:enemy}, {12=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 3=>[{12=>nil, 3=>:enemy}, {12=>nil, 3=>nil}], 7=>[{14=>nil, 7=>:enemy}, {14=>nil, 7=>nil}], 35=>[{28=>nil, 35=>:enemy}, {28=>nil, 35=>nil}], 42=>[{28=>nil, 35=>nil, 42=>:enemy}, {28=>nil, 35=>nil, 42=>nil}], 49=>[{28=>nil, 35=>nil, 42=>nil, 49=>:enemy}, {28=>nil, 35=>nil, 42=>nil, 49=>nil}], 56=>[{28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>nil}], 39=>[{30=>nil, 39=>:enemy}, {30=>nil, 39=>nil}]}, 22=>{13=>[{13=>:enemy}, {13=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 4=>[{13=>nil, 4=>:enemy}, {13=>nil, 4=>nil}], 36=>[{29=>nil, 36=>:enemy}, {29=>nil, 36=>nil}], 43=>[{29=>nil, 36=>nil, 43=>:enemy}, {29=>nil, 36=>nil, 43=>nil}], 50=>[{29=>nil, 36=>nil, 43=>nil, 50=>:enemy}, {29=>nil, 36=>nil, 43=>nil, 50=>nil}], 57=>[{29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>:enemy}, {29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>nil}]}, 23=>{14=>[{14=>:enemy}, {14=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 5=>[{14=>nil, 5=>:enemy}, {14=>nil, 5=>nil}], 37=>[{30=>nil, 37=>:enemy}, {30=>nil, 37=>nil}], 44=>[{30=>nil, 37=>nil, 44=>:enemy}, {30=>nil, 37=>nil, 44=>nil}], 51=>[{30=>nil, 37=>nil, 44=>nil, 51=>:enemy}, {30=>nil, 37=>nil, 44=>nil, 51=>nil}], 58=>[{30=>nil, 37=>nil, 44=>nil, 51=>nil, 58=>:enemy}, {30=>nil, 37=>nil, 44=>nil, 51=>nil, 58=>nil}]}, 24=>{17=>[{17=>:enemy}, {17=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 10=>[{17=>nil, 10=>:enemy}, {17=>nil, 10=>nil}], 3=>[{17=>nil, 10=>nil, 3=>:enemy}, {17=>nil, 10=>nil, 3=>nil}], 42=>[{33=>nil, 42=>:enemy}, {33=>nil, 42=>nil}], 51=>[{33=>nil, 42=>nil, 51=>:enemy}, {33=>nil, 42=>nil, 51=>nil}], 60=>[{33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, {33=>nil, 42=>nil, 51=>nil, 60=>nil}]}, 25=>{16=>[{16=>:enemy}, {16=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 11=>[{18=>nil, 11=>:enemy}, {18=>nil, 11=>nil}], 4=>[{18=>nil, 11=>nil, 4=>:enemy}, {18=>nil, 11=>nil, 4=>nil}], 43=>[{34=>nil, 43=>:enemy}, {34=>nil, 43=>nil}], 52=>[{34=>nil, 43=>nil, 52=>:enemy}, {34=>nil, 43=>nil, 52=>nil}], 61=>[{34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, {34=>nil, 43=>nil, 52=>nil, 61=>nil}]}, 26=>{17=>[{17=>:enemy}, {17=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 8=>[{17=>nil, 8=>:enemy}, {17=>nil, 8=>nil}], 12=>[{19=>nil, 12=>:enemy}, {19=>nil, 12=>nil}], 5=>[{19=>nil, 12=>nil, 5=>:enemy}, {19=>nil, 12=>nil, 5=>nil}], 40=>[{33=>nil, 40=>:enemy}, {33=>nil, 40=>nil}], 44=>[{35=>nil, 44=>:enemy}, {35=>nil, 44=>nil}], 53=>[{35=>nil, 44=>nil, 53=>:enemy}, {35=>nil, 44=>nil, 53=>nil}], 62=>[{35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, {35=>nil, 44=>nil, 53=>nil, 62=>nil}]}, 27=>{18=>[{18=>:enemy}, {18=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 9=>[{18=>nil, 9=>:enemy}, {18=>nil, 9=>nil}], 0=>[{18=>nil, 9=>nil, 0=>:enemy}, {18=>nil, 9=>nil, 0=>nil}], 13=>[{20=>nil, 13=>:enemy}, {20=>nil, 13=>nil}], 6=>[{20=>nil, 13=>nil, 6=>:enemy}, {20=>nil, 13=>nil, 6=>nil}], 41=>[{34=>nil, 41=>:enemy}, {34=>nil, 41=>nil}], 48=>[{34=>nil, 41=>nil, 48=>:enemy}, {34=>nil, 41=>nil, 48=>nil}], 45=>[{36=>nil, 45=>:enemy}, {36=>nil, 45=>nil}], 54=>[{36=>nil, 45=>nil, 54=>:enemy}, {36=>nil, 45=>nil, 54=>nil}], 63=>[{36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 28=>{19=>[{19=>:enemy}, {19=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 10=>[{19=>nil, 10=>:enemy}, {19=>nil, 10=>nil}], 1=>[{19=>nil, 10=>nil, 1=>:enemy}, {19=>nil, 10=>nil, 1=>nil}], 14=>[{21=>nil, 14=>:enemy}, {21=>nil, 14=>nil}], 7=>[{21=>nil, 14=>nil, 7=>:enemy}, {21=>nil, 14=>nil, 7=>nil}], 42=>[{35=>nil, 42=>:enemy}, {35=>nil, 42=>nil}], 49=>[{35=>nil, 42=>nil, 49=>:enemy}, {35=>nil, 42=>nil, 49=>nil}], 56=>[{35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {35=>nil, 42=>nil, 49=>nil, 56=>nil}], 46=>[{37=>nil, 46=>:enemy}, {37=>nil, 46=>nil}], 55=>[{37=>nil, 46=>nil, 55=>:enemy}, {37=>nil, 46=>nil, 55=>nil}]}, 29=>{20=>[{20=>:enemy}, {20=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 11=>[{20=>nil, 11=>:enemy}, {20=>nil, 11=>nil}], 2=>[{20=>nil, 11=>nil, 2=>:enemy}, {20=>nil, 11=>nil, 2=>nil}], 15=>[{22=>nil, 15=>:enemy}, {22=>nil, 15=>nil}], 43=>[{36=>nil, 43=>:enemy}, {36=>nil, 43=>nil}], 50=>[{36=>nil, 43=>nil, 50=>:enemy}, {36=>nil, 43=>nil, 50=>nil}], 57=>[{36=>nil, 43=>nil, 50=>nil, 57=>:enemy}, {36=>nil, 43=>nil, 50=>nil, 57=>nil}], 47=>[{38=>nil, 47=>:enemy}, {38=>nil, 47=>nil}]}, 30=>{21=>[{21=>:enemy}, {21=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 12=>[{21=>nil, 12=>:enemy}, {21=>nil, 12=>nil}], 3=>[{21=>nil, 12=>nil, 3=>:enemy}, {21=>nil, 12=>nil, 3=>nil}], 44=>[{37=>nil, 44=>:enemy}, {37=>nil, 44=>nil}], 51=>[{37=>nil, 44=>nil, 51=>:enemy}, {37=>nil, 44=>nil, 51=>nil}], 58=>[{37=>nil, 44=>nil, 51=>nil, 58=>:enemy}, {37=>nil, 44=>nil, 51=>nil, 58=>nil}]}, 31=>{22=>[{22=>:enemy}, {22=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 13=>[{22=>nil, 13=>:enemy}, {22=>nil, 13=>nil}], 4=>[{22=>nil, 13=>nil, 4=>:enemy}, {22=>nil, 13=>nil, 4=>nil}], 45=>[{38=>nil, 45=>:enemy}, {38=>nil, 45=>nil}], 52=>[{38=>nil, 45=>nil, 52=>:enemy}, {38=>nil, 45=>nil, 52=>nil}], 59=>[{38=>nil, 45=>nil, 52=>nil, 59=>:enemy}, {38=>nil, 45=>nil, 52=>nil, 59=>nil}]}, 32=>{25=>[{25=>:enemy}, {25=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 18=>[{25=>nil, 18=>:enemy}, {25=>nil, 18=>nil}], 11=>[{25=>nil, 18=>nil, 11=>:enemy}, {25=>nil, 18=>nil, 11=>nil}], 4=>[{25=>nil, 18=>nil, 11=>nil, 4=>:enemy}, {25=>nil, 18=>nil, 11=>nil, 4=>nil}], 50=>[{41=>nil, 50=>:enemy}, {41=>nil, 50=>nil}], 59=>[{41=>nil, 50=>nil, 59=>:enemy}, {41=>nil, 50=>nil, 59=>nil}]}, 33=>{24=>[{24=>:enemy}, {24=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 19=>[{26=>nil, 19=>:enemy}, {26=>nil, 19=>nil}], 12=>[{26=>nil, 19=>nil, 12=>:enemy}, {26=>nil, 19=>nil, 12=>nil}], 5=>[{26=>nil, 19=>nil, 12=>nil, 5=>:enemy}, {26=>nil, 19=>nil, 12=>nil, 5=>nil}], 51=>[{42=>nil, 51=>:enemy}, {42=>nil, 51=>nil}], 60=>[{42=>nil, 51=>nil, 60=>:enemy}, {42=>nil, 51=>nil, 60=>nil}]}, 34=>{25=>[{25=>:enemy}, {25=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 16=>[{25=>nil, 16=>:enemy}, {25=>nil, 16=>nil}], 20=>[{27=>nil, 20=>:enemy}, {27=>nil, 20=>nil}], 13=>[{27=>nil, 20=>nil, 13=>:enemy}, {27=>nil, 20=>nil, 13=>nil}], 6=>[{27=>nil, 20=>nil, 13=>nil, 6=>:enemy}, {27=>nil, 20=>nil, 13=>nil, 6=>nil}], 48=>[{41=>nil, 48=>:enemy}, {41=>nil, 48=>nil}], 52=>[{43=>nil, 52=>:enemy}, {43=>nil, 52=>nil}], 61=>[{43=>nil, 52=>nil, 61=>:enemy}, {43=>nil, 52=>nil, 61=>nil}]}, 35=>{26=>[{26=>:enemy}, {26=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 17=>[{26=>nil, 17=>:enemy}, {26=>nil, 17=>nil}], 8=>[{26=>nil, 17=>nil, 8=>:enemy}, {26=>nil, 17=>nil, 8=>nil}], 21=>[{28=>nil, 21=>:enemy}, {28=>nil, 21=>nil}], 14=>[{28=>nil, 21=>nil, 14=>:enemy}, {28=>nil, 21=>nil, 14=>nil}], 7=>[{28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {28=>nil, 21=>nil, 14=>nil, 7=>nil}], 49=>[{42=>nil, 49=>:enemy}, {42=>nil, 49=>nil}], 56=>[{42=>nil, 49=>nil, 56=>:enemy}, {42=>nil, 49=>nil, 56=>nil}], 53=>[{44=>nil, 53=>:enemy}, {44=>nil, 53=>nil}], 62=>[{44=>nil, 53=>nil, 62=>:enemy}, {44=>nil, 53=>nil, 62=>nil}]}, 36=>{27=>[{27=>:enemy}, {27=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 18=>[{27=>nil, 18=>:enemy}, {27=>nil, 18=>nil}], 9=>[{27=>nil, 18=>nil, 9=>:enemy}, {27=>nil, 18=>nil, 9=>nil}], 0=>[{27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {27=>nil, 18=>nil, 9=>nil, 0=>nil}], 22=>[{29=>nil, 22=>:enemy}, {29=>nil, 22=>nil}], 15=>[{29=>nil, 22=>nil, 15=>:enemy}, {29=>nil, 22=>nil, 15=>nil}], 50=>[{43=>nil, 50=>:enemy}, {43=>nil, 50=>nil}], 57=>[{43=>nil, 50=>nil, 57=>:enemy}, {43=>nil, 50=>nil, 57=>nil}], 54=>[{45=>nil, 54=>:enemy}, {45=>nil, 54=>nil}], 63=>[{45=>nil, 54=>nil, 63=>:enemy}, {45=>nil, 54=>nil, 63=>nil}]}, 37=>{28=>[{28=>:enemy}, {28=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 19=>[{28=>nil, 19=>:enemy}, {28=>nil, 19=>nil}], 10=>[{28=>nil, 19=>nil, 10=>:enemy}, {28=>nil, 19=>nil, 10=>nil}], 1=>[{28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, {28=>nil, 19=>nil, 10=>nil, 1=>nil}], 23=>[{30=>nil, 23=>:enemy}, {30=>nil, 23=>nil}], 51=>[{44=>nil, 51=>:enemy}, {44=>nil, 51=>nil}], 58=>[{44=>nil, 51=>nil, 58=>:enemy}, {44=>nil, 51=>nil, 58=>nil}], 55=>[{46=>nil, 55=>:enemy}, {46=>nil, 55=>nil}]}, 38=>{29=>[{29=>:enemy}, {29=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 20=>[{29=>nil, 20=>:enemy}, {29=>nil, 20=>nil}], 11=>[{29=>nil, 20=>nil, 11=>:enemy}, {29=>nil, 20=>nil, 11=>nil}], 2=>[{29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, {29=>nil, 20=>nil, 11=>nil, 2=>nil}], 52=>[{45=>nil, 52=>:enemy}, {45=>nil, 52=>nil}], 59=>[{45=>nil, 52=>nil, 59=>:enemy}, {45=>nil, 52=>nil, 59=>nil}]}, 39=>{30=>[{30=>:enemy}, {30=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 21=>[{30=>nil, 21=>:enemy}, {30=>nil, 21=>nil}], 12=>[{30=>nil, 21=>nil, 12=>:enemy}, {30=>nil, 21=>nil, 12=>nil}], 3=>[{30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, {30=>nil, 21=>nil, 12=>nil, 3=>nil}], 53=>[{46=>nil, 53=>:enemy}, {46=>nil, 53=>nil}], 60=>[{46=>nil, 53=>nil, 60=>:enemy}, {46=>nil, 53=>nil, 60=>nil}]}, 40=>{33=>[{33=>:enemy}, {33=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 26=>[{33=>nil, 26=>:enemy}, {33=>nil, 26=>nil}], 19=>[{33=>nil, 26=>nil, 19=>:enemy}, {33=>nil, 26=>nil, 19=>nil}], 12=>[{33=>nil, 26=>nil, 19=>nil, 12=>:enemy}, {33=>nil, 26=>nil, 19=>nil, 12=>nil}], 5=>[{33=>nil, 26=>nil, 19=>nil, 12=>nil, 5=>:enemy}, {33=>nil, 26=>nil, 19=>nil, 12=>nil, 5=>nil}], 58=>[{49=>nil, 58=>:enemy}, {49=>nil, 58=>nil}]}, 41=>{32=>[{32=>:enemy}, {32=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 27=>[{34=>nil, 27=>:enemy}, {34=>nil, 27=>nil}], 20=>[{34=>nil, 27=>nil, 20=>:enemy}, {34=>nil, 27=>nil, 20=>nil}], 13=>[{34=>nil, 27=>nil, 20=>nil, 13=>:enemy}, {34=>nil, 27=>nil, 20=>nil, 13=>nil}], 6=>[{34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>:enemy}, {34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>nil}], 59=>[{50=>nil, 59=>:enemy}, {50=>nil, 59=>nil}]}, 42=>{33=>[{33=>:enemy}, {33=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 24=>[{33=>nil, 24=>:enemy}, {33=>nil, 24=>nil}], 28=>[{35=>nil, 28=>:enemy}, {35=>nil, 28=>nil}], 21=>[{35=>nil, 28=>nil, 21=>:enemy}, {35=>nil, 28=>nil, 21=>nil}], 14=>[{35=>nil, 28=>nil, 21=>nil, 14=>:enemy}, {35=>nil, 28=>nil, 21=>nil, 14=>nil}], 7=>[{35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>nil}], 56=>[{49=>nil, 56=>:enemy}, {49=>nil, 56=>nil}], 60=>[{51=>nil, 60=>:enemy}, {51=>nil, 60=>nil}]}, 43=>{34=>[{34=>:enemy}, {34=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 25=>[{34=>nil, 25=>:enemy}, {34=>nil, 25=>nil}], 16=>[{34=>nil, 25=>nil, 16=>:enemy}, {34=>nil, 25=>nil, 16=>nil}], 29=>[{36=>nil, 29=>:enemy}, {36=>nil, 29=>nil}], 22=>[{36=>nil, 29=>nil, 22=>:enemy}, {36=>nil, 29=>nil, 22=>nil}], 15=>[{36=>nil, 29=>nil, 22=>nil, 15=>:enemy}, {36=>nil, 29=>nil, 22=>nil, 15=>nil}], 57=>[{50=>nil, 57=>:enemy}, {50=>nil, 57=>nil}], 61=>[{52=>nil, 61=>:enemy}, {52=>nil, 61=>nil}]}, 44=>{35=>[{35=>:enemy}, {35=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 26=>[{35=>nil, 26=>:enemy}, {35=>nil, 26=>nil}], 17=>[{35=>nil, 26=>nil, 17=>:enemy}, {35=>nil, 26=>nil, 17=>nil}], 8=>[{35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, {35=>nil, 26=>nil, 17=>nil, 8=>nil}], 30=>[{37=>nil, 30=>:enemy}, {37=>nil, 30=>nil}], 23=>[{37=>nil, 30=>nil, 23=>:enemy}, {37=>nil, 30=>nil, 23=>nil}], 58=>[{51=>nil, 58=>:enemy}, {51=>nil, 58=>nil}], 62=>[{53=>nil, 62=>:enemy}, {53=>nil, 62=>nil}]}, 45=>{36=>[{36=>:enemy}, {36=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 27=>[{36=>nil, 27=>:enemy}, {36=>nil, 27=>nil}], 18=>[{36=>nil, 27=>nil, 18=>:enemy}, {36=>nil, 27=>nil, 18=>nil}], 9=>[{36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, {36=>nil, 27=>nil, 18=>nil, 9=>nil}], 0=>[{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}], 31=>[{38=>nil, 31=>:enemy}, {38=>nil, 31=>nil}], 59=>[{52=>nil, 59=>:enemy}, {52=>nil, 59=>nil}], 63=>[{54=>nil, 63=>:enemy}, {54=>nil, 63=>nil}]}, 46=>{37=>[{37=>:enemy}, {37=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 28=>[{37=>nil, 28=>:enemy}, {37=>nil, 28=>nil}], 19=>[{37=>nil, 28=>nil, 19=>:enemy}, {37=>nil, 28=>nil, 19=>nil}], 10=>[{37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, {37=>nil, 28=>nil, 19=>nil, 10=>nil}], 1=>[{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, {37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}], 60=>[{53=>nil, 60=>:enemy}, {53=>nil, 60=>nil}]}, 47=>{38=>[{38=>:enemy}, {38=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 29=>[{38=>nil, 29=>:enemy}, {38=>nil, 29=>nil}], 20=>[{38=>nil, 29=>nil, 20=>:enemy}, {38=>nil, 29=>nil, 20=>nil}], 11=>[{38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, {38=>nil, 29=>nil, 20=>nil, 11=>nil}], 2=>[{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, {38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}], 61=>[{54=>nil, 61=>:enemy}, {54=>nil, 61=>nil}]}, 48=>{41=>[{41=>:enemy}, {41=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 34=>[{41=>nil, 34=>:enemy}, {41=>nil, 34=>nil}], 27=>[{41=>nil, 34=>nil, 27=>:enemy}, {41=>nil, 34=>nil, 27=>nil}], 20=>[{41=>nil, 34=>nil, 27=>nil, 20=>:enemy}, {41=>nil, 34=>nil, 27=>nil, 20=>nil}], 13=>[{41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>:enemy}, {41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>nil}], 6=>[{41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>:enemy}, {41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>nil}]}, 49=>{40=>[{40=>:enemy}, {40=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 35=>[{42=>nil, 35=>:enemy}, {42=>nil, 35=>nil}], 28=>[{42=>nil, 35=>nil, 28=>:enemy}, {42=>nil, 35=>nil, 28=>nil}], 21=>[{42=>nil, 35=>nil, 28=>nil, 21=>:enemy}, {42=>nil, 35=>nil, 28=>nil, 21=>nil}], 14=>[{42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>:enemy}, {42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil}], 7=>[{42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>nil}]}, 50=>{41=>[{41=>:enemy}, {41=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 32=>[{41=>nil, 32=>:enemy}, {41=>nil, 32=>nil}], 36=>[{43=>nil, 36=>:enemy}, {43=>nil, 36=>nil}], 29=>[{43=>nil, 36=>nil, 29=>:enemy}, {43=>nil, 36=>nil, 29=>nil}], 22=>[{43=>nil, 36=>nil, 29=>nil, 22=>:enemy}, {43=>nil, 36=>nil, 29=>nil, 22=>nil}], 15=>[{43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>:enemy}, {43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>nil}]}, 51=>{42=>[{42=>:enemy}, {42=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 33=>[{42=>nil, 33=>:enemy}, {42=>nil, 33=>nil}], 24=>[{42=>nil, 33=>nil, 24=>:enemy}, {42=>nil, 33=>nil, 24=>nil}], 37=>[{44=>nil, 37=>:enemy}, {44=>nil, 37=>nil}], 30=>[{44=>nil, 37=>nil, 30=>:enemy}, {44=>nil, 37=>nil, 30=>nil}], 23=>[{44=>nil, 37=>nil, 30=>nil, 23=>:enemy}, {44=>nil, 37=>nil, 30=>nil, 23=>nil}]}, 52=>{43=>[{43=>:enemy}, {43=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 34=>[{43=>nil, 34=>:enemy}, {43=>nil, 34=>nil}], 25=>[{43=>nil, 34=>nil, 25=>:enemy}, {43=>nil, 34=>nil, 25=>nil}], 16=>[{43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, {43=>nil, 34=>nil, 25=>nil, 16=>nil}], 38=>[{45=>nil, 38=>:enemy}, {45=>nil, 38=>nil}], 31=>[{45=>nil, 38=>nil, 31=>:enemy}, {45=>nil, 38=>nil, 31=>nil}]}, 53=>{44=>[{44=>:enemy}, {44=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 35=>[{44=>nil, 35=>:enemy}, {44=>nil, 35=>nil}], 26=>[{44=>nil, 35=>nil, 26=>:enemy}, {44=>nil, 35=>nil, 26=>nil}], 17=>[{44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, {44=>nil, 35=>nil, 26=>nil, 17=>nil}], 8=>[{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, {44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}], 39=>[{46=>nil, 39=>:enemy}, {46=>nil, 39=>nil}]}, 54=>{45=>[{45=>:enemy}, {45=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 63=>[{63=>:enemy}, {63=>nil}], 36=>[{45=>nil, 36=>:enemy}, {45=>nil, 36=>nil}], 27=>[{45=>nil, 36=>nil, 27=>:enemy}, {45=>nil, 36=>nil, 27=>nil}], 18=>[{45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, {45=>nil, 36=>nil, 27=>nil, 18=>nil}], 9=>[{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, {45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}], 0=>[{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}]}, 55=>{46=>[{46=>:enemy}, {46=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 37=>[{46=>nil, 37=>:enemy}, {46=>nil, 37=>nil}], 28=>[{46=>nil, 37=>nil, 28=>:enemy}, {46=>nil, 37=>nil, 28=>nil}], 19=>[{46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, {46=>nil, 37=>nil, 28=>nil, 19=>nil}], 10=>[{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, {46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}], 1=>[{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, {46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}]}, 56=>{49=>[{49=>:enemy}, {49=>nil}], 42=>[{49=>nil, 42=>:enemy}, {49=>nil, 42=>nil}], 35=>[{49=>nil, 42=>nil, 35=>:enemy}, {49=>nil, 42=>nil, 35=>nil}], 28=>[{49=>nil, 42=>nil, 35=>nil, 28=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil}], 21=>[{49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil}], 14=>[{49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil}], 7=>[{49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>nil}]}, 57=>{48=>[{48=>:enemy}, {48=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 43=>[{50=>nil, 43=>:enemy}, {50=>nil, 43=>nil}], 36=>[{50=>nil, 43=>nil, 36=>:enemy}, {50=>nil, 43=>nil, 36=>nil}], 29=>[{50=>nil, 43=>nil, 36=>nil, 29=>:enemy}, {50=>nil, 43=>nil, 36=>nil, 29=>nil}], 22=>[{50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>:enemy}, {50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>nil}], 15=>[{50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>:enemy}, {50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>nil}]}, 58=>{49=>[{49=>:enemy}, {49=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 40=>[{49=>nil, 40=>:enemy}, {49=>nil, 40=>nil}], 44=>[{51=>nil, 44=>:enemy}, {51=>nil, 44=>nil}], 37=>[{51=>nil, 44=>nil, 37=>:enemy}, {51=>nil, 44=>nil, 37=>nil}], 30=>[{51=>nil, 44=>nil, 37=>nil, 30=>:enemy}, {51=>nil, 44=>nil, 37=>nil, 30=>nil}], 23=>[{51=>nil, 44=>nil, 37=>nil, 30=>nil, 23=>:enemy}, {51=>nil, 44=>nil, 37=>nil, 30=>nil, 23=>nil}]}, 59=>{50=>[{50=>:enemy}, {50=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 41=>[{50=>nil, 41=>:enemy}, {50=>nil, 41=>nil}], 32=>[{50=>nil, 41=>nil, 32=>:enemy}, {50=>nil, 41=>nil, 32=>nil}], 45=>[{52=>nil, 45=>:enemy}, {52=>nil, 45=>nil}], 38=>[{52=>nil, 45=>nil, 38=>:enemy}, {52=>nil, 45=>nil, 38=>nil}], 31=>[{52=>nil, 45=>nil, 38=>nil, 31=>:enemy}, {52=>nil, 45=>nil, 38=>nil, 31=>nil}]}, 60=>{51=>[{51=>:enemy}, {51=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 42=>[{51=>nil, 42=>:enemy}, {51=>nil, 42=>nil}], 33=>[{51=>nil, 42=>nil, 33=>:enemy}, {51=>nil, 42=>nil, 33=>nil}], 24=>[{51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, {51=>nil, 42=>nil, 33=>nil, 24=>nil}], 46=>[{53=>nil, 46=>:enemy}, {53=>nil, 46=>nil}], 39=>[{53=>nil, 46=>nil, 39=>:enemy}, {53=>nil, 46=>nil, 39=>nil}]}, 61=>{52=>[{52=>:enemy}, {52=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 43=>[{52=>nil, 43=>:enemy}, {52=>nil, 43=>nil}], 34=>[{52=>nil, 43=>nil, 34=>:enemy}, {52=>nil, 43=>nil, 34=>nil}], 25=>[{52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, {52=>nil, 43=>nil, 34=>nil, 25=>nil}], 16=>[{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, {52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}], 47=>[{54=>nil, 47=>:enemy}, {54=>nil, 47=>nil}]}, 62=>{53=>[{53=>:enemy}, {53=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 44=>[{53=>nil, 44=>:enemy}, {53=>nil, 44=>nil}], 35=>[{53=>nil, 44=>nil, 35=>:enemy}, {53=>nil, 44=>nil, 35=>nil}], 26=>[{53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, {53=>nil, 44=>nil, 35=>nil, 26=>nil}], 17=>[{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, {53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}], 8=>[{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, {53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}]}, 63=>{54=>[{54=>:enemy}, {54=>nil}], 45=>[{54=>nil, 45=>:enemy}, {54=>nil, 45=>nil}], 36=>[{54=>nil, 45=>nil, 36=>:enemy}, {54=>nil, 45=>nil, 36=>nil}], 27=>[{54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil}], 18=>[{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}], 9=>[{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}], 0=>[{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}]}}, "C:N"=>{0=>{10=>[{10=>:enemy}, {10=>nil}], 17=>[{17=>:enemy}, {17=>nil}]}, 1=>{11=>[{11=>:enemy}, {11=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 18=>[{18=>:enemy}, {18=>nil}]}, 2=>{8=>[{8=>:enemy}, {8=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 19=>[{19=>:enemy}, {19=>nil}]}, 3=>{9=>[{9=>:enemy}, {9=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 20=>[{20=>:enemy}, {20=>nil}]}, 4=>{10=>[{10=>:enemy}, {10=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 21=>[{21=>:enemy}, {21=>nil}]}, 5=>{11=>[{11=>:enemy}, {11=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 22=>[{22=>:enemy}, {22=>nil}]}, 6=>{12=>[{12=>:enemy}, {12=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 23=>[{23=>:enemy}, {23=>nil}]}, 7=>{13=>[{13=>:enemy}, {13=>nil}], 22=>[{22=>:enemy}, {22=>nil}]}, 8=>{2=>[{2=>:enemy}, {2=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 25=>[{25=>:enemy}, {25=>nil}]}, 9=>{3=>[{3=>:enemy}, {3=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 26=>[{26=>:enemy}, {26=>nil}]}, 10=>{0=>[{0=>:enemy}, {0=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 27=>[{27=>:enemy}, {27=>nil}]}, 11=>{1=>[{1=>:enemy}, {1=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 28=>[{28=>:enemy}, {28=>nil}]}, 12=>{2=>[{2=>:enemy}, {2=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 29=>[{29=>:enemy}, {29=>nil}]}, 13=>{3=>[{3=>:enemy}, {3=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 30=>[{30=>:enemy}, {30=>nil}]}, 14=>{4=>[{4=>:enemy}, {4=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 31=>[{31=>:enemy}, {31=>nil}]}, 15=>{5=>[{5=>:enemy}, {5=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 30=>[{30=>:enemy}, {30=>nil}]}, 16=>{1=>[{1=>:enemy}, {1=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 33=>[{33=>:enemy}, {33=>nil}]}, 17=>{0=>[{0=>:enemy}, {0=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 34=>[{34=>:enemy}, {34=>nil}]}, 18=>{1=>[{1=>:enemy}, {1=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 35=>[{35=>:enemy}, {35=>nil}]}, 19=>{2=>[{2=>:enemy}, {2=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 36=>[{36=>:enemy}, {36=>nil}]}, 20=>{3=>[{3=>:enemy}, {3=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 37=>[{37=>:enemy}, {37=>nil}]}, 21=>{4=>[{4=>:enemy}, {4=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 38=>[{38=>:enemy}, {38=>nil}]}, 22=>{5=>[{5=>:enemy}, {5=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 39=>[{39=>:enemy}, {39=>nil}]}, 23=>{6=>[{6=>:enemy}, {6=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 38=>[{38=>:enemy}, {38=>nil}]}, 24=>{9=>[{9=>:enemy}, {9=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 41=>[{41=>:enemy}, {41=>nil}]}, 25=>{8=>[{8=>:enemy}, {8=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 42=>[{42=>:enemy}, {42=>nil}]}, 26=>{9=>[{9=>:enemy}, {9=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 43=>[{43=>:enemy}, {43=>nil}]}, 27=>{10=>[{10=>:enemy}, {10=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 44=>[{44=>:enemy}, {44=>nil}]}, 28=>{11=>[{11=>:enemy}, {11=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 45=>[{45=>:enemy}, {45=>nil}]}, 29=>{12=>[{12=>:enemy}, {12=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 46=>[{46=>:enemy}, {46=>nil}]}, 30=>{13=>[{13=>:enemy}, {13=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 47=>[{47=>:enemy}, {47=>nil}]}, 31=>{14=>[{14=>:enemy}, {14=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 46=>[{46=>:enemy}, {46=>nil}]}, 32=>{17=>[{17=>:enemy}, {17=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 49=>[{49=>:enemy}, {49=>nil}]}, 33=>{16=>[{16=>:enemy}, {16=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 50=>[{50=>:enemy}, {50=>nil}]}, 34=>{17=>[{17=>:enemy}, {17=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 51=>[{51=>:enemy}, {51=>nil}]}, 35=>{18=>[{18=>:enemy}, {18=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 52=>[{52=>:enemy}, {52=>nil}]}, 36=>{19=>[{19=>:enemy}, {19=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 53=>[{53=>:enemy}, {53=>nil}]}, 37=>{20=>[{20=>:enemy}, {20=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 54=>[{54=>:enemy}, {54=>nil}]}, 38=>{21=>[{21=>:enemy}, {21=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 55=>[{55=>:enemy}, {55=>nil}]}, 39=>{22=>[{22=>:enemy}, {22=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 54=>[{54=>:enemy}, {54=>nil}]}, 40=>{25=>[{25=>:enemy}, {25=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 57=>[{57=>:enemy}, {57=>nil}]}, 41=>{24=>[{24=>:enemy}, {24=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 58=>[{58=>:enemy}, {58=>nil}]}, 42=>{25=>[{25=>:enemy}, {25=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 59=>[{59=>:enemy}, {59=>nil}]}, 43=>{26=>[{26=>:enemy}, {26=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 60=>[{60=>:enemy}, {60=>nil}]}, 44=>{27=>[{27=>:enemy}, {27=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 61=>[{61=>:enemy}, {61=>nil}]}, 45=>{28=>[{28=>:enemy}, {28=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 62=>[{62=>:enemy}, {62=>nil}]}, 46=>{29=>[{29=>:enemy}, {29=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 63=>[{63=>:enemy}, {63=>nil}]}, 47=>{30=>[{30=>:enemy}, {30=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 62=>[{62=>:enemy}, {62=>nil}]}, 48=>{33=>[{33=>:enemy}, {33=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 58=>[{58=>:enemy}, {58=>nil}]}, 49=>{32=>[{32=>:enemy}, {32=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 59=>[{59=>:enemy}, {59=>nil}]}, 50=>{33=>[{33=>:enemy}, {33=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 60=>[{60=>:enemy}, {60=>nil}]}, 51=>{34=>[{34=>:enemy}, {34=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 61=>[{61=>:enemy}, {61=>nil}]}, 52=>{35=>[{35=>:enemy}, {35=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 62=>[{62=>:enemy}, {62=>nil}]}, 53=>{36=>[{36=>:enemy}, {36=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 63=>[{63=>:enemy}, {63=>nil}]}, 54=>{37=>[{37=>:enemy}, {37=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 60=>[{60=>:enemy}, {60=>nil}]}, 55=>{38=>[{38=>:enemy}, {38=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 61=>[{61=>:enemy}, {61=>nil}]}, 56=>{41=>[{41=>:enemy}, {41=>nil}], 50=>[{50=>:enemy}, {50=>nil}]}, 57=>{40=>[{40=>:enemy}, {40=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 51=>[{51=>:enemy}, {51=>nil}]}, 58=>{41=>[{41=>:enemy}, {41=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 52=>[{52=>:enemy}, {52=>nil}]}, 59=>{42=>[{42=>:enemy}, {42=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 53=>[{53=>:enemy}, {53=>nil}]}, 60=>{43=>[{43=>:enemy}, {43=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 54=>[{54=>:enemy}, {54=>nil}]}, 61=>{44=>[{44=>:enemy}, {44=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 55=>[{55=>:enemy}, {55=>nil}]}, 62=>{45=>[{45=>:enemy}, {45=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 52=>[{52=>:enemy}, {52=>nil}]}, 63=>{46=>[{46=>:enemy}, {46=>nil}], 53=>[{53=>:enemy}, {53=>nil}]}}, "C:P"=>{0=>{}, 1=>{}, 2=>{}, 3=>{}, 4=>{}, 5=>{}, 6=>{}, 7=>{}, 8=>{1=>[{1=>:enemy}], 0=>[{0=>nil}]}, 9=>{0=>[{0=>:enemy}], 2=>[{2=>:enemy}], 1=>[{1=>nil}]}, 10=>{1=>[{1=>:enemy}], 3=>[{3=>:enemy}], 2=>[{2=>nil}]}, 11=>{2=>[{2=>:enemy}], 4=>[{4=>:enemy}], 3=>[{3=>nil}]}, 12=>{3=>[{3=>:enemy}], 5=>[{5=>:enemy}], 4=>[{4=>nil}]}, 13=>{4=>[{4=>:enemy}], 6=>[{6=>:enemy}], 5=>[{5=>nil}]}, 14=>{5=>[{5=>:enemy}], 7=>[{7=>:enemy}], 6=>[{6=>nil}]}, 15=>{6=>[{6=>:enemy}], 7=>[{7=>nil}]}, 16=>{9=>[{9=>:enemy}], 8=>[{8=>nil}]}, 17=>{8=>[{8=>:enemy}], 10=>[{10=>:enemy}], 9=>[{9=>nil}]}, 18=>{9=>[{9=>:enemy}], 11=>[{11=>:enemy}], 10=>[{10=>nil}]}, 19=>{10=>[{10=>:enemy}], 12=>[{12=>:enemy}], 11=>[{11=>nil}]}, 20=>{11=>[{11=>:enemy}], 13=>[{13=>:enemy}], 12=>[{12=>nil}]}, 21=>{12=>[{12=>:enemy}], 14=>[{14=>:enemy}], 13=>[{13=>nil}]}, 22=>{13=>[{13=>:enemy}], 15=>[{15=>:enemy}], 14=>[{14=>nil}]}, 23=>{14=>[{14=>:enemy}], 15=>[{15=>nil}]}, 24=>{17=>[{17=>:enemy}], 16=>[{16=>nil}]}, 25=>{16=>[{16=>:enemy}], 18=>[{18=>:enemy}], 17=>[{17=>nil}]}, 26=>{17=>[{17=>:enemy}], 19=>[{19=>:enemy}], 18=>[{18=>nil}]}, 27=>{18=>[{18=>:enemy}], 20=>[{20=>:enemy}], 19=>[{19=>nil}]}, 28=>{19=>[{19=>:enemy}], 21=>[{21=>:enemy}], 20=>[{20=>nil}]}, 29=>{20=>[{20=>:enemy}], 22=>[{22=>:enemy}], 21=>[{21=>nil}]}, 30=>{21=>[{21=>:enemy}], 23=>[{23=>:enemy}], 22=>[{22=>nil}]}, 31=>{22=>[{22=>:enemy}], 23=>[{23=>nil}]}, 32=>{25=>[{25=>:enemy}], 24=>[{24=>nil}]}, 33=>{24=>[{24=>:enemy}], 26=>[{26=>:enemy}], 25=>[{25=>nil}]}, 34=>{25=>[{25=>:enemy}], 27=>[{27=>:enemy}], 26=>[{26=>nil}]}, 35=>{26=>[{26=>:enemy}], 28=>[{28=>:enemy}], 27=>[{27=>nil}]}, 36=>{27=>[{27=>:enemy}], 29=>[{29=>:enemy}], 28=>[{28=>nil}]}, 37=>{28=>[{28=>:enemy}], 30=>[{30=>:enemy}], 29=>[{29=>nil}]}, 38=>{29=>[{29=>:enemy}], 31=>[{31=>:enemy}], 30=>[{30=>nil}]}, 39=>{30=>[{30=>:enemy}], 31=>[{31=>nil}]}, 40=>{33=>[{33=>:enemy}], 32=>[{32=>nil}]}, 41=>{32=>[{32=>:enemy}], 34=>[{34=>:enemy}], 33=>[{33=>nil}]}, 42=>{33=>[{33=>:enemy}], 35=>[{35=>:enemy}], 34=>[{34=>nil}]}, 43=>{34=>[{34=>:enemy}], 36=>[{36=>:enemy}], 35=>[{35=>nil}]}, 44=>{35=>[{35=>:enemy}], 37=>[{37=>:enemy}], 36=>[{36=>nil}]}, 45=>{36=>[{36=>:enemy}], 38=>[{38=>:enemy}], 37=>[{37=>nil}]}, 46=>{37=>[{37=>:enemy}], 39=>[{39=>:enemy}], 38=>[{38=>nil}]}, 47=>{38=>[{38=>:enemy}], 39=>[{39=>nil}]}, 48=>{41=>[{41=>:enemy}], 40=>[{40=>nil}]}, 49=>{40=>[{40=>:enemy}], 42=>[{42=>:enemy}], 41=>[{41=>nil}]}, 50=>{41=>[{41=>:enemy}], 43=>[{43=>:enemy}], 42=>[{42=>nil}]}, 51=>{42=>[{42=>:enemy}], 44=>[{44=>:enemy}], 43=>[{43=>nil}]}, 52=>{43=>[{43=>:enemy}], 45=>[{45=>:enemy}], 44=>[{44=>nil}]}, 53=>{44=>[{44=>:enemy}], 46=>[{46=>:enemy}], 45=>[{45=>nil}]}, 54=>{45=>[{45=>:enemy}], 47=>[{47=>:enemy}], 46=>[{46=>nil}]}, 55=>{46=>[{46=>:enemy}], 47=>[{47=>nil}]}, 56=>{49=>[{49=>:enemy}], 48=>[{48=>nil}]}, 57=>{48=>[{48=>:enemy}], 50=>[{50=>:enemy}], 49=>[{49=>nil}]}, 58=>{49=>[{49=>:enemy}], 51=>[{51=>:enemy}], 50=>[{50=>nil}]}, 59=>{50=>[{50=>:enemy}], 52=>[{52=>:enemy}], 51=>[{51=>nil}]}, 60=>{51=>[{51=>:enemy}], 53=>[{53=>:enemy}], 52=>[{52=>nil}]}, 61=>{52=>[{52=>:enemy}], 54=>[{54=>:enemy}], 53=>[{53=>nil}]}, 62=>{53=>[{53=>:enemy}], 55=>[{55=>:enemy}], 54=>[{54=>nil}]}, 63=>{54=>[{54=>:enemy}], 55=>[{55=>nil}]}}, "C:Q"=>{0=>{1=>[{1=>:enemy}, {1=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 2=>[{1=>nil, 2=>:enemy}, {1=>nil, 2=>nil}], 3=>[{1=>nil, 2=>nil, 3=>:enemy}, {1=>nil, 2=>nil, 3=>nil}], 4=>[{1=>nil, 2=>nil, 3=>nil, 4=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil}], 5=>[{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil}], 6=>[{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}], 7=>[{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}], 16=>[{8=>nil, 16=>:enemy}, {8=>nil, 16=>nil}], 24=>[{8=>nil, 16=>nil, 24=>:enemy}, {8=>nil, 16=>nil, 24=>nil}], 32=>[{8=>nil, 16=>nil, 24=>nil, 32=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil}], 40=>[{8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil}], 48=>[{8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil}], 56=>[{8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}], 18=>[{9=>nil, 18=>:enemy}, {9=>nil, 18=>nil}], 27=>[{9=>nil, 18=>nil, 27=>:enemy}, {9=>nil, 18=>nil, 27=>nil}], 36=>[{9=>nil, 18=>nil, 27=>nil, 36=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil}], 45=>[{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil}], 54=>[{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}], 63=>[{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 1=>{0=>[{0=>:enemy}, {0=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 3=>[{2=>nil, 3=>:enemy}, {2=>nil, 3=>nil}], 4=>[{2=>nil, 3=>nil, 4=>:enemy}, {2=>nil, 3=>nil, 4=>nil}], 5=>[{2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, {2=>nil, 3=>nil, 4=>nil, 5=>nil}], 6=>[{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, {2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}], 7=>[{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}], 17=>[{9=>nil, 17=>:enemy}, {9=>nil, 17=>nil}], 25=>[{9=>nil, 17=>nil, 25=>:enemy}, {9=>nil, 17=>nil, 25=>nil}], 33=>[{9=>nil, 17=>nil, 25=>nil, 33=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil}], 41=>[{9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil}], 49=>[{9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil}], 57=>[{9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}], 19=>[{10=>nil, 19=>:enemy}, {10=>nil, 19=>nil}], 28=>[{10=>nil, 19=>nil, 28=>:enemy}, {10=>nil, 19=>nil, 28=>nil}], 37=>[{10=>nil, 19=>nil, 28=>nil, 37=>:enemy}, {10=>nil, 19=>nil, 28=>nil, 37=>nil}], 46=>[{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, {10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil}], 55=>[{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, {10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}]}, 2=>{1=>[{1=>:enemy}, {1=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 0=>[{1=>nil, 0=>:enemy}, {1=>nil, 0=>nil}], 4=>[{3=>nil, 4=>:enemy}, {3=>nil, 4=>nil}], 5=>[{3=>nil, 4=>nil, 5=>:enemy}, {3=>nil, 4=>nil, 5=>nil}], 6=>[{3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, {3=>nil, 4=>nil, 5=>nil, 6=>nil}], 7=>[{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}], 16=>[{9=>nil, 16=>:enemy}, {9=>nil, 16=>nil}], 18=>[{10=>nil, 18=>:enemy}, {10=>nil, 18=>nil}], 26=>[{10=>nil, 18=>nil, 26=>:enemy}, {10=>nil, 18=>nil, 26=>nil}], 34=>[{10=>nil, 18=>nil, 26=>nil, 34=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil}], 42=>[{10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil}], 50=>[{10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil}], 58=>[{10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>nil}], 20=>[{11=>nil, 20=>:enemy}, {11=>nil, 20=>nil}], 29=>[{11=>nil, 20=>nil, 29=>:enemy}, {11=>nil, 20=>nil, 29=>nil}], 38=>[{11=>nil, 20=>nil, 29=>nil, 38=>:enemy}, {11=>nil, 20=>nil, 29=>nil, 38=>nil}], 47=>[{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, {11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil}]}, 3=>{2=>[{2=>:enemy}, {2=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 1=>[{2=>nil, 1=>:enemy}, {2=>nil, 1=>nil}], 0=>[{2=>nil, 1=>nil, 0=>:enemy}, {2=>nil, 1=>nil, 0=>nil}], 5=>[{4=>nil, 5=>:enemy}, {4=>nil, 5=>nil}], 6=>[{4=>nil, 5=>nil, 6=>:enemy}, {4=>nil, 5=>nil, 6=>nil}], 7=>[{4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {4=>nil, 5=>nil, 6=>nil, 7=>nil}], 17=>[{10=>nil, 17=>:enemy}, {10=>nil, 17=>nil}], 24=>[{10=>nil, 17=>nil, 24=>:enemy}, {10=>nil, 17=>nil, 24=>nil}], 19=>[{11=>nil, 19=>:enemy}, {11=>nil, 19=>nil}], 27=>[{11=>nil, 19=>nil, 27=>:enemy}, {11=>nil, 19=>nil, 27=>nil}], 35=>[{11=>nil, 19=>nil, 27=>nil, 35=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil}], 43=>[{11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil}], 51=>[{11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil}], 59=>[{11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>nil}], 21=>[{12=>nil, 21=>:enemy}, {12=>nil, 21=>nil}], 30=>[{12=>nil, 21=>nil, 30=>:enemy}, {12=>nil, 21=>nil, 30=>nil}], 39=>[{12=>nil, 21=>nil, 30=>nil, 39=>:enemy}, {12=>nil, 21=>nil, 30=>nil, 39=>nil}]}, 4=>{3=>[{3=>:enemy}, {3=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 2=>[{3=>nil, 2=>:enemy}, {3=>nil, 2=>nil}], 1=>[{3=>nil, 2=>nil, 1=>:enemy}, {3=>nil, 2=>nil, 1=>nil}], 0=>[{3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {3=>nil, 2=>nil, 1=>nil, 0=>nil}], 6=>[{5=>nil, 6=>:enemy}, {5=>nil, 6=>nil}], 7=>[{5=>nil, 6=>nil, 7=>:enemy}, {5=>nil, 6=>nil, 7=>nil}], 18=>[{11=>nil, 18=>:enemy}, {11=>nil, 18=>nil}], 25=>[{11=>nil, 18=>nil, 25=>:enemy}, {11=>nil, 18=>nil, 25=>nil}], 32=>[{11=>nil, 18=>nil, 25=>nil, 32=>:enemy}, {11=>nil, 18=>nil, 25=>nil, 32=>nil}], 20=>[{12=>nil, 20=>:enemy}, {12=>nil, 20=>nil}], 28=>[{12=>nil, 20=>nil, 28=>:enemy}, {12=>nil, 20=>nil, 28=>nil}], 36=>[{12=>nil, 20=>nil, 28=>nil, 36=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil}], 44=>[{12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil}], 52=>[{12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil}], 60=>[{12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>nil}], 22=>[{13=>nil, 22=>:enemy}, {13=>nil, 22=>nil}], 31=>[{13=>nil, 22=>nil, 31=>:enemy}, {13=>nil, 22=>nil, 31=>nil}]}, 5=>{4=>[{4=>:enemy}, {4=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 3=>[{4=>nil, 3=>:enemy}, {4=>nil, 3=>nil}], 2=>[{4=>nil, 3=>nil, 2=>:enemy}, {4=>nil, 3=>nil, 2=>nil}], 1=>[{4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, {4=>nil, 3=>nil, 2=>nil, 1=>nil}], 0=>[{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}], 7=>[{6=>nil, 7=>:enemy}, {6=>nil, 7=>nil}], 19=>[{12=>nil, 19=>:enemy}, {12=>nil, 19=>nil}], 26=>[{12=>nil, 19=>nil, 26=>:enemy}, {12=>nil, 19=>nil, 26=>nil}], 33=>[{12=>nil, 19=>nil, 26=>nil, 33=>:enemy}, {12=>nil, 19=>nil, 26=>nil, 33=>nil}], 40=>[{12=>nil, 19=>nil, 26=>nil, 33=>nil, 40=>:enemy}, {12=>nil, 19=>nil, 26=>nil, 33=>nil, 40=>nil}], 21=>[{13=>nil, 21=>:enemy}, {13=>nil, 21=>nil}], 29=>[{13=>nil, 21=>nil, 29=>:enemy}, {13=>nil, 21=>nil, 29=>nil}], 37=>[{13=>nil, 21=>nil, 29=>nil, 37=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil}], 45=>[{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil}], 53=>[{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil}], 61=>[{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>nil}], 23=>[{14=>nil, 23=>:enemy}, {14=>nil, 23=>nil}]}, 6=>{5=>[{5=>:enemy}, {5=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 4=>[{5=>nil, 4=>:enemy}, {5=>nil, 4=>nil}], 3=>[{5=>nil, 4=>nil, 3=>:enemy}, {5=>nil, 4=>nil, 3=>nil}], 2=>[{5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, {5=>nil, 4=>nil, 3=>nil, 2=>nil}], 1=>[{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, {5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}], 0=>[{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}], 20=>[{13=>nil, 20=>:enemy}, {13=>nil, 20=>nil}], 27=>[{13=>nil, 20=>nil, 27=>:enemy}, {13=>nil, 20=>nil, 27=>nil}], 34=>[{13=>nil, 20=>nil, 27=>nil, 34=>:enemy}, {13=>nil, 20=>nil, 27=>nil, 34=>nil}], 41=>[{13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>:enemy}, {13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>nil}], 48=>[{13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>:enemy}, {13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>nil}], 22=>[{14=>nil, 22=>:enemy}, {14=>nil, 22=>nil}], 30=>[{14=>nil, 22=>nil, 30=>:enemy}, {14=>nil, 22=>nil, 30=>nil}], 38=>[{14=>nil, 22=>nil, 30=>nil, 38=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil}], 46=>[{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil}], 54=>[{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}], 62=>[{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 7=>{6=>[{6=>:enemy}, {6=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 5=>[{6=>nil, 5=>:enemy}, {6=>nil, 5=>nil}], 4=>[{6=>nil, 5=>nil, 4=>:enemy}, {6=>nil, 5=>nil, 4=>nil}], 3=>[{6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil}], 2=>[{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}], 1=>[{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}], 0=>[{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}], 21=>[{14=>nil, 21=>:enemy}, {14=>nil, 21=>nil}], 28=>[{14=>nil, 21=>nil, 28=>:enemy}, {14=>nil, 21=>nil, 28=>nil}], 35=>[{14=>nil, 21=>nil, 28=>nil, 35=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil}], 42=>[{14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil}], 49=>[{14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil}], 56=>[{14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>nil}], 23=>[{15=>nil, 23=>:enemy}, {15=>nil, 23=>nil}], 31=>[{15=>nil, 23=>nil, 31=>:enemy}, {15=>nil, 23=>nil, 31=>nil}], 39=>[{15=>nil, 23=>nil, 31=>nil, 39=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil}], 47=>[{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil}], 55=>[{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}], 63=>[{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 8=>{0=>[{0=>:enemy}, {0=>nil}], 1=>[{1=>:enemy}, {1=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 10=>[{9=>nil, 10=>:enemy}, {9=>nil, 10=>nil}], 11=>[{9=>nil, 10=>nil, 11=>:enemy}, {9=>nil, 10=>nil, 11=>nil}], 12=>[{9=>nil, 10=>nil, 11=>nil, 12=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil}], 13=>[{9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil}], 14=>[{9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}], 15=>[{9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}], 24=>[{16=>nil, 24=>:enemy}, {16=>nil, 24=>nil}], 32=>[{16=>nil, 24=>nil, 32=>:enemy}, {16=>nil, 24=>nil, 32=>nil}], 40=>[{16=>nil, 24=>nil, 32=>nil, 40=>:enemy}, {16=>nil, 24=>nil, 32=>nil, 40=>nil}], 48=>[{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, {16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil}], 56=>[{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}], 26=>[{17=>nil, 26=>:enemy}, {17=>nil, 26=>nil}], 35=>[{17=>nil, 26=>nil, 35=>:enemy}, {17=>nil, 26=>nil, 35=>nil}], 44=>[{17=>nil, 26=>nil, 35=>nil, 44=>:enemy}, {17=>nil, 26=>nil, 35=>nil, 44=>nil}], 53=>[{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, {17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil}], 62=>[{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, {17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}]}, 9=>{0=>[{0=>:enemy}, {0=>nil}], 1=>[{1=>:enemy}, {1=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 11=>[{10=>nil, 11=>:enemy}, {10=>nil, 11=>nil}], 12=>[{10=>nil, 11=>nil, 12=>:enemy}, {10=>nil, 11=>nil, 12=>nil}], 13=>[{10=>nil, 11=>nil, 12=>nil, 13=>:enemy}, {10=>nil, 11=>nil, 12=>nil, 13=>nil}], 14=>[{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, {10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}], 15=>[{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}], 25=>[{17=>nil, 25=>:enemy}, {17=>nil, 25=>nil}], 33=>[{17=>nil, 25=>nil, 33=>:enemy}, {17=>nil, 25=>nil, 33=>nil}], 41=>[{17=>nil, 25=>nil, 33=>nil, 41=>:enemy}, {17=>nil, 25=>nil, 33=>nil, 41=>nil}], 49=>[{17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, {17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil}], 57=>[{17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}], 27=>[{18=>nil, 27=>:enemy}, {18=>nil, 27=>nil}], 36=>[{18=>nil, 27=>nil, 36=>:enemy}, {18=>nil, 27=>nil, 36=>nil}], 45=>[{18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, {18=>nil, 27=>nil, 36=>nil, 45=>nil}], 54=>[{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, {18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}], 63=>[{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 10=>{1=>[{1=>:enemy}, {1=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 8=>[{9=>nil, 8=>:enemy}, {9=>nil, 8=>nil}], 12=>[{11=>nil, 12=>:enemy}, {11=>nil, 12=>nil}], 13=>[{11=>nil, 12=>nil, 13=>:enemy}, {11=>nil, 12=>nil, 13=>nil}], 14=>[{11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, {11=>nil, 12=>nil, 13=>nil, 14=>nil}], 15=>[{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}], 24=>[{17=>nil, 24=>:enemy}, {17=>nil, 24=>nil}], 26=>[{18=>nil, 26=>:enemy}, {18=>nil, 26=>nil}], 34=>[{18=>nil, 26=>nil, 34=>:enemy}, {18=>nil, 26=>nil, 34=>nil}], 42=>[{18=>nil, 26=>nil, 34=>nil, 42=>:enemy}, {18=>nil, 26=>nil, 34=>nil, 42=>nil}], 50=>[{18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>:enemy}, {18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil}], 58=>[{18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>nil}], 28=>[{19=>nil, 28=>:enemy}, {19=>nil, 28=>nil}], 37=>[{19=>nil, 28=>nil, 37=>:enemy}, {19=>nil, 28=>nil, 37=>nil}], 46=>[{19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, {19=>nil, 28=>nil, 37=>nil, 46=>nil}], 55=>[{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, {19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}]}, 11=>{2=>[{2=>:enemy}, {2=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 9=>[{10=>nil, 9=>:enemy}, {10=>nil, 9=>nil}], 8=>[{10=>nil, 9=>nil, 8=>:enemy}, {10=>nil, 9=>nil, 8=>nil}], 13=>[{12=>nil, 13=>:enemy}, {12=>nil, 13=>nil}], 14=>[{12=>nil, 13=>nil, 14=>:enemy}, {12=>nil, 13=>nil, 14=>nil}], 15=>[{12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {12=>nil, 13=>nil, 14=>nil, 15=>nil}], 25=>[{18=>nil, 25=>:enemy}, {18=>nil, 25=>nil}], 32=>[{18=>nil, 25=>nil, 32=>:enemy}, {18=>nil, 25=>nil, 32=>nil}], 27=>[{19=>nil, 27=>:enemy}, {19=>nil, 27=>nil}], 35=>[{19=>nil, 27=>nil, 35=>:enemy}, {19=>nil, 27=>nil, 35=>nil}], 43=>[{19=>nil, 27=>nil, 35=>nil, 43=>:enemy}, {19=>nil, 27=>nil, 35=>nil, 43=>nil}], 51=>[{19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>:enemy}, {19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil}], 59=>[{19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>nil}], 29=>[{20=>nil, 29=>:enemy}, {20=>nil, 29=>nil}], 38=>[{20=>nil, 29=>nil, 38=>:enemy}, {20=>nil, 29=>nil, 38=>nil}], 47=>[{20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, {20=>nil, 29=>nil, 38=>nil, 47=>nil}]}, 12=>{3=>[{3=>:enemy}, {3=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 10=>[{11=>nil, 10=>:enemy}, {11=>nil, 10=>nil}], 9=>[{11=>nil, 10=>nil, 9=>:enemy}, {11=>nil, 10=>nil, 9=>nil}], 8=>[{11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {11=>nil, 10=>nil, 9=>nil, 8=>nil}], 14=>[{13=>nil, 14=>:enemy}, {13=>nil, 14=>nil}], 15=>[{13=>nil, 14=>nil, 15=>:enemy}, {13=>nil, 14=>nil, 15=>nil}], 26=>[{19=>nil, 26=>:enemy}, {19=>nil, 26=>nil}], 33=>[{19=>nil, 26=>nil, 33=>:enemy}, {19=>nil, 26=>nil, 33=>nil}], 40=>[{19=>nil, 26=>nil, 33=>nil, 40=>:enemy}, {19=>nil, 26=>nil, 33=>nil, 40=>nil}], 28=>[{20=>nil, 28=>:enemy}, {20=>nil, 28=>nil}], 36=>[{20=>nil, 28=>nil, 36=>:enemy}, {20=>nil, 28=>nil, 36=>nil}], 44=>[{20=>nil, 28=>nil, 36=>nil, 44=>:enemy}, {20=>nil, 28=>nil, 36=>nil, 44=>nil}], 52=>[{20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>:enemy}, {20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil}], 60=>[{20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>nil}], 30=>[{21=>nil, 30=>:enemy}, {21=>nil, 30=>nil}], 39=>[{21=>nil, 30=>nil, 39=>:enemy}, {21=>nil, 30=>nil, 39=>nil}]}, 13=>{4=>[{4=>:enemy}, {4=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 11=>[{12=>nil, 11=>:enemy}, {12=>nil, 11=>nil}], 10=>[{12=>nil, 11=>nil, 10=>:enemy}, {12=>nil, 11=>nil, 10=>nil}], 9=>[{12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, {12=>nil, 11=>nil, 10=>nil, 9=>nil}], 8=>[{12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>nil}], 15=>[{14=>nil, 15=>:enemy}, {14=>nil, 15=>nil}], 27=>[{20=>nil, 27=>:enemy}, {20=>nil, 27=>nil}], 34=>[{20=>nil, 27=>nil, 34=>:enemy}, {20=>nil, 27=>nil, 34=>nil}], 41=>[{20=>nil, 27=>nil, 34=>nil, 41=>:enemy}, {20=>nil, 27=>nil, 34=>nil, 41=>nil}], 48=>[{20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>:enemy}, {20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>nil}], 29=>[{21=>nil, 29=>:enemy}, {21=>nil, 29=>nil}], 37=>[{21=>nil, 29=>nil, 37=>:enemy}, {21=>nil, 29=>nil, 37=>nil}], 45=>[{21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, {21=>nil, 29=>nil, 37=>nil, 45=>nil}], 53=>[{21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>:enemy}, {21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil}], 61=>[{21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>nil}], 31=>[{22=>nil, 31=>:enemy}, {22=>nil, 31=>nil}]}, 14=>{5=>[{5=>:enemy}, {5=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 12=>[{13=>nil, 12=>:enemy}, {13=>nil, 12=>nil}], 11=>[{13=>nil, 12=>nil, 11=>:enemy}, {13=>nil, 12=>nil, 11=>nil}], 10=>[{13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, {13=>nil, 12=>nil, 11=>nil, 10=>nil}], 9=>[{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, {13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}], 8=>[{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>nil}], 28=>[{21=>nil, 28=>:enemy}, {21=>nil, 28=>nil}], 35=>[{21=>nil, 28=>nil, 35=>:enemy}, {21=>nil, 28=>nil, 35=>nil}], 42=>[{21=>nil, 28=>nil, 35=>nil, 42=>:enemy}, {21=>nil, 28=>nil, 35=>nil, 42=>nil}], 49=>[{21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>:enemy}, {21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil}], 56=>[{21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>nil}], 30=>[{22=>nil, 30=>:enemy}, {22=>nil, 30=>nil}], 38=>[{22=>nil, 30=>nil, 38=>:enemy}, {22=>nil, 30=>nil, 38=>nil}], 46=>[{22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, {22=>nil, 30=>nil, 38=>nil, 46=>nil}], 54=>[{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, {22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}], 62=>[{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 15=>{6=>[{6=>:enemy}, {6=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 13=>[{14=>nil, 13=>:enemy}, {14=>nil, 13=>nil}], 12=>[{14=>nil, 13=>nil, 12=>:enemy}, {14=>nil, 13=>nil, 12=>nil}], 11=>[{14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil}], 10=>[{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}], 9=>[{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}], 8=>[{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>nil}], 29=>[{22=>nil, 29=>:enemy}, {22=>nil, 29=>nil}], 36=>[{22=>nil, 29=>nil, 36=>:enemy}, {22=>nil, 29=>nil, 36=>nil}], 43=>[{22=>nil, 29=>nil, 36=>nil, 43=>:enemy}, {22=>nil, 29=>nil, 36=>nil, 43=>nil}], 50=>[{22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>:enemy}, {22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>nil}], 57=>[{22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>:enemy}, {22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>nil}], 31=>[{23=>nil, 31=>:enemy}, {23=>nil, 31=>nil}], 39=>[{23=>nil, 31=>nil, 39=>:enemy}, {23=>nil, 31=>nil, 39=>nil}], 47=>[{23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, {23=>nil, 31=>nil, 39=>nil, 47=>nil}], 55=>[{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, {23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}], 63=>[{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 16=>{8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 0=>[{8=>nil, 0=>:enemy}, {8=>nil, 0=>nil}], 2=>[{9=>nil, 2=>:enemy}, {9=>nil, 2=>nil}], 18=>[{17=>nil, 18=>:enemy}, {17=>nil, 18=>nil}], 19=>[{17=>nil, 18=>nil, 19=>:enemy}, {17=>nil, 18=>nil, 19=>nil}], 20=>[{17=>nil, 18=>nil, 19=>nil, 20=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil}], 21=>[{17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil}], 22=>[{17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil}], 23=>[{17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}], 32=>[{24=>nil, 32=>:enemy}, {24=>nil, 32=>nil}], 40=>[{24=>nil, 32=>nil, 40=>:enemy}, {24=>nil, 32=>nil, 40=>nil}], 48=>[{24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, {24=>nil, 32=>nil, 40=>nil, 48=>nil}], 56=>[{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}], 34=>[{25=>nil, 34=>:enemy}, {25=>nil, 34=>nil}], 43=>[{25=>nil, 34=>nil, 43=>:enemy}, {25=>nil, 34=>nil, 43=>nil}], 52=>[{25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, {25=>nil, 34=>nil, 43=>nil, 52=>nil}], 61=>[{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, {25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}]}, 17=>{8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 1=>[{9=>nil, 1=>:enemy}, {9=>nil, 1=>nil}], 3=>[{10=>nil, 3=>:enemy}, {10=>nil, 3=>nil}], 19=>[{18=>nil, 19=>:enemy}, {18=>nil, 19=>nil}], 20=>[{18=>nil, 19=>nil, 20=>:enemy}, {18=>nil, 19=>nil, 20=>nil}], 21=>[{18=>nil, 19=>nil, 20=>nil, 21=>:enemy}, {18=>nil, 19=>nil, 20=>nil, 21=>nil}], 22=>[{18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, {18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil}], 23=>[{18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}], 33=>[{25=>nil, 33=>:enemy}, {25=>nil, 33=>nil}], 41=>[{25=>nil, 33=>nil, 41=>:enemy}, {25=>nil, 33=>nil, 41=>nil}], 49=>[{25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, {25=>nil, 33=>nil, 41=>nil, 49=>nil}], 57=>[{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}], 35=>[{26=>nil, 35=>:enemy}, {26=>nil, 35=>nil}], 44=>[{26=>nil, 35=>nil, 44=>:enemy}, {26=>nil, 35=>nil, 44=>nil}], 53=>[{26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, {26=>nil, 35=>nil, 44=>nil, 53=>nil}], 62=>[{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, {26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}]}, 18=>{9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 0=>[{9=>nil, 0=>:enemy}, {9=>nil, 0=>nil}], 2=>[{10=>nil, 2=>:enemy}, {10=>nil, 2=>nil}], 4=>[{11=>nil, 4=>:enemy}, {11=>nil, 4=>nil}], 16=>[{17=>nil, 16=>:enemy}, {17=>nil, 16=>nil}], 20=>[{19=>nil, 20=>:enemy}, {19=>nil, 20=>nil}], 21=>[{19=>nil, 20=>nil, 21=>:enemy}, {19=>nil, 20=>nil, 21=>nil}], 22=>[{19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, {19=>nil, 20=>nil, 21=>nil, 22=>nil}], 23=>[{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}], 32=>[{25=>nil, 32=>:enemy}, {25=>nil, 32=>nil}], 34=>[{26=>nil, 34=>:enemy}, {26=>nil, 34=>nil}], 42=>[{26=>nil, 34=>nil, 42=>:enemy}, {26=>nil, 34=>nil, 42=>nil}], 50=>[{26=>nil, 34=>nil, 42=>nil, 50=>:enemy}, {26=>nil, 34=>nil, 42=>nil, 50=>nil}], 58=>[{26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>nil}], 36=>[{27=>nil, 36=>:enemy}, {27=>nil, 36=>nil}], 45=>[{27=>nil, 36=>nil, 45=>:enemy}, {27=>nil, 36=>nil, 45=>nil}], 54=>[{27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, {27=>nil, 36=>nil, 45=>nil, 54=>nil}], 63=>[{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 19=>{10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 1=>[{10=>nil, 1=>:enemy}, {10=>nil, 1=>nil}], 3=>[{11=>nil, 3=>:enemy}, {11=>nil, 3=>nil}], 5=>[{12=>nil, 5=>:enemy}, {12=>nil, 5=>nil}], 17=>[{18=>nil, 17=>:enemy}, {18=>nil, 17=>nil}], 16=>[{18=>nil, 17=>nil, 16=>:enemy}, {18=>nil, 17=>nil, 16=>nil}], 21=>[{20=>nil, 21=>:enemy}, {20=>nil, 21=>nil}], 22=>[{20=>nil, 21=>nil, 22=>:enemy}, {20=>nil, 21=>nil, 22=>nil}], 23=>[{20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {20=>nil, 21=>nil, 22=>nil, 23=>nil}], 33=>[{26=>nil, 33=>:enemy}, {26=>nil, 33=>nil}], 40=>[{26=>nil, 33=>nil, 40=>:enemy}, {26=>nil, 33=>nil, 40=>nil}], 35=>[{27=>nil, 35=>:enemy}, {27=>nil, 35=>nil}], 43=>[{27=>nil, 35=>nil, 43=>:enemy}, {27=>nil, 35=>nil, 43=>nil}], 51=>[{27=>nil, 35=>nil, 43=>nil, 51=>:enemy}, {27=>nil, 35=>nil, 43=>nil, 51=>nil}], 59=>[{27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>nil}], 37=>[{28=>nil, 37=>:enemy}, {28=>nil, 37=>nil}], 46=>[{28=>nil, 37=>nil, 46=>:enemy}, {28=>nil, 37=>nil, 46=>nil}], 55=>[{28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, {28=>nil, 37=>nil, 46=>nil, 55=>nil}]}, 20=>{11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 2=>[{11=>nil, 2=>:enemy}, {11=>nil, 2=>nil}], 4=>[{12=>nil, 4=>:enemy}, {12=>nil, 4=>nil}], 6=>[{13=>nil, 6=>:enemy}, {13=>nil, 6=>nil}], 18=>[{19=>nil, 18=>:enemy}, {19=>nil, 18=>nil}], 17=>[{19=>nil, 18=>nil, 17=>:enemy}, {19=>nil, 18=>nil, 17=>nil}], 16=>[{19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {19=>nil, 18=>nil, 17=>nil, 16=>nil}], 22=>[{21=>nil, 22=>:enemy}, {21=>nil, 22=>nil}], 23=>[{21=>nil, 22=>nil, 23=>:enemy}, {21=>nil, 22=>nil, 23=>nil}], 34=>[{27=>nil, 34=>:enemy}, {27=>nil, 34=>nil}], 41=>[{27=>nil, 34=>nil, 41=>:enemy}, {27=>nil, 34=>nil, 41=>nil}], 48=>[{27=>nil, 34=>nil, 41=>nil, 48=>:enemy}, {27=>nil, 34=>nil, 41=>nil, 48=>nil}], 36=>[{28=>nil, 36=>:enemy}, {28=>nil, 36=>nil}], 44=>[{28=>nil, 36=>nil, 44=>:enemy}, {28=>nil, 36=>nil, 44=>nil}], 52=>[{28=>nil, 36=>nil, 44=>nil, 52=>:enemy}, {28=>nil, 36=>nil, 44=>nil, 52=>nil}], 60=>[{28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>nil}], 38=>[{29=>nil, 38=>:enemy}, {29=>nil, 38=>nil}], 47=>[{29=>nil, 38=>nil, 47=>:enemy}, {29=>nil, 38=>nil, 47=>nil}]}, 21=>{12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 3=>[{12=>nil, 3=>:enemy}, {12=>nil, 3=>nil}], 5=>[{13=>nil, 5=>:enemy}, {13=>nil, 5=>nil}], 7=>[{14=>nil, 7=>:enemy}, {14=>nil, 7=>nil}], 19=>[{20=>nil, 19=>:enemy}, {20=>nil, 19=>nil}], 18=>[{20=>nil, 19=>nil, 18=>:enemy}, {20=>nil, 19=>nil, 18=>nil}], 17=>[{20=>nil, 19=>nil, 18=>nil, 17=>:enemy}, {20=>nil, 19=>nil, 18=>nil, 17=>nil}], 16=>[{20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>nil}], 23=>[{22=>nil, 23=>:enemy}, {22=>nil, 23=>nil}], 35=>[{28=>nil, 35=>:enemy}, {28=>nil, 35=>nil}], 42=>[{28=>nil, 35=>nil, 42=>:enemy}, {28=>nil, 35=>nil, 42=>nil}], 49=>[{28=>nil, 35=>nil, 42=>nil, 49=>:enemy}, {28=>nil, 35=>nil, 42=>nil, 49=>nil}], 56=>[{28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>nil}], 37=>[{29=>nil, 37=>:enemy}, {29=>nil, 37=>nil}], 45=>[{29=>nil, 37=>nil, 45=>:enemy}, {29=>nil, 37=>nil, 45=>nil}], 53=>[{29=>nil, 37=>nil, 45=>nil, 53=>:enemy}, {29=>nil, 37=>nil, 45=>nil, 53=>nil}], 61=>[{29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>nil}], 39=>[{30=>nil, 39=>:enemy}, {30=>nil, 39=>nil}]}, 22=>{13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 4=>[{13=>nil, 4=>:enemy}, {13=>nil, 4=>nil}], 6=>[{14=>nil, 6=>:enemy}, {14=>nil, 6=>nil}], 20=>[{21=>nil, 20=>:enemy}, {21=>nil, 20=>nil}], 19=>[{21=>nil, 20=>nil, 19=>:enemy}, {21=>nil, 20=>nil, 19=>nil}], 18=>[{21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, {21=>nil, 20=>nil, 19=>nil, 18=>nil}], 17=>[{21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>:enemy}, {21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil}], 16=>[{21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>nil}], 36=>[{29=>nil, 36=>:enemy}, {29=>nil, 36=>nil}], 43=>[{29=>nil, 36=>nil, 43=>:enemy}, {29=>nil, 36=>nil, 43=>nil}], 50=>[{29=>nil, 36=>nil, 43=>nil, 50=>:enemy}, {29=>nil, 36=>nil, 43=>nil, 50=>nil}], 57=>[{29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>:enemy}, {29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>nil}], 38=>[{30=>nil, 38=>:enemy}, {30=>nil, 38=>nil}], 46=>[{30=>nil, 38=>nil, 46=>:enemy}, {30=>nil, 38=>nil, 46=>nil}], 54=>[{30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, {30=>nil, 38=>nil, 46=>nil, 54=>nil}], 62=>[{30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 23=>{14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 5=>[{14=>nil, 5=>:enemy}, {14=>nil, 5=>nil}], 7=>[{15=>nil, 7=>:enemy}, {15=>nil, 7=>nil}], 21=>[{22=>nil, 21=>:enemy}, {22=>nil, 21=>nil}], 20=>[{22=>nil, 21=>nil, 20=>:enemy}, {22=>nil, 21=>nil, 20=>nil}], 19=>[{22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil}], 18=>[{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}], 17=>[{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil}], 16=>[{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>nil}], 37=>[{30=>nil, 37=>:enemy}, {30=>nil, 37=>nil}], 44=>[{30=>nil, 37=>nil, 44=>:enemy}, {30=>nil, 37=>nil, 44=>nil}], 51=>[{30=>nil, 37=>nil, 44=>nil, 51=>:enemy}, {30=>nil, 37=>nil, 44=>nil, 51=>nil}], 58=>[{30=>nil, 37=>nil, 44=>nil, 51=>nil, 58=>:enemy}, {30=>nil, 37=>nil, 44=>nil, 51=>nil, 58=>nil}], 39=>[{31=>nil, 39=>:enemy}, {31=>nil, 39=>nil}], 47=>[{31=>nil, 39=>nil, 47=>:enemy}, {31=>nil, 39=>nil, 47=>nil}], 55=>[{31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, {31=>nil, 39=>nil, 47=>nil, 55=>nil}], 63=>[{31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 24=>{16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 8=>[{16=>nil, 8=>:enemy}, {16=>nil, 8=>nil}], 0=>[{16=>nil, 8=>nil, 0=>:enemy}, {16=>nil, 8=>nil, 0=>nil}], 10=>[{17=>nil, 10=>:enemy}, {17=>nil, 10=>nil}], 3=>[{17=>nil, 10=>nil, 3=>:enemy}, {17=>nil, 10=>nil, 3=>nil}], 26=>[{25=>nil, 26=>:enemy}, {25=>nil, 26=>nil}], 27=>[{25=>nil, 26=>nil, 27=>:enemy}, {25=>nil, 26=>nil, 27=>nil}], 28=>[{25=>nil, 26=>nil, 27=>nil, 28=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil}], 29=>[{25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil}], 30=>[{25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil}], 31=>[{25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>nil}], 40=>[{32=>nil, 40=>:enemy}, {32=>nil, 40=>nil}], 48=>[{32=>nil, 40=>nil, 48=>:enemy}, {32=>nil, 40=>nil, 48=>nil}], 56=>[{32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {32=>nil, 40=>nil, 48=>nil, 56=>nil}], 42=>[{33=>nil, 42=>:enemy}, {33=>nil, 42=>nil}], 51=>[{33=>nil, 42=>nil, 51=>:enemy}, {33=>nil, 42=>nil, 51=>nil}], 60=>[{33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, {33=>nil, 42=>nil, 51=>nil, 60=>nil}]}, 25=>{16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 9=>[{17=>nil, 9=>:enemy}, {17=>nil, 9=>nil}], 1=>[{17=>nil, 9=>nil, 1=>:enemy}, {17=>nil, 9=>nil, 1=>nil}], 11=>[{18=>nil, 11=>:enemy}, {18=>nil, 11=>nil}], 4=>[{18=>nil, 11=>nil, 4=>:enemy}, {18=>nil, 11=>nil, 4=>nil}], 27=>[{26=>nil, 27=>:enemy}, {26=>nil, 27=>nil}], 28=>[{26=>nil, 27=>nil, 28=>:enemy}, {26=>nil, 27=>nil, 28=>nil}], 29=>[{26=>nil, 27=>nil, 28=>nil, 29=>:enemy}, {26=>nil, 27=>nil, 28=>nil, 29=>nil}], 30=>[{26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>:enemy}, {26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil}], 31=>[{26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>nil}], 41=>[{33=>nil, 41=>:enemy}, {33=>nil, 41=>nil}], 49=>[{33=>nil, 41=>nil, 49=>:enemy}, {33=>nil, 41=>nil, 49=>nil}], 57=>[{33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {33=>nil, 41=>nil, 49=>nil, 57=>nil}], 43=>[{34=>nil, 43=>:enemy}, {34=>nil, 43=>nil}], 52=>[{34=>nil, 43=>nil, 52=>:enemy}, {34=>nil, 43=>nil, 52=>nil}], 61=>[{34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, {34=>nil, 43=>nil, 52=>nil, 61=>nil}]}, 26=>{17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 8=>[{17=>nil, 8=>:enemy}, {17=>nil, 8=>nil}], 10=>[{18=>nil, 10=>:enemy}, {18=>nil, 10=>nil}], 2=>[{18=>nil, 10=>nil, 2=>:enemy}, {18=>nil, 10=>nil, 2=>nil}], 12=>[{19=>nil, 12=>:enemy}, {19=>nil, 12=>nil}], 5=>[{19=>nil, 12=>nil, 5=>:enemy}, {19=>nil, 12=>nil, 5=>nil}], 24=>[{25=>nil, 24=>:enemy}, {25=>nil, 24=>nil}], 28=>[{27=>nil, 28=>:enemy}, {27=>nil, 28=>nil}], 29=>[{27=>nil, 28=>nil, 29=>:enemy}, {27=>nil, 28=>nil, 29=>nil}], 30=>[{27=>nil, 28=>nil, 29=>nil, 30=>:enemy}, {27=>nil, 28=>nil, 29=>nil, 30=>nil}], 31=>[{27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>nil}], 40=>[{33=>nil, 40=>:enemy}, {33=>nil, 40=>nil}], 42=>[{34=>nil, 42=>:enemy}, {34=>nil, 42=>nil}], 50=>[{34=>nil, 42=>nil, 50=>:enemy}, {34=>nil, 42=>nil, 50=>nil}], 58=>[{34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {34=>nil, 42=>nil, 50=>nil, 58=>nil}], 44=>[{35=>nil, 44=>:enemy}, {35=>nil, 44=>nil}], 53=>[{35=>nil, 44=>nil, 53=>:enemy}, {35=>nil, 44=>nil, 53=>nil}], 62=>[{35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, {35=>nil, 44=>nil, 53=>nil, 62=>nil}]}, 27=>{18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 9=>[{18=>nil, 9=>:enemy}, {18=>nil, 9=>nil}], 0=>[{18=>nil, 9=>nil, 0=>:enemy}, {18=>nil, 9=>nil, 0=>nil}], 11=>[{19=>nil, 11=>:enemy}, {19=>nil, 11=>nil}], 3=>[{19=>nil, 11=>nil, 3=>:enemy}, {19=>nil, 11=>nil, 3=>nil}], 13=>[{20=>nil, 13=>:enemy}, {20=>nil, 13=>nil}], 6=>[{20=>nil, 13=>nil, 6=>:enemy}, {20=>nil, 13=>nil, 6=>nil}], 25=>[{26=>nil, 25=>:enemy}, {26=>nil, 25=>nil}], 24=>[{26=>nil, 25=>nil, 24=>:enemy}, {26=>nil, 25=>nil, 24=>nil}], 29=>[{28=>nil, 29=>:enemy}, {28=>nil, 29=>nil}], 30=>[{28=>nil, 29=>nil, 30=>:enemy}, {28=>nil, 29=>nil, 30=>nil}], 31=>[{28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {28=>nil, 29=>nil, 30=>nil, 31=>nil}], 41=>[{34=>nil, 41=>:enemy}, {34=>nil, 41=>nil}], 48=>[{34=>nil, 41=>nil, 48=>:enemy}, {34=>nil, 41=>nil, 48=>nil}], 43=>[{35=>nil, 43=>:enemy}, {35=>nil, 43=>nil}], 51=>[{35=>nil, 43=>nil, 51=>:enemy}, {35=>nil, 43=>nil, 51=>nil}], 59=>[{35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {35=>nil, 43=>nil, 51=>nil, 59=>nil}], 45=>[{36=>nil, 45=>:enemy}, {36=>nil, 45=>nil}], 54=>[{36=>nil, 45=>nil, 54=>:enemy}, {36=>nil, 45=>nil, 54=>nil}], 63=>[{36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 28=>{19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 10=>[{19=>nil, 10=>:enemy}, {19=>nil, 10=>nil}], 1=>[{19=>nil, 10=>nil, 1=>:enemy}, {19=>nil, 10=>nil, 1=>nil}], 12=>[{20=>nil, 12=>:enemy}, {20=>nil, 12=>nil}], 4=>[{20=>nil, 12=>nil, 4=>:enemy}, {20=>nil, 12=>nil, 4=>nil}], 14=>[{21=>nil, 14=>:enemy}, {21=>nil, 14=>nil}], 7=>[{21=>nil, 14=>nil, 7=>:enemy}, {21=>nil, 14=>nil, 7=>nil}], 26=>[{27=>nil, 26=>:enemy}, {27=>nil, 26=>nil}], 25=>[{27=>nil, 26=>nil, 25=>:enemy}, {27=>nil, 26=>nil, 25=>nil}], 24=>[{27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {27=>nil, 26=>nil, 25=>nil, 24=>nil}], 30=>[{29=>nil, 30=>:enemy}, {29=>nil, 30=>nil}], 31=>[{29=>nil, 30=>nil, 31=>:enemy}, {29=>nil, 30=>nil, 31=>nil}], 42=>[{35=>nil, 42=>:enemy}, {35=>nil, 42=>nil}], 49=>[{35=>nil, 42=>nil, 49=>:enemy}, {35=>nil, 42=>nil, 49=>nil}], 56=>[{35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {35=>nil, 42=>nil, 49=>nil, 56=>nil}], 44=>[{36=>nil, 44=>:enemy}, {36=>nil, 44=>nil}], 52=>[{36=>nil, 44=>nil, 52=>:enemy}, {36=>nil, 44=>nil, 52=>nil}], 60=>[{36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {36=>nil, 44=>nil, 52=>nil, 60=>nil}], 46=>[{37=>nil, 46=>:enemy}, {37=>nil, 46=>nil}], 55=>[{37=>nil, 46=>nil, 55=>:enemy}, {37=>nil, 46=>nil, 55=>nil}]}, 29=>{20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 11=>[{20=>nil, 11=>:enemy}, {20=>nil, 11=>nil}], 2=>[{20=>nil, 11=>nil, 2=>:enemy}, {20=>nil, 11=>nil, 2=>nil}], 13=>[{21=>nil, 13=>:enemy}, {21=>nil, 13=>nil}], 5=>[{21=>nil, 13=>nil, 5=>:enemy}, {21=>nil, 13=>nil, 5=>nil}], 15=>[{22=>nil, 15=>:enemy}, {22=>nil, 15=>nil}], 27=>[{28=>nil, 27=>:enemy}, {28=>nil, 27=>nil}], 26=>[{28=>nil, 27=>nil, 26=>:enemy}, {28=>nil, 27=>nil, 26=>nil}], 25=>[{28=>nil, 27=>nil, 26=>nil, 25=>:enemy}, {28=>nil, 27=>nil, 26=>nil, 25=>nil}], 24=>[{28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>nil}], 31=>[{30=>nil, 31=>:enemy}, {30=>nil, 31=>nil}], 43=>[{36=>nil, 43=>:enemy}, {36=>nil, 43=>nil}], 50=>[{36=>nil, 43=>nil, 50=>:enemy}, {36=>nil, 43=>nil, 50=>nil}], 57=>[{36=>nil, 43=>nil, 50=>nil, 57=>:enemy}, {36=>nil, 43=>nil, 50=>nil, 57=>nil}], 45=>[{37=>nil, 45=>:enemy}, {37=>nil, 45=>nil}], 53=>[{37=>nil, 45=>nil, 53=>:enemy}, {37=>nil, 45=>nil, 53=>nil}], 61=>[{37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {37=>nil, 45=>nil, 53=>nil, 61=>nil}], 47=>[{38=>nil, 47=>:enemy}, {38=>nil, 47=>nil}]}, 30=>{21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 12=>[{21=>nil, 12=>:enemy}, {21=>nil, 12=>nil}], 3=>[{21=>nil, 12=>nil, 3=>:enemy}, {21=>nil, 12=>nil, 3=>nil}], 14=>[{22=>nil, 14=>:enemy}, {22=>nil, 14=>nil}], 6=>[{22=>nil, 14=>nil, 6=>:enemy}, {22=>nil, 14=>nil, 6=>nil}], 28=>[{29=>nil, 28=>:enemy}, {29=>nil, 28=>nil}], 27=>[{29=>nil, 28=>nil, 27=>:enemy}, {29=>nil, 28=>nil, 27=>nil}], 26=>[{29=>nil, 28=>nil, 27=>nil, 26=>:enemy}, {29=>nil, 28=>nil, 27=>nil, 26=>nil}], 25=>[{29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>:enemy}, {29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil}], 24=>[{29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>nil}], 44=>[{37=>nil, 44=>:enemy}, {37=>nil, 44=>nil}], 51=>[{37=>nil, 44=>nil, 51=>:enemy}, {37=>nil, 44=>nil, 51=>nil}], 58=>[{37=>nil, 44=>nil, 51=>nil, 58=>:enemy}, {37=>nil, 44=>nil, 51=>nil, 58=>nil}], 46=>[{38=>nil, 46=>:enemy}, {38=>nil, 46=>nil}], 54=>[{38=>nil, 46=>nil, 54=>:enemy}, {38=>nil, 46=>nil, 54=>nil}], 62=>[{38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 31=>{22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 13=>[{22=>nil, 13=>:enemy}, {22=>nil, 13=>nil}], 4=>[{22=>nil, 13=>nil, 4=>:enemy}, {22=>nil, 13=>nil, 4=>nil}], 15=>[{23=>nil, 15=>:enemy}, {23=>nil, 15=>nil}], 7=>[{23=>nil, 15=>nil, 7=>:enemy}, {23=>nil, 15=>nil, 7=>nil}], 29=>[{30=>nil, 29=>:enemy}, {30=>nil, 29=>nil}], 28=>[{30=>nil, 29=>nil, 28=>:enemy}, {30=>nil, 29=>nil, 28=>nil}], 27=>[{30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil}], 26=>[{30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil}], 25=>[{30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil}], 24=>[{30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>nil}], 45=>[{38=>nil, 45=>:enemy}, {38=>nil, 45=>nil}], 52=>[{38=>nil, 45=>nil, 52=>:enemy}, {38=>nil, 45=>nil, 52=>nil}], 59=>[{38=>nil, 45=>nil, 52=>nil, 59=>:enemy}, {38=>nil, 45=>nil, 52=>nil, 59=>nil}], 47=>[{39=>nil, 47=>:enemy}, {39=>nil, 47=>nil}], 55=>[{39=>nil, 47=>nil, 55=>:enemy}, {39=>nil, 47=>nil, 55=>nil}], 63=>[{39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 32=>{24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 16=>[{24=>nil, 16=>:enemy}, {24=>nil, 16=>nil}], 8=>[{24=>nil, 16=>nil, 8=>:enemy}, {24=>nil, 16=>nil, 8=>nil}], 0=>[{24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {24=>nil, 16=>nil, 8=>nil, 0=>nil}], 18=>[{25=>nil, 18=>:enemy}, {25=>nil, 18=>nil}], 11=>[{25=>nil, 18=>nil, 11=>:enemy}, {25=>nil, 18=>nil, 11=>nil}], 4=>[{25=>nil, 18=>nil, 11=>nil, 4=>:enemy}, {25=>nil, 18=>nil, 11=>nil, 4=>nil}], 34=>[{33=>nil, 34=>:enemy}, {33=>nil, 34=>nil}], 35=>[{33=>nil, 34=>nil, 35=>:enemy}, {33=>nil, 34=>nil, 35=>nil}], 36=>[{33=>nil, 34=>nil, 35=>nil, 36=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil}], 37=>[{33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil}], 38=>[{33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil}], 39=>[{33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>nil}], 48=>[{40=>nil, 48=>:enemy}, {40=>nil, 48=>nil}], 56=>[{40=>nil, 48=>nil, 56=>:enemy}, {40=>nil, 48=>nil, 56=>nil}], 50=>[{41=>nil, 50=>:enemy}, {41=>nil, 50=>nil}], 59=>[{41=>nil, 50=>nil, 59=>:enemy}, {41=>nil, 50=>nil, 59=>nil}]}, 33=>{24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 17=>[{25=>nil, 17=>:enemy}, {25=>nil, 17=>nil}], 9=>[{25=>nil, 17=>nil, 9=>:enemy}, {25=>nil, 17=>nil, 9=>nil}], 1=>[{25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {25=>nil, 17=>nil, 9=>nil, 1=>nil}], 19=>[{26=>nil, 19=>:enemy}, {26=>nil, 19=>nil}], 12=>[{26=>nil, 19=>nil, 12=>:enemy}, {26=>nil, 19=>nil, 12=>nil}], 5=>[{26=>nil, 19=>nil, 12=>nil, 5=>:enemy}, {26=>nil, 19=>nil, 12=>nil, 5=>nil}], 35=>[{34=>nil, 35=>:enemy}, {34=>nil, 35=>nil}], 36=>[{34=>nil, 35=>nil, 36=>:enemy}, {34=>nil, 35=>nil, 36=>nil}], 37=>[{34=>nil, 35=>nil, 36=>nil, 37=>:enemy}, {34=>nil, 35=>nil, 36=>nil, 37=>nil}], 38=>[{34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>:enemy}, {34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil}], 39=>[{34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>nil}], 49=>[{41=>nil, 49=>:enemy}, {41=>nil, 49=>nil}], 57=>[{41=>nil, 49=>nil, 57=>:enemy}, {41=>nil, 49=>nil, 57=>nil}], 51=>[{42=>nil, 51=>:enemy}, {42=>nil, 51=>nil}], 60=>[{42=>nil, 51=>nil, 60=>:enemy}, {42=>nil, 51=>nil, 60=>nil}]}, 34=>{25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 16=>[{25=>nil, 16=>:enemy}, {25=>nil, 16=>nil}], 18=>[{26=>nil, 18=>:enemy}, {26=>nil, 18=>nil}], 10=>[{26=>nil, 18=>nil, 10=>:enemy}, {26=>nil, 18=>nil, 10=>nil}], 2=>[{26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {26=>nil, 18=>nil, 10=>nil, 2=>nil}], 20=>[{27=>nil, 20=>:enemy}, {27=>nil, 20=>nil}], 13=>[{27=>nil, 20=>nil, 13=>:enemy}, {27=>nil, 20=>nil, 13=>nil}], 6=>[{27=>nil, 20=>nil, 13=>nil, 6=>:enemy}, {27=>nil, 20=>nil, 13=>nil, 6=>nil}], 32=>[{33=>nil, 32=>:enemy}, {33=>nil, 32=>nil}], 36=>[{35=>nil, 36=>:enemy}, {35=>nil, 36=>nil}], 37=>[{35=>nil, 36=>nil, 37=>:enemy}, {35=>nil, 36=>nil, 37=>nil}], 38=>[{35=>nil, 36=>nil, 37=>nil, 38=>:enemy}, {35=>nil, 36=>nil, 37=>nil, 38=>nil}], 39=>[{35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>nil}], 48=>[{41=>nil, 48=>:enemy}, {41=>nil, 48=>nil}], 50=>[{42=>nil, 50=>:enemy}, {42=>nil, 50=>nil}], 58=>[{42=>nil, 50=>nil, 58=>:enemy}, {42=>nil, 50=>nil, 58=>nil}], 52=>[{43=>nil, 52=>:enemy}, {43=>nil, 52=>nil}], 61=>[{43=>nil, 52=>nil, 61=>:enemy}, {43=>nil, 52=>nil, 61=>nil}]}, 35=>{26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 17=>[{26=>nil, 17=>:enemy}, {26=>nil, 17=>nil}], 8=>[{26=>nil, 17=>nil, 8=>:enemy}, {26=>nil, 17=>nil, 8=>nil}], 19=>[{27=>nil, 19=>:enemy}, {27=>nil, 19=>nil}], 11=>[{27=>nil, 19=>nil, 11=>:enemy}, {27=>nil, 19=>nil, 11=>nil}], 3=>[{27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {27=>nil, 19=>nil, 11=>nil, 3=>nil}], 21=>[{28=>nil, 21=>:enemy}, {28=>nil, 21=>nil}], 14=>[{28=>nil, 21=>nil, 14=>:enemy}, {28=>nil, 21=>nil, 14=>nil}], 7=>[{28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {28=>nil, 21=>nil, 14=>nil, 7=>nil}], 33=>[{34=>nil, 33=>:enemy}, {34=>nil, 33=>nil}], 32=>[{34=>nil, 33=>nil, 32=>:enemy}, {34=>nil, 33=>nil, 32=>nil}], 37=>[{36=>nil, 37=>:enemy}, {36=>nil, 37=>nil}], 38=>[{36=>nil, 37=>nil, 38=>:enemy}, {36=>nil, 37=>nil, 38=>nil}], 39=>[{36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {36=>nil, 37=>nil, 38=>nil, 39=>nil}], 49=>[{42=>nil, 49=>:enemy}, {42=>nil, 49=>nil}], 56=>[{42=>nil, 49=>nil, 56=>:enemy}, {42=>nil, 49=>nil, 56=>nil}], 51=>[{43=>nil, 51=>:enemy}, {43=>nil, 51=>nil}], 59=>[{43=>nil, 51=>nil, 59=>:enemy}, {43=>nil, 51=>nil, 59=>nil}], 53=>[{44=>nil, 53=>:enemy}, {44=>nil, 53=>nil}], 62=>[{44=>nil, 53=>nil, 62=>:enemy}, {44=>nil, 53=>nil, 62=>nil}]}, 36=>{27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 18=>[{27=>nil, 18=>:enemy}, {27=>nil, 18=>nil}], 9=>[{27=>nil, 18=>nil, 9=>:enemy}, {27=>nil, 18=>nil, 9=>nil}], 0=>[{27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {27=>nil, 18=>nil, 9=>nil, 0=>nil}], 20=>[{28=>nil, 20=>:enemy}, {28=>nil, 20=>nil}], 12=>[{28=>nil, 20=>nil, 12=>:enemy}, {28=>nil, 20=>nil, 12=>nil}], 4=>[{28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {28=>nil, 20=>nil, 12=>nil, 4=>nil}], 22=>[{29=>nil, 22=>:enemy}, {29=>nil, 22=>nil}], 15=>[{29=>nil, 22=>nil, 15=>:enemy}, {29=>nil, 22=>nil, 15=>nil}], 34=>[{35=>nil, 34=>:enemy}, {35=>nil, 34=>nil}], 33=>[{35=>nil, 34=>nil, 33=>:enemy}, {35=>nil, 34=>nil, 33=>nil}], 32=>[{35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {35=>nil, 34=>nil, 33=>nil, 32=>nil}], 38=>[{37=>nil, 38=>:enemy}, {37=>nil, 38=>nil}], 39=>[{37=>nil, 38=>nil, 39=>:enemy}, {37=>nil, 38=>nil, 39=>nil}], 50=>[{43=>nil, 50=>:enemy}, {43=>nil, 50=>nil}], 57=>[{43=>nil, 50=>nil, 57=>:enemy}, {43=>nil, 50=>nil, 57=>nil}], 52=>[{44=>nil, 52=>:enemy}, {44=>nil, 52=>nil}], 60=>[{44=>nil, 52=>nil, 60=>:enemy}, {44=>nil, 52=>nil, 60=>nil}], 54=>[{45=>nil, 54=>:enemy}, {45=>nil, 54=>nil}], 63=>[{45=>nil, 54=>nil, 63=>:enemy}, {45=>nil, 54=>nil, 63=>nil}]}, 37=>{28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 19=>[{28=>nil, 19=>:enemy}, {28=>nil, 19=>nil}], 10=>[{28=>nil, 19=>nil, 10=>:enemy}, {28=>nil, 19=>nil, 10=>nil}], 1=>[{28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, {28=>nil, 19=>nil, 10=>nil, 1=>nil}], 21=>[{29=>nil, 21=>:enemy}, {29=>nil, 21=>nil}], 13=>[{29=>nil, 21=>nil, 13=>:enemy}, {29=>nil, 21=>nil, 13=>nil}], 5=>[{29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {29=>nil, 21=>nil, 13=>nil, 5=>nil}], 23=>[{30=>nil, 23=>:enemy}, {30=>nil, 23=>nil}], 35=>[{36=>nil, 35=>:enemy}, {36=>nil, 35=>nil}], 34=>[{36=>nil, 35=>nil, 34=>:enemy}, {36=>nil, 35=>nil, 34=>nil}], 33=>[{36=>nil, 35=>nil, 34=>nil, 33=>:enemy}, {36=>nil, 35=>nil, 34=>nil, 33=>nil}], 32=>[{36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>nil}], 39=>[{38=>nil, 39=>:enemy}, {38=>nil, 39=>nil}], 51=>[{44=>nil, 51=>:enemy}, {44=>nil, 51=>nil}], 58=>[{44=>nil, 51=>nil, 58=>:enemy}, {44=>nil, 51=>nil, 58=>nil}], 53=>[{45=>nil, 53=>:enemy}, {45=>nil, 53=>nil}], 61=>[{45=>nil, 53=>nil, 61=>:enemy}, {45=>nil, 53=>nil, 61=>nil}], 55=>[{46=>nil, 55=>:enemy}, {46=>nil, 55=>nil}]}, 38=>{29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 20=>[{29=>nil, 20=>:enemy}, {29=>nil, 20=>nil}], 11=>[{29=>nil, 20=>nil, 11=>:enemy}, {29=>nil, 20=>nil, 11=>nil}], 2=>[{29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, {29=>nil, 20=>nil, 11=>nil, 2=>nil}], 22=>[{30=>nil, 22=>:enemy}, {30=>nil, 22=>nil}], 14=>[{30=>nil, 22=>nil, 14=>:enemy}, {30=>nil, 22=>nil, 14=>nil}], 6=>[{30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {30=>nil, 22=>nil, 14=>nil, 6=>nil}], 36=>[{37=>nil, 36=>:enemy}, {37=>nil, 36=>nil}], 35=>[{37=>nil, 36=>nil, 35=>:enemy}, {37=>nil, 36=>nil, 35=>nil}], 34=>[{37=>nil, 36=>nil, 35=>nil, 34=>:enemy}, {37=>nil, 36=>nil, 35=>nil, 34=>nil}], 33=>[{37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>:enemy}, {37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil}], 32=>[{37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>nil}], 52=>[{45=>nil, 52=>:enemy}, {45=>nil, 52=>nil}], 59=>[{45=>nil, 52=>nil, 59=>:enemy}, {45=>nil, 52=>nil, 59=>nil}], 54=>[{46=>nil, 54=>:enemy}, {46=>nil, 54=>nil}], 62=>[{46=>nil, 54=>nil, 62=>:enemy}, {46=>nil, 54=>nil, 62=>nil}]}, 39=>{30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 21=>[{30=>nil, 21=>:enemy}, {30=>nil, 21=>nil}], 12=>[{30=>nil, 21=>nil, 12=>:enemy}, {30=>nil, 21=>nil, 12=>nil}], 3=>[{30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, {30=>nil, 21=>nil, 12=>nil, 3=>nil}], 23=>[{31=>nil, 23=>:enemy}, {31=>nil, 23=>nil}], 15=>[{31=>nil, 23=>nil, 15=>:enemy}, {31=>nil, 23=>nil, 15=>nil}], 7=>[{31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {31=>nil, 23=>nil, 15=>nil, 7=>nil}], 37=>[{38=>nil, 37=>:enemy}, {38=>nil, 37=>nil}], 36=>[{38=>nil, 37=>nil, 36=>:enemy}, {38=>nil, 37=>nil, 36=>nil}], 35=>[{38=>nil, 37=>nil, 36=>nil, 35=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil}], 34=>[{38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil}], 33=>[{38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil}], 32=>[{38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>nil}], 53=>[{46=>nil, 53=>:enemy}, {46=>nil, 53=>nil}], 60=>[{46=>nil, 53=>nil, 60=>:enemy}, {46=>nil, 53=>nil, 60=>nil}], 55=>[{47=>nil, 55=>:enemy}, {47=>nil, 55=>nil}], 63=>[{47=>nil, 55=>nil, 63=>:enemy}, {47=>nil, 55=>nil, 63=>nil}]}, 40=>{32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 24=>[{32=>nil, 24=>:enemy}, {32=>nil, 24=>nil}], 16=>[{32=>nil, 24=>nil, 16=>:enemy}, {32=>nil, 24=>nil, 16=>nil}], 8=>[{32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, {32=>nil, 24=>nil, 16=>nil, 8=>nil}], 0=>[{32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>nil}], 26=>[{33=>nil, 26=>:enemy}, {33=>nil, 26=>nil}], 19=>[{33=>nil, 26=>nil, 19=>:enemy}, {33=>nil, 26=>nil, 19=>nil}], 12=>[{33=>nil, 26=>nil, 19=>nil, 12=>:enemy}, {33=>nil, 26=>nil, 19=>nil, 12=>nil}], 5=>[{33=>nil, 26=>nil, 19=>nil, 12=>nil, 5=>:enemy}, {33=>nil, 26=>nil, 19=>nil, 12=>nil, 5=>nil}], 42=>[{41=>nil, 42=>:enemy}, {41=>nil, 42=>nil}], 43=>[{41=>nil, 42=>nil, 43=>:enemy}, {41=>nil, 42=>nil, 43=>nil}], 44=>[{41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil}], 45=>[{41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil}], 46=>[{41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil}], 47=>[{41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>nil}], 56=>[{48=>nil, 56=>:enemy}, {48=>nil, 56=>nil}], 58=>[{49=>nil, 58=>:enemy}, {49=>nil, 58=>nil}]}, 41=>{32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 25=>[{33=>nil, 25=>:enemy}, {33=>nil, 25=>nil}], 17=>[{33=>nil, 25=>nil, 17=>:enemy}, {33=>nil, 25=>nil, 17=>nil}], 9=>[{33=>nil, 25=>nil, 17=>nil, 9=>:enemy}, {33=>nil, 25=>nil, 17=>nil, 9=>nil}], 1=>[{33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>nil}], 27=>[{34=>nil, 27=>:enemy}, {34=>nil, 27=>nil}], 20=>[{34=>nil, 27=>nil, 20=>:enemy}, {34=>nil, 27=>nil, 20=>nil}], 13=>[{34=>nil, 27=>nil, 20=>nil, 13=>:enemy}, {34=>nil, 27=>nil, 20=>nil, 13=>nil}], 6=>[{34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>:enemy}, {34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>nil}], 43=>[{42=>nil, 43=>:enemy}, {42=>nil, 43=>nil}], 44=>[{42=>nil, 43=>nil, 44=>:enemy}, {42=>nil, 43=>nil, 44=>nil}], 45=>[{42=>nil, 43=>nil, 44=>nil, 45=>:enemy}, {42=>nil, 43=>nil, 44=>nil, 45=>nil}], 46=>[{42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>:enemy}, {42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil}], 47=>[{42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>nil}], 57=>[{49=>nil, 57=>:enemy}, {49=>nil, 57=>nil}], 59=>[{50=>nil, 59=>:enemy}, {50=>nil, 59=>nil}]}, 42=>{33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 24=>[{33=>nil, 24=>:enemy}, {33=>nil, 24=>nil}], 26=>[{34=>nil, 26=>:enemy}, {34=>nil, 26=>nil}], 18=>[{34=>nil, 26=>nil, 18=>:enemy}, {34=>nil, 26=>nil, 18=>nil}], 10=>[{34=>nil, 26=>nil, 18=>nil, 10=>:enemy}, {34=>nil, 26=>nil, 18=>nil, 10=>nil}], 2=>[{34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>nil}], 28=>[{35=>nil, 28=>:enemy}, {35=>nil, 28=>nil}], 21=>[{35=>nil, 28=>nil, 21=>:enemy}, {35=>nil, 28=>nil, 21=>nil}], 14=>[{35=>nil, 28=>nil, 21=>nil, 14=>:enemy}, {35=>nil, 28=>nil, 21=>nil, 14=>nil}], 7=>[{35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>nil}], 40=>[{41=>nil, 40=>:enemy}, {41=>nil, 40=>nil}], 44=>[{43=>nil, 44=>:enemy}, {43=>nil, 44=>nil}], 45=>[{43=>nil, 44=>nil, 45=>:enemy}, {43=>nil, 44=>nil, 45=>nil}], 46=>[{43=>nil, 44=>nil, 45=>nil, 46=>:enemy}, {43=>nil, 44=>nil, 45=>nil, 46=>nil}], 47=>[{43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>nil}], 56=>[{49=>nil, 56=>:enemy}, {49=>nil, 56=>nil}], 58=>[{50=>nil, 58=>:enemy}, {50=>nil, 58=>nil}], 60=>[{51=>nil, 60=>:enemy}, {51=>nil, 60=>nil}]}, 43=>{34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 25=>[{34=>nil, 25=>:enemy}, {34=>nil, 25=>nil}], 16=>[{34=>nil, 25=>nil, 16=>:enemy}, {34=>nil, 25=>nil, 16=>nil}], 27=>[{35=>nil, 27=>:enemy}, {35=>nil, 27=>nil}], 19=>[{35=>nil, 27=>nil, 19=>:enemy}, {35=>nil, 27=>nil, 19=>nil}], 11=>[{35=>nil, 27=>nil, 19=>nil, 11=>:enemy}, {35=>nil, 27=>nil, 19=>nil, 11=>nil}], 3=>[{35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>nil}], 29=>[{36=>nil, 29=>:enemy}, {36=>nil, 29=>nil}], 22=>[{36=>nil, 29=>nil, 22=>:enemy}, {36=>nil, 29=>nil, 22=>nil}], 15=>[{36=>nil, 29=>nil, 22=>nil, 15=>:enemy}, {36=>nil, 29=>nil, 22=>nil, 15=>nil}], 41=>[{42=>nil, 41=>:enemy}, {42=>nil, 41=>nil}], 40=>[{42=>nil, 41=>nil, 40=>:enemy}, {42=>nil, 41=>nil, 40=>nil}], 45=>[{44=>nil, 45=>:enemy}, {44=>nil, 45=>nil}], 46=>[{44=>nil, 45=>nil, 46=>:enemy}, {44=>nil, 45=>nil, 46=>nil}], 47=>[{44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {44=>nil, 45=>nil, 46=>nil, 47=>nil}], 57=>[{50=>nil, 57=>:enemy}, {50=>nil, 57=>nil}], 59=>[{51=>nil, 59=>:enemy}, {51=>nil, 59=>nil}], 61=>[{52=>nil, 61=>:enemy}, {52=>nil, 61=>nil}]}, 44=>{35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 26=>[{35=>nil, 26=>:enemy}, {35=>nil, 26=>nil}], 17=>[{35=>nil, 26=>nil, 17=>:enemy}, {35=>nil, 26=>nil, 17=>nil}], 8=>[{35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, {35=>nil, 26=>nil, 17=>nil, 8=>nil}], 28=>[{36=>nil, 28=>:enemy}, {36=>nil, 28=>nil}], 20=>[{36=>nil, 28=>nil, 20=>:enemy}, {36=>nil, 28=>nil, 20=>nil}], 12=>[{36=>nil, 28=>nil, 20=>nil, 12=>:enemy}, {36=>nil, 28=>nil, 20=>nil, 12=>nil}], 4=>[{36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>nil}], 30=>[{37=>nil, 30=>:enemy}, {37=>nil, 30=>nil}], 23=>[{37=>nil, 30=>nil, 23=>:enemy}, {37=>nil, 30=>nil, 23=>nil}], 42=>[{43=>nil, 42=>:enemy}, {43=>nil, 42=>nil}], 41=>[{43=>nil, 42=>nil, 41=>:enemy}, {43=>nil, 42=>nil, 41=>nil}], 40=>[{43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {43=>nil, 42=>nil, 41=>nil, 40=>nil}], 46=>[{45=>nil, 46=>:enemy}, {45=>nil, 46=>nil}], 47=>[{45=>nil, 46=>nil, 47=>:enemy}, {45=>nil, 46=>nil, 47=>nil}], 58=>[{51=>nil, 58=>:enemy}, {51=>nil, 58=>nil}], 60=>[{52=>nil, 60=>:enemy}, {52=>nil, 60=>nil}], 62=>[{53=>nil, 62=>:enemy}, {53=>nil, 62=>nil}]}, 45=>{36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 27=>[{36=>nil, 27=>:enemy}, {36=>nil, 27=>nil}], 18=>[{36=>nil, 27=>nil, 18=>:enemy}, {36=>nil, 27=>nil, 18=>nil}], 9=>[{36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, {36=>nil, 27=>nil, 18=>nil, 9=>nil}], 0=>[{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}], 29=>[{37=>nil, 29=>:enemy}, {37=>nil, 29=>nil}], 21=>[{37=>nil, 29=>nil, 21=>:enemy}, {37=>nil, 29=>nil, 21=>nil}], 13=>[{37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, {37=>nil, 29=>nil, 21=>nil, 13=>nil}], 5=>[{37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}], 31=>[{38=>nil, 31=>:enemy}, {38=>nil, 31=>nil}], 43=>[{44=>nil, 43=>:enemy}, {44=>nil, 43=>nil}], 42=>[{44=>nil, 43=>nil, 42=>:enemy}, {44=>nil, 43=>nil, 42=>nil}], 41=>[{44=>nil, 43=>nil, 42=>nil, 41=>:enemy}, {44=>nil, 43=>nil, 42=>nil, 41=>nil}], 40=>[{44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>nil}], 47=>[{46=>nil, 47=>:enemy}, {46=>nil, 47=>nil}], 59=>[{52=>nil, 59=>:enemy}, {52=>nil, 59=>nil}], 61=>[{53=>nil, 61=>:enemy}, {53=>nil, 61=>nil}], 63=>[{54=>nil, 63=>:enemy}, {54=>nil, 63=>nil}]}, 46=>{37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 28=>[{37=>nil, 28=>:enemy}, {37=>nil, 28=>nil}], 19=>[{37=>nil, 28=>nil, 19=>:enemy}, {37=>nil, 28=>nil, 19=>nil}], 10=>[{37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, {37=>nil, 28=>nil, 19=>nil, 10=>nil}], 1=>[{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, {37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}], 30=>[{38=>nil, 30=>:enemy}, {38=>nil, 30=>nil}], 22=>[{38=>nil, 30=>nil, 22=>:enemy}, {38=>nil, 30=>nil, 22=>nil}], 14=>[{38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, {38=>nil, 30=>nil, 22=>nil, 14=>nil}], 6=>[{38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}], 44=>[{45=>nil, 44=>:enemy}, {45=>nil, 44=>nil}], 43=>[{45=>nil, 44=>nil, 43=>:enemy}, {45=>nil, 44=>nil, 43=>nil}], 42=>[{45=>nil, 44=>nil, 43=>nil, 42=>:enemy}, {45=>nil, 44=>nil, 43=>nil, 42=>nil}], 41=>[{45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>:enemy}, {45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil}], 40=>[{45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>nil}], 60=>[{53=>nil, 60=>:enemy}, {53=>nil, 60=>nil}], 62=>[{54=>nil, 62=>:enemy}, {54=>nil, 62=>nil}]}, 47=>{38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 29=>[{38=>nil, 29=>:enemy}, {38=>nil, 29=>nil}], 20=>[{38=>nil, 29=>nil, 20=>:enemy}, {38=>nil, 29=>nil, 20=>nil}], 11=>[{38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, {38=>nil, 29=>nil, 20=>nil, 11=>nil}], 2=>[{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, {38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}], 31=>[{39=>nil, 31=>:enemy}, {39=>nil, 31=>nil}], 23=>[{39=>nil, 31=>nil, 23=>:enemy}, {39=>nil, 31=>nil, 23=>nil}], 15=>[{39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, {39=>nil, 31=>nil, 23=>nil, 15=>nil}], 7=>[{39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}], 45=>[{46=>nil, 45=>:enemy}, {46=>nil, 45=>nil}], 44=>[{46=>nil, 45=>nil, 44=>:enemy}, {46=>nil, 45=>nil, 44=>nil}], 43=>[{46=>nil, 45=>nil, 44=>nil, 43=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil}], 42=>[{46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil}], 41=>[{46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil}], 40=>[{46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>nil}], 61=>[{54=>nil, 61=>:enemy}, {54=>nil, 61=>nil}], 63=>[{55=>nil, 63=>:enemy}, {55=>nil, 63=>nil}]}, 48=>{40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 32=>[{40=>nil, 32=>:enemy}, {40=>nil, 32=>nil}], 24=>[{40=>nil, 32=>nil, 24=>:enemy}, {40=>nil, 32=>nil, 24=>nil}], 16=>[{40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, {40=>nil, 32=>nil, 24=>nil, 16=>nil}], 8=>[{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, {40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}], 0=>[{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>nil}], 34=>[{41=>nil, 34=>:enemy}, {41=>nil, 34=>nil}], 27=>[{41=>nil, 34=>nil, 27=>:enemy}, {41=>nil, 34=>nil, 27=>nil}], 20=>[{41=>nil, 34=>nil, 27=>nil, 20=>:enemy}, {41=>nil, 34=>nil, 27=>nil, 20=>nil}], 13=>[{41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>:enemy}, {41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>nil}], 6=>[{41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>:enemy}, {41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>nil}], 50=>[{49=>nil, 50=>:enemy}, {49=>nil, 50=>nil}], 51=>[{49=>nil, 50=>nil, 51=>:enemy}, {49=>nil, 50=>nil, 51=>nil}], 52=>[{49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil}], 53=>[{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}], 54=>[{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil}], 55=>[{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 49=>{40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 33=>[{41=>nil, 33=>:enemy}, {41=>nil, 33=>nil}], 25=>[{41=>nil, 33=>nil, 25=>:enemy}, {41=>nil, 33=>nil, 25=>nil}], 17=>[{41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, {41=>nil, 33=>nil, 25=>nil, 17=>nil}], 9=>[{41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>:enemy}, {41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil}], 1=>[{41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>nil}], 35=>[{42=>nil, 35=>:enemy}, {42=>nil, 35=>nil}], 28=>[{42=>nil, 35=>nil, 28=>:enemy}, {42=>nil, 35=>nil, 28=>nil}], 21=>[{42=>nil, 35=>nil, 28=>nil, 21=>:enemy}, {42=>nil, 35=>nil, 28=>nil, 21=>nil}], 14=>[{42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>:enemy}, {42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil}], 7=>[{42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>nil}], 51=>[{50=>nil, 51=>:enemy}, {50=>nil, 51=>nil}], 52=>[{50=>nil, 51=>nil, 52=>:enemy}, {50=>nil, 51=>nil, 52=>nil}], 53=>[{50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, {50=>nil, 51=>nil, 52=>nil, 53=>nil}], 54=>[{50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>:enemy}, {50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil}], 55=>[{50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 50=>{41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 32=>[{41=>nil, 32=>:enemy}, {41=>nil, 32=>nil}], 34=>[{42=>nil, 34=>:enemy}, {42=>nil, 34=>nil}], 26=>[{42=>nil, 34=>nil, 26=>:enemy}, {42=>nil, 34=>nil, 26=>nil}], 18=>[{42=>nil, 34=>nil, 26=>nil, 18=>:enemy}, {42=>nil, 34=>nil, 26=>nil, 18=>nil}], 10=>[{42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>:enemy}, {42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil}], 2=>[{42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>nil}], 36=>[{43=>nil, 36=>:enemy}, {43=>nil, 36=>nil}], 29=>[{43=>nil, 36=>nil, 29=>:enemy}, {43=>nil, 36=>nil, 29=>nil}], 22=>[{43=>nil, 36=>nil, 29=>nil, 22=>:enemy}, {43=>nil, 36=>nil, 29=>nil, 22=>nil}], 15=>[{43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>:enemy}, {43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>nil}], 48=>[{49=>nil, 48=>:enemy}, {49=>nil, 48=>nil}], 52=>[{51=>nil, 52=>:enemy}, {51=>nil, 52=>nil}], 53=>[{51=>nil, 52=>nil, 53=>:enemy}, {51=>nil, 52=>nil, 53=>nil}], 54=>[{51=>nil, 52=>nil, 53=>nil, 54=>:enemy}, {51=>nil, 52=>nil, 53=>nil, 54=>nil}], 55=>[{51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 51=>{42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 33=>[{42=>nil, 33=>:enemy}, {42=>nil, 33=>nil}], 24=>[{42=>nil, 33=>nil, 24=>:enemy}, {42=>nil, 33=>nil, 24=>nil}], 35=>[{43=>nil, 35=>:enemy}, {43=>nil, 35=>nil}], 27=>[{43=>nil, 35=>nil, 27=>:enemy}, {43=>nil, 35=>nil, 27=>nil}], 19=>[{43=>nil, 35=>nil, 27=>nil, 19=>:enemy}, {43=>nil, 35=>nil, 27=>nil, 19=>nil}], 11=>[{43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>:enemy}, {43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil}], 3=>[{43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>nil}], 37=>[{44=>nil, 37=>:enemy}, {44=>nil, 37=>nil}], 30=>[{44=>nil, 37=>nil, 30=>:enemy}, {44=>nil, 37=>nil, 30=>nil}], 23=>[{44=>nil, 37=>nil, 30=>nil, 23=>:enemy}, {44=>nil, 37=>nil, 30=>nil, 23=>nil}], 49=>[{50=>nil, 49=>:enemy}, {50=>nil, 49=>nil}], 48=>[{50=>nil, 49=>nil, 48=>:enemy}, {50=>nil, 49=>nil, 48=>nil}], 53=>[{52=>nil, 53=>:enemy}, {52=>nil, 53=>nil}], 54=>[{52=>nil, 53=>nil, 54=>:enemy}, {52=>nil, 53=>nil, 54=>nil}], 55=>[{52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 52=>{43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 34=>[{43=>nil, 34=>:enemy}, {43=>nil, 34=>nil}], 25=>[{43=>nil, 34=>nil, 25=>:enemy}, {43=>nil, 34=>nil, 25=>nil}], 16=>[{43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, {43=>nil, 34=>nil, 25=>nil, 16=>nil}], 36=>[{44=>nil, 36=>:enemy}, {44=>nil, 36=>nil}], 28=>[{44=>nil, 36=>nil, 28=>:enemy}, {44=>nil, 36=>nil, 28=>nil}], 20=>[{44=>nil, 36=>nil, 28=>nil, 20=>:enemy}, {44=>nil, 36=>nil, 28=>nil, 20=>nil}], 12=>[{44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>:enemy}, {44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil}], 4=>[{44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>nil}], 38=>[{45=>nil, 38=>:enemy}, {45=>nil, 38=>nil}], 31=>[{45=>nil, 38=>nil, 31=>:enemy}, {45=>nil, 38=>nil, 31=>nil}], 50=>[{51=>nil, 50=>:enemy}, {51=>nil, 50=>nil}], 49=>[{51=>nil, 50=>nil, 49=>:enemy}, {51=>nil, 50=>nil, 49=>nil}], 48=>[{51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {51=>nil, 50=>nil, 49=>nil, 48=>nil}], 54=>[{53=>nil, 54=>:enemy}, {53=>nil, 54=>nil}], 55=>[{53=>nil, 54=>nil, 55=>:enemy}, {53=>nil, 54=>nil, 55=>nil}]}, 53=>{44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 35=>[{44=>nil, 35=>:enemy}, {44=>nil, 35=>nil}], 26=>[{44=>nil, 35=>nil, 26=>:enemy}, {44=>nil, 35=>nil, 26=>nil}], 17=>[{44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, {44=>nil, 35=>nil, 26=>nil, 17=>nil}], 8=>[{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, {44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}], 37=>[{45=>nil, 37=>:enemy}, {45=>nil, 37=>nil}], 29=>[{45=>nil, 37=>nil, 29=>:enemy}, {45=>nil, 37=>nil, 29=>nil}], 21=>[{45=>nil, 37=>nil, 29=>nil, 21=>:enemy}, {45=>nil, 37=>nil, 29=>nil, 21=>nil}], 13=>[{45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, {45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil}], 5=>[{45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}], 39=>[{46=>nil, 39=>:enemy}, {46=>nil, 39=>nil}], 51=>[{52=>nil, 51=>:enemy}, {52=>nil, 51=>nil}], 50=>[{52=>nil, 51=>nil, 50=>:enemy}, {52=>nil, 51=>nil, 50=>nil}], 49=>[{52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, {52=>nil, 51=>nil, 50=>nil, 49=>nil}], 48=>[{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}], 55=>[{54=>nil, 55=>:enemy}, {54=>nil, 55=>nil}]}, 54=>{45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 63=>[{63=>:enemy}, {63=>nil}], 36=>[{45=>nil, 36=>:enemy}, {45=>nil, 36=>nil}], 27=>[{45=>nil, 36=>nil, 27=>:enemy}, {45=>nil, 36=>nil, 27=>nil}], 18=>[{45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, {45=>nil, 36=>nil, 27=>nil, 18=>nil}], 9=>[{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, {45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}], 0=>[{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}], 38=>[{46=>nil, 38=>:enemy}, {46=>nil, 38=>nil}], 30=>[{46=>nil, 38=>nil, 30=>:enemy}, {46=>nil, 38=>nil, 30=>nil}], 22=>[{46=>nil, 38=>nil, 30=>nil, 22=>:enemy}, {46=>nil, 38=>nil, 30=>nil, 22=>nil}], 14=>[{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, {46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil}], 6=>[{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}], 52=>[{53=>nil, 52=>:enemy}, {53=>nil, 52=>nil}], 51=>[{53=>nil, 52=>nil, 51=>:enemy}, {53=>nil, 52=>nil, 51=>nil}], 50=>[{53=>nil, 52=>nil, 51=>nil, 50=>:enemy}, {53=>nil, 52=>nil, 51=>nil, 50=>nil}], 49=>[{53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, {53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil}], 48=>[{53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}]}, 55=>{46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 63=>[{63=>:enemy}, {63=>nil}], 37=>[{46=>nil, 37=>:enemy}, {46=>nil, 37=>nil}], 28=>[{46=>nil, 37=>nil, 28=>:enemy}, {46=>nil, 37=>nil, 28=>nil}], 19=>[{46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, {46=>nil, 37=>nil, 28=>nil, 19=>nil}], 10=>[{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, {46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}], 1=>[{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, {46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}], 39=>[{47=>nil, 39=>:enemy}, {47=>nil, 39=>nil}], 31=>[{47=>nil, 39=>nil, 31=>:enemy}, {47=>nil, 39=>nil, 31=>nil}], 23=>[{47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, {47=>nil, 39=>nil, 31=>nil, 23=>nil}], 15=>[{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, {47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}], 7=>[{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}], 53=>[{54=>nil, 53=>:enemy}, {54=>nil, 53=>nil}], 52=>[{54=>nil, 53=>nil, 52=>:enemy}, {54=>nil, 53=>nil, 52=>nil}], 51=>[{54=>nil, 53=>nil, 52=>nil, 51=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil}], 50=>[{54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil}], 49=>[{54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil}], 48=>[{54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}]}, 56=>{48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 40=>[{48=>nil, 40=>:enemy}, {48=>nil, 40=>nil}], 32=>[{48=>nil, 40=>nil, 32=>:enemy}, {48=>nil, 40=>nil, 32=>nil}], 24=>[{48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil}], 16=>[{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}], 8=>[{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}], 0=>[{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>nil}], 42=>[{49=>nil, 42=>:enemy}, {49=>nil, 42=>nil}], 35=>[{49=>nil, 42=>nil, 35=>:enemy}, {49=>nil, 42=>nil, 35=>nil}], 28=>[{49=>nil, 42=>nil, 35=>nil, 28=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil}], 21=>[{49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil}], 14=>[{49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil}], 7=>[{49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>nil}], 58=>[{57=>nil, 58=>:enemy}, {57=>nil, 58=>nil}], 59=>[{57=>nil, 58=>nil, 59=>:enemy}, {57=>nil, 58=>nil, 59=>nil}], 60=>[{57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil}], 61=>[{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}], 62=>[{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}], 63=>[{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 57=>{48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 41=>[{49=>nil, 41=>:enemy}, {49=>nil, 41=>nil}], 33=>[{49=>nil, 41=>nil, 33=>:enemy}, {49=>nil, 41=>nil, 33=>nil}], 25=>[{49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil}], 17=>[{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}], 9=>[{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil}], 1=>[{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>nil}], 43=>[{50=>nil, 43=>:enemy}, {50=>nil, 43=>nil}], 36=>[{50=>nil, 43=>nil, 36=>:enemy}, {50=>nil, 43=>nil, 36=>nil}], 29=>[{50=>nil, 43=>nil, 36=>nil, 29=>:enemy}, {50=>nil, 43=>nil, 36=>nil, 29=>nil}], 22=>[{50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>:enemy}, {50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>nil}], 15=>[{50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>:enemy}, {50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>nil}], 59=>[{58=>nil, 59=>:enemy}, {58=>nil, 59=>nil}], 60=>[{58=>nil, 59=>nil, 60=>:enemy}, {58=>nil, 59=>nil, 60=>nil}], 61=>[{58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, {58=>nil, 59=>nil, 60=>nil, 61=>nil}], 62=>[{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, {58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}], 63=>[{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 58=>{49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 40=>[{49=>nil, 40=>:enemy}, {49=>nil, 40=>nil}], 42=>[{50=>nil, 42=>:enemy}, {50=>nil, 42=>nil}], 34=>[{50=>nil, 42=>nil, 34=>:enemy}, {50=>nil, 42=>nil, 34=>nil}], 26=>[{50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil}], 18=>[{50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil}], 10=>[{50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil}], 2=>[{50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>nil}], 44=>[{51=>nil, 44=>:enemy}, {51=>nil, 44=>nil}], 37=>[{51=>nil, 44=>nil, 37=>:enemy}, {51=>nil, 44=>nil, 37=>nil}], 30=>[{51=>nil, 44=>nil, 37=>nil, 30=>:enemy}, {51=>nil, 44=>nil, 37=>nil, 30=>nil}], 23=>[{51=>nil, 44=>nil, 37=>nil, 30=>nil, 23=>:enemy}, {51=>nil, 44=>nil, 37=>nil, 30=>nil, 23=>nil}], 56=>[{57=>nil, 56=>:enemy}, {57=>nil, 56=>nil}], 60=>[{59=>nil, 60=>:enemy}, {59=>nil, 60=>nil}], 61=>[{59=>nil, 60=>nil, 61=>:enemy}, {59=>nil, 60=>nil, 61=>nil}], 62=>[{59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, {59=>nil, 60=>nil, 61=>nil, 62=>nil}], 63=>[{59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 59=>{50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 41=>[{50=>nil, 41=>:enemy}, {50=>nil, 41=>nil}], 32=>[{50=>nil, 41=>nil, 32=>:enemy}, {50=>nil, 41=>nil, 32=>nil}], 43=>[{51=>nil, 43=>:enemy}, {51=>nil, 43=>nil}], 35=>[{51=>nil, 43=>nil, 35=>:enemy}, {51=>nil, 43=>nil, 35=>nil}], 27=>[{51=>nil, 43=>nil, 35=>nil, 27=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil}], 19=>[{51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil}], 11=>[{51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil}], 3=>[{51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>nil}], 45=>[{52=>nil, 45=>:enemy}, {52=>nil, 45=>nil}], 38=>[{52=>nil, 45=>nil, 38=>:enemy}, {52=>nil, 45=>nil, 38=>nil}], 31=>[{52=>nil, 45=>nil, 38=>nil, 31=>:enemy}, {52=>nil, 45=>nil, 38=>nil, 31=>nil}], 57=>[{58=>nil, 57=>:enemy}, {58=>nil, 57=>nil}], 56=>[{58=>nil, 57=>nil, 56=>:enemy}, {58=>nil, 57=>nil, 56=>nil}], 61=>[{60=>nil, 61=>:enemy}, {60=>nil, 61=>nil}], 62=>[{60=>nil, 61=>nil, 62=>:enemy}, {60=>nil, 61=>nil, 62=>nil}], 63=>[{60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 60=>{51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 42=>[{51=>nil, 42=>:enemy}, {51=>nil, 42=>nil}], 33=>[{51=>nil, 42=>nil, 33=>:enemy}, {51=>nil, 42=>nil, 33=>nil}], 24=>[{51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, {51=>nil, 42=>nil, 33=>nil, 24=>nil}], 44=>[{52=>nil, 44=>:enemy}, {52=>nil, 44=>nil}], 36=>[{52=>nil, 44=>nil, 36=>:enemy}, {52=>nil, 44=>nil, 36=>nil}], 28=>[{52=>nil, 44=>nil, 36=>nil, 28=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil}], 20=>[{52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil}], 12=>[{52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil}], 4=>[{52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>nil}], 46=>[{53=>nil, 46=>:enemy}, {53=>nil, 46=>nil}], 39=>[{53=>nil, 46=>nil, 39=>:enemy}, {53=>nil, 46=>nil, 39=>nil}], 58=>[{59=>nil, 58=>:enemy}, {59=>nil, 58=>nil}], 57=>[{59=>nil, 58=>nil, 57=>:enemy}, {59=>nil, 58=>nil, 57=>nil}], 56=>[{59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {59=>nil, 58=>nil, 57=>nil, 56=>nil}], 62=>[{61=>nil, 62=>:enemy}, {61=>nil, 62=>nil}], 63=>[{61=>nil, 62=>nil, 63=>:enemy}, {61=>nil, 62=>nil, 63=>nil}]}, 61=>{52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 43=>[{52=>nil, 43=>:enemy}, {52=>nil, 43=>nil}], 34=>[{52=>nil, 43=>nil, 34=>:enemy}, {52=>nil, 43=>nil, 34=>nil}], 25=>[{52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, {52=>nil, 43=>nil, 34=>nil, 25=>nil}], 16=>[{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, {52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}], 45=>[{53=>nil, 45=>:enemy}, {53=>nil, 45=>nil}], 37=>[{53=>nil, 45=>nil, 37=>:enemy}, {53=>nil, 45=>nil, 37=>nil}], 29=>[{53=>nil, 45=>nil, 37=>nil, 29=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil}], 21=>[{53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil}], 13=>[{53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil}], 5=>[{53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}], 47=>[{54=>nil, 47=>:enemy}, {54=>nil, 47=>nil}], 59=>[{60=>nil, 59=>:enemy}, {60=>nil, 59=>nil}], 58=>[{60=>nil, 59=>nil, 58=>:enemy}, {60=>nil, 59=>nil, 58=>nil}], 57=>[{60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, {60=>nil, 59=>nil, 58=>nil, 57=>nil}], 56=>[{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}], 63=>[{62=>nil, 63=>:enemy}, {62=>nil, 63=>nil}]}, 62=>{53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 63=>[{63=>:enemy}, {63=>nil}], 44=>[{53=>nil, 44=>:enemy}, {53=>nil, 44=>nil}], 35=>[{53=>nil, 44=>nil, 35=>:enemy}, {53=>nil, 44=>nil, 35=>nil}], 26=>[{53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, {53=>nil, 44=>nil, 35=>nil, 26=>nil}], 17=>[{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, {53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}], 8=>[{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, {53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}], 46=>[{54=>nil, 46=>:enemy}, {54=>nil, 46=>nil}], 38=>[{54=>nil, 46=>nil, 38=>:enemy}, {54=>nil, 46=>nil, 38=>nil}], 30=>[{54=>nil, 46=>nil, 38=>nil, 30=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil}], 22=>[{54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil}], 14=>[{54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil}], 6=>[{54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}], 60=>[{61=>nil, 60=>:enemy}, {61=>nil, 60=>nil}], 59=>[{61=>nil, 60=>nil, 59=>:enemy}, {61=>nil, 60=>nil, 59=>nil}], 58=>[{61=>nil, 60=>nil, 59=>nil, 58=>:enemy}, {61=>nil, 60=>nil, 59=>nil, 58=>nil}], 57=>[{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, {61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}], 56=>[{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}]}, 63=>{54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 45=>[{54=>nil, 45=>:enemy}, {54=>nil, 45=>nil}], 36=>[{54=>nil, 45=>nil, 36=>:enemy}, {54=>nil, 45=>nil, 36=>nil}], 27=>[{54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil}], 18=>[{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}], 9=>[{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}], 0=>[{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}], 47=>[{55=>nil, 47=>:enemy}, {55=>nil, 47=>nil}], 39=>[{55=>nil, 47=>nil, 39=>:enemy}, {55=>nil, 47=>nil, 39=>nil}], 31=>[{55=>nil, 47=>nil, 39=>nil, 31=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil}], 23=>[{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil}], 15=>[{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}], 7=>[{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}], 61=>[{62=>nil, 61=>:enemy}, {62=>nil, 61=>nil}], 60=>[{62=>nil, 61=>nil, 60=>:enemy}, {62=>nil, 61=>nil, 60=>nil}], 59=>[{62=>nil, 61=>nil, 60=>nil, 59=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil}], 58=>[{62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil}], 57=>[{62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}], 56=>[{62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}]}}, "C:R"=>{0=>{1=>[{1=>:enemy}, {1=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 2=>[{1=>nil, 2=>:enemy}, {1=>nil, 2=>nil}], 3=>[{1=>nil, 2=>nil, 3=>:enemy}, {1=>nil, 2=>nil, 3=>nil}], 4=>[{1=>nil, 2=>nil, 3=>nil, 4=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil}], 5=>[{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil}], 6=>[{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}], 7=>[{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}], 16=>[{8=>nil, 16=>:enemy}, {8=>nil, 16=>nil}], 24=>[{8=>nil, 16=>nil, 24=>:enemy}, {8=>nil, 16=>nil, 24=>nil}], 32=>[{8=>nil, 16=>nil, 24=>nil, 32=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil}], 40=>[{8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil}], 48=>[{8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil}], 56=>[{8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}]}, 1=>{0=>[{0=>:enemy}, {0=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 3=>[{2=>nil, 3=>:enemy}, {2=>nil, 3=>nil}], 4=>[{2=>nil, 3=>nil, 4=>:enemy}, {2=>nil, 3=>nil, 4=>nil}], 5=>[{2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, {2=>nil, 3=>nil, 4=>nil, 5=>nil}], 6=>[{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, {2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}], 7=>[{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}], 17=>[{9=>nil, 17=>:enemy}, {9=>nil, 17=>nil}], 25=>[{9=>nil, 17=>nil, 25=>:enemy}, {9=>nil, 17=>nil, 25=>nil}], 33=>[{9=>nil, 17=>nil, 25=>nil, 33=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil}], 41=>[{9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil}], 49=>[{9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil}], 57=>[{9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}]}, 2=>{1=>[{1=>:enemy}, {1=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 0=>[{1=>nil, 0=>:enemy}, {1=>nil, 0=>nil}], 4=>[{3=>nil, 4=>:enemy}, {3=>nil, 4=>nil}], 5=>[{3=>nil, 4=>nil, 5=>:enemy}, {3=>nil, 4=>nil, 5=>nil}], 6=>[{3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, {3=>nil, 4=>nil, 5=>nil, 6=>nil}], 7=>[{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}], 18=>[{10=>nil, 18=>:enemy}, {10=>nil, 18=>nil}], 26=>[{10=>nil, 18=>nil, 26=>:enemy}, {10=>nil, 18=>nil, 26=>nil}], 34=>[{10=>nil, 18=>nil, 26=>nil, 34=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil}], 42=>[{10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil}], 50=>[{10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil}], 58=>[{10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>nil}]}, 3=>{2=>[{2=>:enemy}, {2=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 1=>[{2=>nil, 1=>:enemy}, {2=>nil, 1=>nil}], 0=>[{2=>nil, 1=>nil, 0=>:enemy}, {2=>nil, 1=>nil, 0=>nil}], 5=>[{4=>nil, 5=>:enemy}, {4=>nil, 5=>nil}], 6=>[{4=>nil, 5=>nil, 6=>:enemy}, {4=>nil, 5=>nil, 6=>nil}], 7=>[{4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {4=>nil, 5=>nil, 6=>nil, 7=>nil}], 19=>[{11=>nil, 19=>:enemy}, {11=>nil, 19=>nil}], 27=>[{11=>nil, 19=>nil, 27=>:enemy}, {11=>nil, 19=>nil, 27=>nil}], 35=>[{11=>nil, 19=>nil, 27=>nil, 35=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil}], 43=>[{11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil}], 51=>[{11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil}], 59=>[{11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>nil}]}, 4=>{3=>[{3=>:enemy}, {3=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 2=>[{3=>nil, 2=>:enemy}, {3=>nil, 2=>nil}], 1=>[{3=>nil, 2=>nil, 1=>:enemy}, {3=>nil, 2=>nil, 1=>nil}], 0=>[{3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {3=>nil, 2=>nil, 1=>nil, 0=>nil}], 6=>[{5=>nil, 6=>:enemy}, {5=>nil, 6=>nil}], 7=>[{5=>nil, 6=>nil, 7=>:enemy}, {5=>nil, 6=>nil, 7=>nil}], 20=>[{12=>nil, 20=>:enemy}, {12=>nil, 20=>nil}], 28=>[{12=>nil, 20=>nil, 28=>:enemy}, {12=>nil, 20=>nil, 28=>nil}], 36=>[{12=>nil, 20=>nil, 28=>nil, 36=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil}], 44=>[{12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil}], 52=>[{12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil}], 60=>[{12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>nil}]}, 5=>{4=>[{4=>:enemy}, {4=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 3=>[{4=>nil, 3=>:enemy}, {4=>nil, 3=>nil}], 2=>[{4=>nil, 3=>nil, 2=>:enemy}, {4=>nil, 3=>nil, 2=>nil}], 1=>[{4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, {4=>nil, 3=>nil, 2=>nil, 1=>nil}], 0=>[{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}], 7=>[{6=>nil, 7=>:enemy}, {6=>nil, 7=>nil}], 21=>[{13=>nil, 21=>:enemy}, {13=>nil, 21=>nil}], 29=>[{13=>nil, 21=>nil, 29=>:enemy}, {13=>nil, 21=>nil, 29=>nil}], 37=>[{13=>nil, 21=>nil, 29=>nil, 37=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil}], 45=>[{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil}], 53=>[{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil}], 61=>[{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>nil}]}, 6=>{5=>[{5=>:enemy}, {5=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 4=>[{5=>nil, 4=>:enemy}, {5=>nil, 4=>nil}], 3=>[{5=>nil, 4=>nil, 3=>:enemy}, {5=>nil, 4=>nil, 3=>nil}], 2=>[{5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, {5=>nil, 4=>nil, 3=>nil, 2=>nil}], 1=>[{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, {5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}], 0=>[{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}], 22=>[{14=>nil, 22=>:enemy}, {14=>nil, 22=>nil}], 30=>[{14=>nil, 22=>nil, 30=>:enemy}, {14=>nil, 22=>nil, 30=>nil}], 38=>[{14=>nil, 22=>nil, 30=>nil, 38=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil}], 46=>[{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil}], 54=>[{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}], 62=>[{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 7=>{6=>[{6=>:enemy}, {6=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 5=>[{6=>nil, 5=>:enemy}, {6=>nil, 5=>nil}], 4=>[{6=>nil, 5=>nil, 4=>:enemy}, {6=>nil, 5=>nil, 4=>nil}], 3=>[{6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil}], 2=>[{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}], 1=>[{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}], 0=>[{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}], 23=>[{15=>nil, 23=>:enemy}, {15=>nil, 23=>nil}], 31=>[{15=>nil, 23=>nil, 31=>:enemy}, {15=>nil, 23=>nil, 31=>nil}], 39=>[{15=>nil, 23=>nil, 31=>nil, 39=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil}], 47=>[{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil}], 55=>[{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}], 63=>[{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 8=>{0=>[{0=>:enemy}, {0=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 10=>[{9=>nil, 10=>:enemy}, {9=>nil, 10=>nil}], 11=>[{9=>nil, 10=>nil, 11=>:enemy}, {9=>nil, 10=>nil, 11=>nil}], 12=>[{9=>nil, 10=>nil, 11=>nil, 12=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil}], 13=>[{9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil}], 14=>[{9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}], 15=>[{9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}], 24=>[{16=>nil, 24=>:enemy}, {16=>nil, 24=>nil}], 32=>[{16=>nil, 24=>nil, 32=>:enemy}, {16=>nil, 24=>nil, 32=>nil}], 40=>[{16=>nil, 24=>nil, 32=>nil, 40=>:enemy}, {16=>nil, 24=>nil, 32=>nil, 40=>nil}], 48=>[{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, {16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil}], 56=>[{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}]}, 9=>{1=>[{1=>:enemy}, {1=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 11=>[{10=>nil, 11=>:enemy}, {10=>nil, 11=>nil}], 12=>[{10=>nil, 11=>nil, 12=>:enemy}, {10=>nil, 11=>nil, 12=>nil}], 13=>[{10=>nil, 11=>nil, 12=>nil, 13=>:enemy}, {10=>nil, 11=>nil, 12=>nil, 13=>nil}], 14=>[{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, {10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}], 15=>[{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}], 25=>[{17=>nil, 25=>:enemy}, {17=>nil, 25=>nil}], 33=>[{17=>nil, 25=>nil, 33=>:enemy}, {17=>nil, 25=>nil, 33=>nil}], 41=>[{17=>nil, 25=>nil, 33=>nil, 41=>:enemy}, {17=>nil, 25=>nil, 33=>nil, 41=>nil}], 49=>[{17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, {17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil}], 57=>[{17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}]}, 10=>{2=>[{2=>:enemy}, {2=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 8=>[{9=>nil, 8=>:enemy}, {9=>nil, 8=>nil}], 12=>[{11=>nil, 12=>:enemy}, {11=>nil, 12=>nil}], 13=>[{11=>nil, 12=>nil, 13=>:enemy}, {11=>nil, 12=>nil, 13=>nil}], 14=>[{11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, {11=>nil, 12=>nil, 13=>nil, 14=>nil}], 15=>[{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}], 26=>[{18=>nil, 26=>:enemy}, {18=>nil, 26=>nil}], 34=>[{18=>nil, 26=>nil, 34=>:enemy}, {18=>nil, 26=>nil, 34=>nil}], 42=>[{18=>nil, 26=>nil, 34=>nil, 42=>:enemy}, {18=>nil, 26=>nil, 34=>nil, 42=>nil}], 50=>[{18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>:enemy}, {18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil}], 58=>[{18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>nil}]}, 11=>{3=>[{3=>:enemy}, {3=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 9=>[{10=>nil, 9=>:enemy}, {10=>nil, 9=>nil}], 8=>[{10=>nil, 9=>nil, 8=>:enemy}, {10=>nil, 9=>nil, 8=>nil}], 13=>[{12=>nil, 13=>:enemy}, {12=>nil, 13=>nil}], 14=>[{12=>nil, 13=>nil, 14=>:enemy}, {12=>nil, 13=>nil, 14=>nil}], 15=>[{12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {12=>nil, 13=>nil, 14=>nil, 15=>nil}], 27=>[{19=>nil, 27=>:enemy}, {19=>nil, 27=>nil}], 35=>[{19=>nil, 27=>nil, 35=>:enemy}, {19=>nil, 27=>nil, 35=>nil}], 43=>[{19=>nil, 27=>nil, 35=>nil, 43=>:enemy}, {19=>nil, 27=>nil, 35=>nil, 43=>nil}], 51=>[{19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>:enemy}, {19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil}], 59=>[{19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>nil}]}, 12=>{4=>[{4=>:enemy}, {4=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 10=>[{11=>nil, 10=>:enemy}, {11=>nil, 10=>nil}], 9=>[{11=>nil, 10=>nil, 9=>:enemy}, {11=>nil, 10=>nil, 9=>nil}], 8=>[{11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {11=>nil, 10=>nil, 9=>nil, 8=>nil}], 14=>[{13=>nil, 14=>:enemy}, {13=>nil, 14=>nil}], 15=>[{13=>nil, 14=>nil, 15=>:enemy}, {13=>nil, 14=>nil, 15=>nil}], 28=>[{20=>nil, 28=>:enemy}, {20=>nil, 28=>nil}], 36=>[{20=>nil, 28=>nil, 36=>:enemy}, {20=>nil, 28=>nil, 36=>nil}], 44=>[{20=>nil, 28=>nil, 36=>nil, 44=>:enemy}, {20=>nil, 28=>nil, 36=>nil, 44=>nil}], 52=>[{20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>:enemy}, {20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil}], 60=>[{20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>nil}]}, 13=>{5=>[{5=>:enemy}, {5=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 11=>[{12=>nil, 11=>:enemy}, {12=>nil, 11=>nil}], 10=>[{12=>nil, 11=>nil, 10=>:enemy}, {12=>nil, 11=>nil, 10=>nil}], 9=>[{12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, {12=>nil, 11=>nil, 10=>nil, 9=>nil}], 8=>[{12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>nil}], 15=>[{14=>nil, 15=>:enemy}, {14=>nil, 15=>nil}], 29=>[{21=>nil, 29=>:enemy}, {21=>nil, 29=>nil}], 37=>[{21=>nil, 29=>nil, 37=>:enemy}, {21=>nil, 29=>nil, 37=>nil}], 45=>[{21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, {21=>nil, 29=>nil, 37=>nil, 45=>nil}], 53=>[{21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>:enemy}, {21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil}], 61=>[{21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>nil}]}, 14=>{6=>[{6=>:enemy}, {6=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 12=>[{13=>nil, 12=>:enemy}, {13=>nil, 12=>nil}], 11=>[{13=>nil, 12=>nil, 11=>:enemy}, {13=>nil, 12=>nil, 11=>nil}], 10=>[{13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, {13=>nil, 12=>nil, 11=>nil, 10=>nil}], 9=>[{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, {13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}], 8=>[{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>nil}], 30=>[{22=>nil, 30=>:enemy}, {22=>nil, 30=>nil}], 38=>[{22=>nil, 30=>nil, 38=>:enemy}, {22=>nil, 30=>nil, 38=>nil}], 46=>[{22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, {22=>nil, 30=>nil, 38=>nil, 46=>nil}], 54=>[{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, {22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}], 62=>[{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 15=>{7=>[{7=>:enemy}, {7=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 13=>[{14=>nil, 13=>:enemy}, {14=>nil, 13=>nil}], 12=>[{14=>nil, 13=>nil, 12=>:enemy}, {14=>nil, 13=>nil, 12=>nil}], 11=>[{14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil}], 10=>[{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}], 9=>[{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}], 8=>[{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>nil}], 31=>[{23=>nil, 31=>:enemy}, {23=>nil, 31=>nil}], 39=>[{23=>nil, 31=>nil, 39=>:enemy}, {23=>nil, 31=>nil, 39=>nil}], 47=>[{23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, {23=>nil, 31=>nil, 39=>nil, 47=>nil}], 55=>[{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, {23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}], 63=>[{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 16=>{8=>[{8=>:enemy}, {8=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 0=>[{8=>nil, 0=>:enemy}, {8=>nil, 0=>nil}], 18=>[{17=>nil, 18=>:enemy}, {17=>nil, 18=>nil}], 19=>[{17=>nil, 18=>nil, 19=>:enemy}, {17=>nil, 18=>nil, 19=>nil}], 20=>[{17=>nil, 18=>nil, 19=>nil, 20=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil}], 21=>[{17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil}], 22=>[{17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil}], 23=>[{17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}], 32=>[{24=>nil, 32=>:enemy}, {24=>nil, 32=>nil}], 40=>[{24=>nil, 32=>nil, 40=>:enemy}, {24=>nil, 32=>nil, 40=>nil}], 48=>[{24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, {24=>nil, 32=>nil, 40=>nil, 48=>nil}], 56=>[{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}]}, 17=>{9=>[{9=>:enemy}, {9=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 1=>[{9=>nil, 1=>:enemy}, {9=>nil, 1=>nil}], 19=>[{18=>nil, 19=>:enemy}, {18=>nil, 19=>nil}], 20=>[{18=>nil, 19=>nil, 20=>:enemy}, {18=>nil, 19=>nil, 20=>nil}], 21=>[{18=>nil, 19=>nil, 20=>nil, 21=>:enemy}, {18=>nil, 19=>nil, 20=>nil, 21=>nil}], 22=>[{18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, {18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil}], 23=>[{18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}], 33=>[{25=>nil, 33=>:enemy}, {25=>nil, 33=>nil}], 41=>[{25=>nil, 33=>nil, 41=>:enemy}, {25=>nil, 33=>nil, 41=>nil}], 49=>[{25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, {25=>nil, 33=>nil, 41=>nil, 49=>nil}], 57=>[{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}]}, 18=>{10=>[{10=>:enemy}, {10=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 2=>[{10=>nil, 2=>:enemy}, {10=>nil, 2=>nil}], 16=>[{17=>nil, 16=>:enemy}, {17=>nil, 16=>nil}], 20=>[{19=>nil, 20=>:enemy}, {19=>nil, 20=>nil}], 21=>[{19=>nil, 20=>nil, 21=>:enemy}, {19=>nil, 20=>nil, 21=>nil}], 22=>[{19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, {19=>nil, 20=>nil, 21=>nil, 22=>nil}], 23=>[{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}], 34=>[{26=>nil, 34=>:enemy}, {26=>nil, 34=>nil}], 42=>[{26=>nil, 34=>nil, 42=>:enemy}, {26=>nil, 34=>nil, 42=>nil}], 50=>[{26=>nil, 34=>nil, 42=>nil, 50=>:enemy}, {26=>nil, 34=>nil, 42=>nil, 50=>nil}], 58=>[{26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>nil}]}, 19=>{11=>[{11=>:enemy}, {11=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 3=>[{11=>nil, 3=>:enemy}, {11=>nil, 3=>nil}], 17=>[{18=>nil, 17=>:enemy}, {18=>nil, 17=>nil}], 16=>[{18=>nil, 17=>nil, 16=>:enemy}, {18=>nil, 17=>nil, 16=>nil}], 21=>[{20=>nil, 21=>:enemy}, {20=>nil, 21=>nil}], 22=>[{20=>nil, 21=>nil, 22=>:enemy}, {20=>nil, 21=>nil, 22=>nil}], 23=>[{20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {20=>nil, 21=>nil, 22=>nil, 23=>nil}], 35=>[{27=>nil, 35=>:enemy}, {27=>nil, 35=>nil}], 43=>[{27=>nil, 35=>nil, 43=>:enemy}, {27=>nil, 35=>nil, 43=>nil}], 51=>[{27=>nil, 35=>nil, 43=>nil, 51=>:enemy}, {27=>nil, 35=>nil, 43=>nil, 51=>nil}], 59=>[{27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>nil}]}, 20=>{12=>[{12=>:enemy}, {12=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 4=>[{12=>nil, 4=>:enemy}, {12=>nil, 4=>nil}], 18=>[{19=>nil, 18=>:enemy}, {19=>nil, 18=>nil}], 17=>[{19=>nil, 18=>nil, 17=>:enemy}, {19=>nil, 18=>nil, 17=>nil}], 16=>[{19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {19=>nil, 18=>nil, 17=>nil, 16=>nil}], 22=>[{21=>nil, 22=>:enemy}, {21=>nil, 22=>nil}], 23=>[{21=>nil, 22=>nil, 23=>:enemy}, {21=>nil, 22=>nil, 23=>nil}], 36=>[{28=>nil, 36=>:enemy}, {28=>nil, 36=>nil}], 44=>[{28=>nil, 36=>nil, 44=>:enemy}, {28=>nil, 36=>nil, 44=>nil}], 52=>[{28=>nil, 36=>nil, 44=>nil, 52=>:enemy}, {28=>nil, 36=>nil, 44=>nil, 52=>nil}], 60=>[{28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>nil}]}, 21=>{13=>[{13=>:enemy}, {13=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 5=>[{13=>nil, 5=>:enemy}, {13=>nil, 5=>nil}], 19=>[{20=>nil, 19=>:enemy}, {20=>nil, 19=>nil}], 18=>[{20=>nil, 19=>nil, 18=>:enemy}, {20=>nil, 19=>nil, 18=>nil}], 17=>[{20=>nil, 19=>nil, 18=>nil, 17=>:enemy}, {20=>nil, 19=>nil, 18=>nil, 17=>nil}], 16=>[{20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>nil}], 23=>[{22=>nil, 23=>:enemy}, {22=>nil, 23=>nil}], 37=>[{29=>nil, 37=>:enemy}, {29=>nil, 37=>nil}], 45=>[{29=>nil, 37=>nil, 45=>:enemy}, {29=>nil, 37=>nil, 45=>nil}], 53=>[{29=>nil, 37=>nil, 45=>nil, 53=>:enemy}, {29=>nil, 37=>nil, 45=>nil, 53=>nil}], 61=>[{29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>nil}]}, 22=>{14=>[{14=>:enemy}, {14=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 6=>[{14=>nil, 6=>:enemy}, {14=>nil, 6=>nil}], 20=>[{21=>nil, 20=>:enemy}, {21=>nil, 20=>nil}], 19=>[{21=>nil, 20=>nil, 19=>:enemy}, {21=>nil, 20=>nil, 19=>nil}], 18=>[{21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, {21=>nil, 20=>nil, 19=>nil, 18=>nil}], 17=>[{21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>:enemy}, {21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil}], 16=>[{21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>nil}], 38=>[{30=>nil, 38=>:enemy}, {30=>nil, 38=>nil}], 46=>[{30=>nil, 38=>nil, 46=>:enemy}, {30=>nil, 38=>nil, 46=>nil}], 54=>[{30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, {30=>nil, 38=>nil, 46=>nil, 54=>nil}], 62=>[{30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 23=>{15=>[{15=>:enemy}, {15=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 7=>[{15=>nil, 7=>:enemy}, {15=>nil, 7=>nil}], 21=>[{22=>nil, 21=>:enemy}, {22=>nil, 21=>nil}], 20=>[{22=>nil, 21=>nil, 20=>:enemy}, {22=>nil, 21=>nil, 20=>nil}], 19=>[{22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil}], 18=>[{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}], 17=>[{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil}], 16=>[{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>nil}], 39=>[{31=>nil, 39=>:enemy}, {31=>nil, 39=>nil}], 47=>[{31=>nil, 39=>nil, 47=>:enemy}, {31=>nil, 39=>nil, 47=>nil}], 55=>[{31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, {31=>nil, 39=>nil, 47=>nil, 55=>nil}], 63=>[{31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 24=>{16=>[{16=>:enemy}, {16=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 8=>[{16=>nil, 8=>:enemy}, {16=>nil, 8=>nil}], 0=>[{16=>nil, 8=>nil, 0=>:enemy}, {16=>nil, 8=>nil, 0=>nil}], 26=>[{25=>nil, 26=>:enemy}, {25=>nil, 26=>nil}], 27=>[{25=>nil, 26=>nil, 27=>:enemy}, {25=>nil, 26=>nil, 27=>nil}], 28=>[{25=>nil, 26=>nil, 27=>nil, 28=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil}], 29=>[{25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil}], 30=>[{25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil}], 31=>[{25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>nil}], 40=>[{32=>nil, 40=>:enemy}, {32=>nil, 40=>nil}], 48=>[{32=>nil, 40=>nil, 48=>:enemy}, {32=>nil, 40=>nil, 48=>nil}], 56=>[{32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {32=>nil, 40=>nil, 48=>nil, 56=>nil}]}, 25=>{17=>[{17=>:enemy}, {17=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 9=>[{17=>nil, 9=>:enemy}, {17=>nil, 9=>nil}], 1=>[{17=>nil, 9=>nil, 1=>:enemy}, {17=>nil, 9=>nil, 1=>nil}], 27=>[{26=>nil, 27=>:enemy}, {26=>nil, 27=>nil}], 28=>[{26=>nil, 27=>nil, 28=>:enemy}, {26=>nil, 27=>nil, 28=>nil}], 29=>[{26=>nil, 27=>nil, 28=>nil, 29=>:enemy}, {26=>nil, 27=>nil, 28=>nil, 29=>nil}], 30=>[{26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>:enemy}, {26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil}], 31=>[{26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>nil}], 41=>[{33=>nil, 41=>:enemy}, {33=>nil, 41=>nil}], 49=>[{33=>nil, 41=>nil, 49=>:enemy}, {33=>nil, 41=>nil, 49=>nil}], 57=>[{33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {33=>nil, 41=>nil, 49=>nil, 57=>nil}]}, 26=>{18=>[{18=>:enemy}, {18=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 10=>[{18=>nil, 10=>:enemy}, {18=>nil, 10=>nil}], 2=>[{18=>nil, 10=>nil, 2=>:enemy}, {18=>nil, 10=>nil, 2=>nil}], 24=>[{25=>nil, 24=>:enemy}, {25=>nil, 24=>nil}], 28=>[{27=>nil, 28=>:enemy}, {27=>nil, 28=>nil}], 29=>[{27=>nil, 28=>nil, 29=>:enemy}, {27=>nil, 28=>nil, 29=>nil}], 30=>[{27=>nil, 28=>nil, 29=>nil, 30=>:enemy}, {27=>nil, 28=>nil, 29=>nil, 30=>nil}], 31=>[{27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>nil}], 42=>[{34=>nil, 42=>:enemy}, {34=>nil, 42=>nil}], 50=>[{34=>nil, 42=>nil, 50=>:enemy}, {34=>nil, 42=>nil, 50=>nil}], 58=>[{34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {34=>nil, 42=>nil, 50=>nil, 58=>nil}]}, 27=>{19=>[{19=>:enemy}, {19=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 11=>[{19=>nil, 11=>:enemy}, {19=>nil, 11=>nil}], 3=>[{19=>nil, 11=>nil, 3=>:enemy}, {19=>nil, 11=>nil, 3=>nil}], 25=>[{26=>nil, 25=>:enemy}, {26=>nil, 25=>nil}], 24=>[{26=>nil, 25=>nil, 24=>:enemy}, {26=>nil, 25=>nil, 24=>nil}], 29=>[{28=>nil, 29=>:enemy}, {28=>nil, 29=>nil}], 30=>[{28=>nil, 29=>nil, 30=>:enemy}, {28=>nil, 29=>nil, 30=>nil}], 31=>[{28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {28=>nil, 29=>nil, 30=>nil, 31=>nil}], 43=>[{35=>nil, 43=>:enemy}, {35=>nil, 43=>nil}], 51=>[{35=>nil, 43=>nil, 51=>:enemy}, {35=>nil, 43=>nil, 51=>nil}], 59=>[{35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {35=>nil, 43=>nil, 51=>nil, 59=>nil}]}, 28=>{20=>[{20=>:enemy}, {20=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 12=>[{20=>nil, 12=>:enemy}, {20=>nil, 12=>nil}], 4=>[{20=>nil, 12=>nil, 4=>:enemy}, {20=>nil, 12=>nil, 4=>nil}], 26=>[{27=>nil, 26=>:enemy}, {27=>nil, 26=>nil}], 25=>[{27=>nil, 26=>nil, 25=>:enemy}, {27=>nil, 26=>nil, 25=>nil}], 24=>[{27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {27=>nil, 26=>nil, 25=>nil, 24=>nil}], 30=>[{29=>nil, 30=>:enemy}, {29=>nil, 30=>nil}], 31=>[{29=>nil, 30=>nil, 31=>:enemy}, {29=>nil, 30=>nil, 31=>nil}], 44=>[{36=>nil, 44=>:enemy}, {36=>nil, 44=>nil}], 52=>[{36=>nil, 44=>nil, 52=>:enemy}, {36=>nil, 44=>nil, 52=>nil}], 60=>[{36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {36=>nil, 44=>nil, 52=>nil, 60=>nil}]}, 29=>{21=>[{21=>:enemy}, {21=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 13=>[{21=>nil, 13=>:enemy}, {21=>nil, 13=>nil}], 5=>[{21=>nil, 13=>nil, 5=>:enemy}, {21=>nil, 13=>nil, 5=>nil}], 27=>[{28=>nil, 27=>:enemy}, {28=>nil, 27=>nil}], 26=>[{28=>nil, 27=>nil, 26=>:enemy}, {28=>nil, 27=>nil, 26=>nil}], 25=>[{28=>nil, 27=>nil, 26=>nil, 25=>:enemy}, {28=>nil, 27=>nil, 26=>nil, 25=>nil}], 24=>[{28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>nil}], 31=>[{30=>nil, 31=>:enemy}, {30=>nil, 31=>nil}], 45=>[{37=>nil, 45=>:enemy}, {37=>nil, 45=>nil}], 53=>[{37=>nil, 45=>nil, 53=>:enemy}, {37=>nil, 45=>nil, 53=>nil}], 61=>[{37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {37=>nil, 45=>nil, 53=>nil, 61=>nil}]}, 30=>{22=>[{22=>:enemy}, {22=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 14=>[{22=>nil, 14=>:enemy}, {22=>nil, 14=>nil}], 6=>[{22=>nil, 14=>nil, 6=>:enemy}, {22=>nil, 14=>nil, 6=>nil}], 28=>[{29=>nil, 28=>:enemy}, {29=>nil, 28=>nil}], 27=>[{29=>nil, 28=>nil, 27=>:enemy}, {29=>nil, 28=>nil, 27=>nil}], 26=>[{29=>nil, 28=>nil, 27=>nil, 26=>:enemy}, {29=>nil, 28=>nil, 27=>nil, 26=>nil}], 25=>[{29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>:enemy}, {29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil}], 24=>[{29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>nil}], 46=>[{38=>nil, 46=>:enemy}, {38=>nil, 46=>nil}], 54=>[{38=>nil, 46=>nil, 54=>:enemy}, {38=>nil, 46=>nil, 54=>nil}], 62=>[{38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 31=>{23=>[{23=>:enemy}, {23=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 15=>[{23=>nil, 15=>:enemy}, {23=>nil, 15=>nil}], 7=>[{23=>nil, 15=>nil, 7=>:enemy}, {23=>nil, 15=>nil, 7=>nil}], 29=>[{30=>nil, 29=>:enemy}, {30=>nil, 29=>nil}], 28=>[{30=>nil, 29=>nil, 28=>:enemy}, {30=>nil, 29=>nil, 28=>nil}], 27=>[{30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil}], 26=>[{30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil}], 25=>[{30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil}], 24=>[{30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>nil}], 47=>[{39=>nil, 47=>:enemy}, {39=>nil, 47=>nil}], 55=>[{39=>nil, 47=>nil, 55=>:enemy}, {39=>nil, 47=>nil, 55=>nil}], 63=>[{39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 32=>{24=>[{24=>:enemy}, {24=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 16=>[{24=>nil, 16=>:enemy}, {24=>nil, 16=>nil}], 8=>[{24=>nil, 16=>nil, 8=>:enemy}, {24=>nil, 16=>nil, 8=>nil}], 0=>[{24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {24=>nil, 16=>nil, 8=>nil, 0=>nil}], 34=>[{33=>nil, 34=>:enemy}, {33=>nil, 34=>nil}], 35=>[{33=>nil, 34=>nil, 35=>:enemy}, {33=>nil, 34=>nil, 35=>nil}], 36=>[{33=>nil, 34=>nil, 35=>nil, 36=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil}], 37=>[{33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil}], 38=>[{33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil}], 39=>[{33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>nil}], 48=>[{40=>nil, 48=>:enemy}, {40=>nil, 48=>nil}], 56=>[{40=>nil, 48=>nil, 56=>:enemy}, {40=>nil, 48=>nil, 56=>nil}]}, 33=>{25=>[{25=>:enemy}, {25=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 17=>[{25=>nil, 17=>:enemy}, {25=>nil, 17=>nil}], 9=>[{25=>nil, 17=>nil, 9=>:enemy}, {25=>nil, 17=>nil, 9=>nil}], 1=>[{25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {25=>nil, 17=>nil, 9=>nil, 1=>nil}], 35=>[{34=>nil, 35=>:enemy}, {34=>nil, 35=>nil}], 36=>[{34=>nil, 35=>nil, 36=>:enemy}, {34=>nil, 35=>nil, 36=>nil}], 37=>[{34=>nil, 35=>nil, 36=>nil, 37=>:enemy}, {34=>nil, 35=>nil, 36=>nil, 37=>nil}], 38=>[{34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>:enemy}, {34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil}], 39=>[{34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>nil}], 49=>[{41=>nil, 49=>:enemy}, {41=>nil, 49=>nil}], 57=>[{41=>nil, 49=>nil, 57=>:enemy}, {41=>nil, 49=>nil, 57=>nil}]}, 34=>{26=>[{26=>:enemy}, {26=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 18=>[{26=>nil, 18=>:enemy}, {26=>nil, 18=>nil}], 10=>[{26=>nil, 18=>nil, 10=>:enemy}, {26=>nil, 18=>nil, 10=>nil}], 2=>[{26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {26=>nil, 18=>nil, 10=>nil, 2=>nil}], 32=>[{33=>nil, 32=>:enemy}, {33=>nil, 32=>nil}], 36=>[{35=>nil, 36=>:enemy}, {35=>nil, 36=>nil}], 37=>[{35=>nil, 36=>nil, 37=>:enemy}, {35=>nil, 36=>nil, 37=>nil}], 38=>[{35=>nil, 36=>nil, 37=>nil, 38=>:enemy}, {35=>nil, 36=>nil, 37=>nil, 38=>nil}], 39=>[{35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>nil}], 50=>[{42=>nil, 50=>:enemy}, {42=>nil, 50=>nil}], 58=>[{42=>nil, 50=>nil, 58=>:enemy}, {42=>nil, 50=>nil, 58=>nil}]}, 35=>{27=>[{27=>:enemy}, {27=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 19=>[{27=>nil, 19=>:enemy}, {27=>nil, 19=>nil}], 11=>[{27=>nil, 19=>nil, 11=>:enemy}, {27=>nil, 19=>nil, 11=>nil}], 3=>[{27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {27=>nil, 19=>nil, 11=>nil, 3=>nil}], 33=>[{34=>nil, 33=>:enemy}, {34=>nil, 33=>nil}], 32=>[{34=>nil, 33=>nil, 32=>:enemy}, {34=>nil, 33=>nil, 32=>nil}], 37=>[{36=>nil, 37=>:enemy}, {36=>nil, 37=>nil}], 38=>[{36=>nil, 37=>nil, 38=>:enemy}, {36=>nil, 37=>nil, 38=>nil}], 39=>[{36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {36=>nil, 37=>nil, 38=>nil, 39=>nil}], 51=>[{43=>nil, 51=>:enemy}, {43=>nil, 51=>nil}], 59=>[{43=>nil, 51=>nil, 59=>:enemy}, {43=>nil, 51=>nil, 59=>nil}]}, 36=>{28=>[{28=>:enemy}, {28=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 20=>[{28=>nil, 20=>:enemy}, {28=>nil, 20=>nil}], 12=>[{28=>nil, 20=>nil, 12=>:enemy}, {28=>nil, 20=>nil, 12=>nil}], 4=>[{28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {28=>nil, 20=>nil, 12=>nil, 4=>nil}], 34=>[{35=>nil, 34=>:enemy}, {35=>nil, 34=>nil}], 33=>[{35=>nil, 34=>nil, 33=>:enemy}, {35=>nil, 34=>nil, 33=>nil}], 32=>[{35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {35=>nil, 34=>nil, 33=>nil, 32=>nil}], 38=>[{37=>nil, 38=>:enemy}, {37=>nil, 38=>nil}], 39=>[{37=>nil, 38=>nil, 39=>:enemy}, {37=>nil, 38=>nil, 39=>nil}], 52=>[{44=>nil, 52=>:enemy}, {44=>nil, 52=>nil}], 60=>[{44=>nil, 52=>nil, 60=>:enemy}, {44=>nil, 52=>nil, 60=>nil}]}, 37=>{29=>[{29=>:enemy}, {29=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 21=>[{29=>nil, 21=>:enemy}, {29=>nil, 21=>nil}], 13=>[{29=>nil, 21=>nil, 13=>:enemy}, {29=>nil, 21=>nil, 13=>nil}], 5=>[{29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {29=>nil, 21=>nil, 13=>nil, 5=>nil}], 35=>[{36=>nil, 35=>:enemy}, {36=>nil, 35=>nil}], 34=>[{36=>nil, 35=>nil, 34=>:enemy}, {36=>nil, 35=>nil, 34=>nil}], 33=>[{36=>nil, 35=>nil, 34=>nil, 33=>:enemy}, {36=>nil, 35=>nil, 34=>nil, 33=>nil}], 32=>[{36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>nil}], 39=>[{38=>nil, 39=>:enemy}, {38=>nil, 39=>nil}], 53=>[{45=>nil, 53=>:enemy}, {45=>nil, 53=>nil}], 61=>[{45=>nil, 53=>nil, 61=>:enemy}, {45=>nil, 53=>nil, 61=>nil}]}, 38=>{30=>[{30=>:enemy}, {30=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 22=>[{30=>nil, 22=>:enemy}, {30=>nil, 22=>nil}], 14=>[{30=>nil, 22=>nil, 14=>:enemy}, {30=>nil, 22=>nil, 14=>nil}], 6=>[{30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {30=>nil, 22=>nil, 14=>nil, 6=>nil}], 36=>[{37=>nil, 36=>:enemy}, {37=>nil, 36=>nil}], 35=>[{37=>nil, 36=>nil, 35=>:enemy}, {37=>nil, 36=>nil, 35=>nil}], 34=>[{37=>nil, 36=>nil, 35=>nil, 34=>:enemy}, {37=>nil, 36=>nil, 35=>nil, 34=>nil}], 33=>[{37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>:enemy}, {37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil}], 32=>[{37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>nil}], 54=>[{46=>nil, 54=>:enemy}, {46=>nil, 54=>nil}], 62=>[{46=>nil, 54=>nil, 62=>:enemy}, {46=>nil, 54=>nil, 62=>nil}]}, 39=>{31=>[{31=>:enemy}, {31=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 23=>[{31=>nil, 23=>:enemy}, {31=>nil, 23=>nil}], 15=>[{31=>nil, 23=>nil, 15=>:enemy}, {31=>nil, 23=>nil, 15=>nil}], 7=>[{31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {31=>nil, 23=>nil, 15=>nil, 7=>nil}], 37=>[{38=>nil, 37=>:enemy}, {38=>nil, 37=>nil}], 36=>[{38=>nil, 37=>nil, 36=>:enemy}, {38=>nil, 37=>nil, 36=>nil}], 35=>[{38=>nil, 37=>nil, 36=>nil, 35=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil}], 34=>[{38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil}], 33=>[{38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil}], 32=>[{38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>nil}], 55=>[{47=>nil, 55=>:enemy}, {47=>nil, 55=>nil}], 63=>[{47=>nil, 55=>nil, 63=>:enemy}, {47=>nil, 55=>nil, 63=>nil}]}, 40=>{32=>[{32=>:enemy}, {32=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 24=>[{32=>nil, 24=>:enemy}, {32=>nil, 24=>nil}], 16=>[{32=>nil, 24=>nil, 16=>:enemy}, {32=>nil, 24=>nil, 16=>nil}], 8=>[{32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, {32=>nil, 24=>nil, 16=>nil, 8=>nil}], 0=>[{32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>nil}], 42=>[{41=>nil, 42=>:enemy}, {41=>nil, 42=>nil}], 43=>[{41=>nil, 42=>nil, 43=>:enemy}, {41=>nil, 42=>nil, 43=>nil}], 44=>[{41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil}], 45=>[{41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil}], 46=>[{41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil}], 47=>[{41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>nil}], 56=>[{48=>nil, 56=>:enemy}, {48=>nil, 56=>nil}]}, 41=>{33=>[{33=>:enemy}, {33=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 25=>[{33=>nil, 25=>:enemy}, {33=>nil, 25=>nil}], 17=>[{33=>nil, 25=>nil, 17=>:enemy}, {33=>nil, 25=>nil, 17=>nil}], 9=>[{33=>nil, 25=>nil, 17=>nil, 9=>:enemy}, {33=>nil, 25=>nil, 17=>nil, 9=>nil}], 1=>[{33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>nil}], 43=>[{42=>nil, 43=>:enemy}, {42=>nil, 43=>nil}], 44=>[{42=>nil, 43=>nil, 44=>:enemy}, {42=>nil, 43=>nil, 44=>nil}], 45=>[{42=>nil, 43=>nil, 44=>nil, 45=>:enemy}, {42=>nil, 43=>nil, 44=>nil, 45=>nil}], 46=>[{42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>:enemy}, {42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil}], 47=>[{42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>nil}], 57=>[{49=>nil, 57=>:enemy}, {49=>nil, 57=>nil}]}, 42=>{34=>[{34=>:enemy}, {34=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 26=>[{34=>nil, 26=>:enemy}, {34=>nil, 26=>nil}], 18=>[{34=>nil, 26=>nil, 18=>:enemy}, {34=>nil, 26=>nil, 18=>nil}], 10=>[{34=>nil, 26=>nil, 18=>nil, 10=>:enemy}, {34=>nil, 26=>nil, 18=>nil, 10=>nil}], 2=>[{34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>nil}], 40=>[{41=>nil, 40=>:enemy}, {41=>nil, 40=>nil}], 44=>[{43=>nil, 44=>:enemy}, {43=>nil, 44=>nil}], 45=>[{43=>nil, 44=>nil, 45=>:enemy}, {43=>nil, 44=>nil, 45=>nil}], 46=>[{43=>nil, 44=>nil, 45=>nil, 46=>:enemy}, {43=>nil, 44=>nil, 45=>nil, 46=>nil}], 47=>[{43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>nil}], 58=>[{50=>nil, 58=>:enemy}, {50=>nil, 58=>nil}]}, 43=>{35=>[{35=>:enemy}, {35=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 27=>[{35=>nil, 27=>:enemy}, {35=>nil, 27=>nil}], 19=>[{35=>nil, 27=>nil, 19=>:enemy}, {35=>nil, 27=>nil, 19=>nil}], 11=>[{35=>nil, 27=>nil, 19=>nil, 11=>:enemy}, {35=>nil, 27=>nil, 19=>nil, 11=>nil}], 3=>[{35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>nil}], 41=>[{42=>nil, 41=>:enemy}, {42=>nil, 41=>nil}], 40=>[{42=>nil, 41=>nil, 40=>:enemy}, {42=>nil, 41=>nil, 40=>nil}], 45=>[{44=>nil, 45=>:enemy}, {44=>nil, 45=>nil}], 46=>[{44=>nil, 45=>nil, 46=>:enemy}, {44=>nil, 45=>nil, 46=>nil}], 47=>[{44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {44=>nil, 45=>nil, 46=>nil, 47=>nil}], 59=>[{51=>nil, 59=>:enemy}, {51=>nil, 59=>nil}]}, 44=>{36=>[{36=>:enemy}, {36=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 28=>[{36=>nil, 28=>:enemy}, {36=>nil, 28=>nil}], 20=>[{36=>nil, 28=>nil, 20=>:enemy}, {36=>nil, 28=>nil, 20=>nil}], 12=>[{36=>nil, 28=>nil, 20=>nil, 12=>:enemy}, {36=>nil, 28=>nil, 20=>nil, 12=>nil}], 4=>[{36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>nil}], 42=>[{43=>nil, 42=>:enemy}, {43=>nil, 42=>nil}], 41=>[{43=>nil, 42=>nil, 41=>:enemy}, {43=>nil, 42=>nil, 41=>nil}], 40=>[{43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {43=>nil, 42=>nil, 41=>nil, 40=>nil}], 46=>[{45=>nil, 46=>:enemy}, {45=>nil, 46=>nil}], 47=>[{45=>nil, 46=>nil, 47=>:enemy}, {45=>nil, 46=>nil, 47=>nil}], 60=>[{52=>nil, 60=>:enemy}, {52=>nil, 60=>nil}]}, 45=>{37=>[{37=>:enemy}, {37=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 29=>[{37=>nil, 29=>:enemy}, {37=>nil, 29=>nil}], 21=>[{37=>nil, 29=>nil, 21=>:enemy}, {37=>nil, 29=>nil, 21=>nil}], 13=>[{37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, {37=>nil, 29=>nil, 21=>nil, 13=>nil}], 5=>[{37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}], 43=>[{44=>nil, 43=>:enemy}, {44=>nil, 43=>nil}], 42=>[{44=>nil, 43=>nil, 42=>:enemy}, {44=>nil, 43=>nil, 42=>nil}], 41=>[{44=>nil, 43=>nil, 42=>nil, 41=>:enemy}, {44=>nil, 43=>nil, 42=>nil, 41=>nil}], 40=>[{44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>nil}], 47=>[{46=>nil, 47=>:enemy}, {46=>nil, 47=>nil}], 61=>[{53=>nil, 61=>:enemy}, {53=>nil, 61=>nil}]}, 46=>{38=>[{38=>:enemy}, {38=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 30=>[{38=>nil, 30=>:enemy}, {38=>nil, 30=>nil}], 22=>[{38=>nil, 30=>nil, 22=>:enemy}, {38=>nil, 30=>nil, 22=>nil}], 14=>[{38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, {38=>nil, 30=>nil, 22=>nil, 14=>nil}], 6=>[{38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}], 44=>[{45=>nil, 44=>:enemy}, {45=>nil, 44=>nil}], 43=>[{45=>nil, 44=>nil, 43=>:enemy}, {45=>nil, 44=>nil, 43=>nil}], 42=>[{45=>nil, 44=>nil, 43=>nil, 42=>:enemy}, {45=>nil, 44=>nil, 43=>nil, 42=>nil}], 41=>[{45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>:enemy}, {45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil}], 40=>[{45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>nil}], 62=>[{54=>nil, 62=>:enemy}, {54=>nil, 62=>nil}]}, 47=>{39=>[{39=>:enemy}, {39=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 31=>[{39=>nil, 31=>:enemy}, {39=>nil, 31=>nil}], 23=>[{39=>nil, 31=>nil, 23=>:enemy}, {39=>nil, 31=>nil, 23=>nil}], 15=>[{39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, {39=>nil, 31=>nil, 23=>nil, 15=>nil}], 7=>[{39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}], 45=>[{46=>nil, 45=>:enemy}, {46=>nil, 45=>nil}], 44=>[{46=>nil, 45=>nil, 44=>:enemy}, {46=>nil, 45=>nil, 44=>nil}], 43=>[{46=>nil, 45=>nil, 44=>nil, 43=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil}], 42=>[{46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil}], 41=>[{46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil}], 40=>[{46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>nil}], 63=>[{55=>nil, 63=>:enemy}, {55=>nil, 63=>nil}]}, 48=>{40=>[{40=>:enemy}, {40=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 32=>[{40=>nil, 32=>:enemy}, {40=>nil, 32=>nil}], 24=>[{40=>nil, 32=>nil, 24=>:enemy}, {40=>nil, 32=>nil, 24=>nil}], 16=>[{40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, {40=>nil, 32=>nil, 24=>nil, 16=>nil}], 8=>[{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, {40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}], 0=>[{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>nil}], 50=>[{49=>nil, 50=>:enemy}, {49=>nil, 50=>nil}], 51=>[{49=>nil, 50=>nil, 51=>:enemy}, {49=>nil, 50=>nil, 51=>nil}], 52=>[{49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil}], 53=>[{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}], 54=>[{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil}], 55=>[{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 49=>{41=>[{41=>:enemy}, {41=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 33=>[{41=>nil, 33=>:enemy}, {41=>nil, 33=>nil}], 25=>[{41=>nil, 33=>nil, 25=>:enemy}, {41=>nil, 33=>nil, 25=>nil}], 17=>[{41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, {41=>nil, 33=>nil, 25=>nil, 17=>nil}], 9=>[{41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>:enemy}, {41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil}], 1=>[{41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>nil}], 51=>[{50=>nil, 51=>:enemy}, {50=>nil, 51=>nil}], 52=>[{50=>nil, 51=>nil, 52=>:enemy}, {50=>nil, 51=>nil, 52=>nil}], 53=>[{50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, {50=>nil, 51=>nil, 52=>nil, 53=>nil}], 54=>[{50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>:enemy}, {50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil}], 55=>[{50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 50=>{42=>[{42=>:enemy}, {42=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 34=>[{42=>nil, 34=>:enemy}, {42=>nil, 34=>nil}], 26=>[{42=>nil, 34=>nil, 26=>:enemy}, {42=>nil, 34=>nil, 26=>nil}], 18=>[{42=>nil, 34=>nil, 26=>nil, 18=>:enemy}, {42=>nil, 34=>nil, 26=>nil, 18=>nil}], 10=>[{42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>:enemy}, {42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil}], 2=>[{42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>nil}], 48=>[{49=>nil, 48=>:enemy}, {49=>nil, 48=>nil}], 52=>[{51=>nil, 52=>:enemy}, {51=>nil, 52=>nil}], 53=>[{51=>nil, 52=>nil, 53=>:enemy}, {51=>nil, 52=>nil, 53=>nil}], 54=>[{51=>nil, 52=>nil, 53=>nil, 54=>:enemy}, {51=>nil, 52=>nil, 53=>nil, 54=>nil}], 55=>[{51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 51=>{43=>[{43=>:enemy}, {43=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 35=>[{43=>nil, 35=>:enemy}, {43=>nil, 35=>nil}], 27=>[{43=>nil, 35=>nil, 27=>:enemy}, {43=>nil, 35=>nil, 27=>nil}], 19=>[{43=>nil, 35=>nil, 27=>nil, 19=>:enemy}, {43=>nil, 35=>nil, 27=>nil, 19=>nil}], 11=>[{43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>:enemy}, {43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil}], 3=>[{43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>nil}], 49=>[{50=>nil, 49=>:enemy}, {50=>nil, 49=>nil}], 48=>[{50=>nil, 49=>nil, 48=>:enemy}, {50=>nil, 49=>nil, 48=>nil}], 53=>[{52=>nil, 53=>:enemy}, {52=>nil, 53=>nil}], 54=>[{52=>nil, 53=>nil, 54=>:enemy}, {52=>nil, 53=>nil, 54=>nil}], 55=>[{52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 52=>{44=>[{44=>:enemy}, {44=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 36=>[{44=>nil, 36=>:enemy}, {44=>nil, 36=>nil}], 28=>[{44=>nil, 36=>nil, 28=>:enemy}, {44=>nil, 36=>nil, 28=>nil}], 20=>[{44=>nil, 36=>nil, 28=>nil, 20=>:enemy}, {44=>nil, 36=>nil, 28=>nil, 20=>nil}], 12=>[{44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>:enemy}, {44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil}], 4=>[{44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>nil}], 50=>[{51=>nil, 50=>:enemy}, {51=>nil, 50=>nil}], 49=>[{51=>nil, 50=>nil, 49=>:enemy}, {51=>nil, 50=>nil, 49=>nil}], 48=>[{51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {51=>nil, 50=>nil, 49=>nil, 48=>nil}], 54=>[{53=>nil, 54=>:enemy}, {53=>nil, 54=>nil}], 55=>[{53=>nil, 54=>nil, 55=>:enemy}, {53=>nil, 54=>nil, 55=>nil}]}, 53=>{45=>[{45=>:enemy}, {45=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 37=>[{45=>nil, 37=>:enemy}, {45=>nil, 37=>nil}], 29=>[{45=>nil, 37=>nil, 29=>:enemy}, {45=>nil, 37=>nil, 29=>nil}], 21=>[{45=>nil, 37=>nil, 29=>nil, 21=>:enemy}, {45=>nil, 37=>nil, 29=>nil, 21=>nil}], 13=>[{45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, {45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil}], 5=>[{45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}], 51=>[{52=>nil, 51=>:enemy}, {52=>nil, 51=>nil}], 50=>[{52=>nil, 51=>nil, 50=>:enemy}, {52=>nil, 51=>nil, 50=>nil}], 49=>[{52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, {52=>nil, 51=>nil, 50=>nil, 49=>nil}], 48=>[{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}], 55=>[{54=>nil, 55=>:enemy}, {54=>nil, 55=>nil}]}, 54=>{46=>[{46=>:enemy}, {46=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 38=>[{46=>nil, 38=>:enemy}, {46=>nil, 38=>nil}], 30=>[{46=>nil, 38=>nil, 30=>:enemy}, {46=>nil, 38=>nil, 30=>nil}], 22=>[{46=>nil, 38=>nil, 30=>nil, 22=>:enemy}, {46=>nil, 38=>nil, 30=>nil, 22=>nil}], 14=>[{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, {46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil}], 6=>[{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}], 52=>[{53=>nil, 52=>:enemy}, {53=>nil, 52=>nil}], 51=>[{53=>nil, 52=>nil, 51=>:enemy}, {53=>nil, 52=>nil, 51=>nil}], 50=>[{53=>nil, 52=>nil, 51=>nil, 50=>:enemy}, {53=>nil, 52=>nil, 51=>nil, 50=>nil}], 49=>[{53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, {53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil}], 48=>[{53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}]}, 55=>{47=>[{47=>:enemy}, {47=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 63=>[{63=>:enemy}, {63=>nil}], 39=>[{47=>nil, 39=>:enemy}, {47=>nil, 39=>nil}], 31=>[{47=>nil, 39=>nil, 31=>:enemy}, {47=>nil, 39=>nil, 31=>nil}], 23=>[{47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, {47=>nil, 39=>nil, 31=>nil, 23=>nil}], 15=>[{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, {47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}], 7=>[{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}], 53=>[{54=>nil, 53=>:enemy}, {54=>nil, 53=>nil}], 52=>[{54=>nil, 53=>nil, 52=>:enemy}, {54=>nil, 53=>nil, 52=>nil}], 51=>[{54=>nil, 53=>nil, 52=>nil, 51=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil}], 50=>[{54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil}], 49=>[{54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil}], 48=>[{54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}]}, 56=>{48=>[{48=>:enemy}, {48=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 40=>[{48=>nil, 40=>:enemy}, {48=>nil, 40=>nil}], 32=>[{48=>nil, 40=>nil, 32=>:enemy}, {48=>nil, 40=>nil, 32=>nil}], 24=>[{48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil}], 16=>[{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}], 8=>[{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}], 0=>[{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>nil}], 58=>[{57=>nil, 58=>:enemy}, {57=>nil, 58=>nil}], 59=>[{57=>nil, 58=>nil, 59=>:enemy}, {57=>nil, 58=>nil, 59=>nil}], 60=>[{57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil}], 61=>[{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}], 62=>[{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}], 63=>[{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 57=>{49=>[{49=>:enemy}, {49=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 41=>[{49=>nil, 41=>:enemy}, {49=>nil, 41=>nil}], 33=>[{49=>nil, 41=>nil, 33=>:enemy}, {49=>nil, 41=>nil, 33=>nil}], 25=>[{49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil}], 17=>[{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}], 9=>[{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil}], 1=>[{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>nil}], 59=>[{58=>nil, 59=>:enemy}, {58=>nil, 59=>nil}], 60=>[{58=>nil, 59=>nil, 60=>:enemy}, {58=>nil, 59=>nil, 60=>nil}], 61=>[{58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, {58=>nil, 59=>nil, 60=>nil, 61=>nil}], 62=>[{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, {58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}], 63=>[{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 58=>{50=>[{50=>:enemy}, {50=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 42=>[{50=>nil, 42=>:enemy}, {50=>nil, 42=>nil}], 34=>[{50=>nil, 42=>nil, 34=>:enemy}, {50=>nil, 42=>nil, 34=>nil}], 26=>[{50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil}], 18=>[{50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil}], 10=>[{50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil}], 2=>[{50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>nil}], 56=>[{57=>nil, 56=>:enemy}, {57=>nil, 56=>nil}], 60=>[{59=>nil, 60=>:enemy}, {59=>nil, 60=>nil}], 61=>[{59=>nil, 60=>nil, 61=>:enemy}, {59=>nil, 60=>nil, 61=>nil}], 62=>[{59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, {59=>nil, 60=>nil, 61=>nil, 62=>nil}], 63=>[{59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 59=>{51=>[{51=>:enemy}, {51=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 43=>[{51=>nil, 43=>:enemy}, {51=>nil, 43=>nil}], 35=>[{51=>nil, 43=>nil, 35=>:enemy}, {51=>nil, 43=>nil, 35=>nil}], 27=>[{51=>nil, 43=>nil, 35=>nil, 27=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil}], 19=>[{51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil}], 11=>[{51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil}], 3=>[{51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>nil}], 57=>[{58=>nil, 57=>:enemy}, {58=>nil, 57=>nil}], 56=>[{58=>nil, 57=>nil, 56=>:enemy}, {58=>nil, 57=>nil, 56=>nil}], 61=>[{60=>nil, 61=>:enemy}, {60=>nil, 61=>nil}], 62=>[{60=>nil, 61=>nil, 62=>:enemy}, {60=>nil, 61=>nil, 62=>nil}], 63=>[{60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 60=>{52=>[{52=>:enemy}, {52=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 44=>[{52=>nil, 44=>:enemy}, {52=>nil, 44=>nil}], 36=>[{52=>nil, 44=>nil, 36=>:enemy}, {52=>nil, 44=>nil, 36=>nil}], 28=>[{52=>nil, 44=>nil, 36=>nil, 28=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil}], 20=>[{52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil}], 12=>[{52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil}], 4=>[{52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>nil}], 58=>[{59=>nil, 58=>:enemy}, {59=>nil, 58=>nil}], 57=>[{59=>nil, 58=>nil, 57=>:enemy}, {59=>nil, 58=>nil, 57=>nil}], 56=>[{59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {59=>nil, 58=>nil, 57=>nil, 56=>nil}], 62=>[{61=>nil, 62=>:enemy}, {61=>nil, 62=>nil}], 63=>[{61=>nil, 62=>nil, 63=>:enemy}, {61=>nil, 62=>nil, 63=>nil}]}, 61=>{53=>[{53=>:enemy}, {53=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 45=>[{53=>nil, 45=>:enemy}, {53=>nil, 45=>nil}], 37=>[{53=>nil, 45=>nil, 37=>:enemy}, {53=>nil, 45=>nil, 37=>nil}], 29=>[{53=>nil, 45=>nil, 37=>nil, 29=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil}], 21=>[{53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil}], 13=>[{53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil}], 5=>[{53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}], 59=>[{60=>nil, 59=>:enemy}, {60=>nil, 59=>nil}], 58=>[{60=>nil, 59=>nil, 58=>:enemy}, {60=>nil, 59=>nil, 58=>nil}], 57=>[{60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, {60=>nil, 59=>nil, 58=>nil, 57=>nil}], 56=>[{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}], 63=>[{62=>nil, 63=>:enemy}, {62=>nil, 63=>nil}]}, 62=>{54=>[{54=>:enemy}, {54=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 63=>[{63=>:enemy}, {63=>nil}], 46=>[{54=>nil, 46=>:enemy}, {54=>nil, 46=>nil}], 38=>[{54=>nil, 46=>nil, 38=>:enemy}, {54=>nil, 46=>nil, 38=>nil}], 30=>[{54=>nil, 46=>nil, 38=>nil, 30=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil}], 22=>[{54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil}], 14=>[{54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil}], 6=>[{54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}], 60=>[{61=>nil, 60=>:enemy}, {61=>nil, 60=>nil}], 59=>[{61=>nil, 60=>nil, 59=>:enemy}, {61=>nil, 60=>nil, 59=>nil}], 58=>[{61=>nil, 60=>nil, 59=>nil, 58=>:enemy}, {61=>nil, 60=>nil, 59=>nil, 58=>nil}], 57=>[{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, {61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}], 56=>[{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}]}, 63=>{55=>[{55=>:enemy}, {55=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 47=>[{55=>nil, 47=>:enemy}, {55=>nil, 47=>nil}], 39=>[{55=>nil, 47=>nil, 39=>:enemy}, {55=>nil, 47=>nil, 39=>nil}], 31=>[{55=>nil, 47=>nil, 39=>nil, 31=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil}], 23=>[{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil}], 15=>[{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}], 7=>[{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}], 61=>[{62=>nil, 61=>:enemy}, {62=>nil, 61=>nil}], 60=>[{62=>nil, 61=>nil, 60=>:enemy}, {62=>nil, 61=>nil, 60=>nil}], 59=>[{62=>nil, 61=>nil, 60=>nil, 59=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil}], 58=>[{62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil}], 57=>[{62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}], 56=>[{62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}]}}, "c:-k"=>{0=>{1=>[{1=>:enemy}, {1=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}]}, 1=>{0=>[{0=>:enemy}, {0=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}]}, 2=>{1=>[{1=>:enemy}, {1=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}]}, 3=>{2=>[{2=>:enemy}, {2=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}]}, 4=>{3=>[{3=>:enemy}, {3=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}]}, 5=>{4=>[{4=>:enemy}, {4=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}]}, 6=>{5=>[{5=>:enemy}, {5=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}]}, 7=>{6=>[{6=>:enemy}, {6=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}]}, 8=>{0=>[{0=>:enemy}, {0=>nil}], 1=>[{1=>:enemy}, {1=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}]}, 9=>{0=>[{0=>:enemy}, {0=>nil}], 1=>[{1=>:enemy}, {1=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}]}, 10=>{1=>[{1=>:enemy}, {1=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}]}, 11=>{2=>[{2=>:enemy}, {2=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}]}, 12=>{3=>[{3=>:enemy}, {3=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}]}, 13=>{4=>[{4=>:enemy}, {4=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}]}, 14=>{5=>[{5=>:enemy}, {5=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}]}, 15=>{6=>[{6=>:enemy}, {6=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}]}, 16=>{8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}]}, 17=>{8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}]}, 18=>{9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}]}, 19=>{10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}]}, 20=>{11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}]}, 21=>{12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}]}, 22=>{13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}]}, 23=>{14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}]}, 24=>{16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}]}, 25=>{16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}]}, 26=>{17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}]}, 27=>{18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}]}, 28=>{19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}]}, 29=>{20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}]}, 30=>{21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}]}, 31=>{22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}]}, 32=>{24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}]}, 33=>{24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}]}, 34=>{25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}]}, 35=>{26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}]}, 36=>{27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}]}, 37=>{28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}]}, 38=>{29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}]}, 39=>{30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}]}, 40=>{32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}]}, 41=>{32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}]}, 42=>{33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}]}, 43=>{34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}]}, 44=>{35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}]}, 45=>{36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}]}, 46=>{37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}]}, 47=>{38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}]}, 48=>{40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 57=>[{57=>:enemy}, {57=>nil}]}, 49=>{40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 58=>[{58=>:enemy}, {58=>nil}]}, 50=>{41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 59=>[{59=>:enemy}, {59=>nil}]}, 51=>{42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 60=>[{60=>:enemy}, {60=>nil}]}, 52=>{43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 61=>[{61=>:enemy}, {61=>nil}]}, 53=>{44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 62=>[{62=>:enemy}, {62=>nil}]}, 54=>{45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 63=>[{63=>:enemy}, {63=>nil}]}, 55=>{46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 63=>[{63=>:enemy}, {63=>nil}]}, 56=>{48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 57=>[{57=>:enemy}, {57=>nil}]}, 57=>{48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 58=>[{58=>:enemy}, {58=>nil}]}, 58=>{49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 59=>[{59=>:enemy}, {59=>nil}]}, 59=>{50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 60=>[{60=>:enemy}, {60=>nil}]}, 60=>{51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 61=>[{61=>:enemy}, {61=>nil}]}, 61=>{52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 62=>[{62=>:enemy}, {62=>nil}]}, 62=>{53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 63=>[{63=>:enemy}, {63=>nil}]}, 63=>{54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 62=>[{62=>:enemy}, {62=>nil}]}}, "c:b"=>{0=>{9=>[{9=>:enemy}, {9=>nil}], 18=>[{9=>nil, 18=>:enemy}, {9=>nil, 18=>nil}], 27=>[{9=>nil, 18=>nil, 27=>:enemy}, {9=>nil, 18=>nil, 27=>nil}], 36=>[{9=>nil, 18=>nil, 27=>nil, 36=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil}], 45=>[{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil}], 54=>[{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}], 63=>[{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 1=>{8=>[{8=>:enemy}, {8=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 19=>[{10=>nil, 19=>:enemy}, {10=>nil, 19=>nil}], 28=>[{10=>nil, 19=>nil, 28=>:enemy}, {10=>nil, 19=>nil, 28=>nil}], 37=>[{10=>nil, 19=>nil, 28=>nil, 37=>:enemy}, {10=>nil, 19=>nil, 28=>nil, 37=>nil}], 46=>[{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, {10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil}], 55=>[{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, {10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}]}, 2=>{9=>[{9=>:enemy}, {9=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 16=>[{9=>nil, 16=>:enemy}, {9=>nil, 16=>nil}], 20=>[{11=>nil, 20=>:enemy}, {11=>nil, 20=>nil}], 29=>[{11=>nil, 20=>nil, 29=>:enemy}, {11=>nil, 20=>nil, 29=>nil}], 38=>[{11=>nil, 20=>nil, 29=>nil, 38=>:enemy}, {11=>nil, 20=>nil, 29=>nil, 38=>nil}], 47=>[{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, {11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil}]}, 3=>{10=>[{10=>:enemy}, {10=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 17=>[{10=>nil, 17=>:enemy}, {10=>nil, 17=>nil}], 24=>[{10=>nil, 17=>nil, 24=>:enemy}, {10=>nil, 17=>nil, 24=>nil}], 21=>[{12=>nil, 21=>:enemy}, {12=>nil, 21=>nil}], 30=>[{12=>nil, 21=>nil, 30=>:enemy}, {12=>nil, 21=>nil, 30=>nil}], 39=>[{12=>nil, 21=>nil, 30=>nil, 39=>:enemy}, {12=>nil, 21=>nil, 30=>nil, 39=>nil}]}, 4=>{11=>[{11=>:enemy}, {11=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 18=>[{11=>nil, 18=>:enemy}, {11=>nil, 18=>nil}], 25=>[{11=>nil, 18=>nil, 25=>:enemy}, {11=>nil, 18=>nil, 25=>nil}], 32=>[{11=>nil, 18=>nil, 25=>nil, 32=>:enemy}, {11=>nil, 18=>nil, 25=>nil, 32=>nil}], 22=>[{13=>nil, 22=>:enemy}, {13=>nil, 22=>nil}], 31=>[{13=>nil, 22=>nil, 31=>:enemy}, {13=>nil, 22=>nil, 31=>nil}]}, 5=>{12=>[{12=>:enemy}, {12=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 19=>[{12=>nil, 19=>:enemy}, {12=>nil, 19=>nil}], 26=>[{12=>nil, 19=>nil, 26=>:enemy}, {12=>nil, 19=>nil, 26=>nil}], 33=>[{12=>nil, 19=>nil, 26=>nil, 33=>:enemy}, {12=>nil, 19=>nil, 26=>nil, 33=>nil}], 40=>[{12=>nil, 19=>nil, 26=>nil, 33=>nil, 40=>:enemy}, {12=>nil, 19=>nil, 26=>nil, 33=>nil, 40=>nil}], 23=>[{14=>nil, 23=>:enemy}, {14=>nil, 23=>nil}]}, 6=>{13=>[{13=>:enemy}, {13=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 20=>[{13=>nil, 20=>:enemy}, {13=>nil, 20=>nil}], 27=>[{13=>nil, 20=>nil, 27=>:enemy}, {13=>nil, 20=>nil, 27=>nil}], 34=>[{13=>nil, 20=>nil, 27=>nil, 34=>:enemy}, {13=>nil, 20=>nil, 27=>nil, 34=>nil}], 41=>[{13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>:enemy}, {13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>nil}], 48=>[{13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>:enemy}, {13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>nil}]}, 7=>{14=>[{14=>:enemy}, {14=>nil}], 21=>[{14=>nil, 21=>:enemy}, {14=>nil, 21=>nil}], 28=>[{14=>nil, 21=>nil, 28=>:enemy}, {14=>nil, 21=>nil, 28=>nil}], 35=>[{14=>nil, 21=>nil, 28=>nil, 35=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil}], 42=>[{14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil}], 49=>[{14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil}], 56=>[{14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>nil}]}, 8=>{1=>[{1=>:enemy}, {1=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 26=>[{17=>nil, 26=>:enemy}, {17=>nil, 26=>nil}], 35=>[{17=>nil, 26=>nil, 35=>:enemy}, {17=>nil, 26=>nil, 35=>nil}], 44=>[{17=>nil, 26=>nil, 35=>nil, 44=>:enemy}, {17=>nil, 26=>nil, 35=>nil, 44=>nil}], 53=>[{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, {17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil}], 62=>[{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, {17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}]}, 9=>{0=>[{0=>:enemy}, {0=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 27=>[{18=>nil, 27=>:enemy}, {18=>nil, 27=>nil}], 36=>[{18=>nil, 27=>nil, 36=>:enemy}, {18=>nil, 27=>nil, 36=>nil}], 45=>[{18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, {18=>nil, 27=>nil, 36=>nil, 45=>nil}], 54=>[{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, {18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}], 63=>[{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 10=>{1=>[{1=>:enemy}, {1=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 24=>[{17=>nil, 24=>:enemy}, {17=>nil, 24=>nil}], 28=>[{19=>nil, 28=>:enemy}, {19=>nil, 28=>nil}], 37=>[{19=>nil, 28=>nil, 37=>:enemy}, {19=>nil, 28=>nil, 37=>nil}], 46=>[{19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, {19=>nil, 28=>nil, 37=>nil, 46=>nil}], 55=>[{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, {19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}]}, 11=>{2=>[{2=>:enemy}, {2=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 25=>[{18=>nil, 25=>:enemy}, {18=>nil, 25=>nil}], 32=>[{18=>nil, 25=>nil, 32=>:enemy}, {18=>nil, 25=>nil, 32=>nil}], 29=>[{20=>nil, 29=>:enemy}, {20=>nil, 29=>nil}], 38=>[{20=>nil, 29=>nil, 38=>:enemy}, {20=>nil, 29=>nil, 38=>nil}], 47=>[{20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, {20=>nil, 29=>nil, 38=>nil, 47=>nil}]}, 12=>{3=>[{3=>:enemy}, {3=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 26=>[{19=>nil, 26=>:enemy}, {19=>nil, 26=>nil}], 33=>[{19=>nil, 26=>nil, 33=>:enemy}, {19=>nil, 26=>nil, 33=>nil}], 40=>[{19=>nil, 26=>nil, 33=>nil, 40=>:enemy}, {19=>nil, 26=>nil, 33=>nil, 40=>nil}], 30=>[{21=>nil, 30=>:enemy}, {21=>nil, 30=>nil}], 39=>[{21=>nil, 30=>nil, 39=>:enemy}, {21=>nil, 30=>nil, 39=>nil}]}, 13=>{4=>[{4=>:enemy}, {4=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 27=>[{20=>nil, 27=>:enemy}, {20=>nil, 27=>nil}], 34=>[{20=>nil, 27=>nil, 34=>:enemy}, {20=>nil, 27=>nil, 34=>nil}], 41=>[{20=>nil, 27=>nil, 34=>nil, 41=>:enemy}, {20=>nil, 27=>nil, 34=>nil, 41=>nil}], 48=>[{20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>:enemy}, {20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>nil}], 31=>[{22=>nil, 31=>:enemy}, {22=>nil, 31=>nil}]}, 14=>{5=>[{5=>:enemy}, {5=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 28=>[{21=>nil, 28=>:enemy}, {21=>nil, 28=>nil}], 35=>[{21=>nil, 28=>nil, 35=>:enemy}, {21=>nil, 28=>nil, 35=>nil}], 42=>[{21=>nil, 28=>nil, 35=>nil, 42=>:enemy}, {21=>nil, 28=>nil, 35=>nil, 42=>nil}], 49=>[{21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>:enemy}, {21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil}], 56=>[{21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>nil}]}, 15=>{6=>[{6=>:enemy}, {6=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 29=>[{22=>nil, 29=>:enemy}, {22=>nil, 29=>nil}], 36=>[{22=>nil, 29=>nil, 36=>:enemy}, {22=>nil, 29=>nil, 36=>nil}], 43=>[{22=>nil, 29=>nil, 36=>nil, 43=>:enemy}, {22=>nil, 29=>nil, 36=>nil, 43=>nil}], 50=>[{22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>:enemy}, {22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>nil}], 57=>[{22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>:enemy}, {22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>nil}]}, 16=>{9=>[{9=>:enemy}, {9=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 2=>[{9=>nil, 2=>:enemy}, {9=>nil, 2=>nil}], 34=>[{25=>nil, 34=>:enemy}, {25=>nil, 34=>nil}], 43=>[{25=>nil, 34=>nil, 43=>:enemy}, {25=>nil, 34=>nil, 43=>nil}], 52=>[{25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, {25=>nil, 34=>nil, 43=>nil, 52=>nil}], 61=>[{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, {25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}]}, 17=>{8=>[{8=>:enemy}, {8=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 3=>[{10=>nil, 3=>:enemy}, {10=>nil, 3=>nil}], 35=>[{26=>nil, 35=>:enemy}, {26=>nil, 35=>nil}], 44=>[{26=>nil, 35=>nil, 44=>:enemy}, {26=>nil, 35=>nil, 44=>nil}], 53=>[{26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, {26=>nil, 35=>nil, 44=>nil, 53=>nil}], 62=>[{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, {26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}]}, 18=>{9=>[{9=>:enemy}, {9=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 0=>[{9=>nil, 0=>:enemy}, {9=>nil, 0=>nil}], 4=>[{11=>nil, 4=>:enemy}, {11=>nil, 4=>nil}], 32=>[{25=>nil, 32=>:enemy}, {25=>nil, 32=>nil}], 36=>[{27=>nil, 36=>:enemy}, {27=>nil, 36=>nil}], 45=>[{27=>nil, 36=>nil, 45=>:enemy}, {27=>nil, 36=>nil, 45=>nil}], 54=>[{27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, {27=>nil, 36=>nil, 45=>nil, 54=>nil}], 63=>[{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 19=>{10=>[{10=>:enemy}, {10=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 1=>[{10=>nil, 1=>:enemy}, {10=>nil, 1=>nil}], 5=>[{12=>nil, 5=>:enemy}, {12=>nil, 5=>nil}], 33=>[{26=>nil, 33=>:enemy}, {26=>nil, 33=>nil}], 40=>[{26=>nil, 33=>nil, 40=>:enemy}, {26=>nil, 33=>nil, 40=>nil}], 37=>[{28=>nil, 37=>:enemy}, {28=>nil, 37=>nil}], 46=>[{28=>nil, 37=>nil, 46=>:enemy}, {28=>nil, 37=>nil, 46=>nil}], 55=>[{28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, {28=>nil, 37=>nil, 46=>nil, 55=>nil}]}, 20=>{11=>[{11=>:enemy}, {11=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 2=>[{11=>nil, 2=>:enemy}, {11=>nil, 2=>nil}], 6=>[{13=>nil, 6=>:enemy}, {13=>nil, 6=>nil}], 34=>[{27=>nil, 34=>:enemy}, {27=>nil, 34=>nil}], 41=>[{27=>nil, 34=>nil, 41=>:enemy}, {27=>nil, 34=>nil, 41=>nil}], 48=>[{27=>nil, 34=>nil, 41=>nil, 48=>:enemy}, {27=>nil, 34=>nil, 41=>nil, 48=>nil}], 38=>[{29=>nil, 38=>:enemy}, {29=>nil, 38=>nil}], 47=>[{29=>nil, 38=>nil, 47=>:enemy}, {29=>nil, 38=>nil, 47=>nil}]}, 21=>{12=>[{12=>:enemy}, {12=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 3=>[{12=>nil, 3=>:enemy}, {12=>nil, 3=>nil}], 7=>[{14=>nil, 7=>:enemy}, {14=>nil, 7=>nil}], 35=>[{28=>nil, 35=>:enemy}, {28=>nil, 35=>nil}], 42=>[{28=>nil, 35=>nil, 42=>:enemy}, {28=>nil, 35=>nil, 42=>nil}], 49=>[{28=>nil, 35=>nil, 42=>nil, 49=>:enemy}, {28=>nil, 35=>nil, 42=>nil, 49=>nil}], 56=>[{28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>nil}], 39=>[{30=>nil, 39=>:enemy}, {30=>nil, 39=>nil}]}, 22=>{13=>[{13=>:enemy}, {13=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 4=>[{13=>nil, 4=>:enemy}, {13=>nil, 4=>nil}], 36=>[{29=>nil, 36=>:enemy}, {29=>nil, 36=>nil}], 43=>[{29=>nil, 36=>nil, 43=>:enemy}, {29=>nil, 36=>nil, 43=>nil}], 50=>[{29=>nil, 36=>nil, 43=>nil, 50=>:enemy}, {29=>nil, 36=>nil, 43=>nil, 50=>nil}], 57=>[{29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>:enemy}, {29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>nil}]}, 23=>{14=>[{14=>:enemy}, {14=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 5=>[{14=>nil, 5=>:enemy}, {14=>nil, 5=>nil}], 37=>[{30=>nil, 37=>:enemy}, {30=>nil, 37=>nil}], 44=>[{30=>nil, 37=>nil, 44=>:enemy}, {30=>nil, 37=>nil, 44=>nil}], 51=>[{30=>nil, 37=>nil, 44=>nil, 51=>:enemy}, {30=>nil, 37=>nil, 44=>nil, 51=>nil}], 58=>[{30=>nil, 37=>nil, 44=>nil, 51=>nil, 58=>:enemy}, {30=>nil, 37=>nil, 44=>nil, 51=>nil, 58=>nil}]}, 24=>{17=>[{17=>:enemy}, {17=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 10=>[{17=>nil, 10=>:enemy}, {17=>nil, 10=>nil}], 3=>[{17=>nil, 10=>nil, 3=>:enemy}, {17=>nil, 10=>nil, 3=>nil}], 42=>[{33=>nil, 42=>:enemy}, {33=>nil, 42=>nil}], 51=>[{33=>nil, 42=>nil, 51=>:enemy}, {33=>nil, 42=>nil, 51=>nil}], 60=>[{33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, {33=>nil, 42=>nil, 51=>nil, 60=>nil}]}, 25=>{16=>[{16=>:enemy}, {16=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 11=>[{18=>nil, 11=>:enemy}, {18=>nil, 11=>nil}], 4=>[{18=>nil, 11=>nil, 4=>:enemy}, {18=>nil, 11=>nil, 4=>nil}], 43=>[{34=>nil, 43=>:enemy}, {34=>nil, 43=>nil}], 52=>[{34=>nil, 43=>nil, 52=>:enemy}, {34=>nil, 43=>nil, 52=>nil}], 61=>[{34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, {34=>nil, 43=>nil, 52=>nil, 61=>nil}]}, 26=>{17=>[{17=>:enemy}, {17=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 8=>[{17=>nil, 8=>:enemy}, {17=>nil, 8=>nil}], 12=>[{19=>nil, 12=>:enemy}, {19=>nil, 12=>nil}], 5=>[{19=>nil, 12=>nil, 5=>:enemy}, {19=>nil, 12=>nil, 5=>nil}], 40=>[{33=>nil, 40=>:enemy}, {33=>nil, 40=>nil}], 44=>[{35=>nil, 44=>:enemy}, {35=>nil, 44=>nil}], 53=>[{35=>nil, 44=>nil, 53=>:enemy}, {35=>nil, 44=>nil, 53=>nil}], 62=>[{35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, {35=>nil, 44=>nil, 53=>nil, 62=>nil}]}, 27=>{18=>[{18=>:enemy}, {18=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 9=>[{18=>nil, 9=>:enemy}, {18=>nil, 9=>nil}], 0=>[{18=>nil, 9=>nil, 0=>:enemy}, {18=>nil, 9=>nil, 0=>nil}], 13=>[{20=>nil, 13=>:enemy}, {20=>nil, 13=>nil}], 6=>[{20=>nil, 13=>nil, 6=>:enemy}, {20=>nil, 13=>nil, 6=>nil}], 41=>[{34=>nil, 41=>:enemy}, {34=>nil, 41=>nil}], 48=>[{34=>nil, 41=>nil, 48=>:enemy}, {34=>nil, 41=>nil, 48=>nil}], 45=>[{36=>nil, 45=>:enemy}, {36=>nil, 45=>nil}], 54=>[{36=>nil, 45=>nil, 54=>:enemy}, {36=>nil, 45=>nil, 54=>nil}], 63=>[{36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 28=>{19=>[{19=>:enemy}, {19=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 10=>[{19=>nil, 10=>:enemy}, {19=>nil, 10=>nil}], 1=>[{19=>nil, 10=>nil, 1=>:enemy}, {19=>nil, 10=>nil, 1=>nil}], 14=>[{21=>nil, 14=>:enemy}, {21=>nil, 14=>nil}], 7=>[{21=>nil, 14=>nil, 7=>:enemy}, {21=>nil, 14=>nil, 7=>nil}], 42=>[{35=>nil, 42=>:enemy}, {35=>nil, 42=>nil}], 49=>[{35=>nil, 42=>nil, 49=>:enemy}, {35=>nil, 42=>nil, 49=>nil}], 56=>[{35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {35=>nil, 42=>nil, 49=>nil, 56=>nil}], 46=>[{37=>nil, 46=>:enemy}, {37=>nil, 46=>nil}], 55=>[{37=>nil, 46=>nil, 55=>:enemy}, {37=>nil, 46=>nil, 55=>nil}]}, 29=>{20=>[{20=>:enemy}, {20=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 11=>[{20=>nil, 11=>:enemy}, {20=>nil, 11=>nil}], 2=>[{20=>nil, 11=>nil, 2=>:enemy}, {20=>nil, 11=>nil, 2=>nil}], 15=>[{22=>nil, 15=>:enemy}, {22=>nil, 15=>nil}], 43=>[{36=>nil, 43=>:enemy}, {36=>nil, 43=>nil}], 50=>[{36=>nil, 43=>nil, 50=>:enemy}, {36=>nil, 43=>nil, 50=>nil}], 57=>[{36=>nil, 43=>nil, 50=>nil, 57=>:enemy}, {36=>nil, 43=>nil, 50=>nil, 57=>nil}], 47=>[{38=>nil, 47=>:enemy}, {38=>nil, 47=>nil}]}, 30=>{21=>[{21=>:enemy}, {21=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 12=>[{21=>nil, 12=>:enemy}, {21=>nil, 12=>nil}], 3=>[{21=>nil, 12=>nil, 3=>:enemy}, {21=>nil, 12=>nil, 3=>nil}], 44=>[{37=>nil, 44=>:enemy}, {37=>nil, 44=>nil}], 51=>[{37=>nil, 44=>nil, 51=>:enemy}, {37=>nil, 44=>nil, 51=>nil}], 58=>[{37=>nil, 44=>nil, 51=>nil, 58=>:enemy}, {37=>nil, 44=>nil, 51=>nil, 58=>nil}]}, 31=>{22=>[{22=>:enemy}, {22=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 13=>[{22=>nil, 13=>:enemy}, {22=>nil, 13=>nil}], 4=>[{22=>nil, 13=>nil, 4=>:enemy}, {22=>nil, 13=>nil, 4=>nil}], 45=>[{38=>nil, 45=>:enemy}, {38=>nil, 45=>nil}], 52=>[{38=>nil, 45=>nil, 52=>:enemy}, {38=>nil, 45=>nil, 52=>nil}], 59=>[{38=>nil, 45=>nil, 52=>nil, 59=>:enemy}, {38=>nil, 45=>nil, 52=>nil, 59=>nil}]}, 32=>{25=>[{25=>:enemy}, {25=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 18=>[{25=>nil, 18=>:enemy}, {25=>nil, 18=>nil}], 11=>[{25=>nil, 18=>nil, 11=>:enemy}, {25=>nil, 18=>nil, 11=>nil}], 4=>[{25=>nil, 18=>nil, 11=>nil, 4=>:enemy}, {25=>nil, 18=>nil, 11=>nil, 4=>nil}], 50=>[{41=>nil, 50=>:enemy}, {41=>nil, 50=>nil}], 59=>[{41=>nil, 50=>nil, 59=>:enemy}, {41=>nil, 50=>nil, 59=>nil}]}, 33=>{24=>[{24=>:enemy}, {24=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 19=>[{26=>nil, 19=>:enemy}, {26=>nil, 19=>nil}], 12=>[{26=>nil, 19=>nil, 12=>:enemy}, {26=>nil, 19=>nil, 12=>nil}], 5=>[{26=>nil, 19=>nil, 12=>nil, 5=>:enemy}, {26=>nil, 19=>nil, 12=>nil, 5=>nil}], 51=>[{42=>nil, 51=>:enemy}, {42=>nil, 51=>nil}], 60=>[{42=>nil, 51=>nil, 60=>:enemy}, {42=>nil, 51=>nil, 60=>nil}]}, 34=>{25=>[{25=>:enemy}, {25=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 16=>[{25=>nil, 16=>:enemy}, {25=>nil, 16=>nil}], 20=>[{27=>nil, 20=>:enemy}, {27=>nil, 20=>nil}], 13=>[{27=>nil, 20=>nil, 13=>:enemy}, {27=>nil, 20=>nil, 13=>nil}], 6=>[{27=>nil, 20=>nil, 13=>nil, 6=>:enemy}, {27=>nil, 20=>nil, 13=>nil, 6=>nil}], 48=>[{41=>nil, 48=>:enemy}, {41=>nil, 48=>nil}], 52=>[{43=>nil, 52=>:enemy}, {43=>nil, 52=>nil}], 61=>[{43=>nil, 52=>nil, 61=>:enemy}, {43=>nil, 52=>nil, 61=>nil}]}, 35=>{26=>[{26=>:enemy}, {26=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 17=>[{26=>nil, 17=>:enemy}, {26=>nil, 17=>nil}], 8=>[{26=>nil, 17=>nil, 8=>:enemy}, {26=>nil, 17=>nil, 8=>nil}], 21=>[{28=>nil, 21=>:enemy}, {28=>nil, 21=>nil}], 14=>[{28=>nil, 21=>nil, 14=>:enemy}, {28=>nil, 21=>nil, 14=>nil}], 7=>[{28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {28=>nil, 21=>nil, 14=>nil, 7=>nil}], 49=>[{42=>nil, 49=>:enemy}, {42=>nil, 49=>nil}], 56=>[{42=>nil, 49=>nil, 56=>:enemy}, {42=>nil, 49=>nil, 56=>nil}], 53=>[{44=>nil, 53=>:enemy}, {44=>nil, 53=>nil}], 62=>[{44=>nil, 53=>nil, 62=>:enemy}, {44=>nil, 53=>nil, 62=>nil}]}, 36=>{27=>[{27=>:enemy}, {27=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 18=>[{27=>nil, 18=>:enemy}, {27=>nil, 18=>nil}], 9=>[{27=>nil, 18=>nil, 9=>:enemy}, {27=>nil, 18=>nil, 9=>nil}], 0=>[{27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {27=>nil, 18=>nil, 9=>nil, 0=>nil}], 22=>[{29=>nil, 22=>:enemy}, {29=>nil, 22=>nil}], 15=>[{29=>nil, 22=>nil, 15=>:enemy}, {29=>nil, 22=>nil, 15=>nil}], 50=>[{43=>nil, 50=>:enemy}, {43=>nil, 50=>nil}], 57=>[{43=>nil, 50=>nil, 57=>:enemy}, {43=>nil, 50=>nil, 57=>nil}], 54=>[{45=>nil, 54=>:enemy}, {45=>nil, 54=>nil}], 63=>[{45=>nil, 54=>nil, 63=>:enemy}, {45=>nil, 54=>nil, 63=>nil}]}, 37=>{28=>[{28=>:enemy}, {28=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 19=>[{28=>nil, 19=>:enemy}, {28=>nil, 19=>nil}], 10=>[{28=>nil, 19=>nil, 10=>:enemy}, {28=>nil, 19=>nil, 10=>nil}], 1=>[{28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, {28=>nil, 19=>nil, 10=>nil, 1=>nil}], 23=>[{30=>nil, 23=>:enemy}, {30=>nil, 23=>nil}], 51=>[{44=>nil, 51=>:enemy}, {44=>nil, 51=>nil}], 58=>[{44=>nil, 51=>nil, 58=>:enemy}, {44=>nil, 51=>nil, 58=>nil}], 55=>[{46=>nil, 55=>:enemy}, {46=>nil, 55=>nil}]}, 38=>{29=>[{29=>:enemy}, {29=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 20=>[{29=>nil, 20=>:enemy}, {29=>nil, 20=>nil}], 11=>[{29=>nil, 20=>nil, 11=>:enemy}, {29=>nil, 20=>nil, 11=>nil}], 2=>[{29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, {29=>nil, 20=>nil, 11=>nil, 2=>nil}], 52=>[{45=>nil, 52=>:enemy}, {45=>nil, 52=>nil}], 59=>[{45=>nil, 52=>nil, 59=>:enemy}, {45=>nil, 52=>nil, 59=>nil}]}, 39=>{30=>[{30=>:enemy}, {30=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 21=>[{30=>nil, 21=>:enemy}, {30=>nil, 21=>nil}], 12=>[{30=>nil, 21=>nil, 12=>:enemy}, {30=>nil, 21=>nil, 12=>nil}], 3=>[{30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, {30=>nil, 21=>nil, 12=>nil, 3=>nil}], 53=>[{46=>nil, 53=>:enemy}, {46=>nil, 53=>nil}], 60=>[{46=>nil, 53=>nil, 60=>:enemy}, {46=>nil, 53=>nil, 60=>nil}]}, 40=>{33=>[{33=>:enemy}, {33=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 26=>[{33=>nil, 26=>:enemy}, {33=>nil, 26=>nil}], 19=>[{33=>nil, 26=>nil, 19=>:enemy}, {33=>nil, 26=>nil, 19=>nil}], 12=>[{33=>nil, 26=>nil, 19=>nil, 12=>:enemy}, {33=>nil, 26=>nil, 19=>nil, 12=>nil}], 5=>[{33=>nil, 26=>nil, 19=>nil, 12=>nil, 5=>:enemy}, {33=>nil, 26=>nil, 19=>nil, 12=>nil, 5=>nil}], 58=>[{49=>nil, 58=>:enemy}, {49=>nil, 58=>nil}]}, 41=>{32=>[{32=>:enemy}, {32=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 27=>[{34=>nil, 27=>:enemy}, {34=>nil, 27=>nil}], 20=>[{34=>nil, 27=>nil, 20=>:enemy}, {34=>nil, 27=>nil, 20=>nil}], 13=>[{34=>nil, 27=>nil, 20=>nil, 13=>:enemy}, {34=>nil, 27=>nil, 20=>nil, 13=>nil}], 6=>[{34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>:enemy}, {34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>nil}], 59=>[{50=>nil, 59=>:enemy}, {50=>nil, 59=>nil}]}, 42=>{33=>[{33=>:enemy}, {33=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 24=>[{33=>nil, 24=>:enemy}, {33=>nil, 24=>nil}], 28=>[{35=>nil, 28=>:enemy}, {35=>nil, 28=>nil}], 21=>[{35=>nil, 28=>nil, 21=>:enemy}, {35=>nil, 28=>nil, 21=>nil}], 14=>[{35=>nil, 28=>nil, 21=>nil, 14=>:enemy}, {35=>nil, 28=>nil, 21=>nil, 14=>nil}], 7=>[{35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>nil}], 56=>[{49=>nil, 56=>:enemy}, {49=>nil, 56=>nil}], 60=>[{51=>nil, 60=>:enemy}, {51=>nil, 60=>nil}]}, 43=>{34=>[{34=>:enemy}, {34=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 25=>[{34=>nil, 25=>:enemy}, {34=>nil, 25=>nil}], 16=>[{34=>nil, 25=>nil, 16=>:enemy}, {34=>nil, 25=>nil, 16=>nil}], 29=>[{36=>nil, 29=>:enemy}, {36=>nil, 29=>nil}], 22=>[{36=>nil, 29=>nil, 22=>:enemy}, {36=>nil, 29=>nil, 22=>nil}], 15=>[{36=>nil, 29=>nil, 22=>nil, 15=>:enemy}, {36=>nil, 29=>nil, 22=>nil, 15=>nil}], 57=>[{50=>nil, 57=>:enemy}, {50=>nil, 57=>nil}], 61=>[{52=>nil, 61=>:enemy}, {52=>nil, 61=>nil}]}, 44=>{35=>[{35=>:enemy}, {35=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 26=>[{35=>nil, 26=>:enemy}, {35=>nil, 26=>nil}], 17=>[{35=>nil, 26=>nil, 17=>:enemy}, {35=>nil, 26=>nil, 17=>nil}], 8=>[{35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, {35=>nil, 26=>nil, 17=>nil, 8=>nil}], 30=>[{37=>nil, 30=>:enemy}, {37=>nil, 30=>nil}], 23=>[{37=>nil, 30=>nil, 23=>:enemy}, {37=>nil, 30=>nil, 23=>nil}], 58=>[{51=>nil, 58=>:enemy}, {51=>nil, 58=>nil}], 62=>[{53=>nil, 62=>:enemy}, {53=>nil, 62=>nil}]}, 45=>{36=>[{36=>:enemy}, {36=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 27=>[{36=>nil, 27=>:enemy}, {36=>nil, 27=>nil}], 18=>[{36=>nil, 27=>nil, 18=>:enemy}, {36=>nil, 27=>nil, 18=>nil}], 9=>[{36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, {36=>nil, 27=>nil, 18=>nil, 9=>nil}], 0=>[{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}], 31=>[{38=>nil, 31=>:enemy}, {38=>nil, 31=>nil}], 59=>[{52=>nil, 59=>:enemy}, {52=>nil, 59=>nil}], 63=>[{54=>nil, 63=>:enemy}, {54=>nil, 63=>nil}]}, 46=>{37=>[{37=>:enemy}, {37=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 28=>[{37=>nil, 28=>:enemy}, {37=>nil, 28=>nil}], 19=>[{37=>nil, 28=>nil, 19=>:enemy}, {37=>nil, 28=>nil, 19=>nil}], 10=>[{37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, {37=>nil, 28=>nil, 19=>nil, 10=>nil}], 1=>[{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, {37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}], 60=>[{53=>nil, 60=>:enemy}, {53=>nil, 60=>nil}]}, 47=>{38=>[{38=>:enemy}, {38=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 29=>[{38=>nil, 29=>:enemy}, {38=>nil, 29=>nil}], 20=>[{38=>nil, 29=>nil, 20=>:enemy}, {38=>nil, 29=>nil, 20=>nil}], 11=>[{38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, {38=>nil, 29=>nil, 20=>nil, 11=>nil}], 2=>[{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, {38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}], 61=>[{54=>nil, 61=>:enemy}, {54=>nil, 61=>nil}]}, 48=>{41=>[{41=>:enemy}, {41=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 34=>[{41=>nil, 34=>:enemy}, {41=>nil, 34=>nil}], 27=>[{41=>nil, 34=>nil, 27=>:enemy}, {41=>nil, 34=>nil, 27=>nil}], 20=>[{41=>nil, 34=>nil, 27=>nil, 20=>:enemy}, {41=>nil, 34=>nil, 27=>nil, 20=>nil}], 13=>[{41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>:enemy}, {41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>nil}], 6=>[{41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>:enemy}, {41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>nil}]}, 49=>{40=>[{40=>:enemy}, {40=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 35=>[{42=>nil, 35=>:enemy}, {42=>nil, 35=>nil}], 28=>[{42=>nil, 35=>nil, 28=>:enemy}, {42=>nil, 35=>nil, 28=>nil}], 21=>[{42=>nil, 35=>nil, 28=>nil, 21=>:enemy}, {42=>nil, 35=>nil, 28=>nil, 21=>nil}], 14=>[{42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>:enemy}, {42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil}], 7=>[{42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>nil}]}, 50=>{41=>[{41=>:enemy}, {41=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 32=>[{41=>nil, 32=>:enemy}, {41=>nil, 32=>nil}], 36=>[{43=>nil, 36=>:enemy}, {43=>nil, 36=>nil}], 29=>[{43=>nil, 36=>nil, 29=>:enemy}, {43=>nil, 36=>nil, 29=>nil}], 22=>[{43=>nil, 36=>nil, 29=>nil, 22=>:enemy}, {43=>nil, 36=>nil, 29=>nil, 22=>nil}], 15=>[{43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>:enemy}, {43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>nil}]}, 51=>{42=>[{42=>:enemy}, {42=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 33=>[{42=>nil, 33=>:enemy}, {42=>nil, 33=>nil}], 24=>[{42=>nil, 33=>nil, 24=>:enemy}, {42=>nil, 33=>nil, 24=>nil}], 37=>[{44=>nil, 37=>:enemy}, {44=>nil, 37=>nil}], 30=>[{44=>nil, 37=>nil, 30=>:enemy}, {44=>nil, 37=>nil, 30=>nil}], 23=>[{44=>nil, 37=>nil, 30=>nil, 23=>:enemy}, {44=>nil, 37=>nil, 30=>nil, 23=>nil}]}, 52=>{43=>[{43=>:enemy}, {43=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 34=>[{43=>nil, 34=>:enemy}, {43=>nil, 34=>nil}], 25=>[{43=>nil, 34=>nil, 25=>:enemy}, {43=>nil, 34=>nil, 25=>nil}], 16=>[{43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, {43=>nil, 34=>nil, 25=>nil, 16=>nil}], 38=>[{45=>nil, 38=>:enemy}, {45=>nil, 38=>nil}], 31=>[{45=>nil, 38=>nil, 31=>:enemy}, {45=>nil, 38=>nil, 31=>nil}]}, 53=>{44=>[{44=>:enemy}, {44=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 35=>[{44=>nil, 35=>:enemy}, {44=>nil, 35=>nil}], 26=>[{44=>nil, 35=>nil, 26=>:enemy}, {44=>nil, 35=>nil, 26=>nil}], 17=>[{44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, {44=>nil, 35=>nil, 26=>nil, 17=>nil}], 8=>[{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, {44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}], 39=>[{46=>nil, 39=>:enemy}, {46=>nil, 39=>nil}]}, 54=>{45=>[{45=>:enemy}, {45=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 63=>[{63=>:enemy}, {63=>nil}], 36=>[{45=>nil, 36=>:enemy}, {45=>nil, 36=>nil}], 27=>[{45=>nil, 36=>nil, 27=>:enemy}, {45=>nil, 36=>nil, 27=>nil}], 18=>[{45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, {45=>nil, 36=>nil, 27=>nil, 18=>nil}], 9=>[{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, {45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}], 0=>[{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}]}, 55=>{46=>[{46=>:enemy}, {46=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 37=>[{46=>nil, 37=>:enemy}, {46=>nil, 37=>nil}], 28=>[{46=>nil, 37=>nil, 28=>:enemy}, {46=>nil, 37=>nil, 28=>nil}], 19=>[{46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, {46=>nil, 37=>nil, 28=>nil, 19=>nil}], 10=>[{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, {46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}], 1=>[{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, {46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}]}, 56=>{49=>[{49=>:enemy}, {49=>nil}], 42=>[{49=>nil, 42=>:enemy}, {49=>nil, 42=>nil}], 35=>[{49=>nil, 42=>nil, 35=>:enemy}, {49=>nil, 42=>nil, 35=>nil}], 28=>[{49=>nil, 42=>nil, 35=>nil, 28=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil}], 21=>[{49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil}], 14=>[{49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil}], 7=>[{49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>nil}]}, 57=>{48=>[{48=>:enemy}, {48=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 43=>[{50=>nil, 43=>:enemy}, {50=>nil, 43=>nil}], 36=>[{50=>nil, 43=>nil, 36=>:enemy}, {50=>nil, 43=>nil, 36=>nil}], 29=>[{50=>nil, 43=>nil, 36=>nil, 29=>:enemy}, {50=>nil, 43=>nil, 36=>nil, 29=>nil}], 22=>[{50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>:enemy}, {50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>nil}], 15=>[{50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>:enemy}, {50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>nil}]}, 58=>{49=>[{49=>:enemy}, {49=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 40=>[{49=>nil, 40=>:enemy}, {49=>nil, 40=>nil}], 44=>[{51=>nil, 44=>:enemy}, {51=>nil, 44=>nil}], 37=>[{51=>nil, 44=>nil, 37=>:enemy}, {51=>nil, 44=>nil, 37=>nil}], 30=>[{51=>nil, 44=>nil, 37=>nil, 30=>:enemy}, {51=>nil, 44=>nil, 37=>nil, 30=>nil}], 23=>[{51=>nil, 44=>nil, 37=>nil, 30=>nil, 23=>:enemy}, {51=>nil, 44=>nil, 37=>nil, 30=>nil, 23=>nil}]}, 59=>{50=>[{50=>:enemy}, {50=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 41=>[{50=>nil, 41=>:enemy}, {50=>nil, 41=>nil}], 32=>[{50=>nil, 41=>nil, 32=>:enemy}, {50=>nil, 41=>nil, 32=>nil}], 45=>[{52=>nil, 45=>:enemy}, {52=>nil, 45=>nil}], 38=>[{52=>nil, 45=>nil, 38=>:enemy}, {52=>nil, 45=>nil, 38=>nil}], 31=>[{52=>nil, 45=>nil, 38=>nil, 31=>:enemy}, {52=>nil, 45=>nil, 38=>nil, 31=>nil}]}, 60=>{51=>[{51=>:enemy}, {51=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 42=>[{51=>nil, 42=>:enemy}, {51=>nil, 42=>nil}], 33=>[{51=>nil, 42=>nil, 33=>:enemy}, {51=>nil, 42=>nil, 33=>nil}], 24=>[{51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, {51=>nil, 42=>nil, 33=>nil, 24=>nil}], 46=>[{53=>nil, 46=>:enemy}, {53=>nil, 46=>nil}], 39=>[{53=>nil, 46=>nil, 39=>:enemy}, {53=>nil, 46=>nil, 39=>nil}]}, 61=>{52=>[{52=>:enemy}, {52=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 43=>[{52=>nil, 43=>:enemy}, {52=>nil, 43=>nil}], 34=>[{52=>nil, 43=>nil, 34=>:enemy}, {52=>nil, 43=>nil, 34=>nil}], 25=>[{52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, {52=>nil, 43=>nil, 34=>nil, 25=>nil}], 16=>[{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, {52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}], 47=>[{54=>nil, 47=>:enemy}, {54=>nil, 47=>nil}]}, 62=>{53=>[{53=>:enemy}, {53=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 44=>[{53=>nil, 44=>:enemy}, {53=>nil, 44=>nil}], 35=>[{53=>nil, 44=>nil, 35=>:enemy}, {53=>nil, 44=>nil, 35=>nil}], 26=>[{53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, {53=>nil, 44=>nil, 35=>nil, 26=>nil}], 17=>[{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, {53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}], 8=>[{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, {53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}]}, 63=>{54=>[{54=>:enemy}, {54=>nil}], 45=>[{54=>nil, 45=>:enemy}, {54=>nil, 45=>nil}], 36=>[{54=>nil, 45=>nil, 36=>:enemy}, {54=>nil, 45=>nil, 36=>nil}], 27=>[{54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil}], 18=>[{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}], 9=>[{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}], 0=>[{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}]}}, "c:n"=>{0=>{10=>[{10=>:enemy}, {10=>nil}], 17=>[{17=>:enemy}, {17=>nil}]}, 1=>{11=>[{11=>:enemy}, {11=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 18=>[{18=>:enemy}, {18=>nil}]}, 2=>{8=>[{8=>:enemy}, {8=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 19=>[{19=>:enemy}, {19=>nil}]}, 3=>{9=>[{9=>:enemy}, {9=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 20=>[{20=>:enemy}, {20=>nil}]}, 4=>{10=>[{10=>:enemy}, {10=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 21=>[{21=>:enemy}, {21=>nil}]}, 5=>{11=>[{11=>:enemy}, {11=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 22=>[{22=>:enemy}, {22=>nil}]}, 6=>{12=>[{12=>:enemy}, {12=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 23=>[{23=>:enemy}, {23=>nil}]}, 7=>{13=>[{13=>:enemy}, {13=>nil}], 22=>[{22=>:enemy}, {22=>nil}]}, 8=>{2=>[{2=>:enemy}, {2=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 25=>[{25=>:enemy}, {25=>nil}]}, 9=>{3=>[{3=>:enemy}, {3=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 26=>[{26=>:enemy}, {26=>nil}]}, 10=>{0=>[{0=>:enemy}, {0=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 27=>[{27=>:enemy}, {27=>nil}]}, 11=>{1=>[{1=>:enemy}, {1=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 28=>[{28=>:enemy}, {28=>nil}]}, 12=>{2=>[{2=>:enemy}, {2=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 29=>[{29=>:enemy}, {29=>nil}]}, 13=>{3=>[{3=>:enemy}, {3=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 30=>[{30=>:enemy}, {30=>nil}]}, 14=>{4=>[{4=>:enemy}, {4=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 31=>[{31=>:enemy}, {31=>nil}]}, 15=>{5=>[{5=>:enemy}, {5=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 30=>[{30=>:enemy}, {30=>nil}]}, 16=>{1=>[{1=>:enemy}, {1=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 33=>[{33=>:enemy}, {33=>nil}]}, 17=>{0=>[{0=>:enemy}, {0=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 34=>[{34=>:enemy}, {34=>nil}]}, 18=>{1=>[{1=>:enemy}, {1=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 35=>[{35=>:enemy}, {35=>nil}]}, 19=>{2=>[{2=>:enemy}, {2=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 36=>[{36=>:enemy}, {36=>nil}]}, 20=>{3=>[{3=>:enemy}, {3=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 37=>[{37=>:enemy}, {37=>nil}]}, 21=>{4=>[{4=>:enemy}, {4=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 38=>[{38=>:enemy}, {38=>nil}]}, 22=>{5=>[{5=>:enemy}, {5=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 39=>[{39=>:enemy}, {39=>nil}]}, 23=>{6=>[{6=>:enemy}, {6=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 38=>[{38=>:enemy}, {38=>nil}]}, 24=>{9=>[{9=>:enemy}, {9=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 41=>[{41=>:enemy}, {41=>nil}]}, 25=>{8=>[{8=>:enemy}, {8=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 42=>[{42=>:enemy}, {42=>nil}]}, 26=>{9=>[{9=>:enemy}, {9=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 43=>[{43=>:enemy}, {43=>nil}]}, 27=>{10=>[{10=>:enemy}, {10=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 44=>[{44=>:enemy}, {44=>nil}]}, 28=>{11=>[{11=>:enemy}, {11=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 45=>[{45=>:enemy}, {45=>nil}]}, 29=>{12=>[{12=>:enemy}, {12=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 46=>[{46=>:enemy}, {46=>nil}]}, 30=>{13=>[{13=>:enemy}, {13=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 47=>[{47=>:enemy}, {47=>nil}]}, 31=>{14=>[{14=>:enemy}, {14=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 46=>[{46=>:enemy}, {46=>nil}]}, 32=>{17=>[{17=>:enemy}, {17=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 49=>[{49=>:enemy}, {49=>nil}]}, 33=>{16=>[{16=>:enemy}, {16=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 50=>[{50=>:enemy}, {50=>nil}]}, 34=>{17=>[{17=>:enemy}, {17=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 51=>[{51=>:enemy}, {51=>nil}]}, 35=>{18=>[{18=>:enemy}, {18=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 52=>[{52=>:enemy}, {52=>nil}]}, 36=>{19=>[{19=>:enemy}, {19=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 53=>[{53=>:enemy}, {53=>nil}]}, 37=>{20=>[{20=>:enemy}, {20=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 54=>[{54=>:enemy}, {54=>nil}]}, 38=>{21=>[{21=>:enemy}, {21=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 55=>[{55=>:enemy}, {55=>nil}]}, 39=>{22=>[{22=>:enemy}, {22=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 54=>[{54=>:enemy}, {54=>nil}]}, 40=>{25=>[{25=>:enemy}, {25=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 57=>[{57=>:enemy}, {57=>nil}]}, 41=>{24=>[{24=>:enemy}, {24=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 58=>[{58=>:enemy}, {58=>nil}]}, 42=>{25=>[{25=>:enemy}, {25=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 59=>[{59=>:enemy}, {59=>nil}]}, 43=>{26=>[{26=>:enemy}, {26=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 60=>[{60=>:enemy}, {60=>nil}]}, 44=>{27=>[{27=>:enemy}, {27=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 61=>[{61=>:enemy}, {61=>nil}]}, 45=>{28=>[{28=>:enemy}, {28=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 62=>[{62=>:enemy}, {62=>nil}]}, 46=>{29=>[{29=>:enemy}, {29=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 63=>[{63=>:enemy}, {63=>nil}]}, 47=>{30=>[{30=>:enemy}, {30=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 62=>[{62=>:enemy}, {62=>nil}]}, 48=>{33=>[{33=>:enemy}, {33=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 58=>[{58=>:enemy}, {58=>nil}]}, 49=>{32=>[{32=>:enemy}, {32=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 59=>[{59=>:enemy}, {59=>nil}]}, 50=>{33=>[{33=>:enemy}, {33=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 60=>[{60=>:enemy}, {60=>nil}]}, 51=>{34=>[{34=>:enemy}, {34=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 61=>[{61=>:enemy}, {61=>nil}]}, 52=>{35=>[{35=>:enemy}, {35=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 62=>[{62=>:enemy}, {62=>nil}]}, 53=>{36=>[{36=>:enemy}, {36=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 63=>[{63=>:enemy}, {63=>nil}]}, 54=>{37=>[{37=>:enemy}, {37=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 60=>[{60=>:enemy}, {60=>nil}]}, 55=>{38=>[{38=>:enemy}, {38=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 61=>[{61=>:enemy}, {61=>nil}]}, 56=>{41=>[{41=>:enemy}, {41=>nil}], 50=>[{50=>:enemy}, {50=>nil}]}, 57=>{40=>[{40=>:enemy}, {40=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 51=>[{51=>:enemy}, {51=>nil}]}, 58=>{41=>[{41=>:enemy}, {41=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 52=>[{52=>:enemy}, {52=>nil}]}, 59=>{42=>[{42=>:enemy}, {42=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 53=>[{53=>:enemy}, {53=>nil}]}, 60=>{43=>[{43=>:enemy}, {43=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 54=>[{54=>:enemy}, {54=>nil}]}, 61=>{44=>[{44=>:enemy}, {44=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 55=>[{55=>:enemy}, {55=>nil}]}, 62=>{45=>[{45=>:enemy}, {45=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 52=>[{52=>:enemy}, {52=>nil}]}, 63=>{46=>[{46=>:enemy}, {46=>nil}], 53=>[{53=>:enemy}, {53=>nil}]}}, "c:p"=>{0=>{9=>[{9=>:enemy}], 8=>[{8=>nil}]}, 1=>{8=>[{8=>:enemy}], 10=>[{10=>:enemy}], 9=>[{9=>nil}]}, 2=>{9=>[{9=>:enemy}], 11=>[{11=>:enemy}], 10=>[{10=>nil}]}, 3=>{10=>[{10=>:enemy}], 12=>[{12=>:enemy}], 11=>[{11=>nil}]}, 4=>{11=>[{11=>:enemy}], 13=>[{13=>:enemy}], 12=>[{12=>nil}]}, 5=>{12=>[{12=>:enemy}], 14=>[{14=>:enemy}], 13=>[{13=>nil}]}, 6=>{13=>[{13=>:enemy}], 15=>[{15=>:enemy}], 14=>[{14=>nil}]}, 7=>{14=>[{14=>:enemy}], 15=>[{15=>nil}]}, 8=>{17=>[{17=>:enemy}], 16=>[{16=>nil}]}, 9=>{16=>[{16=>:enemy}], 18=>[{18=>:enemy}], 17=>[{17=>nil}]}, 10=>{17=>[{17=>:enemy}], 19=>[{19=>:enemy}], 18=>[{18=>nil}]}, 11=>{18=>[{18=>:enemy}], 20=>[{20=>:enemy}], 19=>[{19=>nil}]}, 12=>{19=>[{19=>:enemy}], 21=>[{21=>:enemy}], 20=>[{20=>nil}]}, 13=>{20=>[{20=>:enemy}], 22=>[{22=>:enemy}], 21=>[{21=>nil}]}, 14=>{21=>[{21=>:enemy}], 23=>[{23=>:enemy}], 22=>[{22=>nil}]}, 15=>{22=>[{22=>:enemy}], 23=>[{23=>nil}]}, 16=>{25=>[{25=>:enemy}], 24=>[{24=>nil}]}, 17=>{24=>[{24=>:enemy}], 26=>[{26=>:enemy}], 25=>[{25=>nil}]}, 18=>{25=>[{25=>:enemy}], 27=>[{27=>:enemy}], 26=>[{26=>nil}]}, 19=>{26=>[{26=>:enemy}], 28=>[{28=>:enemy}], 27=>[{27=>nil}]}, 20=>{27=>[{27=>:enemy}], 29=>[{29=>:enemy}], 28=>[{28=>nil}]}, 21=>{28=>[{28=>:enemy}], 30=>[{30=>:enemy}], 29=>[{29=>nil}]}, 22=>{29=>[{29=>:enemy}], 31=>[{31=>:enemy}], 30=>[{30=>nil}]}, 23=>{30=>[{30=>:enemy}], 31=>[{31=>nil}]}, 24=>{33=>[{33=>:enemy}], 32=>[{32=>nil}]}, 25=>{32=>[{32=>:enemy}], 34=>[{34=>:enemy}], 33=>[{33=>nil}]}, 26=>{33=>[{33=>:enemy}], 35=>[{35=>:enemy}], 34=>[{34=>nil}]}, 27=>{34=>[{34=>:enemy}], 36=>[{36=>:enemy}], 35=>[{35=>nil}]}, 28=>{35=>[{35=>:enemy}], 37=>[{37=>:enemy}], 36=>[{36=>nil}]}, 29=>{36=>[{36=>:enemy}], 38=>[{38=>:enemy}], 37=>[{37=>nil}]}, 30=>{37=>[{37=>:enemy}], 39=>[{39=>:enemy}], 38=>[{38=>nil}]}, 31=>{38=>[{38=>:enemy}], 39=>[{39=>nil}]}, 32=>{41=>[{41=>:enemy}], 40=>[{40=>nil}]}, 33=>{40=>[{40=>:enemy}], 42=>[{42=>:enemy}], 41=>[{41=>nil}]}, 34=>{41=>[{41=>:enemy}], 43=>[{43=>:enemy}], 42=>[{42=>nil}]}, 35=>{42=>[{42=>:enemy}], 44=>[{44=>:enemy}], 43=>[{43=>nil}]}, 36=>{43=>[{43=>:enemy}], 45=>[{45=>:enemy}], 44=>[{44=>nil}]}, 37=>{44=>[{44=>:enemy}], 46=>[{46=>:enemy}], 45=>[{45=>nil}]}, 38=>{45=>[{45=>:enemy}], 47=>[{47=>:enemy}], 46=>[{46=>nil}]}, 39=>{46=>[{46=>:enemy}], 47=>[{47=>nil}]}, 40=>{49=>[{49=>:enemy}], 48=>[{48=>nil}]}, 41=>{48=>[{48=>:enemy}], 50=>[{50=>:enemy}], 49=>[{49=>nil}]}, 42=>{49=>[{49=>:enemy}], 51=>[{51=>:enemy}], 50=>[{50=>nil}]}, 43=>{50=>[{50=>:enemy}], 52=>[{52=>:enemy}], 51=>[{51=>nil}]}, 44=>{51=>[{51=>:enemy}], 53=>[{53=>:enemy}], 52=>[{52=>nil}]}, 45=>{52=>[{52=>:enemy}], 54=>[{54=>:enemy}], 53=>[{53=>nil}]}, 46=>{53=>[{53=>:enemy}], 55=>[{55=>:enemy}], 54=>[{54=>nil}]}, 47=>{54=>[{54=>:enemy}], 55=>[{55=>nil}]}, 48=>{57=>[{57=>:enemy}], 56=>[{56=>nil}]}, 49=>{56=>[{56=>:enemy}], 58=>[{58=>:enemy}], 57=>[{57=>nil}]}, 50=>{57=>[{57=>:enemy}], 59=>[{59=>:enemy}], 58=>[{58=>nil}]}, 51=>{58=>[{58=>:enemy}], 60=>[{60=>:enemy}], 59=>[{59=>nil}]}, 52=>{59=>[{59=>:enemy}], 61=>[{61=>:enemy}], 60=>[{60=>nil}]}, 53=>{60=>[{60=>:enemy}], 62=>[{62=>:enemy}], 61=>[{61=>nil}]}, 54=>{61=>[{61=>:enemy}], 63=>[{63=>:enemy}], 62=>[{62=>nil}]}, 55=>{62=>[{62=>:enemy}], 63=>[{63=>nil}]}, 56=>{}, 57=>{}, 58=>{}, 59=>{}, 60=>{}, 61=>{}, 62=>{}, 63=>{}}, "c:q"=>{0=>{1=>[{1=>:enemy}, {1=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 2=>[{1=>nil, 2=>:enemy}, {1=>nil, 2=>nil}], 3=>[{1=>nil, 2=>nil, 3=>:enemy}, {1=>nil, 2=>nil, 3=>nil}], 4=>[{1=>nil, 2=>nil, 3=>nil, 4=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil}], 5=>[{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil}], 6=>[{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}], 7=>[{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}], 16=>[{8=>nil, 16=>:enemy}, {8=>nil, 16=>nil}], 24=>[{8=>nil, 16=>nil, 24=>:enemy}, {8=>nil, 16=>nil, 24=>nil}], 32=>[{8=>nil, 16=>nil, 24=>nil, 32=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil}], 40=>[{8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil}], 48=>[{8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil}], 56=>[{8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}], 18=>[{9=>nil, 18=>:enemy}, {9=>nil, 18=>nil}], 27=>[{9=>nil, 18=>nil, 27=>:enemy}, {9=>nil, 18=>nil, 27=>nil}], 36=>[{9=>nil, 18=>nil, 27=>nil, 36=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil}], 45=>[{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil}], 54=>[{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}], 63=>[{9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {9=>nil, 18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 1=>{0=>[{0=>:enemy}, {0=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 3=>[{2=>nil, 3=>:enemy}, {2=>nil, 3=>nil}], 4=>[{2=>nil, 3=>nil, 4=>:enemy}, {2=>nil, 3=>nil, 4=>nil}], 5=>[{2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, {2=>nil, 3=>nil, 4=>nil, 5=>nil}], 6=>[{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, {2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}], 7=>[{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}], 17=>[{9=>nil, 17=>:enemy}, {9=>nil, 17=>nil}], 25=>[{9=>nil, 17=>nil, 25=>:enemy}, {9=>nil, 17=>nil, 25=>nil}], 33=>[{9=>nil, 17=>nil, 25=>nil, 33=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil}], 41=>[{9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil}], 49=>[{9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil}], 57=>[{9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}], 19=>[{10=>nil, 19=>:enemy}, {10=>nil, 19=>nil}], 28=>[{10=>nil, 19=>nil, 28=>:enemy}, {10=>nil, 19=>nil, 28=>nil}], 37=>[{10=>nil, 19=>nil, 28=>nil, 37=>:enemy}, {10=>nil, 19=>nil, 28=>nil, 37=>nil}], 46=>[{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, {10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil}], 55=>[{10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, {10=>nil, 19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}]}, 2=>{1=>[{1=>:enemy}, {1=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 0=>[{1=>nil, 0=>:enemy}, {1=>nil, 0=>nil}], 4=>[{3=>nil, 4=>:enemy}, {3=>nil, 4=>nil}], 5=>[{3=>nil, 4=>nil, 5=>:enemy}, {3=>nil, 4=>nil, 5=>nil}], 6=>[{3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, {3=>nil, 4=>nil, 5=>nil, 6=>nil}], 7=>[{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}], 16=>[{9=>nil, 16=>:enemy}, {9=>nil, 16=>nil}], 18=>[{10=>nil, 18=>:enemy}, {10=>nil, 18=>nil}], 26=>[{10=>nil, 18=>nil, 26=>:enemy}, {10=>nil, 18=>nil, 26=>nil}], 34=>[{10=>nil, 18=>nil, 26=>nil, 34=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil}], 42=>[{10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil}], 50=>[{10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil}], 58=>[{10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>nil}], 20=>[{11=>nil, 20=>:enemy}, {11=>nil, 20=>nil}], 29=>[{11=>nil, 20=>nil, 29=>:enemy}, {11=>nil, 20=>nil, 29=>nil}], 38=>[{11=>nil, 20=>nil, 29=>nil, 38=>:enemy}, {11=>nil, 20=>nil, 29=>nil, 38=>nil}], 47=>[{11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, {11=>nil, 20=>nil, 29=>nil, 38=>nil, 47=>nil}]}, 3=>{2=>[{2=>:enemy}, {2=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 1=>[{2=>nil, 1=>:enemy}, {2=>nil, 1=>nil}], 0=>[{2=>nil, 1=>nil, 0=>:enemy}, {2=>nil, 1=>nil, 0=>nil}], 5=>[{4=>nil, 5=>:enemy}, {4=>nil, 5=>nil}], 6=>[{4=>nil, 5=>nil, 6=>:enemy}, {4=>nil, 5=>nil, 6=>nil}], 7=>[{4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {4=>nil, 5=>nil, 6=>nil, 7=>nil}], 17=>[{10=>nil, 17=>:enemy}, {10=>nil, 17=>nil}], 24=>[{10=>nil, 17=>nil, 24=>:enemy}, {10=>nil, 17=>nil, 24=>nil}], 19=>[{11=>nil, 19=>:enemy}, {11=>nil, 19=>nil}], 27=>[{11=>nil, 19=>nil, 27=>:enemy}, {11=>nil, 19=>nil, 27=>nil}], 35=>[{11=>nil, 19=>nil, 27=>nil, 35=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil}], 43=>[{11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil}], 51=>[{11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil}], 59=>[{11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>nil}], 21=>[{12=>nil, 21=>:enemy}, {12=>nil, 21=>nil}], 30=>[{12=>nil, 21=>nil, 30=>:enemy}, {12=>nil, 21=>nil, 30=>nil}], 39=>[{12=>nil, 21=>nil, 30=>nil, 39=>:enemy}, {12=>nil, 21=>nil, 30=>nil, 39=>nil}]}, 4=>{3=>[{3=>:enemy}, {3=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 2=>[{3=>nil, 2=>:enemy}, {3=>nil, 2=>nil}], 1=>[{3=>nil, 2=>nil, 1=>:enemy}, {3=>nil, 2=>nil, 1=>nil}], 0=>[{3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {3=>nil, 2=>nil, 1=>nil, 0=>nil}], 6=>[{5=>nil, 6=>:enemy}, {5=>nil, 6=>nil}], 7=>[{5=>nil, 6=>nil, 7=>:enemy}, {5=>nil, 6=>nil, 7=>nil}], 18=>[{11=>nil, 18=>:enemy}, {11=>nil, 18=>nil}], 25=>[{11=>nil, 18=>nil, 25=>:enemy}, {11=>nil, 18=>nil, 25=>nil}], 32=>[{11=>nil, 18=>nil, 25=>nil, 32=>:enemy}, {11=>nil, 18=>nil, 25=>nil, 32=>nil}], 20=>[{12=>nil, 20=>:enemy}, {12=>nil, 20=>nil}], 28=>[{12=>nil, 20=>nil, 28=>:enemy}, {12=>nil, 20=>nil, 28=>nil}], 36=>[{12=>nil, 20=>nil, 28=>nil, 36=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil}], 44=>[{12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil}], 52=>[{12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil}], 60=>[{12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>nil}], 22=>[{13=>nil, 22=>:enemy}, {13=>nil, 22=>nil}], 31=>[{13=>nil, 22=>nil, 31=>:enemy}, {13=>nil, 22=>nil, 31=>nil}]}, 5=>{4=>[{4=>:enemy}, {4=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 3=>[{4=>nil, 3=>:enemy}, {4=>nil, 3=>nil}], 2=>[{4=>nil, 3=>nil, 2=>:enemy}, {4=>nil, 3=>nil, 2=>nil}], 1=>[{4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, {4=>nil, 3=>nil, 2=>nil, 1=>nil}], 0=>[{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}], 7=>[{6=>nil, 7=>:enemy}, {6=>nil, 7=>nil}], 19=>[{12=>nil, 19=>:enemy}, {12=>nil, 19=>nil}], 26=>[{12=>nil, 19=>nil, 26=>:enemy}, {12=>nil, 19=>nil, 26=>nil}], 33=>[{12=>nil, 19=>nil, 26=>nil, 33=>:enemy}, {12=>nil, 19=>nil, 26=>nil, 33=>nil}], 40=>[{12=>nil, 19=>nil, 26=>nil, 33=>nil, 40=>:enemy}, {12=>nil, 19=>nil, 26=>nil, 33=>nil, 40=>nil}], 21=>[{13=>nil, 21=>:enemy}, {13=>nil, 21=>nil}], 29=>[{13=>nil, 21=>nil, 29=>:enemy}, {13=>nil, 21=>nil, 29=>nil}], 37=>[{13=>nil, 21=>nil, 29=>nil, 37=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil}], 45=>[{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil}], 53=>[{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil}], 61=>[{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>nil}], 23=>[{14=>nil, 23=>:enemy}, {14=>nil, 23=>nil}]}, 6=>{5=>[{5=>:enemy}, {5=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 4=>[{5=>nil, 4=>:enemy}, {5=>nil, 4=>nil}], 3=>[{5=>nil, 4=>nil, 3=>:enemy}, {5=>nil, 4=>nil, 3=>nil}], 2=>[{5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, {5=>nil, 4=>nil, 3=>nil, 2=>nil}], 1=>[{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, {5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}], 0=>[{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}], 20=>[{13=>nil, 20=>:enemy}, {13=>nil, 20=>nil}], 27=>[{13=>nil, 20=>nil, 27=>:enemy}, {13=>nil, 20=>nil, 27=>nil}], 34=>[{13=>nil, 20=>nil, 27=>nil, 34=>:enemy}, {13=>nil, 20=>nil, 27=>nil, 34=>nil}], 41=>[{13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>:enemy}, {13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>nil}], 48=>[{13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>:enemy}, {13=>nil, 20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>nil}], 22=>[{14=>nil, 22=>:enemy}, {14=>nil, 22=>nil}], 30=>[{14=>nil, 22=>nil, 30=>:enemy}, {14=>nil, 22=>nil, 30=>nil}], 38=>[{14=>nil, 22=>nil, 30=>nil, 38=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil}], 46=>[{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil}], 54=>[{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}], 62=>[{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 7=>{6=>[{6=>:enemy}, {6=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 5=>[{6=>nil, 5=>:enemy}, {6=>nil, 5=>nil}], 4=>[{6=>nil, 5=>nil, 4=>:enemy}, {6=>nil, 5=>nil, 4=>nil}], 3=>[{6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil}], 2=>[{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}], 1=>[{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}], 0=>[{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}], 21=>[{14=>nil, 21=>:enemy}, {14=>nil, 21=>nil}], 28=>[{14=>nil, 21=>nil, 28=>:enemy}, {14=>nil, 21=>nil, 28=>nil}], 35=>[{14=>nil, 21=>nil, 28=>nil, 35=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil}], 42=>[{14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil}], 49=>[{14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil}], 56=>[{14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {14=>nil, 21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>nil}], 23=>[{15=>nil, 23=>:enemy}, {15=>nil, 23=>nil}], 31=>[{15=>nil, 23=>nil, 31=>:enemy}, {15=>nil, 23=>nil, 31=>nil}], 39=>[{15=>nil, 23=>nil, 31=>nil, 39=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil}], 47=>[{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil}], 55=>[{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}], 63=>[{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 8=>{0=>[{0=>:enemy}, {0=>nil}], 1=>[{1=>:enemy}, {1=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 10=>[{9=>nil, 10=>:enemy}, {9=>nil, 10=>nil}], 11=>[{9=>nil, 10=>nil, 11=>:enemy}, {9=>nil, 10=>nil, 11=>nil}], 12=>[{9=>nil, 10=>nil, 11=>nil, 12=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil}], 13=>[{9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil}], 14=>[{9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}], 15=>[{9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}], 24=>[{16=>nil, 24=>:enemy}, {16=>nil, 24=>nil}], 32=>[{16=>nil, 24=>nil, 32=>:enemy}, {16=>nil, 24=>nil, 32=>nil}], 40=>[{16=>nil, 24=>nil, 32=>nil, 40=>:enemy}, {16=>nil, 24=>nil, 32=>nil, 40=>nil}], 48=>[{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, {16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil}], 56=>[{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}], 26=>[{17=>nil, 26=>:enemy}, {17=>nil, 26=>nil}], 35=>[{17=>nil, 26=>nil, 35=>:enemy}, {17=>nil, 26=>nil, 35=>nil}], 44=>[{17=>nil, 26=>nil, 35=>nil, 44=>:enemy}, {17=>nil, 26=>nil, 35=>nil, 44=>nil}], 53=>[{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, {17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil}], 62=>[{17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, {17=>nil, 26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}]}, 9=>{0=>[{0=>:enemy}, {0=>nil}], 1=>[{1=>:enemy}, {1=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 11=>[{10=>nil, 11=>:enemy}, {10=>nil, 11=>nil}], 12=>[{10=>nil, 11=>nil, 12=>:enemy}, {10=>nil, 11=>nil, 12=>nil}], 13=>[{10=>nil, 11=>nil, 12=>nil, 13=>:enemy}, {10=>nil, 11=>nil, 12=>nil, 13=>nil}], 14=>[{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, {10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}], 15=>[{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}], 25=>[{17=>nil, 25=>:enemy}, {17=>nil, 25=>nil}], 33=>[{17=>nil, 25=>nil, 33=>:enemy}, {17=>nil, 25=>nil, 33=>nil}], 41=>[{17=>nil, 25=>nil, 33=>nil, 41=>:enemy}, {17=>nil, 25=>nil, 33=>nil, 41=>nil}], 49=>[{17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, {17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil}], 57=>[{17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}], 27=>[{18=>nil, 27=>:enemy}, {18=>nil, 27=>nil}], 36=>[{18=>nil, 27=>nil, 36=>:enemy}, {18=>nil, 27=>nil, 36=>nil}], 45=>[{18=>nil, 27=>nil, 36=>nil, 45=>:enemy}, {18=>nil, 27=>nil, 36=>nil, 45=>nil}], 54=>[{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, {18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil}], 63=>[{18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {18=>nil, 27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 10=>{1=>[{1=>:enemy}, {1=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 8=>[{9=>nil, 8=>:enemy}, {9=>nil, 8=>nil}], 12=>[{11=>nil, 12=>:enemy}, {11=>nil, 12=>nil}], 13=>[{11=>nil, 12=>nil, 13=>:enemy}, {11=>nil, 12=>nil, 13=>nil}], 14=>[{11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, {11=>nil, 12=>nil, 13=>nil, 14=>nil}], 15=>[{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}], 24=>[{17=>nil, 24=>:enemy}, {17=>nil, 24=>nil}], 26=>[{18=>nil, 26=>:enemy}, {18=>nil, 26=>nil}], 34=>[{18=>nil, 26=>nil, 34=>:enemy}, {18=>nil, 26=>nil, 34=>nil}], 42=>[{18=>nil, 26=>nil, 34=>nil, 42=>:enemy}, {18=>nil, 26=>nil, 34=>nil, 42=>nil}], 50=>[{18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>:enemy}, {18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil}], 58=>[{18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>nil}], 28=>[{19=>nil, 28=>:enemy}, {19=>nil, 28=>nil}], 37=>[{19=>nil, 28=>nil, 37=>:enemy}, {19=>nil, 28=>nil, 37=>nil}], 46=>[{19=>nil, 28=>nil, 37=>nil, 46=>:enemy}, {19=>nil, 28=>nil, 37=>nil, 46=>nil}], 55=>[{19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, {19=>nil, 28=>nil, 37=>nil, 46=>nil, 55=>nil}]}, 11=>{2=>[{2=>:enemy}, {2=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 9=>[{10=>nil, 9=>:enemy}, {10=>nil, 9=>nil}], 8=>[{10=>nil, 9=>nil, 8=>:enemy}, {10=>nil, 9=>nil, 8=>nil}], 13=>[{12=>nil, 13=>:enemy}, {12=>nil, 13=>nil}], 14=>[{12=>nil, 13=>nil, 14=>:enemy}, {12=>nil, 13=>nil, 14=>nil}], 15=>[{12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {12=>nil, 13=>nil, 14=>nil, 15=>nil}], 25=>[{18=>nil, 25=>:enemy}, {18=>nil, 25=>nil}], 32=>[{18=>nil, 25=>nil, 32=>:enemy}, {18=>nil, 25=>nil, 32=>nil}], 27=>[{19=>nil, 27=>:enemy}, {19=>nil, 27=>nil}], 35=>[{19=>nil, 27=>nil, 35=>:enemy}, {19=>nil, 27=>nil, 35=>nil}], 43=>[{19=>nil, 27=>nil, 35=>nil, 43=>:enemy}, {19=>nil, 27=>nil, 35=>nil, 43=>nil}], 51=>[{19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>:enemy}, {19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil}], 59=>[{19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>nil}], 29=>[{20=>nil, 29=>:enemy}, {20=>nil, 29=>nil}], 38=>[{20=>nil, 29=>nil, 38=>:enemy}, {20=>nil, 29=>nil, 38=>nil}], 47=>[{20=>nil, 29=>nil, 38=>nil, 47=>:enemy}, {20=>nil, 29=>nil, 38=>nil, 47=>nil}]}, 12=>{3=>[{3=>:enemy}, {3=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 10=>[{11=>nil, 10=>:enemy}, {11=>nil, 10=>nil}], 9=>[{11=>nil, 10=>nil, 9=>:enemy}, {11=>nil, 10=>nil, 9=>nil}], 8=>[{11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {11=>nil, 10=>nil, 9=>nil, 8=>nil}], 14=>[{13=>nil, 14=>:enemy}, {13=>nil, 14=>nil}], 15=>[{13=>nil, 14=>nil, 15=>:enemy}, {13=>nil, 14=>nil, 15=>nil}], 26=>[{19=>nil, 26=>:enemy}, {19=>nil, 26=>nil}], 33=>[{19=>nil, 26=>nil, 33=>:enemy}, {19=>nil, 26=>nil, 33=>nil}], 40=>[{19=>nil, 26=>nil, 33=>nil, 40=>:enemy}, {19=>nil, 26=>nil, 33=>nil, 40=>nil}], 28=>[{20=>nil, 28=>:enemy}, {20=>nil, 28=>nil}], 36=>[{20=>nil, 28=>nil, 36=>:enemy}, {20=>nil, 28=>nil, 36=>nil}], 44=>[{20=>nil, 28=>nil, 36=>nil, 44=>:enemy}, {20=>nil, 28=>nil, 36=>nil, 44=>nil}], 52=>[{20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>:enemy}, {20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil}], 60=>[{20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>nil}], 30=>[{21=>nil, 30=>:enemy}, {21=>nil, 30=>nil}], 39=>[{21=>nil, 30=>nil, 39=>:enemy}, {21=>nil, 30=>nil, 39=>nil}]}, 13=>{4=>[{4=>:enemy}, {4=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 11=>[{12=>nil, 11=>:enemy}, {12=>nil, 11=>nil}], 10=>[{12=>nil, 11=>nil, 10=>:enemy}, {12=>nil, 11=>nil, 10=>nil}], 9=>[{12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, {12=>nil, 11=>nil, 10=>nil, 9=>nil}], 8=>[{12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>nil}], 15=>[{14=>nil, 15=>:enemy}, {14=>nil, 15=>nil}], 27=>[{20=>nil, 27=>:enemy}, {20=>nil, 27=>nil}], 34=>[{20=>nil, 27=>nil, 34=>:enemy}, {20=>nil, 27=>nil, 34=>nil}], 41=>[{20=>nil, 27=>nil, 34=>nil, 41=>:enemy}, {20=>nil, 27=>nil, 34=>nil, 41=>nil}], 48=>[{20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>:enemy}, {20=>nil, 27=>nil, 34=>nil, 41=>nil, 48=>nil}], 29=>[{21=>nil, 29=>:enemy}, {21=>nil, 29=>nil}], 37=>[{21=>nil, 29=>nil, 37=>:enemy}, {21=>nil, 29=>nil, 37=>nil}], 45=>[{21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, {21=>nil, 29=>nil, 37=>nil, 45=>nil}], 53=>[{21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>:enemy}, {21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil}], 61=>[{21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>nil}], 31=>[{22=>nil, 31=>:enemy}, {22=>nil, 31=>nil}]}, 14=>{5=>[{5=>:enemy}, {5=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 12=>[{13=>nil, 12=>:enemy}, {13=>nil, 12=>nil}], 11=>[{13=>nil, 12=>nil, 11=>:enemy}, {13=>nil, 12=>nil, 11=>nil}], 10=>[{13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, {13=>nil, 12=>nil, 11=>nil, 10=>nil}], 9=>[{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, {13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}], 8=>[{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>nil}], 28=>[{21=>nil, 28=>:enemy}, {21=>nil, 28=>nil}], 35=>[{21=>nil, 28=>nil, 35=>:enemy}, {21=>nil, 28=>nil, 35=>nil}], 42=>[{21=>nil, 28=>nil, 35=>nil, 42=>:enemy}, {21=>nil, 28=>nil, 35=>nil, 42=>nil}], 49=>[{21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>:enemy}, {21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil}], 56=>[{21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {21=>nil, 28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>nil}], 30=>[{22=>nil, 30=>:enemy}, {22=>nil, 30=>nil}], 38=>[{22=>nil, 30=>nil, 38=>:enemy}, {22=>nil, 30=>nil, 38=>nil}], 46=>[{22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, {22=>nil, 30=>nil, 38=>nil, 46=>nil}], 54=>[{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, {22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}], 62=>[{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 15=>{6=>[{6=>:enemy}, {6=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 13=>[{14=>nil, 13=>:enemy}, {14=>nil, 13=>nil}], 12=>[{14=>nil, 13=>nil, 12=>:enemy}, {14=>nil, 13=>nil, 12=>nil}], 11=>[{14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil}], 10=>[{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}], 9=>[{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}], 8=>[{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>nil}], 29=>[{22=>nil, 29=>:enemy}, {22=>nil, 29=>nil}], 36=>[{22=>nil, 29=>nil, 36=>:enemy}, {22=>nil, 29=>nil, 36=>nil}], 43=>[{22=>nil, 29=>nil, 36=>nil, 43=>:enemy}, {22=>nil, 29=>nil, 36=>nil, 43=>nil}], 50=>[{22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>:enemy}, {22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>nil}], 57=>[{22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>:enemy}, {22=>nil, 29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>nil}], 31=>[{23=>nil, 31=>:enemy}, {23=>nil, 31=>nil}], 39=>[{23=>nil, 31=>nil, 39=>:enemy}, {23=>nil, 31=>nil, 39=>nil}], 47=>[{23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, {23=>nil, 31=>nil, 39=>nil, 47=>nil}], 55=>[{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, {23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}], 63=>[{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 16=>{8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 0=>[{8=>nil, 0=>:enemy}, {8=>nil, 0=>nil}], 2=>[{9=>nil, 2=>:enemy}, {9=>nil, 2=>nil}], 18=>[{17=>nil, 18=>:enemy}, {17=>nil, 18=>nil}], 19=>[{17=>nil, 18=>nil, 19=>:enemy}, {17=>nil, 18=>nil, 19=>nil}], 20=>[{17=>nil, 18=>nil, 19=>nil, 20=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil}], 21=>[{17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil}], 22=>[{17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil}], 23=>[{17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}], 32=>[{24=>nil, 32=>:enemy}, {24=>nil, 32=>nil}], 40=>[{24=>nil, 32=>nil, 40=>:enemy}, {24=>nil, 32=>nil, 40=>nil}], 48=>[{24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, {24=>nil, 32=>nil, 40=>nil, 48=>nil}], 56=>[{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}], 34=>[{25=>nil, 34=>:enemy}, {25=>nil, 34=>nil}], 43=>[{25=>nil, 34=>nil, 43=>:enemy}, {25=>nil, 34=>nil, 43=>nil}], 52=>[{25=>nil, 34=>nil, 43=>nil, 52=>:enemy}, {25=>nil, 34=>nil, 43=>nil, 52=>nil}], 61=>[{25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, {25=>nil, 34=>nil, 43=>nil, 52=>nil, 61=>nil}]}, 17=>{8=>[{8=>:enemy}, {8=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 1=>[{9=>nil, 1=>:enemy}, {9=>nil, 1=>nil}], 3=>[{10=>nil, 3=>:enemy}, {10=>nil, 3=>nil}], 19=>[{18=>nil, 19=>:enemy}, {18=>nil, 19=>nil}], 20=>[{18=>nil, 19=>nil, 20=>:enemy}, {18=>nil, 19=>nil, 20=>nil}], 21=>[{18=>nil, 19=>nil, 20=>nil, 21=>:enemy}, {18=>nil, 19=>nil, 20=>nil, 21=>nil}], 22=>[{18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, {18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil}], 23=>[{18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}], 33=>[{25=>nil, 33=>:enemy}, {25=>nil, 33=>nil}], 41=>[{25=>nil, 33=>nil, 41=>:enemy}, {25=>nil, 33=>nil, 41=>nil}], 49=>[{25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, {25=>nil, 33=>nil, 41=>nil, 49=>nil}], 57=>[{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}], 35=>[{26=>nil, 35=>:enemy}, {26=>nil, 35=>nil}], 44=>[{26=>nil, 35=>nil, 44=>:enemy}, {26=>nil, 35=>nil, 44=>nil}], 53=>[{26=>nil, 35=>nil, 44=>nil, 53=>:enemy}, {26=>nil, 35=>nil, 44=>nil, 53=>nil}], 62=>[{26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, {26=>nil, 35=>nil, 44=>nil, 53=>nil, 62=>nil}]}, 18=>{9=>[{9=>:enemy}, {9=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 0=>[{9=>nil, 0=>:enemy}, {9=>nil, 0=>nil}], 2=>[{10=>nil, 2=>:enemy}, {10=>nil, 2=>nil}], 4=>[{11=>nil, 4=>:enemy}, {11=>nil, 4=>nil}], 16=>[{17=>nil, 16=>:enemy}, {17=>nil, 16=>nil}], 20=>[{19=>nil, 20=>:enemy}, {19=>nil, 20=>nil}], 21=>[{19=>nil, 20=>nil, 21=>:enemy}, {19=>nil, 20=>nil, 21=>nil}], 22=>[{19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, {19=>nil, 20=>nil, 21=>nil, 22=>nil}], 23=>[{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}], 32=>[{25=>nil, 32=>:enemy}, {25=>nil, 32=>nil}], 34=>[{26=>nil, 34=>:enemy}, {26=>nil, 34=>nil}], 42=>[{26=>nil, 34=>nil, 42=>:enemy}, {26=>nil, 34=>nil, 42=>nil}], 50=>[{26=>nil, 34=>nil, 42=>nil, 50=>:enemy}, {26=>nil, 34=>nil, 42=>nil, 50=>nil}], 58=>[{26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>nil}], 36=>[{27=>nil, 36=>:enemy}, {27=>nil, 36=>nil}], 45=>[{27=>nil, 36=>nil, 45=>:enemy}, {27=>nil, 36=>nil, 45=>nil}], 54=>[{27=>nil, 36=>nil, 45=>nil, 54=>:enemy}, {27=>nil, 36=>nil, 45=>nil, 54=>nil}], 63=>[{27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {27=>nil, 36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 19=>{10=>[{10=>:enemy}, {10=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 1=>[{10=>nil, 1=>:enemy}, {10=>nil, 1=>nil}], 3=>[{11=>nil, 3=>:enemy}, {11=>nil, 3=>nil}], 5=>[{12=>nil, 5=>:enemy}, {12=>nil, 5=>nil}], 17=>[{18=>nil, 17=>:enemy}, {18=>nil, 17=>nil}], 16=>[{18=>nil, 17=>nil, 16=>:enemy}, {18=>nil, 17=>nil, 16=>nil}], 21=>[{20=>nil, 21=>:enemy}, {20=>nil, 21=>nil}], 22=>[{20=>nil, 21=>nil, 22=>:enemy}, {20=>nil, 21=>nil, 22=>nil}], 23=>[{20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {20=>nil, 21=>nil, 22=>nil, 23=>nil}], 33=>[{26=>nil, 33=>:enemy}, {26=>nil, 33=>nil}], 40=>[{26=>nil, 33=>nil, 40=>:enemy}, {26=>nil, 33=>nil, 40=>nil}], 35=>[{27=>nil, 35=>:enemy}, {27=>nil, 35=>nil}], 43=>[{27=>nil, 35=>nil, 43=>:enemy}, {27=>nil, 35=>nil, 43=>nil}], 51=>[{27=>nil, 35=>nil, 43=>nil, 51=>:enemy}, {27=>nil, 35=>nil, 43=>nil, 51=>nil}], 59=>[{27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>nil}], 37=>[{28=>nil, 37=>:enemy}, {28=>nil, 37=>nil}], 46=>[{28=>nil, 37=>nil, 46=>:enemy}, {28=>nil, 37=>nil, 46=>nil}], 55=>[{28=>nil, 37=>nil, 46=>nil, 55=>:enemy}, {28=>nil, 37=>nil, 46=>nil, 55=>nil}]}, 20=>{11=>[{11=>:enemy}, {11=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 2=>[{11=>nil, 2=>:enemy}, {11=>nil, 2=>nil}], 4=>[{12=>nil, 4=>:enemy}, {12=>nil, 4=>nil}], 6=>[{13=>nil, 6=>:enemy}, {13=>nil, 6=>nil}], 18=>[{19=>nil, 18=>:enemy}, {19=>nil, 18=>nil}], 17=>[{19=>nil, 18=>nil, 17=>:enemy}, {19=>nil, 18=>nil, 17=>nil}], 16=>[{19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {19=>nil, 18=>nil, 17=>nil, 16=>nil}], 22=>[{21=>nil, 22=>:enemy}, {21=>nil, 22=>nil}], 23=>[{21=>nil, 22=>nil, 23=>:enemy}, {21=>nil, 22=>nil, 23=>nil}], 34=>[{27=>nil, 34=>:enemy}, {27=>nil, 34=>nil}], 41=>[{27=>nil, 34=>nil, 41=>:enemy}, {27=>nil, 34=>nil, 41=>nil}], 48=>[{27=>nil, 34=>nil, 41=>nil, 48=>:enemy}, {27=>nil, 34=>nil, 41=>nil, 48=>nil}], 36=>[{28=>nil, 36=>:enemy}, {28=>nil, 36=>nil}], 44=>[{28=>nil, 36=>nil, 44=>:enemy}, {28=>nil, 36=>nil, 44=>nil}], 52=>[{28=>nil, 36=>nil, 44=>nil, 52=>:enemy}, {28=>nil, 36=>nil, 44=>nil, 52=>nil}], 60=>[{28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>nil}], 38=>[{29=>nil, 38=>:enemy}, {29=>nil, 38=>nil}], 47=>[{29=>nil, 38=>nil, 47=>:enemy}, {29=>nil, 38=>nil, 47=>nil}]}, 21=>{12=>[{12=>:enemy}, {12=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 3=>[{12=>nil, 3=>:enemy}, {12=>nil, 3=>nil}], 5=>[{13=>nil, 5=>:enemy}, {13=>nil, 5=>nil}], 7=>[{14=>nil, 7=>:enemy}, {14=>nil, 7=>nil}], 19=>[{20=>nil, 19=>:enemy}, {20=>nil, 19=>nil}], 18=>[{20=>nil, 19=>nil, 18=>:enemy}, {20=>nil, 19=>nil, 18=>nil}], 17=>[{20=>nil, 19=>nil, 18=>nil, 17=>:enemy}, {20=>nil, 19=>nil, 18=>nil, 17=>nil}], 16=>[{20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>nil}], 23=>[{22=>nil, 23=>:enemy}, {22=>nil, 23=>nil}], 35=>[{28=>nil, 35=>:enemy}, {28=>nil, 35=>nil}], 42=>[{28=>nil, 35=>nil, 42=>:enemy}, {28=>nil, 35=>nil, 42=>nil}], 49=>[{28=>nil, 35=>nil, 42=>nil, 49=>:enemy}, {28=>nil, 35=>nil, 42=>nil, 49=>nil}], 56=>[{28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {28=>nil, 35=>nil, 42=>nil, 49=>nil, 56=>nil}], 37=>[{29=>nil, 37=>:enemy}, {29=>nil, 37=>nil}], 45=>[{29=>nil, 37=>nil, 45=>:enemy}, {29=>nil, 37=>nil, 45=>nil}], 53=>[{29=>nil, 37=>nil, 45=>nil, 53=>:enemy}, {29=>nil, 37=>nil, 45=>nil, 53=>nil}], 61=>[{29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>nil}], 39=>[{30=>nil, 39=>:enemy}, {30=>nil, 39=>nil}]}, 22=>{13=>[{13=>:enemy}, {13=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 4=>[{13=>nil, 4=>:enemy}, {13=>nil, 4=>nil}], 6=>[{14=>nil, 6=>:enemy}, {14=>nil, 6=>nil}], 20=>[{21=>nil, 20=>:enemy}, {21=>nil, 20=>nil}], 19=>[{21=>nil, 20=>nil, 19=>:enemy}, {21=>nil, 20=>nil, 19=>nil}], 18=>[{21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, {21=>nil, 20=>nil, 19=>nil, 18=>nil}], 17=>[{21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>:enemy}, {21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil}], 16=>[{21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>nil}], 36=>[{29=>nil, 36=>:enemy}, {29=>nil, 36=>nil}], 43=>[{29=>nil, 36=>nil, 43=>:enemy}, {29=>nil, 36=>nil, 43=>nil}], 50=>[{29=>nil, 36=>nil, 43=>nil, 50=>:enemy}, {29=>nil, 36=>nil, 43=>nil, 50=>nil}], 57=>[{29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>:enemy}, {29=>nil, 36=>nil, 43=>nil, 50=>nil, 57=>nil}], 38=>[{30=>nil, 38=>:enemy}, {30=>nil, 38=>nil}], 46=>[{30=>nil, 38=>nil, 46=>:enemy}, {30=>nil, 38=>nil, 46=>nil}], 54=>[{30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, {30=>nil, 38=>nil, 46=>nil, 54=>nil}], 62=>[{30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 23=>{14=>[{14=>:enemy}, {14=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 5=>[{14=>nil, 5=>:enemy}, {14=>nil, 5=>nil}], 7=>[{15=>nil, 7=>:enemy}, {15=>nil, 7=>nil}], 21=>[{22=>nil, 21=>:enemy}, {22=>nil, 21=>nil}], 20=>[{22=>nil, 21=>nil, 20=>:enemy}, {22=>nil, 21=>nil, 20=>nil}], 19=>[{22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil}], 18=>[{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}], 17=>[{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil}], 16=>[{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>nil}], 37=>[{30=>nil, 37=>:enemy}, {30=>nil, 37=>nil}], 44=>[{30=>nil, 37=>nil, 44=>:enemy}, {30=>nil, 37=>nil, 44=>nil}], 51=>[{30=>nil, 37=>nil, 44=>nil, 51=>:enemy}, {30=>nil, 37=>nil, 44=>nil, 51=>nil}], 58=>[{30=>nil, 37=>nil, 44=>nil, 51=>nil, 58=>:enemy}, {30=>nil, 37=>nil, 44=>nil, 51=>nil, 58=>nil}], 39=>[{31=>nil, 39=>:enemy}, {31=>nil, 39=>nil}], 47=>[{31=>nil, 39=>nil, 47=>:enemy}, {31=>nil, 39=>nil, 47=>nil}], 55=>[{31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, {31=>nil, 39=>nil, 47=>nil, 55=>nil}], 63=>[{31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 24=>{16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 8=>[{16=>nil, 8=>:enemy}, {16=>nil, 8=>nil}], 0=>[{16=>nil, 8=>nil, 0=>:enemy}, {16=>nil, 8=>nil, 0=>nil}], 10=>[{17=>nil, 10=>:enemy}, {17=>nil, 10=>nil}], 3=>[{17=>nil, 10=>nil, 3=>:enemy}, {17=>nil, 10=>nil, 3=>nil}], 26=>[{25=>nil, 26=>:enemy}, {25=>nil, 26=>nil}], 27=>[{25=>nil, 26=>nil, 27=>:enemy}, {25=>nil, 26=>nil, 27=>nil}], 28=>[{25=>nil, 26=>nil, 27=>nil, 28=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil}], 29=>[{25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil}], 30=>[{25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil}], 31=>[{25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>nil}], 40=>[{32=>nil, 40=>:enemy}, {32=>nil, 40=>nil}], 48=>[{32=>nil, 40=>nil, 48=>:enemy}, {32=>nil, 40=>nil, 48=>nil}], 56=>[{32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {32=>nil, 40=>nil, 48=>nil, 56=>nil}], 42=>[{33=>nil, 42=>:enemy}, {33=>nil, 42=>nil}], 51=>[{33=>nil, 42=>nil, 51=>:enemy}, {33=>nil, 42=>nil, 51=>nil}], 60=>[{33=>nil, 42=>nil, 51=>nil, 60=>:enemy}, {33=>nil, 42=>nil, 51=>nil, 60=>nil}]}, 25=>{16=>[{16=>:enemy}, {16=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 9=>[{17=>nil, 9=>:enemy}, {17=>nil, 9=>nil}], 1=>[{17=>nil, 9=>nil, 1=>:enemy}, {17=>nil, 9=>nil, 1=>nil}], 11=>[{18=>nil, 11=>:enemy}, {18=>nil, 11=>nil}], 4=>[{18=>nil, 11=>nil, 4=>:enemy}, {18=>nil, 11=>nil, 4=>nil}], 27=>[{26=>nil, 27=>:enemy}, {26=>nil, 27=>nil}], 28=>[{26=>nil, 27=>nil, 28=>:enemy}, {26=>nil, 27=>nil, 28=>nil}], 29=>[{26=>nil, 27=>nil, 28=>nil, 29=>:enemy}, {26=>nil, 27=>nil, 28=>nil, 29=>nil}], 30=>[{26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>:enemy}, {26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil}], 31=>[{26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>nil}], 41=>[{33=>nil, 41=>:enemy}, {33=>nil, 41=>nil}], 49=>[{33=>nil, 41=>nil, 49=>:enemy}, {33=>nil, 41=>nil, 49=>nil}], 57=>[{33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {33=>nil, 41=>nil, 49=>nil, 57=>nil}], 43=>[{34=>nil, 43=>:enemy}, {34=>nil, 43=>nil}], 52=>[{34=>nil, 43=>nil, 52=>:enemy}, {34=>nil, 43=>nil, 52=>nil}], 61=>[{34=>nil, 43=>nil, 52=>nil, 61=>:enemy}, {34=>nil, 43=>nil, 52=>nil, 61=>nil}]}, 26=>{17=>[{17=>:enemy}, {17=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 8=>[{17=>nil, 8=>:enemy}, {17=>nil, 8=>nil}], 10=>[{18=>nil, 10=>:enemy}, {18=>nil, 10=>nil}], 2=>[{18=>nil, 10=>nil, 2=>:enemy}, {18=>nil, 10=>nil, 2=>nil}], 12=>[{19=>nil, 12=>:enemy}, {19=>nil, 12=>nil}], 5=>[{19=>nil, 12=>nil, 5=>:enemy}, {19=>nil, 12=>nil, 5=>nil}], 24=>[{25=>nil, 24=>:enemy}, {25=>nil, 24=>nil}], 28=>[{27=>nil, 28=>:enemy}, {27=>nil, 28=>nil}], 29=>[{27=>nil, 28=>nil, 29=>:enemy}, {27=>nil, 28=>nil, 29=>nil}], 30=>[{27=>nil, 28=>nil, 29=>nil, 30=>:enemy}, {27=>nil, 28=>nil, 29=>nil, 30=>nil}], 31=>[{27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>nil}], 40=>[{33=>nil, 40=>:enemy}, {33=>nil, 40=>nil}], 42=>[{34=>nil, 42=>:enemy}, {34=>nil, 42=>nil}], 50=>[{34=>nil, 42=>nil, 50=>:enemy}, {34=>nil, 42=>nil, 50=>nil}], 58=>[{34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {34=>nil, 42=>nil, 50=>nil, 58=>nil}], 44=>[{35=>nil, 44=>:enemy}, {35=>nil, 44=>nil}], 53=>[{35=>nil, 44=>nil, 53=>:enemy}, {35=>nil, 44=>nil, 53=>nil}], 62=>[{35=>nil, 44=>nil, 53=>nil, 62=>:enemy}, {35=>nil, 44=>nil, 53=>nil, 62=>nil}]}, 27=>{18=>[{18=>:enemy}, {18=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 9=>[{18=>nil, 9=>:enemy}, {18=>nil, 9=>nil}], 0=>[{18=>nil, 9=>nil, 0=>:enemy}, {18=>nil, 9=>nil, 0=>nil}], 11=>[{19=>nil, 11=>:enemy}, {19=>nil, 11=>nil}], 3=>[{19=>nil, 11=>nil, 3=>:enemy}, {19=>nil, 11=>nil, 3=>nil}], 13=>[{20=>nil, 13=>:enemy}, {20=>nil, 13=>nil}], 6=>[{20=>nil, 13=>nil, 6=>:enemy}, {20=>nil, 13=>nil, 6=>nil}], 25=>[{26=>nil, 25=>:enemy}, {26=>nil, 25=>nil}], 24=>[{26=>nil, 25=>nil, 24=>:enemy}, {26=>nil, 25=>nil, 24=>nil}], 29=>[{28=>nil, 29=>:enemy}, {28=>nil, 29=>nil}], 30=>[{28=>nil, 29=>nil, 30=>:enemy}, {28=>nil, 29=>nil, 30=>nil}], 31=>[{28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {28=>nil, 29=>nil, 30=>nil, 31=>nil}], 41=>[{34=>nil, 41=>:enemy}, {34=>nil, 41=>nil}], 48=>[{34=>nil, 41=>nil, 48=>:enemy}, {34=>nil, 41=>nil, 48=>nil}], 43=>[{35=>nil, 43=>:enemy}, {35=>nil, 43=>nil}], 51=>[{35=>nil, 43=>nil, 51=>:enemy}, {35=>nil, 43=>nil, 51=>nil}], 59=>[{35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {35=>nil, 43=>nil, 51=>nil, 59=>nil}], 45=>[{36=>nil, 45=>:enemy}, {36=>nil, 45=>nil}], 54=>[{36=>nil, 45=>nil, 54=>:enemy}, {36=>nil, 45=>nil, 54=>nil}], 63=>[{36=>nil, 45=>nil, 54=>nil, 63=>:enemy}, {36=>nil, 45=>nil, 54=>nil, 63=>nil}]}, 28=>{19=>[{19=>:enemy}, {19=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 10=>[{19=>nil, 10=>:enemy}, {19=>nil, 10=>nil}], 1=>[{19=>nil, 10=>nil, 1=>:enemy}, {19=>nil, 10=>nil, 1=>nil}], 12=>[{20=>nil, 12=>:enemy}, {20=>nil, 12=>nil}], 4=>[{20=>nil, 12=>nil, 4=>:enemy}, {20=>nil, 12=>nil, 4=>nil}], 14=>[{21=>nil, 14=>:enemy}, {21=>nil, 14=>nil}], 7=>[{21=>nil, 14=>nil, 7=>:enemy}, {21=>nil, 14=>nil, 7=>nil}], 26=>[{27=>nil, 26=>:enemy}, {27=>nil, 26=>nil}], 25=>[{27=>nil, 26=>nil, 25=>:enemy}, {27=>nil, 26=>nil, 25=>nil}], 24=>[{27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {27=>nil, 26=>nil, 25=>nil, 24=>nil}], 30=>[{29=>nil, 30=>:enemy}, {29=>nil, 30=>nil}], 31=>[{29=>nil, 30=>nil, 31=>:enemy}, {29=>nil, 30=>nil, 31=>nil}], 42=>[{35=>nil, 42=>:enemy}, {35=>nil, 42=>nil}], 49=>[{35=>nil, 42=>nil, 49=>:enemy}, {35=>nil, 42=>nil, 49=>nil}], 56=>[{35=>nil, 42=>nil, 49=>nil, 56=>:enemy}, {35=>nil, 42=>nil, 49=>nil, 56=>nil}], 44=>[{36=>nil, 44=>:enemy}, {36=>nil, 44=>nil}], 52=>[{36=>nil, 44=>nil, 52=>:enemy}, {36=>nil, 44=>nil, 52=>nil}], 60=>[{36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {36=>nil, 44=>nil, 52=>nil, 60=>nil}], 46=>[{37=>nil, 46=>:enemy}, {37=>nil, 46=>nil}], 55=>[{37=>nil, 46=>nil, 55=>:enemy}, {37=>nil, 46=>nil, 55=>nil}]}, 29=>{20=>[{20=>:enemy}, {20=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 11=>[{20=>nil, 11=>:enemy}, {20=>nil, 11=>nil}], 2=>[{20=>nil, 11=>nil, 2=>:enemy}, {20=>nil, 11=>nil, 2=>nil}], 13=>[{21=>nil, 13=>:enemy}, {21=>nil, 13=>nil}], 5=>[{21=>nil, 13=>nil, 5=>:enemy}, {21=>nil, 13=>nil, 5=>nil}], 15=>[{22=>nil, 15=>:enemy}, {22=>nil, 15=>nil}], 27=>[{28=>nil, 27=>:enemy}, {28=>nil, 27=>nil}], 26=>[{28=>nil, 27=>nil, 26=>:enemy}, {28=>nil, 27=>nil, 26=>nil}], 25=>[{28=>nil, 27=>nil, 26=>nil, 25=>:enemy}, {28=>nil, 27=>nil, 26=>nil, 25=>nil}], 24=>[{28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>nil}], 31=>[{30=>nil, 31=>:enemy}, {30=>nil, 31=>nil}], 43=>[{36=>nil, 43=>:enemy}, {36=>nil, 43=>nil}], 50=>[{36=>nil, 43=>nil, 50=>:enemy}, {36=>nil, 43=>nil, 50=>nil}], 57=>[{36=>nil, 43=>nil, 50=>nil, 57=>:enemy}, {36=>nil, 43=>nil, 50=>nil, 57=>nil}], 45=>[{37=>nil, 45=>:enemy}, {37=>nil, 45=>nil}], 53=>[{37=>nil, 45=>nil, 53=>:enemy}, {37=>nil, 45=>nil, 53=>nil}], 61=>[{37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {37=>nil, 45=>nil, 53=>nil, 61=>nil}], 47=>[{38=>nil, 47=>:enemy}, {38=>nil, 47=>nil}]}, 30=>{21=>[{21=>:enemy}, {21=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 12=>[{21=>nil, 12=>:enemy}, {21=>nil, 12=>nil}], 3=>[{21=>nil, 12=>nil, 3=>:enemy}, {21=>nil, 12=>nil, 3=>nil}], 14=>[{22=>nil, 14=>:enemy}, {22=>nil, 14=>nil}], 6=>[{22=>nil, 14=>nil, 6=>:enemy}, {22=>nil, 14=>nil, 6=>nil}], 28=>[{29=>nil, 28=>:enemy}, {29=>nil, 28=>nil}], 27=>[{29=>nil, 28=>nil, 27=>:enemy}, {29=>nil, 28=>nil, 27=>nil}], 26=>[{29=>nil, 28=>nil, 27=>nil, 26=>:enemy}, {29=>nil, 28=>nil, 27=>nil, 26=>nil}], 25=>[{29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>:enemy}, {29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil}], 24=>[{29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>nil}], 44=>[{37=>nil, 44=>:enemy}, {37=>nil, 44=>nil}], 51=>[{37=>nil, 44=>nil, 51=>:enemy}, {37=>nil, 44=>nil, 51=>nil}], 58=>[{37=>nil, 44=>nil, 51=>nil, 58=>:enemy}, {37=>nil, 44=>nil, 51=>nil, 58=>nil}], 46=>[{38=>nil, 46=>:enemy}, {38=>nil, 46=>nil}], 54=>[{38=>nil, 46=>nil, 54=>:enemy}, {38=>nil, 46=>nil, 54=>nil}], 62=>[{38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 31=>{22=>[{22=>:enemy}, {22=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 13=>[{22=>nil, 13=>:enemy}, {22=>nil, 13=>nil}], 4=>[{22=>nil, 13=>nil, 4=>:enemy}, {22=>nil, 13=>nil, 4=>nil}], 15=>[{23=>nil, 15=>:enemy}, {23=>nil, 15=>nil}], 7=>[{23=>nil, 15=>nil, 7=>:enemy}, {23=>nil, 15=>nil, 7=>nil}], 29=>[{30=>nil, 29=>:enemy}, {30=>nil, 29=>nil}], 28=>[{30=>nil, 29=>nil, 28=>:enemy}, {30=>nil, 29=>nil, 28=>nil}], 27=>[{30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil}], 26=>[{30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil}], 25=>[{30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil}], 24=>[{30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>nil}], 45=>[{38=>nil, 45=>:enemy}, {38=>nil, 45=>nil}], 52=>[{38=>nil, 45=>nil, 52=>:enemy}, {38=>nil, 45=>nil, 52=>nil}], 59=>[{38=>nil, 45=>nil, 52=>nil, 59=>:enemy}, {38=>nil, 45=>nil, 52=>nil, 59=>nil}], 47=>[{39=>nil, 47=>:enemy}, {39=>nil, 47=>nil}], 55=>[{39=>nil, 47=>nil, 55=>:enemy}, {39=>nil, 47=>nil, 55=>nil}], 63=>[{39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 32=>{24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 16=>[{24=>nil, 16=>:enemy}, {24=>nil, 16=>nil}], 8=>[{24=>nil, 16=>nil, 8=>:enemy}, {24=>nil, 16=>nil, 8=>nil}], 0=>[{24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {24=>nil, 16=>nil, 8=>nil, 0=>nil}], 18=>[{25=>nil, 18=>:enemy}, {25=>nil, 18=>nil}], 11=>[{25=>nil, 18=>nil, 11=>:enemy}, {25=>nil, 18=>nil, 11=>nil}], 4=>[{25=>nil, 18=>nil, 11=>nil, 4=>:enemy}, {25=>nil, 18=>nil, 11=>nil, 4=>nil}], 34=>[{33=>nil, 34=>:enemy}, {33=>nil, 34=>nil}], 35=>[{33=>nil, 34=>nil, 35=>:enemy}, {33=>nil, 34=>nil, 35=>nil}], 36=>[{33=>nil, 34=>nil, 35=>nil, 36=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil}], 37=>[{33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil}], 38=>[{33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil}], 39=>[{33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>nil}], 48=>[{40=>nil, 48=>:enemy}, {40=>nil, 48=>nil}], 56=>[{40=>nil, 48=>nil, 56=>:enemy}, {40=>nil, 48=>nil, 56=>nil}], 50=>[{41=>nil, 50=>:enemy}, {41=>nil, 50=>nil}], 59=>[{41=>nil, 50=>nil, 59=>:enemy}, {41=>nil, 50=>nil, 59=>nil}]}, 33=>{24=>[{24=>:enemy}, {24=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 17=>[{25=>nil, 17=>:enemy}, {25=>nil, 17=>nil}], 9=>[{25=>nil, 17=>nil, 9=>:enemy}, {25=>nil, 17=>nil, 9=>nil}], 1=>[{25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {25=>nil, 17=>nil, 9=>nil, 1=>nil}], 19=>[{26=>nil, 19=>:enemy}, {26=>nil, 19=>nil}], 12=>[{26=>nil, 19=>nil, 12=>:enemy}, {26=>nil, 19=>nil, 12=>nil}], 5=>[{26=>nil, 19=>nil, 12=>nil, 5=>:enemy}, {26=>nil, 19=>nil, 12=>nil, 5=>nil}], 35=>[{34=>nil, 35=>:enemy}, {34=>nil, 35=>nil}], 36=>[{34=>nil, 35=>nil, 36=>:enemy}, {34=>nil, 35=>nil, 36=>nil}], 37=>[{34=>nil, 35=>nil, 36=>nil, 37=>:enemy}, {34=>nil, 35=>nil, 36=>nil, 37=>nil}], 38=>[{34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>:enemy}, {34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil}], 39=>[{34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>nil}], 49=>[{41=>nil, 49=>:enemy}, {41=>nil, 49=>nil}], 57=>[{41=>nil, 49=>nil, 57=>:enemy}, {41=>nil, 49=>nil, 57=>nil}], 51=>[{42=>nil, 51=>:enemy}, {42=>nil, 51=>nil}], 60=>[{42=>nil, 51=>nil, 60=>:enemy}, {42=>nil, 51=>nil, 60=>nil}]}, 34=>{25=>[{25=>:enemy}, {25=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 16=>[{25=>nil, 16=>:enemy}, {25=>nil, 16=>nil}], 18=>[{26=>nil, 18=>:enemy}, {26=>nil, 18=>nil}], 10=>[{26=>nil, 18=>nil, 10=>:enemy}, {26=>nil, 18=>nil, 10=>nil}], 2=>[{26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {26=>nil, 18=>nil, 10=>nil, 2=>nil}], 20=>[{27=>nil, 20=>:enemy}, {27=>nil, 20=>nil}], 13=>[{27=>nil, 20=>nil, 13=>:enemy}, {27=>nil, 20=>nil, 13=>nil}], 6=>[{27=>nil, 20=>nil, 13=>nil, 6=>:enemy}, {27=>nil, 20=>nil, 13=>nil, 6=>nil}], 32=>[{33=>nil, 32=>:enemy}, {33=>nil, 32=>nil}], 36=>[{35=>nil, 36=>:enemy}, {35=>nil, 36=>nil}], 37=>[{35=>nil, 36=>nil, 37=>:enemy}, {35=>nil, 36=>nil, 37=>nil}], 38=>[{35=>nil, 36=>nil, 37=>nil, 38=>:enemy}, {35=>nil, 36=>nil, 37=>nil, 38=>nil}], 39=>[{35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>nil}], 48=>[{41=>nil, 48=>:enemy}, {41=>nil, 48=>nil}], 50=>[{42=>nil, 50=>:enemy}, {42=>nil, 50=>nil}], 58=>[{42=>nil, 50=>nil, 58=>:enemy}, {42=>nil, 50=>nil, 58=>nil}], 52=>[{43=>nil, 52=>:enemy}, {43=>nil, 52=>nil}], 61=>[{43=>nil, 52=>nil, 61=>:enemy}, {43=>nil, 52=>nil, 61=>nil}]}, 35=>{26=>[{26=>:enemy}, {26=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 17=>[{26=>nil, 17=>:enemy}, {26=>nil, 17=>nil}], 8=>[{26=>nil, 17=>nil, 8=>:enemy}, {26=>nil, 17=>nil, 8=>nil}], 19=>[{27=>nil, 19=>:enemy}, {27=>nil, 19=>nil}], 11=>[{27=>nil, 19=>nil, 11=>:enemy}, {27=>nil, 19=>nil, 11=>nil}], 3=>[{27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {27=>nil, 19=>nil, 11=>nil, 3=>nil}], 21=>[{28=>nil, 21=>:enemy}, {28=>nil, 21=>nil}], 14=>[{28=>nil, 21=>nil, 14=>:enemy}, {28=>nil, 21=>nil, 14=>nil}], 7=>[{28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {28=>nil, 21=>nil, 14=>nil, 7=>nil}], 33=>[{34=>nil, 33=>:enemy}, {34=>nil, 33=>nil}], 32=>[{34=>nil, 33=>nil, 32=>:enemy}, {34=>nil, 33=>nil, 32=>nil}], 37=>[{36=>nil, 37=>:enemy}, {36=>nil, 37=>nil}], 38=>[{36=>nil, 37=>nil, 38=>:enemy}, {36=>nil, 37=>nil, 38=>nil}], 39=>[{36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {36=>nil, 37=>nil, 38=>nil, 39=>nil}], 49=>[{42=>nil, 49=>:enemy}, {42=>nil, 49=>nil}], 56=>[{42=>nil, 49=>nil, 56=>:enemy}, {42=>nil, 49=>nil, 56=>nil}], 51=>[{43=>nil, 51=>:enemy}, {43=>nil, 51=>nil}], 59=>[{43=>nil, 51=>nil, 59=>:enemy}, {43=>nil, 51=>nil, 59=>nil}], 53=>[{44=>nil, 53=>:enemy}, {44=>nil, 53=>nil}], 62=>[{44=>nil, 53=>nil, 62=>:enemy}, {44=>nil, 53=>nil, 62=>nil}]}, 36=>{27=>[{27=>:enemy}, {27=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 18=>[{27=>nil, 18=>:enemy}, {27=>nil, 18=>nil}], 9=>[{27=>nil, 18=>nil, 9=>:enemy}, {27=>nil, 18=>nil, 9=>nil}], 0=>[{27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {27=>nil, 18=>nil, 9=>nil, 0=>nil}], 20=>[{28=>nil, 20=>:enemy}, {28=>nil, 20=>nil}], 12=>[{28=>nil, 20=>nil, 12=>:enemy}, {28=>nil, 20=>nil, 12=>nil}], 4=>[{28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {28=>nil, 20=>nil, 12=>nil, 4=>nil}], 22=>[{29=>nil, 22=>:enemy}, {29=>nil, 22=>nil}], 15=>[{29=>nil, 22=>nil, 15=>:enemy}, {29=>nil, 22=>nil, 15=>nil}], 34=>[{35=>nil, 34=>:enemy}, {35=>nil, 34=>nil}], 33=>[{35=>nil, 34=>nil, 33=>:enemy}, {35=>nil, 34=>nil, 33=>nil}], 32=>[{35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {35=>nil, 34=>nil, 33=>nil, 32=>nil}], 38=>[{37=>nil, 38=>:enemy}, {37=>nil, 38=>nil}], 39=>[{37=>nil, 38=>nil, 39=>:enemy}, {37=>nil, 38=>nil, 39=>nil}], 50=>[{43=>nil, 50=>:enemy}, {43=>nil, 50=>nil}], 57=>[{43=>nil, 50=>nil, 57=>:enemy}, {43=>nil, 50=>nil, 57=>nil}], 52=>[{44=>nil, 52=>:enemy}, {44=>nil, 52=>nil}], 60=>[{44=>nil, 52=>nil, 60=>:enemy}, {44=>nil, 52=>nil, 60=>nil}], 54=>[{45=>nil, 54=>:enemy}, {45=>nil, 54=>nil}], 63=>[{45=>nil, 54=>nil, 63=>:enemy}, {45=>nil, 54=>nil, 63=>nil}]}, 37=>{28=>[{28=>:enemy}, {28=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 19=>[{28=>nil, 19=>:enemy}, {28=>nil, 19=>nil}], 10=>[{28=>nil, 19=>nil, 10=>:enemy}, {28=>nil, 19=>nil, 10=>nil}], 1=>[{28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, {28=>nil, 19=>nil, 10=>nil, 1=>nil}], 21=>[{29=>nil, 21=>:enemy}, {29=>nil, 21=>nil}], 13=>[{29=>nil, 21=>nil, 13=>:enemy}, {29=>nil, 21=>nil, 13=>nil}], 5=>[{29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {29=>nil, 21=>nil, 13=>nil, 5=>nil}], 23=>[{30=>nil, 23=>:enemy}, {30=>nil, 23=>nil}], 35=>[{36=>nil, 35=>:enemy}, {36=>nil, 35=>nil}], 34=>[{36=>nil, 35=>nil, 34=>:enemy}, {36=>nil, 35=>nil, 34=>nil}], 33=>[{36=>nil, 35=>nil, 34=>nil, 33=>:enemy}, {36=>nil, 35=>nil, 34=>nil, 33=>nil}], 32=>[{36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>nil}], 39=>[{38=>nil, 39=>:enemy}, {38=>nil, 39=>nil}], 51=>[{44=>nil, 51=>:enemy}, {44=>nil, 51=>nil}], 58=>[{44=>nil, 51=>nil, 58=>:enemy}, {44=>nil, 51=>nil, 58=>nil}], 53=>[{45=>nil, 53=>:enemy}, {45=>nil, 53=>nil}], 61=>[{45=>nil, 53=>nil, 61=>:enemy}, {45=>nil, 53=>nil, 61=>nil}], 55=>[{46=>nil, 55=>:enemy}, {46=>nil, 55=>nil}]}, 38=>{29=>[{29=>:enemy}, {29=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 20=>[{29=>nil, 20=>:enemy}, {29=>nil, 20=>nil}], 11=>[{29=>nil, 20=>nil, 11=>:enemy}, {29=>nil, 20=>nil, 11=>nil}], 2=>[{29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, {29=>nil, 20=>nil, 11=>nil, 2=>nil}], 22=>[{30=>nil, 22=>:enemy}, {30=>nil, 22=>nil}], 14=>[{30=>nil, 22=>nil, 14=>:enemy}, {30=>nil, 22=>nil, 14=>nil}], 6=>[{30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {30=>nil, 22=>nil, 14=>nil, 6=>nil}], 36=>[{37=>nil, 36=>:enemy}, {37=>nil, 36=>nil}], 35=>[{37=>nil, 36=>nil, 35=>:enemy}, {37=>nil, 36=>nil, 35=>nil}], 34=>[{37=>nil, 36=>nil, 35=>nil, 34=>:enemy}, {37=>nil, 36=>nil, 35=>nil, 34=>nil}], 33=>[{37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>:enemy}, {37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil}], 32=>[{37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>nil}], 52=>[{45=>nil, 52=>:enemy}, {45=>nil, 52=>nil}], 59=>[{45=>nil, 52=>nil, 59=>:enemy}, {45=>nil, 52=>nil, 59=>nil}], 54=>[{46=>nil, 54=>:enemy}, {46=>nil, 54=>nil}], 62=>[{46=>nil, 54=>nil, 62=>:enemy}, {46=>nil, 54=>nil, 62=>nil}]}, 39=>{30=>[{30=>:enemy}, {30=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 21=>[{30=>nil, 21=>:enemy}, {30=>nil, 21=>nil}], 12=>[{30=>nil, 21=>nil, 12=>:enemy}, {30=>nil, 21=>nil, 12=>nil}], 3=>[{30=>nil, 21=>nil, 12=>nil, 3=>:enemy}, {30=>nil, 21=>nil, 12=>nil, 3=>nil}], 23=>[{31=>nil, 23=>:enemy}, {31=>nil, 23=>nil}], 15=>[{31=>nil, 23=>nil, 15=>:enemy}, {31=>nil, 23=>nil, 15=>nil}], 7=>[{31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {31=>nil, 23=>nil, 15=>nil, 7=>nil}], 37=>[{38=>nil, 37=>:enemy}, {38=>nil, 37=>nil}], 36=>[{38=>nil, 37=>nil, 36=>:enemy}, {38=>nil, 37=>nil, 36=>nil}], 35=>[{38=>nil, 37=>nil, 36=>nil, 35=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil}], 34=>[{38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil}], 33=>[{38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil}], 32=>[{38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>nil}], 53=>[{46=>nil, 53=>:enemy}, {46=>nil, 53=>nil}], 60=>[{46=>nil, 53=>nil, 60=>:enemy}, {46=>nil, 53=>nil, 60=>nil}], 55=>[{47=>nil, 55=>:enemy}, {47=>nil, 55=>nil}], 63=>[{47=>nil, 55=>nil, 63=>:enemy}, {47=>nil, 55=>nil, 63=>nil}]}, 40=>{32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 24=>[{32=>nil, 24=>:enemy}, {32=>nil, 24=>nil}], 16=>[{32=>nil, 24=>nil, 16=>:enemy}, {32=>nil, 24=>nil, 16=>nil}], 8=>[{32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, {32=>nil, 24=>nil, 16=>nil, 8=>nil}], 0=>[{32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>nil}], 26=>[{33=>nil, 26=>:enemy}, {33=>nil, 26=>nil}], 19=>[{33=>nil, 26=>nil, 19=>:enemy}, {33=>nil, 26=>nil, 19=>nil}], 12=>[{33=>nil, 26=>nil, 19=>nil, 12=>:enemy}, {33=>nil, 26=>nil, 19=>nil, 12=>nil}], 5=>[{33=>nil, 26=>nil, 19=>nil, 12=>nil, 5=>:enemy}, {33=>nil, 26=>nil, 19=>nil, 12=>nil, 5=>nil}], 42=>[{41=>nil, 42=>:enemy}, {41=>nil, 42=>nil}], 43=>[{41=>nil, 42=>nil, 43=>:enemy}, {41=>nil, 42=>nil, 43=>nil}], 44=>[{41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil}], 45=>[{41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil}], 46=>[{41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil}], 47=>[{41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>nil}], 56=>[{48=>nil, 56=>:enemy}, {48=>nil, 56=>nil}], 58=>[{49=>nil, 58=>:enemy}, {49=>nil, 58=>nil}]}, 41=>{32=>[{32=>:enemy}, {32=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 25=>[{33=>nil, 25=>:enemy}, {33=>nil, 25=>nil}], 17=>[{33=>nil, 25=>nil, 17=>:enemy}, {33=>nil, 25=>nil, 17=>nil}], 9=>[{33=>nil, 25=>nil, 17=>nil, 9=>:enemy}, {33=>nil, 25=>nil, 17=>nil, 9=>nil}], 1=>[{33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>nil}], 27=>[{34=>nil, 27=>:enemy}, {34=>nil, 27=>nil}], 20=>[{34=>nil, 27=>nil, 20=>:enemy}, {34=>nil, 27=>nil, 20=>nil}], 13=>[{34=>nil, 27=>nil, 20=>nil, 13=>:enemy}, {34=>nil, 27=>nil, 20=>nil, 13=>nil}], 6=>[{34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>:enemy}, {34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>nil}], 43=>[{42=>nil, 43=>:enemy}, {42=>nil, 43=>nil}], 44=>[{42=>nil, 43=>nil, 44=>:enemy}, {42=>nil, 43=>nil, 44=>nil}], 45=>[{42=>nil, 43=>nil, 44=>nil, 45=>:enemy}, {42=>nil, 43=>nil, 44=>nil, 45=>nil}], 46=>[{42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>:enemy}, {42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil}], 47=>[{42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>nil}], 57=>[{49=>nil, 57=>:enemy}, {49=>nil, 57=>nil}], 59=>[{50=>nil, 59=>:enemy}, {50=>nil, 59=>nil}]}, 42=>{33=>[{33=>:enemy}, {33=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 24=>[{33=>nil, 24=>:enemy}, {33=>nil, 24=>nil}], 26=>[{34=>nil, 26=>:enemy}, {34=>nil, 26=>nil}], 18=>[{34=>nil, 26=>nil, 18=>:enemy}, {34=>nil, 26=>nil, 18=>nil}], 10=>[{34=>nil, 26=>nil, 18=>nil, 10=>:enemy}, {34=>nil, 26=>nil, 18=>nil, 10=>nil}], 2=>[{34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>nil}], 28=>[{35=>nil, 28=>:enemy}, {35=>nil, 28=>nil}], 21=>[{35=>nil, 28=>nil, 21=>:enemy}, {35=>nil, 28=>nil, 21=>nil}], 14=>[{35=>nil, 28=>nil, 21=>nil, 14=>:enemy}, {35=>nil, 28=>nil, 21=>nil, 14=>nil}], 7=>[{35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>nil}], 40=>[{41=>nil, 40=>:enemy}, {41=>nil, 40=>nil}], 44=>[{43=>nil, 44=>:enemy}, {43=>nil, 44=>nil}], 45=>[{43=>nil, 44=>nil, 45=>:enemy}, {43=>nil, 44=>nil, 45=>nil}], 46=>[{43=>nil, 44=>nil, 45=>nil, 46=>:enemy}, {43=>nil, 44=>nil, 45=>nil, 46=>nil}], 47=>[{43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>nil}], 56=>[{49=>nil, 56=>:enemy}, {49=>nil, 56=>nil}], 58=>[{50=>nil, 58=>:enemy}, {50=>nil, 58=>nil}], 60=>[{51=>nil, 60=>:enemy}, {51=>nil, 60=>nil}]}, 43=>{34=>[{34=>:enemy}, {34=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 25=>[{34=>nil, 25=>:enemy}, {34=>nil, 25=>nil}], 16=>[{34=>nil, 25=>nil, 16=>:enemy}, {34=>nil, 25=>nil, 16=>nil}], 27=>[{35=>nil, 27=>:enemy}, {35=>nil, 27=>nil}], 19=>[{35=>nil, 27=>nil, 19=>:enemy}, {35=>nil, 27=>nil, 19=>nil}], 11=>[{35=>nil, 27=>nil, 19=>nil, 11=>:enemy}, {35=>nil, 27=>nil, 19=>nil, 11=>nil}], 3=>[{35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>nil}], 29=>[{36=>nil, 29=>:enemy}, {36=>nil, 29=>nil}], 22=>[{36=>nil, 29=>nil, 22=>:enemy}, {36=>nil, 29=>nil, 22=>nil}], 15=>[{36=>nil, 29=>nil, 22=>nil, 15=>:enemy}, {36=>nil, 29=>nil, 22=>nil, 15=>nil}], 41=>[{42=>nil, 41=>:enemy}, {42=>nil, 41=>nil}], 40=>[{42=>nil, 41=>nil, 40=>:enemy}, {42=>nil, 41=>nil, 40=>nil}], 45=>[{44=>nil, 45=>:enemy}, {44=>nil, 45=>nil}], 46=>[{44=>nil, 45=>nil, 46=>:enemy}, {44=>nil, 45=>nil, 46=>nil}], 47=>[{44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {44=>nil, 45=>nil, 46=>nil, 47=>nil}], 57=>[{50=>nil, 57=>:enemy}, {50=>nil, 57=>nil}], 59=>[{51=>nil, 59=>:enemy}, {51=>nil, 59=>nil}], 61=>[{52=>nil, 61=>:enemy}, {52=>nil, 61=>nil}]}, 44=>{35=>[{35=>:enemy}, {35=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 26=>[{35=>nil, 26=>:enemy}, {35=>nil, 26=>nil}], 17=>[{35=>nil, 26=>nil, 17=>:enemy}, {35=>nil, 26=>nil, 17=>nil}], 8=>[{35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, {35=>nil, 26=>nil, 17=>nil, 8=>nil}], 28=>[{36=>nil, 28=>:enemy}, {36=>nil, 28=>nil}], 20=>[{36=>nil, 28=>nil, 20=>:enemy}, {36=>nil, 28=>nil, 20=>nil}], 12=>[{36=>nil, 28=>nil, 20=>nil, 12=>:enemy}, {36=>nil, 28=>nil, 20=>nil, 12=>nil}], 4=>[{36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>nil}], 30=>[{37=>nil, 30=>:enemy}, {37=>nil, 30=>nil}], 23=>[{37=>nil, 30=>nil, 23=>:enemy}, {37=>nil, 30=>nil, 23=>nil}], 42=>[{43=>nil, 42=>:enemy}, {43=>nil, 42=>nil}], 41=>[{43=>nil, 42=>nil, 41=>:enemy}, {43=>nil, 42=>nil, 41=>nil}], 40=>[{43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {43=>nil, 42=>nil, 41=>nil, 40=>nil}], 46=>[{45=>nil, 46=>:enemy}, {45=>nil, 46=>nil}], 47=>[{45=>nil, 46=>nil, 47=>:enemy}, {45=>nil, 46=>nil, 47=>nil}], 58=>[{51=>nil, 58=>:enemy}, {51=>nil, 58=>nil}], 60=>[{52=>nil, 60=>:enemy}, {52=>nil, 60=>nil}], 62=>[{53=>nil, 62=>:enemy}, {53=>nil, 62=>nil}]}, 45=>{36=>[{36=>:enemy}, {36=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 27=>[{36=>nil, 27=>:enemy}, {36=>nil, 27=>nil}], 18=>[{36=>nil, 27=>nil, 18=>:enemy}, {36=>nil, 27=>nil, 18=>nil}], 9=>[{36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, {36=>nil, 27=>nil, 18=>nil, 9=>nil}], 0=>[{36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}], 29=>[{37=>nil, 29=>:enemy}, {37=>nil, 29=>nil}], 21=>[{37=>nil, 29=>nil, 21=>:enemy}, {37=>nil, 29=>nil, 21=>nil}], 13=>[{37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, {37=>nil, 29=>nil, 21=>nil, 13=>nil}], 5=>[{37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}], 31=>[{38=>nil, 31=>:enemy}, {38=>nil, 31=>nil}], 43=>[{44=>nil, 43=>:enemy}, {44=>nil, 43=>nil}], 42=>[{44=>nil, 43=>nil, 42=>:enemy}, {44=>nil, 43=>nil, 42=>nil}], 41=>[{44=>nil, 43=>nil, 42=>nil, 41=>:enemy}, {44=>nil, 43=>nil, 42=>nil, 41=>nil}], 40=>[{44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>nil}], 47=>[{46=>nil, 47=>:enemy}, {46=>nil, 47=>nil}], 59=>[{52=>nil, 59=>:enemy}, {52=>nil, 59=>nil}], 61=>[{53=>nil, 61=>:enemy}, {53=>nil, 61=>nil}], 63=>[{54=>nil, 63=>:enemy}, {54=>nil, 63=>nil}]}, 46=>{37=>[{37=>:enemy}, {37=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 28=>[{37=>nil, 28=>:enemy}, {37=>nil, 28=>nil}], 19=>[{37=>nil, 28=>nil, 19=>:enemy}, {37=>nil, 28=>nil, 19=>nil}], 10=>[{37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, {37=>nil, 28=>nil, 19=>nil, 10=>nil}], 1=>[{37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, {37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}], 30=>[{38=>nil, 30=>:enemy}, {38=>nil, 30=>nil}], 22=>[{38=>nil, 30=>nil, 22=>:enemy}, {38=>nil, 30=>nil, 22=>nil}], 14=>[{38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, {38=>nil, 30=>nil, 22=>nil, 14=>nil}], 6=>[{38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}], 44=>[{45=>nil, 44=>:enemy}, {45=>nil, 44=>nil}], 43=>[{45=>nil, 44=>nil, 43=>:enemy}, {45=>nil, 44=>nil, 43=>nil}], 42=>[{45=>nil, 44=>nil, 43=>nil, 42=>:enemy}, {45=>nil, 44=>nil, 43=>nil, 42=>nil}], 41=>[{45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>:enemy}, {45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil}], 40=>[{45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>nil}], 60=>[{53=>nil, 60=>:enemy}, {53=>nil, 60=>nil}], 62=>[{54=>nil, 62=>:enemy}, {54=>nil, 62=>nil}]}, 47=>{38=>[{38=>:enemy}, {38=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 29=>[{38=>nil, 29=>:enemy}, {38=>nil, 29=>nil}], 20=>[{38=>nil, 29=>nil, 20=>:enemy}, {38=>nil, 29=>nil, 20=>nil}], 11=>[{38=>nil, 29=>nil, 20=>nil, 11=>:enemy}, {38=>nil, 29=>nil, 20=>nil, 11=>nil}], 2=>[{38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>:enemy}, {38=>nil, 29=>nil, 20=>nil, 11=>nil, 2=>nil}], 31=>[{39=>nil, 31=>:enemy}, {39=>nil, 31=>nil}], 23=>[{39=>nil, 31=>nil, 23=>:enemy}, {39=>nil, 31=>nil, 23=>nil}], 15=>[{39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, {39=>nil, 31=>nil, 23=>nil, 15=>nil}], 7=>[{39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}], 45=>[{46=>nil, 45=>:enemy}, {46=>nil, 45=>nil}], 44=>[{46=>nil, 45=>nil, 44=>:enemy}, {46=>nil, 45=>nil, 44=>nil}], 43=>[{46=>nil, 45=>nil, 44=>nil, 43=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil}], 42=>[{46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil}], 41=>[{46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil}], 40=>[{46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>nil}], 61=>[{54=>nil, 61=>:enemy}, {54=>nil, 61=>nil}], 63=>[{55=>nil, 63=>:enemy}, {55=>nil, 63=>nil}]}, 48=>{40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 32=>[{40=>nil, 32=>:enemy}, {40=>nil, 32=>nil}], 24=>[{40=>nil, 32=>nil, 24=>:enemy}, {40=>nil, 32=>nil, 24=>nil}], 16=>[{40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, {40=>nil, 32=>nil, 24=>nil, 16=>nil}], 8=>[{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, {40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}], 0=>[{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>nil}], 34=>[{41=>nil, 34=>:enemy}, {41=>nil, 34=>nil}], 27=>[{41=>nil, 34=>nil, 27=>:enemy}, {41=>nil, 34=>nil, 27=>nil}], 20=>[{41=>nil, 34=>nil, 27=>nil, 20=>:enemy}, {41=>nil, 34=>nil, 27=>nil, 20=>nil}], 13=>[{41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>:enemy}, {41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>nil}], 6=>[{41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>:enemy}, {41=>nil, 34=>nil, 27=>nil, 20=>nil, 13=>nil, 6=>nil}], 50=>[{49=>nil, 50=>:enemy}, {49=>nil, 50=>nil}], 51=>[{49=>nil, 50=>nil, 51=>:enemy}, {49=>nil, 50=>nil, 51=>nil}], 52=>[{49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil}], 53=>[{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}], 54=>[{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil}], 55=>[{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 49=>{40=>[{40=>:enemy}, {40=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 33=>[{41=>nil, 33=>:enemy}, {41=>nil, 33=>nil}], 25=>[{41=>nil, 33=>nil, 25=>:enemy}, {41=>nil, 33=>nil, 25=>nil}], 17=>[{41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, {41=>nil, 33=>nil, 25=>nil, 17=>nil}], 9=>[{41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>:enemy}, {41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil}], 1=>[{41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>nil}], 35=>[{42=>nil, 35=>:enemy}, {42=>nil, 35=>nil}], 28=>[{42=>nil, 35=>nil, 28=>:enemy}, {42=>nil, 35=>nil, 28=>nil}], 21=>[{42=>nil, 35=>nil, 28=>nil, 21=>:enemy}, {42=>nil, 35=>nil, 28=>nil, 21=>nil}], 14=>[{42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>:enemy}, {42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil}], 7=>[{42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>nil}], 51=>[{50=>nil, 51=>:enemy}, {50=>nil, 51=>nil}], 52=>[{50=>nil, 51=>nil, 52=>:enemy}, {50=>nil, 51=>nil, 52=>nil}], 53=>[{50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, {50=>nil, 51=>nil, 52=>nil, 53=>nil}], 54=>[{50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>:enemy}, {50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil}], 55=>[{50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 50=>{41=>[{41=>:enemy}, {41=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 32=>[{41=>nil, 32=>:enemy}, {41=>nil, 32=>nil}], 34=>[{42=>nil, 34=>:enemy}, {42=>nil, 34=>nil}], 26=>[{42=>nil, 34=>nil, 26=>:enemy}, {42=>nil, 34=>nil, 26=>nil}], 18=>[{42=>nil, 34=>nil, 26=>nil, 18=>:enemy}, {42=>nil, 34=>nil, 26=>nil, 18=>nil}], 10=>[{42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>:enemy}, {42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil}], 2=>[{42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>nil}], 36=>[{43=>nil, 36=>:enemy}, {43=>nil, 36=>nil}], 29=>[{43=>nil, 36=>nil, 29=>:enemy}, {43=>nil, 36=>nil, 29=>nil}], 22=>[{43=>nil, 36=>nil, 29=>nil, 22=>:enemy}, {43=>nil, 36=>nil, 29=>nil, 22=>nil}], 15=>[{43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>:enemy}, {43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>nil}], 48=>[{49=>nil, 48=>:enemy}, {49=>nil, 48=>nil}], 52=>[{51=>nil, 52=>:enemy}, {51=>nil, 52=>nil}], 53=>[{51=>nil, 52=>nil, 53=>:enemy}, {51=>nil, 52=>nil, 53=>nil}], 54=>[{51=>nil, 52=>nil, 53=>nil, 54=>:enemy}, {51=>nil, 52=>nil, 53=>nil, 54=>nil}], 55=>[{51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 51=>{42=>[{42=>:enemy}, {42=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 33=>[{42=>nil, 33=>:enemy}, {42=>nil, 33=>nil}], 24=>[{42=>nil, 33=>nil, 24=>:enemy}, {42=>nil, 33=>nil, 24=>nil}], 35=>[{43=>nil, 35=>:enemy}, {43=>nil, 35=>nil}], 27=>[{43=>nil, 35=>nil, 27=>:enemy}, {43=>nil, 35=>nil, 27=>nil}], 19=>[{43=>nil, 35=>nil, 27=>nil, 19=>:enemy}, {43=>nil, 35=>nil, 27=>nil, 19=>nil}], 11=>[{43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>:enemy}, {43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil}], 3=>[{43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>nil}], 37=>[{44=>nil, 37=>:enemy}, {44=>nil, 37=>nil}], 30=>[{44=>nil, 37=>nil, 30=>:enemy}, {44=>nil, 37=>nil, 30=>nil}], 23=>[{44=>nil, 37=>nil, 30=>nil, 23=>:enemy}, {44=>nil, 37=>nil, 30=>nil, 23=>nil}], 49=>[{50=>nil, 49=>:enemy}, {50=>nil, 49=>nil}], 48=>[{50=>nil, 49=>nil, 48=>:enemy}, {50=>nil, 49=>nil, 48=>nil}], 53=>[{52=>nil, 53=>:enemy}, {52=>nil, 53=>nil}], 54=>[{52=>nil, 53=>nil, 54=>:enemy}, {52=>nil, 53=>nil, 54=>nil}], 55=>[{52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 52=>{43=>[{43=>:enemy}, {43=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 34=>[{43=>nil, 34=>:enemy}, {43=>nil, 34=>nil}], 25=>[{43=>nil, 34=>nil, 25=>:enemy}, {43=>nil, 34=>nil, 25=>nil}], 16=>[{43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, {43=>nil, 34=>nil, 25=>nil, 16=>nil}], 36=>[{44=>nil, 36=>:enemy}, {44=>nil, 36=>nil}], 28=>[{44=>nil, 36=>nil, 28=>:enemy}, {44=>nil, 36=>nil, 28=>nil}], 20=>[{44=>nil, 36=>nil, 28=>nil, 20=>:enemy}, {44=>nil, 36=>nil, 28=>nil, 20=>nil}], 12=>[{44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>:enemy}, {44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil}], 4=>[{44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>nil}], 38=>[{45=>nil, 38=>:enemy}, {45=>nil, 38=>nil}], 31=>[{45=>nil, 38=>nil, 31=>:enemy}, {45=>nil, 38=>nil, 31=>nil}], 50=>[{51=>nil, 50=>:enemy}, {51=>nil, 50=>nil}], 49=>[{51=>nil, 50=>nil, 49=>:enemy}, {51=>nil, 50=>nil, 49=>nil}], 48=>[{51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {51=>nil, 50=>nil, 49=>nil, 48=>nil}], 54=>[{53=>nil, 54=>:enemy}, {53=>nil, 54=>nil}], 55=>[{53=>nil, 54=>nil, 55=>:enemy}, {53=>nil, 54=>nil, 55=>nil}]}, 53=>{44=>[{44=>:enemy}, {44=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 35=>[{44=>nil, 35=>:enemy}, {44=>nil, 35=>nil}], 26=>[{44=>nil, 35=>nil, 26=>:enemy}, {44=>nil, 35=>nil, 26=>nil}], 17=>[{44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, {44=>nil, 35=>nil, 26=>nil, 17=>nil}], 8=>[{44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, {44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}], 37=>[{45=>nil, 37=>:enemy}, {45=>nil, 37=>nil}], 29=>[{45=>nil, 37=>nil, 29=>:enemy}, {45=>nil, 37=>nil, 29=>nil}], 21=>[{45=>nil, 37=>nil, 29=>nil, 21=>:enemy}, {45=>nil, 37=>nil, 29=>nil, 21=>nil}], 13=>[{45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, {45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil}], 5=>[{45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}], 39=>[{46=>nil, 39=>:enemy}, {46=>nil, 39=>nil}], 51=>[{52=>nil, 51=>:enemy}, {52=>nil, 51=>nil}], 50=>[{52=>nil, 51=>nil, 50=>:enemy}, {52=>nil, 51=>nil, 50=>nil}], 49=>[{52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, {52=>nil, 51=>nil, 50=>nil, 49=>nil}], 48=>[{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}], 55=>[{54=>nil, 55=>:enemy}, {54=>nil, 55=>nil}]}, 54=>{45=>[{45=>:enemy}, {45=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 63=>[{63=>:enemy}, {63=>nil}], 36=>[{45=>nil, 36=>:enemy}, {45=>nil, 36=>nil}], 27=>[{45=>nil, 36=>nil, 27=>:enemy}, {45=>nil, 36=>nil, 27=>nil}], 18=>[{45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, {45=>nil, 36=>nil, 27=>nil, 18=>nil}], 9=>[{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, {45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}], 0=>[{45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}], 38=>[{46=>nil, 38=>:enemy}, {46=>nil, 38=>nil}], 30=>[{46=>nil, 38=>nil, 30=>:enemy}, {46=>nil, 38=>nil, 30=>nil}], 22=>[{46=>nil, 38=>nil, 30=>nil, 22=>:enemy}, {46=>nil, 38=>nil, 30=>nil, 22=>nil}], 14=>[{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, {46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil}], 6=>[{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}], 52=>[{53=>nil, 52=>:enemy}, {53=>nil, 52=>nil}], 51=>[{53=>nil, 52=>nil, 51=>:enemy}, {53=>nil, 52=>nil, 51=>nil}], 50=>[{53=>nil, 52=>nil, 51=>nil, 50=>:enemy}, {53=>nil, 52=>nil, 51=>nil, 50=>nil}], 49=>[{53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, {53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil}], 48=>[{53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}]}, 55=>{46=>[{46=>:enemy}, {46=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 63=>[{63=>:enemy}, {63=>nil}], 37=>[{46=>nil, 37=>:enemy}, {46=>nil, 37=>nil}], 28=>[{46=>nil, 37=>nil, 28=>:enemy}, {46=>nil, 37=>nil, 28=>nil}], 19=>[{46=>nil, 37=>nil, 28=>nil, 19=>:enemy}, {46=>nil, 37=>nil, 28=>nil, 19=>nil}], 10=>[{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>:enemy}, {46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil}], 1=>[{46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>:enemy}, {46=>nil, 37=>nil, 28=>nil, 19=>nil, 10=>nil, 1=>nil}], 39=>[{47=>nil, 39=>:enemy}, {47=>nil, 39=>nil}], 31=>[{47=>nil, 39=>nil, 31=>:enemy}, {47=>nil, 39=>nil, 31=>nil}], 23=>[{47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, {47=>nil, 39=>nil, 31=>nil, 23=>nil}], 15=>[{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, {47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}], 7=>[{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}], 53=>[{54=>nil, 53=>:enemy}, {54=>nil, 53=>nil}], 52=>[{54=>nil, 53=>nil, 52=>:enemy}, {54=>nil, 53=>nil, 52=>nil}], 51=>[{54=>nil, 53=>nil, 52=>nil, 51=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil}], 50=>[{54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil}], 49=>[{54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil}], 48=>[{54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}]}, 56=>{48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 40=>[{48=>nil, 40=>:enemy}, {48=>nil, 40=>nil}], 32=>[{48=>nil, 40=>nil, 32=>:enemy}, {48=>nil, 40=>nil, 32=>nil}], 24=>[{48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil}], 16=>[{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}], 8=>[{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}], 0=>[{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>nil}], 42=>[{49=>nil, 42=>:enemy}, {49=>nil, 42=>nil}], 35=>[{49=>nil, 42=>nil, 35=>:enemy}, {49=>nil, 42=>nil, 35=>nil}], 28=>[{49=>nil, 42=>nil, 35=>nil, 28=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil}], 21=>[{49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil}], 14=>[{49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil}], 7=>[{49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>:enemy}, {49=>nil, 42=>nil, 35=>nil, 28=>nil, 21=>nil, 14=>nil, 7=>nil}], 58=>[{57=>nil, 58=>:enemy}, {57=>nil, 58=>nil}], 59=>[{57=>nil, 58=>nil, 59=>:enemy}, {57=>nil, 58=>nil, 59=>nil}], 60=>[{57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil}], 61=>[{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}], 62=>[{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}], 63=>[{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 57=>{48=>[{48=>:enemy}, {48=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 41=>[{49=>nil, 41=>:enemy}, {49=>nil, 41=>nil}], 33=>[{49=>nil, 41=>nil, 33=>:enemy}, {49=>nil, 41=>nil, 33=>nil}], 25=>[{49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil}], 17=>[{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}], 9=>[{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil}], 1=>[{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>nil}], 43=>[{50=>nil, 43=>:enemy}, {50=>nil, 43=>nil}], 36=>[{50=>nil, 43=>nil, 36=>:enemy}, {50=>nil, 43=>nil, 36=>nil}], 29=>[{50=>nil, 43=>nil, 36=>nil, 29=>:enemy}, {50=>nil, 43=>nil, 36=>nil, 29=>nil}], 22=>[{50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>:enemy}, {50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>nil}], 15=>[{50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>:enemy}, {50=>nil, 43=>nil, 36=>nil, 29=>nil, 22=>nil, 15=>nil}], 59=>[{58=>nil, 59=>:enemy}, {58=>nil, 59=>nil}], 60=>[{58=>nil, 59=>nil, 60=>:enemy}, {58=>nil, 59=>nil, 60=>nil}], 61=>[{58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, {58=>nil, 59=>nil, 60=>nil, 61=>nil}], 62=>[{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, {58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}], 63=>[{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 58=>{49=>[{49=>:enemy}, {49=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 40=>[{49=>nil, 40=>:enemy}, {49=>nil, 40=>nil}], 42=>[{50=>nil, 42=>:enemy}, {50=>nil, 42=>nil}], 34=>[{50=>nil, 42=>nil, 34=>:enemy}, {50=>nil, 42=>nil, 34=>nil}], 26=>[{50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil}], 18=>[{50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil}], 10=>[{50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil}], 2=>[{50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>nil}], 44=>[{51=>nil, 44=>:enemy}, {51=>nil, 44=>nil}], 37=>[{51=>nil, 44=>nil, 37=>:enemy}, {51=>nil, 44=>nil, 37=>nil}], 30=>[{51=>nil, 44=>nil, 37=>nil, 30=>:enemy}, {51=>nil, 44=>nil, 37=>nil, 30=>nil}], 23=>[{51=>nil, 44=>nil, 37=>nil, 30=>nil, 23=>:enemy}, {51=>nil, 44=>nil, 37=>nil, 30=>nil, 23=>nil}], 56=>[{57=>nil, 56=>:enemy}, {57=>nil, 56=>nil}], 60=>[{59=>nil, 60=>:enemy}, {59=>nil, 60=>nil}], 61=>[{59=>nil, 60=>nil, 61=>:enemy}, {59=>nil, 60=>nil, 61=>nil}], 62=>[{59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, {59=>nil, 60=>nil, 61=>nil, 62=>nil}], 63=>[{59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 59=>{50=>[{50=>:enemy}, {50=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 41=>[{50=>nil, 41=>:enemy}, {50=>nil, 41=>nil}], 32=>[{50=>nil, 41=>nil, 32=>:enemy}, {50=>nil, 41=>nil, 32=>nil}], 43=>[{51=>nil, 43=>:enemy}, {51=>nil, 43=>nil}], 35=>[{51=>nil, 43=>nil, 35=>:enemy}, {51=>nil, 43=>nil, 35=>nil}], 27=>[{51=>nil, 43=>nil, 35=>nil, 27=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil}], 19=>[{51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil}], 11=>[{51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil}], 3=>[{51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>nil}], 45=>[{52=>nil, 45=>:enemy}, {52=>nil, 45=>nil}], 38=>[{52=>nil, 45=>nil, 38=>:enemy}, {52=>nil, 45=>nil, 38=>nil}], 31=>[{52=>nil, 45=>nil, 38=>nil, 31=>:enemy}, {52=>nil, 45=>nil, 38=>nil, 31=>nil}], 57=>[{58=>nil, 57=>:enemy}, {58=>nil, 57=>nil}], 56=>[{58=>nil, 57=>nil, 56=>:enemy}, {58=>nil, 57=>nil, 56=>nil}], 61=>[{60=>nil, 61=>:enemy}, {60=>nil, 61=>nil}], 62=>[{60=>nil, 61=>nil, 62=>:enemy}, {60=>nil, 61=>nil, 62=>nil}], 63=>[{60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 60=>{51=>[{51=>:enemy}, {51=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 42=>[{51=>nil, 42=>:enemy}, {51=>nil, 42=>nil}], 33=>[{51=>nil, 42=>nil, 33=>:enemy}, {51=>nil, 42=>nil, 33=>nil}], 24=>[{51=>nil, 42=>nil, 33=>nil, 24=>:enemy}, {51=>nil, 42=>nil, 33=>nil, 24=>nil}], 44=>[{52=>nil, 44=>:enemy}, {52=>nil, 44=>nil}], 36=>[{52=>nil, 44=>nil, 36=>:enemy}, {52=>nil, 44=>nil, 36=>nil}], 28=>[{52=>nil, 44=>nil, 36=>nil, 28=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil}], 20=>[{52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil}], 12=>[{52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil}], 4=>[{52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>nil}], 46=>[{53=>nil, 46=>:enemy}, {53=>nil, 46=>nil}], 39=>[{53=>nil, 46=>nil, 39=>:enemy}, {53=>nil, 46=>nil, 39=>nil}], 58=>[{59=>nil, 58=>:enemy}, {59=>nil, 58=>nil}], 57=>[{59=>nil, 58=>nil, 57=>:enemy}, {59=>nil, 58=>nil, 57=>nil}], 56=>[{59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {59=>nil, 58=>nil, 57=>nil, 56=>nil}], 62=>[{61=>nil, 62=>:enemy}, {61=>nil, 62=>nil}], 63=>[{61=>nil, 62=>nil, 63=>:enemy}, {61=>nil, 62=>nil, 63=>nil}]}, 61=>{52=>[{52=>:enemy}, {52=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 43=>[{52=>nil, 43=>:enemy}, {52=>nil, 43=>nil}], 34=>[{52=>nil, 43=>nil, 34=>:enemy}, {52=>nil, 43=>nil, 34=>nil}], 25=>[{52=>nil, 43=>nil, 34=>nil, 25=>:enemy}, {52=>nil, 43=>nil, 34=>nil, 25=>nil}], 16=>[{52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>:enemy}, {52=>nil, 43=>nil, 34=>nil, 25=>nil, 16=>nil}], 45=>[{53=>nil, 45=>:enemy}, {53=>nil, 45=>nil}], 37=>[{53=>nil, 45=>nil, 37=>:enemy}, {53=>nil, 45=>nil, 37=>nil}], 29=>[{53=>nil, 45=>nil, 37=>nil, 29=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil}], 21=>[{53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil}], 13=>[{53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil}], 5=>[{53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}], 47=>[{54=>nil, 47=>:enemy}, {54=>nil, 47=>nil}], 59=>[{60=>nil, 59=>:enemy}, {60=>nil, 59=>nil}], 58=>[{60=>nil, 59=>nil, 58=>:enemy}, {60=>nil, 59=>nil, 58=>nil}], 57=>[{60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, {60=>nil, 59=>nil, 58=>nil, 57=>nil}], 56=>[{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}], 63=>[{62=>nil, 63=>:enemy}, {62=>nil, 63=>nil}]}, 62=>{53=>[{53=>:enemy}, {53=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 63=>[{63=>:enemy}, {63=>nil}], 44=>[{53=>nil, 44=>:enemy}, {53=>nil, 44=>nil}], 35=>[{53=>nil, 44=>nil, 35=>:enemy}, {53=>nil, 44=>nil, 35=>nil}], 26=>[{53=>nil, 44=>nil, 35=>nil, 26=>:enemy}, {53=>nil, 44=>nil, 35=>nil, 26=>nil}], 17=>[{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>:enemy}, {53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil}], 8=>[{53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>:enemy}, {53=>nil, 44=>nil, 35=>nil, 26=>nil, 17=>nil, 8=>nil}], 46=>[{54=>nil, 46=>:enemy}, {54=>nil, 46=>nil}], 38=>[{54=>nil, 46=>nil, 38=>:enemy}, {54=>nil, 46=>nil, 38=>nil}], 30=>[{54=>nil, 46=>nil, 38=>nil, 30=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil}], 22=>[{54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil}], 14=>[{54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil}], 6=>[{54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}], 60=>[{61=>nil, 60=>:enemy}, {61=>nil, 60=>nil}], 59=>[{61=>nil, 60=>nil, 59=>:enemy}, {61=>nil, 60=>nil, 59=>nil}], 58=>[{61=>nil, 60=>nil, 59=>nil, 58=>:enemy}, {61=>nil, 60=>nil, 59=>nil, 58=>nil}], 57=>[{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, {61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}], 56=>[{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}]}, 63=>{54=>[{54=>:enemy}, {54=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 45=>[{54=>nil, 45=>:enemy}, {54=>nil, 45=>nil}], 36=>[{54=>nil, 45=>nil, 36=>:enemy}, {54=>nil, 45=>nil, 36=>nil}], 27=>[{54=>nil, 45=>nil, 36=>nil, 27=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil}], 18=>[{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil}], 9=>[{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil}], 0=>[{54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>:enemy}, {54=>nil, 45=>nil, 36=>nil, 27=>nil, 18=>nil, 9=>nil, 0=>nil}], 47=>[{55=>nil, 47=>:enemy}, {55=>nil, 47=>nil}], 39=>[{55=>nil, 47=>nil, 39=>:enemy}, {55=>nil, 47=>nil, 39=>nil}], 31=>[{55=>nil, 47=>nil, 39=>nil, 31=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil}], 23=>[{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil}], 15=>[{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}], 7=>[{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}], 61=>[{62=>nil, 61=>:enemy}, {62=>nil, 61=>nil}], 60=>[{62=>nil, 61=>nil, 60=>:enemy}, {62=>nil, 61=>nil, 60=>nil}], 59=>[{62=>nil, 61=>nil, 60=>nil, 59=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil}], 58=>[{62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil}], 57=>[{62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}], 56=>[{62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}]}}, "c:r"=>{0=>{1=>[{1=>:enemy}, {1=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 2=>[{1=>nil, 2=>:enemy}, {1=>nil, 2=>nil}], 3=>[{1=>nil, 2=>nil, 3=>:enemy}, {1=>nil, 2=>nil, 3=>nil}], 4=>[{1=>nil, 2=>nil, 3=>nil, 4=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil}], 5=>[{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil}], 6=>[{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}], 7=>[{1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {1=>nil, 2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}], 16=>[{8=>nil, 16=>:enemy}, {8=>nil, 16=>nil}], 24=>[{8=>nil, 16=>nil, 24=>:enemy}, {8=>nil, 16=>nil, 24=>nil}], 32=>[{8=>nil, 16=>nil, 24=>nil, 32=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil}], 40=>[{8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil}], 48=>[{8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil}], 56=>[{8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {8=>nil, 16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}]}, 1=>{0=>[{0=>:enemy}, {0=>nil}], 2=>[{2=>:enemy}, {2=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 3=>[{2=>nil, 3=>:enemy}, {2=>nil, 3=>nil}], 4=>[{2=>nil, 3=>nil, 4=>:enemy}, {2=>nil, 3=>nil, 4=>nil}], 5=>[{2=>nil, 3=>nil, 4=>nil, 5=>:enemy}, {2=>nil, 3=>nil, 4=>nil, 5=>nil}], 6=>[{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, {2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil}], 7=>[{2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {2=>nil, 3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}], 17=>[{9=>nil, 17=>:enemy}, {9=>nil, 17=>nil}], 25=>[{9=>nil, 17=>nil, 25=>:enemy}, {9=>nil, 17=>nil, 25=>nil}], 33=>[{9=>nil, 17=>nil, 25=>nil, 33=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil}], 41=>[{9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil}], 49=>[{9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil}], 57=>[{9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {9=>nil, 17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}]}, 2=>{1=>[{1=>:enemy}, {1=>nil}], 3=>[{3=>:enemy}, {3=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 0=>[{1=>nil, 0=>:enemy}, {1=>nil, 0=>nil}], 4=>[{3=>nil, 4=>:enemy}, {3=>nil, 4=>nil}], 5=>[{3=>nil, 4=>nil, 5=>:enemy}, {3=>nil, 4=>nil, 5=>nil}], 6=>[{3=>nil, 4=>nil, 5=>nil, 6=>:enemy}, {3=>nil, 4=>nil, 5=>nil, 6=>nil}], 7=>[{3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {3=>nil, 4=>nil, 5=>nil, 6=>nil, 7=>nil}], 18=>[{10=>nil, 18=>:enemy}, {10=>nil, 18=>nil}], 26=>[{10=>nil, 18=>nil, 26=>:enemy}, {10=>nil, 18=>nil, 26=>nil}], 34=>[{10=>nil, 18=>nil, 26=>nil, 34=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil}], 42=>[{10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil}], 50=>[{10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil}], 58=>[{10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {10=>nil, 18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>nil}]}, 3=>{2=>[{2=>:enemy}, {2=>nil}], 4=>[{4=>:enemy}, {4=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 1=>[{2=>nil, 1=>:enemy}, {2=>nil, 1=>nil}], 0=>[{2=>nil, 1=>nil, 0=>:enemy}, {2=>nil, 1=>nil, 0=>nil}], 5=>[{4=>nil, 5=>:enemy}, {4=>nil, 5=>nil}], 6=>[{4=>nil, 5=>nil, 6=>:enemy}, {4=>nil, 5=>nil, 6=>nil}], 7=>[{4=>nil, 5=>nil, 6=>nil, 7=>:enemy}, {4=>nil, 5=>nil, 6=>nil, 7=>nil}], 19=>[{11=>nil, 19=>:enemy}, {11=>nil, 19=>nil}], 27=>[{11=>nil, 19=>nil, 27=>:enemy}, {11=>nil, 19=>nil, 27=>nil}], 35=>[{11=>nil, 19=>nil, 27=>nil, 35=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil}], 43=>[{11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil}], 51=>[{11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil}], 59=>[{11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {11=>nil, 19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>nil}]}, 4=>{3=>[{3=>:enemy}, {3=>nil}], 5=>[{5=>:enemy}, {5=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 2=>[{3=>nil, 2=>:enemy}, {3=>nil, 2=>nil}], 1=>[{3=>nil, 2=>nil, 1=>:enemy}, {3=>nil, 2=>nil, 1=>nil}], 0=>[{3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {3=>nil, 2=>nil, 1=>nil, 0=>nil}], 6=>[{5=>nil, 6=>:enemy}, {5=>nil, 6=>nil}], 7=>[{5=>nil, 6=>nil, 7=>:enemy}, {5=>nil, 6=>nil, 7=>nil}], 20=>[{12=>nil, 20=>:enemy}, {12=>nil, 20=>nil}], 28=>[{12=>nil, 20=>nil, 28=>:enemy}, {12=>nil, 20=>nil, 28=>nil}], 36=>[{12=>nil, 20=>nil, 28=>nil, 36=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil}], 44=>[{12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil}], 52=>[{12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil}], 60=>[{12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {12=>nil, 20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>nil}]}, 5=>{4=>[{4=>:enemy}, {4=>nil}], 6=>[{6=>:enemy}, {6=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 3=>[{4=>nil, 3=>:enemy}, {4=>nil, 3=>nil}], 2=>[{4=>nil, 3=>nil, 2=>:enemy}, {4=>nil, 3=>nil, 2=>nil}], 1=>[{4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, {4=>nil, 3=>nil, 2=>nil, 1=>nil}], 0=>[{4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}], 7=>[{6=>nil, 7=>:enemy}, {6=>nil, 7=>nil}], 21=>[{13=>nil, 21=>:enemy}, {13=>nil, 21=>nil}], 29=>[{13=>nil, 21=>nil, 29=>:enemy}, {13=>nil, 21=>nil, 29=>nil}], 37=>[{13=>nil, 21=>nil, 29=>nil, 37=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil}], 45=>[{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil}], 53=>[{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil}], 61=>[{13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {13=>nil, 21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>nil}]}, 6=>{5=>[{5=>:enemy}, {5=>nil}], 7=>[{7=>:enemy}, {7=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 4=>[{5=>nil, 4=>:enemy}, {5=>nil, 4=>nil}], 3=>[{5=>nil, 4=>nil, 3=>:enemy}, {5=>nil, 4=>nil, 3=>nil}], 2=>[{5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, {5=>nil, 4=>nil, 3=>nil, 2=>nil}], 1=>[{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, {5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}], 0=>[{5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}], 22=>[{14=>nil, 22=>:enemy}, {14=>nil, 22=>nil}], 30=>[{14=>nil, 22=>nil, 30=>:enemy}, {14=>nil, 22=>nil, 30=>nil}], 38=>[{14=>nil, 22=>nil, 30=>nil, 38=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil}], 46=>[{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil}], 54=>[{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}], 62=>[{14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {14=>nil, 22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 7=>{6=>[{6=>:enemy}, {6=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 5=>[{6=>nil, 5=>:enemy}, {6=>nil, 5=>nil}], 4=>[{6=>nil, 5=>nil, 4=>:enemy}, {6=>nil, 5=>nil, 4=>nil}], 3=>[{6=>nil, 5=>nil, 4=>nil, 3=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil}], 2=>[{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil}], 1=>[{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil}], 0=>[{6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>:enemy}, {6=>nil, 5=>nil, 4=>nil, 3=>nil, 2=>nil, 1=>nil, 0=>nil}], 23=>[{15=>nil, 23=>:enemy}, {15=>nil, 23=>nil}], 31=>[{15=>nil, 23=>nil, 31=>:enemy}, {15=>nil, 23=>nil, 31=>nil}], 39=>[{15=>nil, 23=>nil, 31=>nil, 39=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil}], 47=>[{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil}], 55=>[{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}], 63=>[{15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {15=>nil, 23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 8=>{0=>[{0=>:enemy}, {0=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 10=>[{9=>nil, 10=>:enemy}, {9=>nil, 10=>nil}], 11=>[{9=>nil, 10=>nil, 11=>:enemy}, {9=>nil, 10=>nil, 11=>nil}], 12=>[{9=>nil, 10=>nil, 11=>nil, 12=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil}], 13=>[{9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil}], 14=>[{9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}], 15=>[{9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {9=>nil, 10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}], 24=>[{16=>nil, 24=>:enemy}, {16=>nil, 24=>nil}], 32=>[{16=>nil, 24=>nil, 32=>:enemy}, {16=>nil, 24=>nil, 32=>nil}], 40=>[{16=>nil, 24=>nil, 32=>nil, 40=>:enemy}, {16=>nil, 24=>nil, 32=>nil, 40=>nil}], 48=>[{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, {16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil}], 56=>[{16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {16=>nil, 24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}]}, 9=>{1=>[{1=>:enemy}, {1=>nil}], 8=>[{8=>:enemy}, {8=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 11=>[{10=>nil, 11=>:enemy}, {10=>nil, 11=>nil}], 12=>[{10=>nil, 11=>nil, 12=>:enemy}, {10=>nil, 11=>nil, 12=>nil}], 13=>[{10=>nil, 11=>nil, 12=>nil, 13=>:enemy}, {10=>nil, 11=>nil, 12=>nil, 13=>nil}], 14=>[{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, {10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil}], 15=>[{10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {10=>nil, 11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}], 25=>[{17=>nil, 25=>:enemy}, {17=>nil, 25=>nil}], 33=>[{17=>nil, 25=>nil, 33=>:enemy}, {17=>nil, 25=>nil, 33=>nil}], 41=>[{17=>nil, 25=>nil, 33=>nil, 41=>:enemy}, {17=>nil, 25=>nil, 33=>nil, 41=>nil}], 49=>[{17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, {17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil}], 57=>[{17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {17=>nil, 25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}]}, 10=>{2=>[{2=>:enemy}, {2=>nil}], 9=>[{9=>:enemy}, {9=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 8=>[{9=>nil, 8=>:enemy}, {9=>nil, 8=>nil}], 12=>[{11=>nil, 12=>:enemy}, {11=>nil, 12=>nil}], 13=>[{11=>nil, 12=>nil, 13=>:enemy}, {11=>nil, 12=>nil, 13=>nil}], 14=>[{11=>nil, 12=>nil, 13=>nil, 14=>:enemy}, {11=>nil, 12=>nil, 13=>nil, 14=>nil}], 15=>[{11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {11=>nil, 12=>nil, 13=>nil, 14=>nil, 15=>nil}], 26=>[{18=>nil, 26=>:enemy}, {18=>nil, 26=>nil}], 34=>[{18=>nil, 26=>nil, 34=>:enemy}, {18=>nil, 26=>nil, 34=>nil}], 42=>[{18=>nil, 26=>nil, 34=>nil, 42=>:enemy}, {18=>nil, 26=>nil, 34=>nil, 42=>nil}], 50=>[{18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>:enemy}, {18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil}], 58=>[{18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {18=>nil, 26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>nil}]}, 11=>{3=>[{3=>:enemy}, {3=>nil}], 10=>[{10=>:enemy}, {10=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 9=>[{10=>nil, 9=>:enemy}, {10=>nil, 9=>nil}], 8=>[{10=>nil, 9=>nil, 8=>:enemy}, {10=>nil, 9=>nil, 8=>nil}], 13=>[{12=>nil, 13=>:enemy}, {12=>nil, 13=>nil}], 14=>[{12=>nil, 13=>nil, 14=>:enemy}, {12=>nil, 13=>nil, 14=>nil}], 15=>[{12=>nil, 13=>nil, 14=>nil, 15=>:enemy}, {12=>nil, 13=>nil, 14=>nil, 15=>nil}], 27=>[{19=>nil, 27=>:enemy}, {19=>nil, 27=>nil}], 35=>[{19=>nil, 27=>nil, 35=>:enemy}, {19=>nil, 27=>nil, 35=>nil}], 43=>[{19=>nil, 27=>nil, 35=>nil, 43=>:enemy}, {19=>nil, 27=>nil, 35=>nil, 43=>nil}], 51=>[{19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>:enemy}, {19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil}], 59=>[{19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {19=>nil, 27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>nil}]}, 12=>{4=>[{4=>:enemy}, {4=>nil}], 11=>[{11=>:enemy}, {11=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 10=>[{11=>nil, 10=>:enemy}, {11=>nil, 10=>nil}], 9=>[{11=>nil, 10=>nil, 9=>:enemy}, {11=>nil, 10=>nil, 9=>nil}], 8=>[{11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {11=>nil, 10=>nil, 9=>nil, 8=>nil}], 14=>[{13=>nil, 14=>:enemy}, {13=>nil, 14=>nil}], 15=>[{13=>nil, 14=>nil, 15=>:enemy}, {13=>nil, 14=>nil, 15=>nil}], 28=>[{20=>nil, 28=>:enemy}, {20=>nil, 28=>nil}], 36=>[{20=>nil, 28=>nil, 36=>:enemy}, {20=>nil, 28=>nil, 36=>nil}], 44=>[{20=>nil, 28=>nil, 36=>nil, 44=>:enemy}, {20=>nil, 28=>nil, 36=>nil, 44=>nil}], 52=>[{20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>:enemy}, {20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil}], 60=>[{20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {20=>nil, 28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>nil}]}, 13=>{5=>[{5=>:enemy}, {5=>nil}], 12=>[{12=>:enemy}, {12=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 11=>[{12=>nil, 11=>:enemy}, {12=>nil, 11=>nil}], 10=>[{12=>nil, 11=>nil, 10=>:enemy}, {12=>nil, 11=>nil, 10=>nil}], 9=>[{12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, {12=>nil, 11=>nil, 10=>nil, 9=>nil}], 8=>[{12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>nil}], 15=>[{14=>nil, 15=>:enemy}, {14=>nil, 15=>nil}], 29=>[{21=>nil, 29=>:enemy}, {21=>nil, 29=>nil}], 37=>[{21=>nil, 29=>nil, 37=>:enemy}, {21=>nil, 29=>nil, 37=>nil}], 45=>[{21=>nil, 29=>nil, 37=>nil, 45=>:enemy}, {21=>nil, 29=>nil, 37=>nil, 45=>nil}], 53=>[{21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>:enemy}, {21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil}], 61=>[{21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {21=>nil, 29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>nil}]}, 14=>{6=>[{6=>:enemy}, {6=>nil}], 13=>[{13=>:enemy}, {13=>nil}], 15=>[{15=>:enemy}, {15=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 12=>[{13=>nil, 12=>:enemy}, {13=>nil, 12=>nil}], 11=>[{13=>nil, 12=>nil, 11=>:enemy}, {13=>nil, 12=>nil, 11=>nil}], 10=>[{13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, {13=>nil, 12=>nil, 11=>nil, 10=>nil}], 9=>[{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, {13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}], 8=>[{13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>nil}], 30=>[{22=>nil, 30=>:enemy}, {22=>nil, 30=>nil}], 38=>[{22=>nil, 30=>nil, 38=>:enemy}, {22=>nil, 30=>nil, 38=>nil}], 46=>[{22=>nil, 30=>nil, 38=>nil, 46=>:enemy}, {22=>nil, 30=>nil, 38=>nil, 46=>nil}], 54=>[{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, {22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil}], 62=>[{22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {22=>nil, 30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 15=>{7=>[{7=>:enemy}, {7=>nil}], 14=>[{14=>:enemy}, {14=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 13=>[{14=>nil, 13=>:enemy}, {14=>nil, 13=>nil}], 12=>[{14=>nil, 13=>nil, 12=>:enemy}, {14=>nil, 13=>nil, 12=>nil}], 11=>[{14=>nil, 13=>nil, 12=>nil, 11=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil}], 10=>[{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil}], 9=>[{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil}], 8=>[{14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>:enemy}, {14=>nil, 13=>nil, 12=>nil, 11=>nil, 10=>nil, 9=>nil, 8=>nil}], 31=>[{23=>nil, 31=>:enemy}, {23=>nil, 31=>nil}], 39=>[{23=>nil, 31=>nil, 39=>:enemy}, {23=>nil, 31=>nil, 39=>nil}], 47=>[{23=>nil, 31=>nil, 39=>nil, 47=>:enemy}, {23=>nil, 31=>nil, 39=>nil, 47=>nil}], 55=>[{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, {23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil}], 63=>[{23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {23=>nil, 31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 16=>{8=>[{8=>:enemy}, {8=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 0=>[{8=>nil, 0=>:enemy}, {8=>nil, 0=>nil}], 18=>[{17=>nil, 18=>:enemy}, {17=>nil, 18=>nil}], 19=>[{17=>nil, 18=>nil, 19=>:enemy}, {17=>nil, 18=>nil, 19=>nil}], 20=>[{17=>nil, 18=>nil, 19=>nil, 20=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil}], 21=>[{17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil}], 22=>[{17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil}], 23=>[{17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {17=>nil, 18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}], 32=>[{24=>nil, 32=>:enemy}, {24=>nil, 32=>nil}], 40=>[{24=>nil, 32=>nil, 40=>:enemy}, {24=>nil, 32=>nil, 40=>nil}], 48=>[{24=>nil, 32=>nil, 40=>nil, 48=>:enemy}, {24=>nil, 32=>nil, 40=>nil, 48=>nil}], 56=>[{24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {24=>nil, 32=>nil, 40=>nil, 48=>nil, 56=>nil}]}, 17=>{9=>[{9=>:enemy}, {9=>nil}], 16=>[{16=>:enemy}, {16=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 1=>[{9=>nil, 1=>:enemy}, {9=>nil, 1=>nil}], 19=>[{18=>nil, 19=>:enemy}, {18=>nil, 19=>nil}], 20=>[{18=>nil, 19=>nil, 20=>:enemy}, {18=>nil, 19=>nil, 20=>nil}], 21=>[{18=>nil, 19=>nil, 20=>nil, 21=>:enemy}, {18=>nil, 19=>nil, 20=>nil, 21=>nil}], 22=>[{18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, {18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil}], 23=>[{18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {18=>nil, 19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}], 33=>[{25=>nil, 33=>:enemy}, {25=>nil, 33=>nil}], 41=>[{25=>nil, 33=>nil, 41=>:enemy}, {25=>nil, 33=>nil, 41=>nil}], 49=>[{25=>nil, 33=>nil, 41=>nil, 49=>:enemy}, {25=>nil, 33=>nil, 41=>nil, 49=>nil}], 57=>[{25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {25=>nil, 33=>nil, 41=>nil, 49=>nil, 57=>nil}]}, 18=>{10=>[{10=>:enemy}, {10=>nil}], 17=>[{17=>:enemy}, {17=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 2=>[{10=>nil, 2=>:enemy}, {10=>nil, 2=>nil}], 16=>[{17=>nil, 16=>:enemy}, {17=>nil, 16=>nil}], 20=>[{19=>nil, 20=>:enemy}, {19=>nil, 20=>nil}], 21=>[{19=>nil, 20=>nil, 21=>:enemy}, {19=>nil, 20=>nil, 21=>nil}], 22=>[{19=>nil, 20=>nil, 21=>nil, 22=>:enemy}, {19=>nil, 20=>nil, 21=>nil, 22=>nil}], 23=>[{19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {19=>nil, 20=>nil, 21=>nil, 22=>nil, 23=>nil}], 34=>[{26=>nil, 34=>:enemy}, {26=>nil, 34=>nil}], 42=>[{26=>nil, 34=>nil, 42=>:enemy}, {26=>nil, 34=>nil, 42=>nil}], 50=>[{26=>nil, 34=>nil, 42=>nil, 50=>:enemy}, {26=>nil, 34=>nil, 42=>nil, 50=>nil}], 58=>[{26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {26=>nil, 34=>nil, 42=>nil, 50=>nil, 58=>nil}]}, 19=>{11=>[{11=>:enemy}, {11=>nil}], 18=>[{18=>:enemy}, {18=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 3=>[{11=>nil, 3=>:enemy}, {11=>nil, 3=>nil}], 17=>[{18=>nil, 17=>:enemy}, {18=>nil, 17=>nil}], 16=>[{18=>nil, 17=>nil, 16=>:enemy}, {18=>nil, 17=>nil, 16=>nil}], 21=>[{20=>nil, 21=>:enemy}, {20=>nil, 21=>nil}], 22=>[{20=>nil, 21=>nil, 22=>:enemy}, {20=>nil, 21=>nil, 22=>nil}], 23=>[{20=>nil, 21=>nil, 22=>nil, 23=>:enemy}, {20=>nil, 21=>nil, 22=>nil, 23=>nil}], 35=>[{27=>nil, 35=>:enemy}, {27=>nil, 35=>nil}], 43=>[{27=>nil, 35=>nil, 43=>:enemy}, {27=>nil, 35=>nil, 43=>nil}], 51=>[{27=>nil, 35=>nil, 43=>nil, 51=>:enemy}, {27=>nil, 35=>nil, 43=>nil, 51=>nil}], 59=>[{27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {27=>nil, 35=>nil, 43=>nil, 51=>nil, 59=>nil}]}, 20=>{12=>[{12=>:enemy}, {12=>nil}], 19=>[{19=>:enemy}, {19=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 4=>[{12=>nil, 4=>:enemy}, {12=>nil, 4=>nil}], 18=>[{19=>nil, 18=>:enemy}, {19=>nil, 18=>nil}], 17=>[{19=>nil, 18=>nil, 17=>:enemy}, {19=>nil, 18=>nil, 17=>nil}], 16=>[{19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {19=>nil, 18=>nil, 17=>nil, 16=>nil}], 22=>[{21=>nil, 22=>:enemy}, {21=>nil, 22=>nil}], 23=>[{21=>nil, 22=>nil, 23=>:enemy}, {21=>nil, 22=>nil, 23=>nil}], 36=>[{28=>nil, 36=>:enemy}, {28=>nil, 36=>nil}], 44=>[{28=>nil, 36=>nil, 44=>:enemy}, {28=>nil, 36=>nil, 44=>nil}], 52=>[{28=>nil, 36=>nil, 44=>nil, 52=>:enemy}, {28=>nil, 36=>nil, 44=>nil, 52=>nil}], 60=>[{28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {28=>nil, 36=>nil, 44=>nil, 52=>nil, 60=>nil}]}, 21=>{13=>[{13=>:enemy}, {13=>nil}], 20=>[{20=>:enemy}, {20=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 5=>[{13=>nil, 5=>:enemy}, {13=>nil, 5=>nil}], 19=>[{20=>nil, 19=>:enemy}, {20=>nil, 19=>nil}], 18=>[{20=>nil, 19=>nil, 18=>:enemy}, {20=>nil, 19=>nil, 18=>nil}], 17=>[{20=>nil, 19=>nil, 18=>nil, 17=>:enemy}, {20=>nil, 19=>nil, 18=>nil, 17=>nil}], 16=>[{20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>nil}], 23=>[{22=>nil, 23=>:enemy}, {22=>nil, 23=>nil}], 37=>[{29=>nil, 37=>:enemy}, {29=>nil, 37=>nil}], 45=>[{29=>nil, 37=>nil, 45=>:enemy}, {29=>nil, 37=>nil, 45=>nil}], 53=>[{29=>nil, 37=>nil, 45=>nil, 53=>:enemy}, {29=>nil, 37=>nil, 45=>nil, 53=>nil}], 61=>[{29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {29=>nil, 37=>nil, 45=>nil, 53=>nil, 61=>nil}]}, 22=>{14=>[{14=>:enemy}, {14=>nil}], 21=>[{21=>:enemy}, {21=>nil}], 23=>[{23=>:enemy}, {23=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 6=>[{14=>nil, 6=>:enemy}, {14=>nil, 6=>nil}], 20=>[{21=>nil, 20=>:enemy}, {21=>nil, 20=>nil}], 19=>[{21=>nil, 20=>nil, 19=>:enemy}, {21=>nil, 20=>nil, 19=>nil}], 18=>[{21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, {21=>nil, 20=>nil, 19=>nil, 18=>nil}], 17=>[{21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>:enemy}, {21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil}], 16=>[{21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>nil}], 38=>[{30=>nil, 38=>:enemy}, {30=>nil, 38=>nil}], 46=>[{30=>nil, 38=>nil, 46=>:enemy}, {30=>nil, 38=>nil, 46=>nil}], 54=>[{30=>nil, 38=>nil, 46=>nil, 54=>:enemy}, {30=>nil, 38=>nil, 46=>nil, 54=>nil}], 62=>[{30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {30=>nil, 38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 23=>{15=>[{15=>:enemy}, {15=>nil}], 22=>[{22=>:enemy}, {22=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 7=>[{15=>nil, 7=>:enemy}, {15=>nil, 7=>nil}], 21=>[{22=>nil, 21=>:enemy}, {22=>nil, 21=>nil}], 20=>[{22=>nil, 21=>nil, 20=>:enemy}, {22=>nil, 21=>nil, 20=>nil}], 19=>[{22=>nil, 21=>nil, 20=>nil, 19=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil}], 18=>[{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil}], 17=>[{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil}], 16=>[{22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>:enemy}, {22=>nil, 21=>nil, 20=>nil, 19=>nil, 18=>nil, 17=>nil, 16=>nil}], 39=>[{31=>nil, 39=>:enemy}, {31=>nil, 39=>nil}], 47=>[{31=>nil, 39=>nil, 47=>:enemy}, {31=>nil, 39=>nil, 47=>nil}], 55=>[{31=>nil, 39=>nil, 47=>nil, 55=>:enemy}, {31=>nil, 39=>nil, 47=>nil, 55=>nil}], 63=>[{31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {31=>nil, 39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 24=>{16=>[{16=>:enemy}, {16=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 8=>[{16=>nil, 8=>:enemy}, {16=>nil, 8=>nil}], 0=>[{16=>nil, 8=>nil, 0=>:enemy}, {16=>nil, 8=>nil, 0=>nil}], 26=>[{25=>nil, 26=>:enemy}, {25=>nil, 26=>nil}], 27=>[{25=>nil, 26=>nil, 27=>:enemy}, {25=>nil, 26=>nil, 27=>nil}], 28=>[{25=>nil, 26=>nil, 27=>nil, 28=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil}], 29=>[{25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil}], 30=>[{25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil}], 31=>[{25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {25=>nil, 26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>nil}], 40=>[{32=>nil, 40=>:enemy}, {32=>nil, 40=>nil}], 48=>[{32=>nil, 40=>nil, 48=>:enemy}, {32=>nil, 40=>nil, 48=>nil}], 56=>[{32=>nil, 40=>nil, 48=>nil, 56=>:enemy}, {32=>nil, 40=>nil, 48=>nil, 56=>nil}]}, 25=>{17=>[{17=>:enemy}, {17=>nil}], 24=>[{24=>:enemy}, {24=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 9=>[{17=>nil, 9=>:enemy}, {17=>nil, 9=>nil}], 1=>[{17=>nil, 9=>nil, 1=>:enemy}, {17=>nil, 9=>nil, 1=>nil}], 27=>[{26=>nil, 27=>:enemy}, {26=>nil, 27=>nil}], 28=>[{26=>nil, 27=>nil, 28=>:enemy}, {26=>nil, 27=>nil, 28=>nil}], 29=>[{26=>nil, 27=>nil, 28=>nil, 29=>:enemy}, {26=>nil, 27=>nil, 28=>nil, 29=>nil}], 30=>[{26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>:enemy}, {26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil}], 31=>[{26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {26=>nil, 27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>nil}], 41=>[{33=>nil, 41=>:enemy}, {33=>nil, 41=>nil}], 49=>[{33=>nil, 41=>nil, 49=>:enemy}, {33=>nil, 41=>nil, 49=>nil}], 57=>[{33=>nil, 41=>nil, 49=>nil, 57=>:enemy}, {33=>nil, 41=>nil, 49=>nil, 57=>nil}]}, 26=>{18=>[{18=>:enemy}, {18=>nil}], 25=>[{25=>:enemy}, {25=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 10=>[{18=>nil, 10=>:enemy}, {18=>nil, 10=>nil}], 2=>[{18=>nil, 10=>nil, 2=>:enemy}, {18=>nil, 10=>nil, 2=>nil}], 24=>[{25=>nil, 24=>:enemy}, {25=>nil, 24=>nil}], 28=>[{27=>nil, 28=>:enemy}, {27=>nil, 28=>nil}], 29=>[{27=>nil, 28=>nil, 29=>:enemy}, {27=>nil, 28=>nil, 29=>nil}], 30=>[{27=>nil, 28=>nil, 29=>nil, 30=>:enemy}, {27=>nil, 28=>nil, 29=>nil, 30=>nil}], 31=>[{27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {27=>nil, 28=>nil, 29=>nil, 30=>nil, 31=>nil}], 42=>[{34=>nil, 42=>:enemy}, {34=>nil, 42=>nil}], 50=>[{34=>nil, 42=>nil, 50=>:enemy}, {34=>nil, 42=>nil, 50=>nil}], 58=>[{34=>nil, 42=>nil, 50=>nil, 58=>:enemy}, {34=>nil, 42=>nil, 50=>nil, 58=>nil}]}, 27=>{19=>[{19=>:enemy}, {19=>nil}], 26=>[{26=>:enemy}, {26=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 11=>[{19=>nil, 11=>:enemy}, {19=>nil, 11=>nil}], 3=>[{19=>nil, 11=>nil, 3=>:enemy}, {19=>nil, 11=>nil, 3=>nil}], 25=>[{26=>nil, 25=>:enemy}, {26=>nil, 25=>nil}], 24=>[{26=>nil, 25=>nil, 24=>:enemy}, {26=>nil, 25=>nil, 24=>nil}], 29=>[{28=>nil, 29=>:enemy}, {28=>nil, 29=>nil}], 30=>[{28=>nil, 29=>nil, 30=>:enemy}, {28=>nil, 29=>nil, 30=>nil}], 31=>[{28=>nil, 29=>nil, 30=>nil, 31=>:enemy}, {28=>nil, 29=>nil, 30=>nil, 31=>nil}], 43=>[{35=>nil, 43=>:enemy}, {35=>nil, 43=>nil}], 51=>[{35=>nil, 43=>nil, 51=>:enemy}, {35=>nil, 43=>nil, 51=>nil}], 59=>[{35=>nil, 43=>nil, 51=>nil, 59=>:enemy}, {35=>nil, 43=>nil, 51=>nil, 59=>nil}]}, 28=>{20=>[{20=>:enemy}, {20=>nil}], 27=>[{27=>:enemy}, {27=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 12=>[{20=>nil, 12=>:enemy}, {20=>nil, 12=>nil}], 4=>[{20=>nil, 12=>nil, 4=>:enemy}, {20=>nil, 12=>nil, 4=>nil}], 26=>[{27=>nil, 26=>:enemy}, {27=>nil, 26=>nil}], 25=>[{27=>nil, 26=>nil, 25=>:enemy}, {27=>nil, 26=>nil, 25=>nil}], 24=>[{27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {27=>nil, 26=>nil, 25=>nil, 24=>nil}], 30=>[{29=>nil, 30=>:enemy}, {29=>nil, 30=>nil}], 31=>[{29=>nil, 30=>nil, 31=>:enemy}, {29=>nil, 30=>nil, 31=>nil}], 44=>[{36=>nil, 44=>:enemy}, {36=>nil, 44=>nil}], 52=>[{36=>nil, 44=>nil, 52=>:enemy}, {36=>nil, 44=>nil, 52=>nil}], 60=>[{36=>nil, 44=>nil, 52=>nil, 60=>:enemy}, {36=>nil, 44=>nil, 52=>nil, 60=>nil}]}, 29=>{21=>[{21=>:enemy}, {21=>nil}], 28=>[{28=>:enemy}, {28=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 13=>[{21=>nil, 13=>:enemy}, {21=>nil, 13=>nil}], 5=>[{21=>nil, 13=>nil, 5=>:enemy}, {21=>nil, 13=>nil, 5=>nil}], 27=>[{28=>nil, 27=>:enemy}, {28=>nil, 27=>nil}], 26=>[{28=>nil, 27=>nil, 26=>:enemy}, {28=>nil, 27=>nil, 26=>nil}], 25=>[{28=>nil, 27=>nil, 26=>nil, 25=>:enemy}, {28=>nil, 27=>nil, 26=>nil, 25=>nil}], 24=>[{28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>nil}], 31=>[{30=>nil, 31=>:enemy}, {30=>nil, 31=>nil}], 45=>[{37=>nil, 45=>:enemy}, {37=>nil, 45=>nil}], 53=>[{37=>nil, 45=>nil, 53=>:enemy}, {37=>nil, 45=>nil, 53=>nil}], 61=>[{37=>nil, 45=>nil, 53=>nil, 61=>:enemy}, {37=>nil, 45=>nil, 53=>nil, 61=>nil}]}, 30=>{22=>[{22=>:enemy}, {22=>nil}], 29=>[{29=>:enemy}, {29=>nil}], 31=>[{31=>:enemy}, {31=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 14=>[{22=>nil, 14=>:enemy}, {22=>nil, 14=>nil}], 6=>[{22=>nil, 14=>nil, 6=>:enemy}, {22=>nil, 14=>nil, 6=>nil}], 28=>[{29=>nil, 28=>:enemy}, {29=>nil, 28=>nil}], 27=>[{29=>nil, 28=>nil, 27=>:enemy}, {29=>nil, 28=>nil, 27=>nil}], 26=>[{29=>nil, 28=>nil, 27=>nil, 26=>:enemy}, {29=>nil, 28=>nil, 27=>nil, 26=>nil}], 25=>[{29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>:enemy}, {29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil}], 24=>[{29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>nil}], 46=>[{38=>nil, 46=>:enemy}, {38=>nil, 46=>nil}], 54=>[{38=>nil, 46=>nil, 54=>:enemy}, {38=>nil, 46=>nil, 54=>nil}], 62=>[{38=>nil, 46=>nil, 54=>nil, 62=>:enemy}, {38=>nil, 46=>nil, 54=>nil, 62=>nil}]}, 31=>{23=>[{23=>:enemy}, {23=>nil}], 30=>[{30=>:enemy}, {30=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 15=>[{23=>nil, 15=>:enemy}, {23=>nil, 15=>nil}], 7=>[{23=>nil, 15=>nil, 7=>:enemy}, {23=>nil, 15=>nil, 7=>nil}], 29=>[{30=>nil, 29=>:enemy}, {30=>nil, 29=>nil}], 28=>[{30=>nil, 29=>nil, 28=>:enemy}, {30=>nil, 29=>nil, 28=>nil}], 27=>[{30=>nil, 29=>nil, 28=>nil, 27=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil}], 26=>[{30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil}], 25=>[{30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil}], 24=>[{30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>:enemy}, {30=>nil, 29=>nil, 28=>nil, 27=>nil, 26=>nil, 25=>nil, 24=>nil}], 47=>[{39=>nil, 47=>:enemy}, {39=>nil, 47=>nil}], 55=>[{39=>nil, 47=>nil, 55=>:enemy}, {39=>nil, 47=>nil, 55=>nil}], 63=>[{39=>nil, 47=>nil, 55=>nil, 63=>:enemy}, {39=>nil, 47=>nil, 55=>nil, 63=>nil}]}, 32=>{24=>[{24=>:enemy}, {24=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 16=>[{24=>nil, 16=>:enemy}, {24=>nil, 16=>nil}], 8=>[{24=>nil, 16=>nil, 8=>:enemy}, {24=>nil, 16=>nil, 8=>nil}], 0=>[{24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {24=>nil, 16=>nil, 8=>nil, 0=>nil}], 34=>[{33=>nil, 34=>:enemy}, {33=>nil, 34=>nil}], 35=>[{33=>nil, 34=>nil, 35=>:enemy}, {33=>nil, 34=>nil, 35=>nil}], 36=>[{33=>nil, 34=>nil, 35=>nil, 36=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil}], 37=>[{33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil}], 38=>[{33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil}], 39=>[{33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {33=>nil, 34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>nil}], 48=>[{40=>nil, 48=>:enemy}, {40=>nil, 48=>nil}], 56=>[{40=>nil, 48=>nil, 56=>:enemy}, {40=>nil, 48=>nil, 56=>nil}]}, 33=>{25=>[{25=>:enemy}, {25=>nil}], 32=>[{32=>:enemy}, {32=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 17=>[{25=>nil, 17=>:enemy}, {25=>nil, 17=>nil}], 9=>[{25=>nil, 17=>nil, 9=>:enemy}, {25=>nil, 17=>nil, 9=>nil}], 1=>[{25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {25=>nil, 17=>nil, 9=>nil, 1=>nil}], 35=>[{34=>nil, 35=>:enemy}, {34=>nil, 35=>nil}], 36=>[{34=>nil, 35=>nil, 36=>:enemy}, {34=>nil, 35=>nil, 36=>nil}], 37=>[{34=>nil, 35=>nil, 36=>nil, 37=>:enemy}, {34=>nil, 35=>nil, 36=>nil, 37=>nil}], 38=>[{34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>:enemy}, {34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil}], 39=>[{34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {34=>nil, 35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>nil}], 49=>[{41=>nil, 49=>:enemy}, {41=>nil, 49=>nil}], 57=>[{41=>nil, 49=>nil, 57=>:enemy}, {41=>nil, 49=>nil, 57=>nil}]}, 34=>{26=>[{26=>:enemy}, {26=>nil}], 33=>[{33=>:enemy}, {33=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 18=>[{26=>nil, 18=>:enemy}, {26=>nil, 18=>nil}], 10=>[{26=>nil, 18=>nil, 10=>:enemy}, {26=>nil, 18=>nil, 10=>nil}], 2=>[{26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {26=>nil, 18=>nil, 10=>nil, 2=>nil}], 32=>[{33=>nil, 32=>:enemy}, {33=>nil, 32=>nil}], 36=>[{35=>nil, 36=>:enemy}, {35=>nil, 36=>nil}], 37=>[{35=>nil, 36=>nil, 37=>:enemy}, {35=>nil, 36=>nil, 37=>nil}], 38=>[{35=>nil, 36=>nil, 37=>nil, 38=>:enemy}, {35=>nil, 36=>nil, 37=>nil, 38=>nil}], 39=>[{35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {35=>nil, 36=>nil, 37=>nil, 38=>nil, 39=>nil}], 50=>[{42=>nil, 50=>:enemy}, {42=>nil, 50=>nil}], 58=>[{42=>nil, 50=>nil, 58=>:enemy}, {42=>nil, 50=>nil, 58=>nil}]}, 35=>{27=>[{27=>:enemy}, {27=>nil}], 34=>[{34=>:enemy}, {34=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 19=>[{27=>nil, 19=>:enemy}, {27=>nil, 19=>nil}], 11=>[{27=>nil, 19=>nil, 11=>:enemy}, {27=>nil, 19=>nil, 11=>nil}], 3=>[{27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {27=>nil, 19=>nil, 11=>nil, 3=>nil}], 33=>[{34=>nil, 33=>:enemy}, {34=>nil, 33=>nil}], 32=>[{34=>nil, 33=>nil, 32=>:enemy}, {34=>nil, 33=>nil, 32=>nil}], 37=>[{36=>nil, 37=>:enemy}, {36=>nil, 37=>nil}], 38=>[{36=>nil, 37=>nil, 38=>:enemy}, {36=>nil, 37=>nil, 38=>nil}], 39=>[{36=>nil, 37=>nil, 38=>nil, 39=>:enemy}, {36=>nil, 37=>nil, 38=>nil, 39=>nil}], 51=>[{43=>nil, 51=>:enemy}, {43=>nil, 51=>nil}], 59=>[{43=>nil, 51=>nil, 59=>:enemy}, {43=>nil, 51=>nil, 59=>nil}]}, 36=>{28=>[{28=>:enemy}, {28=>nil}], 35=>[{35=>:enemy}, {35=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 20=>[{28=>nil, 20=>:enemy}, {28=>nil, 20=>nil}], 12=>[{28=>nil, 20=>nil, 12=>:enemy}, {28=>nil, 20=>nil, 12=>nil}], 4=>[{28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {28=>nil, 20=>nil, 12=>nil, 4=>nil}], 34=>[{35=>nil, 34=>:enemy}, {35=>nil, 34=>nil}], 33=>[{35=>nil, 34=>nil, 33=>:enemy}, {35=>nil, 34=>nil, 33=>nil}], 32=>[{35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {35=>nil, 34=>nil, 33=>nil, 32=>nil}], 38=>[{37=>nil, 38=>:enemy}, {37=>nil, 38=>nil}], 39=>[{37=>nil, 38=>nil, 39=>:enemy}, {37=>nil, 38=>nil, 39=>nil}], 52=>[{44=>nil, 52=>:enemy}, {44=>nil, 52=>nil}], 60=>[{44=>nil, 52=>nil, 60=>:enemy}, {44=>nil, 52=>nil, 60=>nil}]}, 37=>{29=>[{29=>:enemy}, {29=>nil}], 36=>[{36=>:enemy}, {36=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 21=>[{29=>nil, 21=>:enemy}, {29=>nil, 21=>nil}], 13=>[{29=>nil, 21=>nil, 13=>:enemy}, {29=>nil, 21=>nil, 13=>nil}], 5=>[{29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {29=>nil, 21=>nil, 13=>nil, 5=>nil}], 35=>[{36=>nil, 35=>:enemy}, {36=>nil, 35=>nil}], 34=>[{36=>nil, 35=>nil, 34=>:enemy}, {36=>nil, 35=>nil, 34=>nil}], 33=>[{36=>nil, 35=>nil, 34=>nil, 33=>:enemy}, {36=>nil, 35=>nil, 34=>nil, 33=>nil}], 32=>[{36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>nil}], 39=>[{38=>nil, 39=>:enemy}, {38=>nil, 39=>nil}], 53=>[{45=>nil, 53=>:enemy}, {45=>nil, 53=>nil}], 61=>[{45=>nil, 53=>nil, 61=>:enemy}, {45=>nil, 53=>nil, 61=>nil}]}, 38=>{30=>[{30=>:enemy}, {30=>nil}], 37=>[{37=>:enemy}, {37=>nil}], 39=>[{39=>:enemy}, {39=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 22=>[{30=>nil, 22=>:enemy}, {30=>nil, 22=>nil}], 14=>[{30=>nil, 22=>nil, 14=>:enemy}, {30=>nil, 22=>nil, 14=>nil}], 6=>[{30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {30=>nil, 22=>nil, 14=>nil, 6=>nil}], 36=>[{37=>nil, 36=>:enemy}, {37=>nil, 36=>nil}], 35=>[{37=>nil, 36=>nil, 35=>:enemy}, {37=>nil, 36=>nil, 35=>nil}], 34=>[{37=>nil, 36=>nil, 35=>nil, 34=>:enemy}, {37=>nil, 36=>nil, 35=>nil, 34=>nil}], 33=>[{37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>:enemy}, {37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil}], 32=>[{37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>nil}], 54=>[{46=>nil, 54=>:enemy}, {46=>nil, 54=>nil}], 62=>[{46=>nil, 54=>nil, 62=>:enemy}, {46=>nil, 54=>nil, 62=>nil}]}, 39=>{31=>[{31=>:enemy}, {31=>nil}], 38=>[{38=>:enemy}, {38=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 23=>[{31=>nil, 23=>:enemy}, {31=>nil, 23=>nil}], 15=>[{31=>nil, 23=>nil, 15=>:enemy}, {31=>nil, 23=>nil, 15=>nil}], 7=>[{31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {31=>nil, 23=>nil, 15=>nil, 7=>nil}], 37=>[{38=>nil, 37=>:enemy}, {38=>nil, 37=>nil}], 36=>[{38=>nil, 37=>nil, 36=>:enemy}, {38=>nil, 37=>nil, 36=>nil}], 35=>[{38=>nil, 37=>nil, 36=>nil, 35=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil}], 34=>[{38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil}], 33=>[{38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil}], 32=>[{38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>:enemy}, {38=>nil, 37=>nil, 36=>nil, 35=>nil, 34=>nil, 33=>nil, 32=>nil}], 55=>[{47=>nil, 55=>:enemy}, {47=>nil, 55=>nil}], 63=>[{47=>nil, 55=>nil, 63=>:enemy}, {47=>nil, 55=>nil, 63=>nil}]}, 40=>{32=>[{32=>:enemy}, {32=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 24=>[{32=>nil, 24=>:enemy}, {32=>nil, 24=>nil}], 16=>[{32=>nil, 24=>nil, 16=>:enemy}, {32=>nil, 24=>nil, 16=>nil}], 8=>[{32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, {32=>nil, 24=>nil, 16=>nil, 8=>nil}], 0=>[{32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>nil}], 42=>[{41=>nil, 42=>:enemy}, {41=>nil, 42=>nil}], 43=>[{41=>nil, 42=>nil, 43=>:enemy}, {41=>nil, 42=>nil, 43=>nil}], 44=>[{41=>nil, 42=>nil, 43=>nil, 44=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil}], 45=>[{41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil}], 46=>[{41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil}], 47=>[{41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {41=>nil, 42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>nil}], 56=>[{48=>nil, 56=>:enemy}, {48=>nil, 56=>nil}]}, 41=>{33=>[{33=>:enemy}, {33=>nil}], 40=>[{40=>:enemy}, {40=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 25=>[{33=>nil, 25=>:enemy}, {33=>nil, 25=>nil}], 17=>[{33=>nil, 25=>nil, 17=>:enemy}, {33=>nil, 25=>nil, 17=>nil}], 9=>[{33=>nil, 25=>nil, 17=>nil, 9=>:enemy}, {33=>nil, 25=>nil, 17=>nil, 9=>nil}], 1=>[{33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>nil}], 43=>[{42=>nil, 43=>:enemy}, {42=>nil, 43=>nil}], 44=>[{42=>nil, 43=>nil, 44=>:enemy}, {42=>nil, 43=>nil, 44=>nil}], 45=>[{42=>nil, 43=>nil, 44=>nil, 45=>:enemy}, {42=>nil, 43=>nil, 44=>nil, 45=>nil}], 46=>[{42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>:enemy}, {42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil}], 47=>[{42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {42=>nil, 43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>nil}], 57=>[{49=>nil, 57=>:enemy}, {49=>nil, 57=>nil}]}, 42=>{34=>[{34=>:enemy}, {34=>nil}], 41=>[{41=>:enemy}, {41=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 26=>[{34=>nil, 26=>:enemy}, {34=>nil, 26=>nil}], 18=>[{34=>nil, 26=>nil, 18=>:enemy}, {34=>nil, 26=>nil, 18=>nil}], 10=>[{34=>nil, 26=>nil, 18=>nil, 10=>:enemy}, {34=>nil, 26=>nil, 18=>nil, 10=>nil}], 2=>[{34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>nil}], 40=>[{41=>nil, 40=>:enemy}, {41=>nil, 40=>nil}], 44=>[{43=>nil, 44=>:enemy}, {43=>nil, 44=>nil}], 45=>[{43=>nil, 44=>nil, 45=>:enemy}, {43=>nil, 44=>nil, 45=>nil}], 46=>[{43=>nil, 44=>nil, 45=>nil, 46=>:enemy}, {43=>nil, 44=>nil, 45=>nil, 46=>nil}], 47=>[{43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {43=>nil, 44=>nil, 45=>nil, 46=>nil, 47=>nil}], 58=>[{50=>nil, 58=>:enemy}, {50=>nil, 58=>nil}]}, 43=>{35=>[{35=>:enemy}, {35=>nil}], 42=>[{42=>:enemy}, {42=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 27=>[{35=>nil, 27=>:enemy}, {35=>nil, 27=>nil}], 19=>[{35=>nil, 27=>nil, 19=>:enemy}, {35=>nil, 27=>nil, 19=>nil}], 11=>[{35=>nil, 27=>nil, 19=>nil, 11=>:enemy}, {35=>nil, 27=>nil, 19=>nil, 11=>nil}], 3=>[{35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>nil}], 41=>[{42=>nil, 41=>:enemy}, {42=>nil, 41=>nil}], 40=>[{42=>nil, 41=>nil, 40=>:enemy}, {42=>nil, 41=>nil, 40=>nil}], 45=>[{44=>nil, 45=>:enemy}, {44=>nil, 45=>nil}], 46=>[{44=>nil, 45=>nil, 46=>:enemy}, {44=>nil, 45=>nil, 46=>nil}], 47=>[{44=>nil, 45=>nil, 46=>nil, 47=>:enemy}, {44=>nil, 45=>nil, 46=>nil, 47=>nil}], 59=>[{51=>nil, 59=>:enemy}, {51=>nil, 59=>nil}]}, 44=>{36=>[{36=>:enemy}, {36=>nil}], 43=>[{43=>:enemy}, {43=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 28=>[{36=>nil, 28=>:enemy}, {36=>nil, 28=>nil}], 20=>[{36=>nil, 28=>nil, 20=>:enemy}, {36=>nil, 28=>nil, 20=>nil}], 12=>[{36=>nil, 28=>nil, 20=>nil, 12=>:enemy}, {36=>nil, 28=>nil, 20=>nil, 12=>nil}], 4=>[{36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>nil}], 42=>[{43=>nil, 42=>:enemy}, {43=>nil, 42=>nil}], 41=>[{43=>nil, 42=>nil, 41=>:enemy}, {43=>nil, 42=>nil, 41=>nil}], 40=>[{43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {43=>nil, 42=>nil, 41=>nil, 40=>nil}], 46=>[{45=>nil, 46=>:enemy}, {45=>nil, 46=>nil}], 47=>[{45=>nil, 46=>nil, 47=>:enemy}, {45=>nil, 46=>nil, 47=>nil}], 60=>[{52=>nil, 60=>:enemy}, {52=>nil, 60=>nil}]}, 45=>{37=>[{37=>:enemy}, {37=>nil}], 44=>[{44=>:enemy}, {44=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 29=>[{37=>nil, 29=>:enemy}, {37=>nil, 29=>nil}], 21=>[{37=>nil, 29=>nil, 21=>:enemy}, {37=>nil, 29=>nil, 21=>nil}], 13=>[{37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, {37=>nil, 29=>nil, 21=>nil, 13=>nil}], 5=>[{37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}], 43=>[{44=>nil, 43=>:enemy}, {44=>nil, 43=>nil}], 42=>[{44=>nil, 43=>nil, 42=>:enemy}, {44=>nil, 43=>nil, 42=>nil}], 41=>[{44=>nil, 43=>nil, 42=>nil, 41=>:enemy}, {44=>nil, 43=>nil, 42=>nil, 41=>nil}], 40=>[{44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>nil}], 47=>[{46=>nil, 47=>:enemy}, {46=>nil, 47=>nil}], 61=>[{53=>nil, 61=>:enemy}, {53=>nil, 61=>nil}]}, 46=>{38=>[{38=>:enemy}, {38=>nil}], 45=>[{45=>:enemy}, {45=>nil}], 47=>[{47=>:enemy}, {47=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 30=>[{38=>nil, 30=>:enemy}, {38=>nil, 30=>nil}], 22=>[{38=>nil, 30=>nil, 22=>:enemy}, {38=>nil, 30=>nil, 22=>nil}], 14=>[{38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, {38=>nil, 30=>nil, 22=>nil, 14=>nil}], 6=>[{38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}], 44=>[{45=>nil, 44=>:enemy}, {45=>nil, 44=>nil}], 43=>[{45=>nil, 44=>nil, 43=>:enemy}, {45=>nil, 44=>nil, 43=>nil}], 42=>[{45=>nil, 44=>nil, 43=>nil, 42=>:enemy}, {45=>nil, 44=>nil, 43=>nil, 42=>nil}], 41=>[{45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>:enemy}, {45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil}], 40=>[{45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>nil}], 62=>[{54=>nil, 62=>:enemy}, {54=>nil, 62=>nil}]}, 47=>{39=>[{39=>:enemy}, {39=>nil}], 46=>[{46=>:enemy}, {46=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 31=>[{39=>nil, 31=>:enemy}, {39=>nil, 31=>nil}], 23=>[{39=>nil, 31=>nil, 23=>:enemy}, {39=>nil, 31=>nil, 23=>nil}], 15=>[{39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, {39=>nil, 31=>nil, 23=>nil, 15=>nil}], 7=>[{39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}], 45=>[{46=>nil, 45=>:enemy}, {46=>nil, 45=>nil}], 44=>[{46=>nil, 45=>nil, 44=>:enemy}, {46=>nil, 45=>nil, 44=>nil}], 43=>[{46=>nil, 45=>nil, 44=>nil, 43=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil}], 42=>[{46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil}], 41=>[{46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil}], 40=>[{46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>:enemy}, {46=>nil, 45=>nil, 44=>nil, 43=>nil, 42=>nil, 41=>nil, 40=>nil}], 63=>[{55=>nil, 63=>:enemy}, {55=>nil, 63=>nil}]}, 48=>{40=>[{40=>:enemy}, {40=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 32=>[{40=>nil, 32=>:enemy}, {40=>nil, 32=>nil}], 24=>[{40=>nil, 32=>nil, 24=>:enemy}, {40=>nil, 32=>nil, 24=>nil}], 16=>[{40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, {40=>nil, 32=>nil, 24=>nil, 16=>nil}], 8=>[{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, {40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}], 0=>[{40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>nil}], 50=>[{49=>nil, 50=>:enemy}, {49=>nil, 50=>nil}], 51=>[{49=>nil, 50=>nil, 51=>:enemy}, {49=>nil, 50=>nil, 51=>nil}], 52=>[{49=>nil, 50=>nil, 51=>nil, 52=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil}], 53=>[{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil}], 54=>[{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil}], 55=>[{49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {49=>nil, 50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 49=>{41=>[{41=>:enemy}, {41=>nil}], 48=>[{48=>:enemy}, {48=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 33=>[{41=>nil, 33=>:enemy}, {41=>nil, 33=>nil}], 25=>[{41=>nil, 33=>nil, 25=>:enemy}, {41=>nil, 33=>nil, 25=>nil}], 17=>[{41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, {41=>nil, 33=>nil, 25=>nil, 17=>nil}], 9=>[{41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>:enemy}, {41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil}], 1=>[{41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>nil}], 51=>[{50=>nil, 51=>:enemy}, {50=>nil, 51=>nil}], 52=>[{50=>nil, 51=>nil, 52=>:enemy}, {50=>nil, 51=>nil, 52=>nil}], 53=>[{50=>nil, 51=>nil, 52=>nil, 53=>:enemy}, {50=>nil, 51=>nil, 52=>nil, 53=>nil}], 54=>[{50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>:enemy}, {50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil}], 55=>[{50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {50=>nil, 51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 50=>{42=>[{42=>:enemy}, {42=>nil}], 49=>[{49=>:enemy}, {49=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 34=>[{42=>nil, 34=>:enemy}, {42=>nil, 34=>nil}], 26=>[{42=>nil, 34=>nil, 26=>:enemy}, {42=>nil, 34=>nil, 26=>nil}], 18=>[{42=>nil, 34=>nil, 26=>nil, 18=>:enemy}, {42=>nil, 34=>nil, 26=>nil, 18=>nil}], 10=>[{42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>:enemy}, {42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil}], 2=>[{42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>nil}], 48=>[{49=>nil, 48=>:enemy}, {49=>nil, 48=>nil}], 52=>[{51=>nil, 52=>:enemy}, {51=>nil, 52=>nil}], 53=>[{51=>nil, 52=>nil, 53=>:enemy}, {51=>nil, 52=>nil, 53=>nil}], 54=>[{51=>nil, 52=>nil, 53=>nil, 54=>:enemy}, {51=>nil, 52=>nil, 53=>nil, 54=>nil}], 55=>[{51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {51=>nil, 52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 51=>{43=>[{43=>:enemy}, {43=>nil}], 50=>[{50=>:enemy}, {50=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 35=>[{43=>nil, 35=>:enemy}, {43=>nil, 35=>nil}], 27=>[{43=>nil, 35=>nil, 27=>:enemy}, {43=>nil, 35=>nil, 27=>nil}], 19=>[{43=>nil, 35=>nil, 27=>nil, 19=>:enemy}, {43=>nil, 35=>nil, 27=>nil, 19=>nil}], 11=>[{43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>:enemy}, {43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil}], 3=>[{43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>nil}], 49=>[{50=>nil, 49=>:enemy}, {50=>nil, 49=>nil}], 48=>[{50=>nil, 49=>nil, 48=>:enemy}, {50=>nil, 49=>nil, 48=>nil}], 53=>[{52=>nil, 53=>:enemy}, {52=>nil, 53=>nil}], 54=>[{52=>nil, 53=>nil, 54=>:enemy}, {52=>nil, 53=>nil, 54=>nil}], 55=>[{52=>nil, 53=>nil, 54=>nil, 55=>:enemy}, {52=>nil, 53=>nil, 54=>nil, 55=>nil}]}, 52=>{44=>[{44=>:enemy}, {44=>nil}], 51=>[{51=>:enemy}, {51=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 36=>[{44=>nil, 36=>:enemy}, {44=>nil, 36=>nil}], 28=>[{44=>nil, 36=>nil, 28=>:enemy}, {44=>nil, 36=>nil, 28=>nil}], 20=>[{44=>nil, 36=>nil, 28=>nil, 20=>:enemy}, {44=>nil, 36=>nil, 28=>nil, 20=>nil}], 12=>[{44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>:enemy}, {44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil}], 4=>[{44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>nil}], 50=>[{51=>nil, 50=>:enemy}, {51=>nil, 50=>nil}], 49=>[{51=>nil, 50=>nil, 49=>:enemy}, {51=>nil, 50=>nil, 49=>nil}], 48=>[{51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {51=>nil, 50=>nil, 49=>nil, 48=>nil}], 54=>[{53=>nil, 54=>:enemy}, {53=>nil, 54=>nil}], 55=>[{53=>nil, 54=>nil, 55=>:enemy}, {53=>nil, 54=>nil, 55=>nil}]}, 53=>{45=>[{45=>:enemy}, {45=>nil}], 52=>[{52=>:enemy}, {52=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 37=>[{45=>nil, 37=>:enemy}, {45=>nil, 37=>nil}], 29=>[{45=>nil, 37=>nil, 29=>:enemy}, {45=>nil, 37=>nil, 29=>nil}], 21=>[{45=>nil, 37=>nil, 29=>nil, 21=>:enemy}, {45=>nil, 37=>nil, 29=>nil, 21=>nil}], 13=>[{45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, {45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil}], 5=>[{45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}], 51=>[{52=>nil, 51=>:enemy}, {52=>nil, 51=>nil}], 50=>[{52=>nil, 51=>nil, 50=>:enemy}, {52=>nil, 51=>nil, 50=>nil}], 49=>[{52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, {52=>nil, 51=>nil, 50=>nil, 49=>nil}], 48=>[{52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}], 55=>[{54=>nil, 55=>:enemy}, {54=>nil, 55=>nil}]}, 54=>{46=>[{46=>:enemy}, {46=>nil}], 53=>[{53=>:enemy}, {53=>nil}], 55=>[{55=>:enemy}, {55=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 38=>[{46=>nil, 38=>:enemy}, {46=>nil, 38=>nil}], 30=>[{46=>nil, 38=>nil, 30=>:enemy}, {46=>nil, 38=>nil, 30=>nil}], 22=>[{46=>nil, 38=>nil, 30=>nil, 22=>:enemy}, {46=>nil, 38=>nil, 30=>nil, 22=>nil}], 14=>[{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, {46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil}], 6=>[{46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}], 52=>[{53=>nil, 52=>:enemy}, {53=>nil, 52=>nil}], 51=>[{53=>nil, 52=>nil, 51=>:enemy}, {53=>nil, 52=>nil, 51=>nil}], 50=>[{53=>nil, 52=>nil, 51=>nil, 50=>:enemy}, {53=>nil, 52=>nil, 51=>nil, 50=>nil}], 49=>[{53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, {53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil}], 48=>[{53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}]}, 55=>{47=>[{47=>:enemy}, {47=>nil}], 54=>[{54=>:enemy}, {54=>nil}], 63=>[{63=>:enemy}, {63=>nil}], 39=>[{47=>nil, 39=>:enemy}, {47=>nil, 39=>nil}], 31=>[{47=>nil, 39=>nil, 31=>:enemy}, {47=>nil, 39=>nil, 31=>nil}], 23=>[{47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, {47=>nil, 39=>nil, 31=>nil, 23=>nil}], 15=>[{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, {47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}], 7=>[{47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}], 53=>[{54=>nil, 53=>:enemy}, {54=>nil, 53=>nil}], 52=>[{54=>nil, 53=>nil, 52=>:enemy}, {54=>nil, 53=>nil, 52=>nil}], 51=>[{54=>nil, 53=>nil, 52=>nil, 51=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil}], 50=>[{54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil}], 49=>[{54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil}], 48=>[{54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>:enemy}, {54=>nil, 53=>nil, 52=>nil, 51=>nil, 50=>nil, 49=>nil, 48=>nil}]}, 56=>{48=>[{48=>:enemy}, {48=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 40=>[{48=>nil, 40=>:enemy}, {48=>nil, 40=>nil}], 32=>[{48=>nil, 40=>nil, 32=>:enemy}, {48=>nil, 40=>nil, 32=>nil}], 24=>[{48=>nil, 40=>nil, 32=>nil, 24=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil}], 16=>[{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil}], 8=>[{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil}], 0=>[{48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>:enemy}, {48=>nil, 40=>nil, 32=>nil, 24=>nil, 16=>nil, 8=>nil, 0=>nil}], 58=>[{57=>nil, 58=>:enemy}, {57=>nil, 58=>nil}], 59=>[{57=>nil, 58=>nil, 59=>:enemy}, {57=>nil, 58=>nil, 59=>nil}], 60=>[{57=>nil, 58=>nil, 59=>nil, 60=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil}], 61=>[{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil}], 62=>[{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}], 63=>[{57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {57=>nil, 58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 57=>{49=>[{49=>:enemy}, {49=>nil}], 56=>[{56=>:enemy}, {56=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 41=>[{49=>nil, 41=>:enemy}, {49=>nil, 41=>nil}], 33=>[{49=>nil, 41=>nil, 33=>:enemy}, {49=>nil, 41=>nil, 33=>nil}], 25=>[{49=>nil, 41=>nil, 33=>nil, 25=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil}], 17=>[{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil}], 9=>[{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil}], 1=>[{49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>:enemy}, {49=>nil, 41=>nil, 33=>nil, 25=>nil, 17=>nil, 9=>nil, 1=>nil}], 59=>[{58=>nil, 59=>:enemy}, {58=>nil, 59=>nil}], 60=>[{58=>nil, 59=>nil, 60=>:enemy}, {58=>nil, 59=>nil, 60=>nil}], 61=>[{58=>nil, 59=>nil, 60=>nil, 61=>:enemy}, {58=>nil, 59=>nil, 60=>nil, 61=>nil}], 62=>[{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, {58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil}], 63=>[{58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {58=>nil, 59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 58=>{50=>[{50=>:enemy}, {50=>nil}], 57=>[{57=>:enemy}, {57=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 42=>[{50=>nil, 42=>:enemy}, {50=>nil, 42=>nil}], 34=>[{50=>nil, 42=>nil, 34=>:enemy}, {50=>nil, 42=>nil, 34=>nil}], 26=>[{50=>nil, 42=>nil, 34=>nil, 26=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil}], 18=>[{50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil}], 10=>[{50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil}], 2=>[{50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>:enemy}, {50=>nil, 42=>nil, 34=>nil, 26=>nil, 18=>nil, 10=>nil, 2=>nil}], 56=>[{57=>nil, 56=>:enemy}, {57=>nil, 56=>nil}], 60=>[{59=>nil, 60=>:enemy}, {59=>nil, 60=>nil}], 61=>[{59=>nil, 60=>nil, 61=>:enemy}, {59=>nil, 60=>nil, 61=>nil}], 62=>[{59=>nil, 60=>nil, 61=>nil, 62=>:enemy}, {59=>nil, 60=>nil, 61=>nil, 62=>nil}], 63=>[{59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {59=>nil, 60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 59=>{51=>[{51=>:enemy}, {51=>nil}], 58=>[{58=>:enemy}, {58=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 43=>[{51=>nil, 43=>:enemy}, {51=>nil, 43=>nil}], 35=>[{51=>nil, 43=>nil, 35=>:enemy}, {51=>nil, 43=>nil, 35=>nil}], 27=>[{51=>nil, 43=>nil, 35=>nil, 27=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil}], 19=>[{51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil}], 11=>[{51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil}], 3=>[{51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>:enemy}, {51=>nil, 43=>nil, 35=>nil, 27=>nil, 19=>nil, 11=>nil, 3=>nil}], 57=>[{58=>nil, 57=>:enemy}, {58=>nil, 57=>nil}], 56=>[{58=>nil, 57=>nil, 56=>:enemy}, {58=>nil, 57=>nil, 56=>nil}], 61=>[{60=>nil, 61=>:enemy}, {60=>nil, 61=>nil}], 62=>[{60=>nil, 61=>nil, 62=>:enemy}, {60=>nil, 61=>nil, 62=>nil}], 63=>[{60=>nil, 61=>nil, 62=>nil, 63=>:enemy}, {60=>nil, 61=>nil, 62=>nil, 63=>nil}]}, 60=>{52=>[{52=>:enemy}, {52=>nil}], 59=>[{59=>:enemy}, {59=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 44=>[{52=>nil, 44=>:enemy}, {52=>nil, 44=>nil}], 36=>[{52=>nil, 44=>nil, 36=>:enemy}, {52=>nil, 44=>nil, 36=>nil}], 28=>[{52=>nil, 44=>nil, 36=>nil, 28=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil}], 20=>[{52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil}], 12=>[{52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil}], 4=>[{52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>:enemy}, {52=>nil, 44=>nil, 36=>nil, 28=>nil, 20=>nil, 12=>nil, 4=>nil}], 58=>[{59=>nil, 58=>:enemy}, {59=>nil, 58=>nil}], 57=>[{59=>nil, 58=>nil, 57=>:enemy}, {59=>nil, 58=>nil, 57=>nil}], 56=>[{59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {59=>nil, 58=>nil, 57=>nil, 56=>nil}], 62=>[{61=>nil, 62=>:enemy}, {61=>nil, 62=>nil}], 63=>[{61=>nil, 62=>nil, 63=>:enemy}, {61=>nil, 62=>nil, 63=>nil}]}, 61=>{53=>[{53=>:enemy}, {53=>nil}], 60=>[{60=>:enemy}, {60=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 45=>[{53=>nil, 45=>:enemy}, {53=>nil, 45=>nil}], 37=>[{53=>nil, 45=>nil, 37=>:enemy}, {53=>nil, 45=>nil, 37=>nil}], 29=>[{53=>nil, 45=>nil, 37=>nil, 29=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil}], 21=>[{53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil}], 13=>[{53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil}], 5=>[{53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>:enemy}, {53=>nil, 45=>nil, 37=>nil, 29=>nil, 21=>nil, 13=>nil, 5=>nil}], 59=>[{60=>nil, 59=>:enemy}, {60=>nil, 59=>nil}], 58=>[{60=>nil, 59=>nil, 58=>:enemy}, {60=>nil, 59=>nil, 58=>nil}], 57=>[{60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, {60=>nil, 59=>nil, 58=>nil, 57=>nil}], 56=>[{60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}], 63=>[{62=>nil, 63=>:enemy}, {62=>nil, 63=>nil}]}, 62=>{54=>[{54=>:enemy}, {54=>nil}], 61=>[{61=>:enemy}, {61=>nil}], 63=>[{63=>:enemy}, {63=>nil}], 46=>[{54=>nil, 46=>:enemy}, {54=>nil, 46=>nil}], 38=>[{54=>nil, 46=>nil, 38=>:enemy}, {54=>nil, 46=>nil, 38=>nil}], 30=>[{54=>nil, 46=>nil, 38=>nil, 30=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil}], 22=>[{54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil}], 14=>[{54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil}], 6=>[{54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>:enemy}, {54=>nil, 46=>nil, 38=>nil, 30=>nil, 22=>nil, 14=>nil, 6=>nil}], 60=>[{61=>nil, 60=>:enemy}, {61=>nil, 60=>nil}], 59=>[{61=>nil, 60=>nil, 59=>:enemy}, {61=>nil, 60=>nil, 59=>nil}], 58=>[{61=>nil, 60=>nil, 59=>nil, 58=>:enemy}, {61=>nil, 60=>nil, 59=>nil, 58=>nil}], 57=>[{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, {61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}], 56=>[{61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}]}, 63=>{55=>[{55=>:enemy}, {55=>nil}], 62=>[{62=>:enemy}, {62=>nil}], 47=>[{55=>nil, 47=>:enemy}, {55=>nil, 47=>nil}], 39=>[{55=>nil, 47=>nil, 39=>:enemy}, {55=>nil, 47=>nil, 39=>nil}], 31=>[{55=>nil, 47=>nil, 39=>nil, 31=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil}], 23=>[{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil}], 15=>[{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil}], 7=>[{55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>:enemy}, {55=>nil, 47=>nil, 39=>nil, 31=>nil, 23=>nil, 15=>nil, 7=>nil}], 61=>[{62=>nil, 61=>:enemy}, {62=>nil, 61=>nil}], 60=>[{62=>nil, 61=>nil, 60=>:enemy}, {62=>nil, 61=>nil, 60=>nil}], 59=>[{62=>nil, 61=>nil, 60=>nil, 59=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil}], 58=>[{62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil}], 57=>[{62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil}], 56=>[{62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>:enemy}, {62=>nil, 61=>nil, 60=>nil, 59=>nil, 58=>nil, 57=>nil, 56=>nil}]}}}
  end
end
